<?php
/**
 * Setup Website Meta Box
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2016, Andre Gagnon
 * @since       2.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )  exit;

/**
 * PH_Meta_Box_Project_Options Class
 *
 * @since 1.0
 */
class PH_Website_Meta_Box_Setup {

	public static $fields = array();

	public static function meta_fields() {

		$fields = apply_filters( 'ph_website_meta_box_options', array(
			array(
				'id'          => 'website_url',
				'description'  => __('Enter the website URL to collect comments.', 'project-huddle'),
				'label'       => __( '1. Enter the Website URL', 'project-huddle' ),
				'placeholder' => 'http://',
				'type'        => 'url',
			)
		) );

		return $fields;
	}

	/**
	 * Output the metabox
	 *
	 * @access public
	 * @since  1.0
	 * @return void
	 */
	public static function output( $post ) {

		// create nonce field
		wp_nonce_field( 'project_huddle_save_data', 'project_huddle_meta_nonce' );

		$fields  = self::meta_fields();
		$api_key = get_post_meta( $post->ID, 'ph_website_api', true );
		$url     = get_post_meta( $post->ID, 'ph_website_url', true );

		$not_set_correctly = !filter_var($url, FILTER_VALIDATE_URL) && get_post_status($post) != 'auto-draft';
		$installed = get_post_meta($post->ID, 'ph_installed', true );
		$error = get_post_meta($post->ID, 'ph_installation_error', true); ?>

		<div id="project_website_container" class="ph_meta_box">

			<?php if ( $not_set_correctly ) : ?>
				<p class="notice notice-error"><?php _e('You need to enter a valid website URL.', 'project-huddle'); ?></p>
			<?php endif; ?>

			<?php
			foreach( $fields as $field ) {
				PH()->meta->display_field( $field, $post );
			}
			?>

			<?php if ( get_post_status($post) != 'auto-draft' && ! $not_set_correctly) { ?>
				<input type="submit" name="publish" id="publish_website" class="button button-primary button-large" value="<?php _e('Update URL', 'project-huddle'); ?>">
			<?php } ?>

			<?php if ( $api_key && ! $not_set_correctly ) : ?>
				<p class="form-field">
					<label for=ph_website_js_code" style="float:none;"><strong><?php _e( '2. Install Website Code', 'project-huddle'); ?></strong></label>
					<span class="description">
						<?php echo htmlspecialchars( __('Copy and paste this right before the closing </body> tag on the website address above.', 'project-huddle') ); ?>
					</span><br><br>
<textarea id="ph_website_js_code" onclick="this.focus();this.select()" readonly="readonly" style="width: 100%;" rows="8">
<script>
	(function (d, t, g) {
		var ph    = d.createElement(t), s = d.getElementsByTagName(t)[0];
		ph.type   = 'text/javascript';
		ph.async   = true;
		ph.charset = 'UTF-8';
		ph.src     = g + '&v=' + (new Date()).getTime();
		s.parentNode.insertBefore(ph, s);
	})(document, 'script', '<?php ph_the_api_url( $post ); ?>');
</script></textarea>
				</p>
				<strong><?php _e( '3. After you add the code, you can verify it\'s installed correctly.', 'project-huddle'); ?></strong>
				<p>
				<?php
				if ( $installed ) {
					echo '<div class="ph-installed">' . __('Installed!', 'project-huddle') . '</div>';
				} else if ( $error ) {
					echo '<div class="ph-installed ph-error">' . esc_html($error) . '</div>';
				} else {
					echo '<a href="' . get_the_permalink( $post ) . '">' . __( 'Verify Installation', 'project-huddle' ) . '</a>';
				}
				?>
				</p>
			<?php else: ?>
					<input type="submit" name="publish" id="publish_website" class="button button-primary button-large" value="Next">
					<span class="spinner"></span>
			<?php endif; ?>
		</div>
<?php }

	/**
	 * Save meta box data
	 *
	 * @access public
	 * @since  1.0
	 * @return void
	 */
	public static function save( $post_id, $post ) {

		$fields = self::meta_fields();

		foreach( $fields as $field ) {
			$value = self::sanitize_field( $field );
			if ( $value == get_site_url() && get_post_status( (int) get_option( 'ph_site_post' ) ) == 'publish' && $value == get_post_meta( get_option( 'ph_site_post' ), 'website_url', true ) ) {
				PH_Website_Meta_Boxes::add_error( __( 'This website has already been added!', 'project-huddle' ) . ' <a href="' . get_edit_post_link( (int) get_option( 'ph_site_post' ) ) . '">' . __( 'View Project', 'project-huddle' ) . '</a>' );
				continue;
			}
			update_post_meta( $post_id, 'ph_' . $field['id'], esc_attr( $value ) );
			update_post_meta( $post_id, $field['id'], esc_attr( $value ) );
		}
	}

	public static function sanitize_field( $field ) {

		$value = isset( $_POST['ph_' . $field['id'] ] ) ? $_POST['ph_' . $field['id'] ] : false;

		switch( $field['type'] ) {
			case 'checkbox':
				$value = $value ? esc_html( $value ) : 'off';
				break;
		}

		return $value;
	}
}