<?php
/**
 * Website Scripts
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       2.0.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Admin scripts
 *
 * @param string $hook Page hook called.
 *
 * @return bool
 */
function ph_website_admin_scripts( $hook ) {

	// get post type.
	global $post_type;

	// bail out early if we are not on a project add/edit screen.
	if ( 'ph-website' !== $post_type || ( 'post.php' !== $hook && 'post-new.php' !== $hook ) ) {
		return false;
	}

	wp_deregister_script( 'yoast-seo-select2' );
	wp_dequeue_script( 'yoast-seo-select2' );
	wp_deregister_style( 'select2-css' );
	wp_deregister_script( 'select2-js' );
	wp_dequeue_style( 'select2' );
	wp_deregister_style( 'select2' );
	wp_dequeue_script( 'select2' );
	wp_deregister_script( 'select2' );

	// store css and javascript directories.
	$css_dir = PH_WEBSITE_PLUGIN_URL . 'assets/css/';
	$js_dir  = PH_WEBSITE_PLUGIN_URL . 'assets/js/';

	$main_css_dir = PH_PLUGIN_URL . 'assets/css/';
	$main_js_dir  = PH_PLUGIN_URL . 'assets/js/';

	// Use minified libraries if SCRIPT_DEBUG is turned off.
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	// register reusable scripts.
	wp_register_script( 'ph-select2-admin', $main_js_dir . 'select2-admin.js', array( 'jquery', 'select2' ), PH_VERSION );
	wp_register_script( 'select2', $main_js_dir . 'includes/select2.full.min.js', array( 'jquery' ), '4.0.2' );

	wp_register_style( 'select2', $main_css_dir . 'includes/select2.min.css', array(), '4.0.2' );
	wp_register_style( 'ph-select2-admin', $main_css_dir . 'project-huddle-select2-admin' . $suffix . '.css', array( 'select2' ), '4.0.2' );

	wp_register_script( 'quill', $main_js_dir . 'includes/quill.min.js', array(), '1.2.0', true );

	// enqueue website admin js.
	wp_enqueue_script(
		'ph-website-admin-js', $main_js_dir . 'dist/ph-website-comments-admin' . $suffix . '.js', array(
			'underscore',
			'autosize',
			'quill',
			'backbone',
			'wp-api',
			'wp-backbone',
			'jquery-placecursoratend',
			'jquery-ui-sortable',
			'select2',
			'ph-select2-admin',
		), PH_VERSION
	);

	wp_enqueue_style( 'ph-ionicons', '//code.ionicframework.com/ionicons/2.0.1/css/ionicons.min.css', false, '2.0.1' );
	// enqueue main style.
	wp_enqueue_style( 'ph-website-admin-css', $main_css_dir . 'dist/ph-website-comments-admin' . $suffix . '.css', array( 'ph-select2-admin' ), PH_VERSION );

	// Add nonce.
	wp_localize_script(
		'ph-website-admin-js', 'PH', array(
			'debug'        => defined( 'SCRIPT_DEBUG' ) ? SCRIPT_DEBUG : false,
			'translations' => ph_website_translation_strings(),
		)
	);

	wp_localize_script(
		'ph-select2-admin', 'PH_Select2', array(
			'options' => array(
				'anon_users' => false,
			),
		)
	);

	global $wp_rest_server;

	// Ensure the rest server is intiialized.
	if ( empty( $wp_rest_server ) ) {
		/** This filter is documented in wp-includes/rest-api.php */
		$wp_rest_server_class = apply_filters( 'wp_rest_server_class', 'WP_REST_Server' );
		$wp_rest_server       = new $wp_rest_server_class();
		/** This filter is documented in wp-includes/rest-api.php */
		do_action( 'rest_api_init', $wp_rest_server );
	}

	// Load the schema.
	$schema_request  = new WP_REST_Request( 'GET', '/projecthuddle/v2' );
	$schema_response = $wp_rest_server->dispatch( $schema_request );
	$schema          = null;
	if ( ! $schema_response->is_error() ) {
		$schema = $schema_response->get_data();
	}

	// Localize the plugin settings and schema.
	$settings = array(
		'root'          => esc_url_raw( get_rest_url() ),
		'nonce'         => wp_create_nonce( 'wp_rest' ),
		'versionString' => 'projecthuddle/v2/',
		'schema'        => $schema,
		'cacheSchema'   => true,
	);

	/**
	 * Filter the JavaScript Client settings before localizing.
	 *
	 * Enables modifying the config values sent to the JS client.
	 *
	 * @param array  $settings The JS Client settings.
	 */
	$settings = apply_filters( 'rest_js_client_settings', $settings );
	wp_localize_script( 'wp-api', 'wpApiSettings', $settings );
}

add_action( 'admin_enqueue_scripts', 'ph_website_admin_scripts', 30 );

function ph_change_version_string_admin($settings) {
	global $post;
//	if ( ! is_admin() || 'ph-website' !== get_post_type($post) ) {
//		return $settings;
//	}
	$settings['versionString'] = 'projecthuddle/v2/';
	return $settings;
}
add_filter('rest_js_client_settings', 'ph_change_version_string_admin' );
