<?php
/**
 * Template Functions
 *
 * Functions for the templating system.
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Checks for template and includes
 * To edit this, simply place single-project.php in your theme or child theme.
 *
 * @since 1.2.0
 * @return string
 */
function ph_website_set_template( $template ) {
	global $wp;
	// Check if the single post type is     being viewed and check if template already exists
	if ( is_singular( 'ph-website' ) && ! ph_is_template( $template ) ) {
		if ( isset( $wp->query_vars['ph_apikey'] ) && $wp->query_vars['ph_apikey'] ) {
			$template = PH_WEBSITE_PLUGIN_DIR . 'templates/single-website-script.php';
		} else {
			$template = PH_WEBSITE_PLUGIN_DIR . 'templates/single-website.php';
		}
	}

	if ( is_singular( 'phw_comment_loc' ) && ! ph_is_template( $template ) ) {
		$template = PH_WEBSITE_PLUGIN_DIR . 'templates/single-comment-thread.php';
	}

	if ( is_singular( 'ph-webpage' ) && ! ph_is_template( $template ) ) {
		$template = PH_WEBSITE_PLUGIN_DIR . 'templates/single-website-page.php';
	}

	if ( $template ) {
		include $template;
		exit;
	}
}

add_filter( 'template_redirect', 'ph_website_set_template' );

/**
 * Adds underscore templates via filter action
 *
 * @since 1.0
 */
function ph_output_website_underscore_templates() {
	// globals
	ph_get_template( 'global/loading.tmpl.php' );

	// comment threads.
	ph_get_template( 'thread/thread-dot.tmpl.php' );
	ph_get_template( 'thread/thread-bubble-container.tmpl.php' );
	ph_get_template( 'thread/thread-bubble.tmpl.php' );
	ph_get_template( 'thread/thread-form-controls.tmpl.php' );
	ph_get_template( 'thread/thread-header.tmpl.php' );
	ph_get_template( 'thread/thread-submit-button.tmpl.php' );
	ph_get_template( 'thread/thread-cancel-button.tmpl.php' );
	ph_get_template( 'thread/thread-resolve.tmpl.php' );
	ph_get_template( 'thread/thread-close.tmpl.php' );

	// thread details.
	ph_get_template( 'thread/thread-tech-details.tmpl.php' );
	ph_get_template( 'thread/thread-tech-detail-browser.tmpl.php' );
	ph_get_template( 'thread/thread-tech-detail-os.tmpl.php' );
	ph_get_template( 'thread/thread-tech-detail-additional.tmpl.php' );
	ph_get_template( 'thread/thread-tech-detail-resolution.tmpl.php' );
	ph_get_template( 'thread/thread-detail-link.tmpl.php' );
	ph_get_template( 'thread/thread-detail-delete.tmpl.php' );

	// comments.
	ph_get_template( 'comment/comment-avatar.tmpl.php' );
	ph_get_template( 'comment/comment-edit-form.tmpl.php' );
	ph_get_template( 'comment/comment-text.tmpl.php' );
	ph_get_template( 'comment/comment-controls.tmpl.php' );
	ph_get_template( 'comment/comment.tmpl.php' ); 	// backwards compat.
	ph_get_template( 'comment/comment-item.tmpl.php' );
	ph_get_template( 'comment/comment-item-minimal.tmpl.php' );

	// assign.
	ph_get_template( 'assign/assign-dropdown.tmpl.php' );
	ph_get_template( 'assign/assign-dropdown-option.tmpl.php' );

	// toolbar stuff
	ph_get_template( 'website/toolbar/toolbar.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'website/toolbar/toolbar-buttons.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// dialogs.
	ph_get_template( 'website/dialog/popup-css.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'website/dialog/popup-tech.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	ph_get_template( 'dialog/popup-register.tmpl.php' );
	ph_get_template( 'dialog/popup-reset.tmpl.php' );
	ph_get_template( 'dialog/popup-login.tmpl.php' );

	// panel.
	ph_get_template( 'website/panel/panel.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// filter.
	ph_get_template( 'website/panel/filter.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'website/panel/resolved-toggle.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// project container and data.
	ph_get_template(
		'website/website.tmpl.php', array(
			'project_data' => PHW()->website->get_item(),
		), '', PH_WEBSITE_PLUGIN_DIR . 'templates/'
	);
}

// add underscore templates
add_action( 'ph_website_header', 'ph_output_website_underscore_templates', 20 );


/**
 * Adds underscore templates via filter action
 *
 * @since 1.0
 */
function ph_output_admin_underscore_templates() {
	global $typenow, $pagenow, $adminpage;

	if ( 'ph-website' !== $typenow ) {
		return;
	}
	// check correct page.
	if ( 'post.php' !== $pagenow && 'post-new.php' !== $pagenow ) {
		return false;
	}

	// project container and data.
	ph_get_template(
		'admin/website/website-container.tmpl.php', array(
		'project_data' => PHW()->website->get_item(),
	), '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// general
	ph_get_template( 'admin/website/website-loading.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// filter
	ph_get_template( 'admin/website/website-thread-filter.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// defaults
	ph_get_template( 'admin/website/website-thread-no-comments.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// website page
	ph_get_template( 'admin/website/website-page.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-page-title.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-page-title-edit.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// resolved threads container
	ph_get_template( 'admin/website/website-resolved-threads-container.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// individual website thread
	ph_get_template( 'admin/website/website-thread.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-thread-text.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-thread-assign.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-thread-assign-option.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-thread-controls.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-thread-resolve-checkbox.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-thread-info-panel.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-thread-submit-button.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	ph_get_template( 'admin/website/website-comment-avatar.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-comment.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-minimal-comment.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-comment-edit-form.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-comment-text.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-comment-controls.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	ph_get_template( 'admin/website/website-resolved-tab.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template( 'admin/website/website-all-resolved.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
}

// add underscore templates.
add_action( 'admin_footer', 'ph_output_admin_underscore_templates', 9 );

/**
 * Get css file and read it to prevent cross origin issues
 */
function ph_website_thread_css() {
	$file = PH_PLUGIN_DIR . 'assets/css/dist/ph-website-comment-bubble.css';

	if ( file_exists( $file ) ) {
		// phpcs:ignore
		readfile( $file );
	}
}
add_action( 'ph_website_thread_css', 'ph_website_thread_css' );

/**
 * Output website style options
 */
function ph_website_output_style_options() {
	echo ph_website_style_options();
}
add_action( 'ph_website_thread_css', 'ph_website_output_style_options', 20 );
