<?php
/**
 * The template creating the website comment iframe
 *
 * @package     ProjectHuddle
 * @subpackage  Website Comments
 * @copyright   Copyright (c) 2016, Andre Gagnon
 * @since       1.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// simlulate ajax to prevent other plugins from outputting html here
define( 'DOING_AJAX', true );

// dynamic javascript output
header( 'Content-type: text/javascript' );

// get post
global $post;

// get comment and url
$url = get_post_meta( $post->ID, 'ph_website_url', true );

// CORS request header
header( "Access-Control-Allow-Origin: $url" );

// should the script load?
if ( is_wp_error( $should_load = ph_should_script_load() ) ) {
	echo "console.log('{$should_load->get_error_message()}');";
	if ( ! get_post_meta( $post->ID, 'ph_installed', true ) ) {
		update_post_meta( $post->ID, 'ph_installation_error', $should_load->get_error_message() );
	}
	exit;
}

// get access token from session
$token = ph_get_access_token( get_the_ID() );

// check access
if ( is_wp_error( $token ) ) {
	echo "console.log('{$token->get_error_message()}');";
	exit;
} elseif ( ! $token ) {
	exit;
}

/**
 * Here we store the page template in the output buffer,
 * so we can send it via json to our javascript file.
 */
ob_start();

// get single website iframe page
ph_get_template( 'ph-website-iframe.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

// store HTML
$container = ob_get_contents();
ob_end_clean(); ?>

// add iframe content
var PH_Website = {
    "container":<?php echo json_encode( htmlspecialchars( $container ) ); // output page content via json ?>,
    "origin": '<?php get_site_url(); ?>'
};

function decodeHtml(str) {
    var map = {
        '&amp;': '&',
        '&lt;': '<',
        '&gt;': '>',
        '&quot;': '"',
        '&#039;': "'"
    };
    return str.replace(/&amp;|&lt;|&gt;|&quot;|&#039;/g, function(m) {return map[m];});
}

// decode special chars in javascript
PH_Website.container = decodeHtml(PH_Website.container);

var head = document.getElementsByTagName('head')[0];
var cssnode = document.createElement('link');

// add css
cssnode.type = 'text/css';
cssnode.rel = 'stylesheet';
cssnode.href = '<?php echo esc_url( PH_PLUGIN_URL . 'assets/css/dist/ph-website-comments-parent.css' ); ?>?v=<?php echo esc_html(PH_VERSION); ?>';
head.appendChild(cssnode);

var css = '<?php echo ph_parent_website_style_options(); ?>',
head = document.head || document.getElementsByTagName('head')[0],
style = document.createElement('style');

style.type = 'text/css';
if (style.styleSheet){
    style.styleSheet.cssText = css;
} else {
    style.appendChild(document.createTextNode(css));
}

head.appendChild(style);
<?php
    // create iframe
    $file = PH_WEBSITE_PLUGIN_DIR . 'assets/js/ph-iframe-creator.js';

    if (file_exists($file)) {
        readfile($file);
    }

    do_action( 'ph_website_script_loaded' );
    exit;
?>