<?php
/**
 * Projects in Admin
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * PH_Admin_Project_Images Class
 *
 * This class handles the metabox for the project images in the admin
 *
 * @since 1.0
 */
class PH_Project_Admin {

	/**
	 * Custom post type slug
	 *
	 * @since 1.0
	 */
	public $post_type_slug = 'ph-project';

	/**
	 * Setup project admin
	 *
	 * @since 10
	 */
	public function __construct() {

		// run only on admin pages
		if ( ! is_admin() ) {
			return;
		}

		// remove project shortlink
		remove_action( 'wp_head', 'wp_shortlink_wp_head', 10 );

		// remove shortlink
		add_filter( 'pre_get_shortlink', array( $this, 'remove_shortlink' ), 10, 2 );

		// add collaborators ui
		add_action( 'post_submitbox_start', array( $this, 'collaboratorsBox' ) );

		// add help beacon
		add_action( 'admin_footer', array( $this, 'beacon' ) );

		// add help url to menu
		add_action( 'admin_menu', array( $this, 'help_url' ), 9999999 );

		// maybe add update notice
		add_action( 'admin_notices', array( $this, 'maybe_add_update_notice') );
	}

	/**
	 * Add helpscout beacon for help
	 */
	public function beacon() {
	    if ( ! current_user_can('manage_options')) {
	        return;
        }
	    ?>

        <?php if ( is_ssl() ) : ?>
            <script>!function(e,o,n){window.HSCW=o,window.HS=n,n.beacon=n.beacon||{};var t=n.beacon;t.userConfig={},t.readyQueue=[],t.config=function(e){this.userConfig=e},t.ready=function(e){this.readyQueue.push(e)},o.config={docs:{enabled:!0,baseUrl:"//projecthuddle.helpscoutdocs.com/"},contact:{enabled:!0,formId:"44423039-23b4-11e8-b466-0ec85169275a"}};var r=e.getElementsByTagName("script")[0],c=e.createElement("script");c.type="text/javascript",c.async=!0,c.src="https://djtflbt20bdde.cloudfront.net/",r.parentNode.insertBefore(c,r)}(document,window.HSCW||{},window.HS||{});</script>
        <?php else: ?>
            <script>!function(e,o,n){window.HSCW=o,window.HS=n,n.beacon=n.beacon||{};var t=n.beacon;t.userConfig={},t.readyQueue=[],t.config=function(e){this.userConfig=e},t.ready=function(e){this.readyQueue.push(e)},o.config={docs:{enabled:!1,baseUrl:""},contact:{enabled:!0,formId:"9873a768-23b9-11e8-b466-0ec85169275a"}};var r=e.getElementsByTagName("script")[0],c=e.createElement("script");c.type="text/javascript",c.async=!0,c.src="https://djtflbt20bdde.cloudfront.net/",r.parentNode.insertBefore(c,r)}(document,window.HSCW||{},window.HS||{});</script>
		<?php endif; ?>

        <script>
            HS.beacon.config({
				modal: true,
				autoInit: false,
				zIndex: 999999,
				topArticles: true,
				instructions: 'Send a message to ProjectHuddle Support! We typically respond within 24 hours during weekdays.',
				color: '#4353ff',
				attachment: true,
				poweredBy: false,
				showContactFields: true,
				topics: [
					{ val: 'technical', label: 'I need technical support.' },
					{ val: 'bug', label: 'I think I found a bug.' },
					{ val: 'feature', label: 'I have a feature suggestion.' },
					{ val: 'other', label: 'Other'}
				]
			});

			jQuery('[href="#show-help"]').click(function (e) {
			  if ( typeof HS.beacon === 'undefined' ) {
			    return true;
              }
				HS.beacon.init();
				e.preventDefault();
				HS.beacon.ready(function () {
		            <?php if ( $data = get_option( 'ph_license_data', false )) { ?>
					HS.beacon.identify({
						name        : '<?php echo esc_html( $data->customer_name ); ?>',
						email       : '<?php echo esc_html( $data->customer_email ); ?>',
						'License'   : '<?php echo esc_html( $data->license ); ?>',
						'Expires'   : '<?php echo esc_html( date( "F j, Y, g:i a", strtotime( $data->expires ) ) ); ?>',
						'Key'       : '<?php echo esc_html( get_option( 'ph_license_key' ) ) ?>',
						'Payment ID': '<?php echo (int) $data->payment_id; ?>',
						'Price Tier': '<?php echo (int) $data->price_id; ?>'
					});
		            <?php } else { ?>
                        HS.beacon.identify({
                            'Key': '<?php echo esc_html( get_option( 'ph_license_key' ) ) ?>'
                        });
                    <?php } ?>
					HS.beacon.open();
				});
			});
        </script>
    <?php }

	public function maybe_add_update_notice() {
		if ( isset( $_GET['ph_message'] ) ) { ?>
            <div class="notice notice-warning">
                <p><?php echo esc_html( $_GET['ph_message'] ); ?></p>
            </div>
			<?php
		}
	}

	public function help_url() {
		global $submenu;
		if ( ! current_user_can('manage_options') ) {
		    return;
        }
		if ( ! get_option('ph_license_key')) {
			$permalink = esc_url('edit.php?post_type=ph-project&page=project_huddle_settings&tab=updates&ph_message="Please enter your license key for help."');
		} else if ( get_option('ph_license_status') !== 'valid') {
			$permalink = esc_url('edit.php?post_type=ph-project&page=project_huddle_settings&tab=updates&ph_message="Please enter a valid license key for help."');
		} else {
			$permalink = '#show-help';
		}
		$submenu['edit.php?post_type=ph-project'][] = array( __( 'Help', 'project-huddle' ), 'manage_options', $permalink );
	}

	/**
	 * Display the metabox that holds our project images
	 * Holds spinner animation for loading
	 *
	 * @since 1.0
	 */
	public function get_project_meta_box() { ?>

		<!-- projects wrapper -->
		<div class="ph-projects-wrapper">
			<span class="spinner"></span>
		</div>
		<!-- ph-projects-wrapper -->

	<?php
	}

	/**
	 * Shows collaborators and controls
	 *
	 * @since 1.0
	 */
	// TODO: Maybe separate functionality of collaborators
	public function collaboratorsBox() { ?>
	<?php
	}


	/**
	 * Removes wp.me shortlink functionality
	 *
	 * @param $false
	 * @param $post_id
	 *
	 * @return string
	 */
	public function remove_shortlink( $false, $post_id ) {
		return 'ph-project' === get_post_type( $post_id ) ? '' : $false;
	}

}