<?php
/**
 * Project Options Meta Box
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * PH_Meta_Box_Images Class
 *
 * @since 1.0
 */
class PH_Meta_Box_Images {
	/**
	 * Stores the image collection
	 *
	 * @var array
	 */
	public static $collection = array();

	/**
	 * Display the metabox that holds our project images
	 * Holds spinner animation for loading
	 *
	 * @since 1.0
	 */
	public static function output() {
		global $post;

		// create nonce.
		wp_nonce_field( 'project_huddle_save_data', 'project_huddle_meta_nonce' );

		// add thickbox popup.
		add_thickbox();
		?>

		<!-- projects wrapper -->
		<div class="ph-projects-wrapper">
			<span class="spinner"></span>
		</div>
		<!-- ph-projects-wrapper -->

		<?php

		// allow adding additional output.
		do_action( 'ph_image_meta_box_output', $post );
	}

	/**
	 * Save meta box data
	 * Validates data on input
	 *
	 * @param integer $post_id Post ID.
	 * @param WP_Post $post Post object.
	 */
	public static function save( $post_id, $post ) {
		// phpcs:ignore
		$images = $_POST['ph-image-model'];
		if ( ! empty( $images ) && is_array( $images ) ) {
			foreach ( $images as $image ) {
				$object             = json_decode( stripslashes( $image ) );
				self::$collection[] = json_decode( wp_json_encode( $object ), true );
			}
		}

		// if we have an image, update, otherwise create
		// we're using rest functions here, so sanitization and permissions
		// are handled by controller.
		if ( ! empty( self::$collection ) ) {
			$order = 0;
			foreach ( self::$collection as $key => $image ) {
				$image['menu_order'] = $order++; // set menu order.
				$image['parent_id'] = $post_id; // force mockup id as parent
				if ( isset( $image['id'] ) && PH()->image->get_item( $image['id'] ) ) {
					PH()->image->update_item( $image['id'], $image );
				} else {
					PH()->image->create_item( $image );
				}
			}
		}

		// return nothing.
		return false;
	}
}
