<?php
/**
 * Mockup Post Type Functions
 *
 * @package    project-huddle
 * @subpackage ph-image-approvals
 */

/**
 * Add new column
 *
 * @param $defaults
 *
 * @return mixed
 */
function ph_project_columns_head( $defaults ) {
	$defaults['progress'] = __( 'Progress', 'project-huddle' );
	$defaults['approval'] = __( 'Status', 'project-huddle' );

	return $defaults;
}

add_filter( 'manage_ph-project_posts_columns', 'ph_project_columns_head', 9 );

/**
 * Add new column
 *
 * @param $defaults
 *
 * @return mixed
 */
function ph_mockup_threads_head( $defaults ) {
	$defaults['page'] = __( 'Page', 'project-huddle' );
	$defaults['author'] = __( 'Reporter', 'project-huddle' );

	return $defaults;
}

add_filter( 'manage_phw_comment_loc_posts_columns', 'ph_mockup_threads_head', 9 );

function ph_mockup_threads_sortable( $columns ) {
	$columns['page'] = 'Page';

	//To make a column 'un-sortable' remove it from the array
	//unset($columns['date']);

	return $columns;

//	if ( 'page' != $column_name ) {
//		return;
//	}
//	// get page id from post
//	$parents = ph_get_parents_ids( $post_id );
//
//	if ( $parents['item'] ) {
//		echo intval( $parents['item'] );
//	}
}

add_action( 'manage_edit-phw_comment_loc_sortable_columns', 'ph_mockup_threads_sortable' );


function ph_orderby_page_query( $query ) {
	if( ! is_admin() )
		return;

	$orderby = $query->get( 'orderby');

	if( 'Page' == $orderby ) {
		$query->set('meta_key','parent_id');
		$query->set('orderby','meta_value_num');
	}
}
add_action( 'pre_get_posts', 'ph_orderby_page_query' );


/**
 * Show column value
 *
 * @param $column_name
 * @param $post_ID
 */
function ph_project_columns_content( $column_name, $post_ID ) {
	if ( $column_name == 'page' ) {
		$page = get_post_meta( $post_ID, 'parent_id', true );

		if ( $page ) {
			$id       = (int) $page;
			$edit_url = esc_url( admin_url( "post.php?post=$id&action=edit" ) );
			$page_url = esc_url( get_post_meta( $page, 'page_url', true ) );
			echo "<a href='$edit_url'>$page_url</a>";
		}
	}
}

add_action( 'manage_phw_comment_loc_posts_custom_column', 'ph_project_columns_content', 10, 2 );

/**
 * Show column value
 *
 * @param $column_name
 * @param $post_ID
 */
function ph_listing_columns_content( $column_name, $post_ID ) {
	if ( $column_name == 'approval' ) {
		ph_approval_badge( $post_ID );
	}
	if ( $column_name == 'progress' ) {
		ph_approval_progress_bar( $post_ID );
	}
}

add_action( 'manage_ph-project_posts_custom_column', 'ph_listing_columns_content', 10, 2 );

if ( ! function_exists( 'ph_approval_progress_bar' ) ) :
	/**
	 * Displays a progress bar for the project
	 *
	 * @param int $id Project ID
	 *
	 * @return void
	 */
	function ph_approval_progress_bar( $id = 0 ) {
		global $post;
		if ( ! $id ) {
			$id = is_object( $post ) ? $post->ID : false;
		}
		if ( ! $id ) {
			return;
		}

		$approval = ph_get_mockup_approval_status($id);
		$total    = isset( $approval['total'] ) ? $approval['total'] : 0;
		$approved = isset( $approval['approved'] ) ? $approval['approved'] : 0;

		if ( ! $total ) {
			return;
		}

		$percentage      = $total ? $approved / $total * 100 : 0;
		$approval_class  = $total && $approved >= $total ? 'approved' : 'unapproved';
		$progress_string = sprintf( __( '%1$s of %2$s images approved.', 'project-huddle' ),
			$approved,
			$total
		);

		echo '<div class="progress-wrap ' . $approval_class . '" data-tooltip="' . esc_attr( $progress_string ) . '">';
		echo '<div class="ph-approval-bar"><div class="ph-approval-amount" style="width: ' . $percentage . '%;"></div></div>';
		echo '</div>';
	}
endif;

if ( ! function_exists( 'ph_approval_badge' ) ) :
	/**
	 * Displays an approval badge for the project
	 *
	 * @param int $id Project ID
	 *
	 * @return void
	 */
	function ph_approval_badge( $id = 0 ) {
		global $post;
		if ( ! $id ) {
			$id = is_object( $post ) ? $post->ID : false;
		}
		if ( ! $id ) {
			return;
		}

		$approval = ph_get_mockup_approval_status( $id );

		if ( $approval && is_array( $approval ) && isset( $approval['approved'] ) ) {
			if ( $approval['approved'] >= $approval['total'] ) {

				if ( isset( $approval['on'] ) && isset( $approval['by'] ) ) {
					if ( $approval['on'] && $approval['by']) {
						$date = new DateTime($approval['on']);
						$date_string = sprintf( __( 'By %1$s on %2$s at %3$s', 'project-huddle' ),
							$approval['by'],
							date_format( $date, get_option( 'date_format' ) ),
							date_format( $date, get_option( 'time_format' ) )
						);
					} else {
						$date_string = __( 'Approved', 'project-huddle' );
					}

					echo '<span class="approval-badge approved" data-tooltip="' . esc_attr( $date_string ) . '">' . __( 'Approved', 'project-huddle' ) . '</span>';
				} else {
					echo '<span class="approval-badge approved">' . __( 'Approved', 'project-huddle' ) . '</span>';
				}
			} else {
				echo '<span class="approval-badge">' . __( 'UnApproved', 'project-huddle' ) . '</span>';
			}
		} else {
			echo '<span class="approval-badge">' . __( 'UnApproved', 'project-huddle' ) . '</span>';
		}
	}
endif;