<?php
/**
 * Settings page settings
 *
 * @package     Project Huddle
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Function that holds the array of fields for the settings page
 *
 * @since 1.0.0
 * @return array Fields to be displayed on settings page
 */
function ph_settings_fields() {

	/**
	 * Filters are provided for each settings section to allow plugins
	 * to add their own settings to an already created section.
	 */
	$settings['customize'] = apply_filters( 'ph_settings_customize', array(
		'title'  => __( 'Customize', 'project-huddle' ),
		'fields' => array(
			'logo_divider' => array(
				'id'          => 'logo_divider',
				'label'       => __( 'Logos', 'project-huddle' ),
				'description' => '',
				'type'        => 'divider',
			),
			'login_logo' => array(
				'id'          => 'login_logo',
				'label'       => __( 'Logo', 'project-huddle' ),
				'description' => __( 'Logo used for login forms and at the top of emails.', 'project-huddle' ),
				'type'        => 'image',
				'default'     => '',
				'placeholder' => ''
			),
			'login_logo_retina' => array(
				'id'          => 'login_logo_retina',
				'label'       => __( 'Retina Logo', 'project-huddle' ),
				'description' => __( 'This will display your logo at half it\'s size.', 'project-huddle' ),
				'type'        => 'checkbox',
				'default'     => '',
			),

			/* Highlight Color */
			'highlight_divider' => array(
				'id'          => 'highlight_divider',
				'label'       => __( 'Highlights', 'project-huddle' ),
				'description' => '',
				'type'        => 'divider',
			),
			'highlight_color' => array(
				'id'          => 'highlight_color',
				'label'       => __( 'Highlight Color', 'project-huddle' ),
				'description' => __( 'Choose a highlight color to match your brand.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#4353ff'
			),

			/* Comments */
			'comments_divider' => array(
				'id'          => 'comments_divider',
				'label'       => __( 'Comments', 'project-huddle' ),
				'description' => '',
				'type'        => 'divider',
			),
			'auto_close' => array(
				'id'          => 'auto_close',
				'label'       => __( 'Auto Close', 'project-huddle' ),
				'description' => __( 'Automatically close comment bubbles after commenting.', 'project-huddle' ),
				'type'        => 'checkbox',
				'default'     => 'on',
			),

			/* Comments */
			'permissions_divider' => array(
				'id'          => 'permissions_divider',
				'label'       => __( 'Permissions', 'project-huddle' ),
				'description' => '',
				'type'        => 'divider',
			),
			'un_silo' => array(
				'id'          => 'un_silo',
				'label'       => __( 'Universal Project Access', 'project-huddle' ),
				'description' => __( 'Allow Project Client and Project Collaborators to view and access projects they aren\'t subscribed to.', 'project-huddle' ),
				'type'        => 'checkbox',
				'default'     => 'on',
			),
		)
	) );

	$settings['mockups'] = apply_filters( 'ph_settings_mockups', array(
		'title'  => __( 'Mockups', 'project-huddle' ),
		'fields' => array(
			'control_logo' => array(
				'id'          => 'control_logo',
				'label'       => __( 'Control Bar Logo', 'project-huddle' ),
				'description' => __( 'Logo seen in the control bar. This will typically be smaller than the login logo to fit in the top bar. This displays on a dark background.', 'project-huddle' ),
				'type'        => 'image',
				'default'     => '',
				'placeholder' => ''
			),
			'control_logo_retina' => array(
				'id'          => 'control_logo_retina',
				'label'       => __( 'Retina Control Logo', 'project-huddle' ),
				'description' => __( 'This will display your logo at half it\'s size.', 'project-huddle' ),
				'type'        => 'checkbox',
				'default'     => '',
			),
			/* Control Bar */
			'control_bar_divider' => array(
				'id'          => 'control_bar_divider',
				'label'       => __( 'Control Bar', 'project-huddle' ),
				'description' => '',
				'type'        => 'divider',
			),
			'control_bg_color' => array(
				'id'          => 'control_bg_color',
				'label'       => __( 'Control Bar Color', 'project-huddle' ),
				'description' => __( 'This color is the background of the control bar.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#23282d'
			),
			'control_color' => array(
				'id'          => 'control_color',
				'label'       => __( 'Control Bar Text Color', 'project-huddle' ),
				'description' => __( 'This is the icon and text color on the control bar.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#6F7C8A'
			),
			'control_hover_color' => array(
				'id'          => 'control_hover_color',
				'label'       => __( 'Control Bar Text Hover Color', 'project-huddle' ),
				'description' => __( 'This is the icon and text hover color on the control bar.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#fff'
			),

			/* Image Tray */
			'image_tray_divider' => array(
				'id'          => 'image_tray_divider',
				'label'       => __( 'Image Tray', 'project-huddle' ),
				'description' => '',
				'type'        => 'divider',
			),
			'image_tray_bg_color' => array(
				'id'          => 'image_tray_bg_color',
				'label'       => __( 'Image Tray Background Color', 'project-huddle' ),
				'description' => __( 'This is a color that is the background of the image tray.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#191d21'
			),
			'image_tray_color' => array(
				'id'          => 'image_tray_color',
				'label'       => __( 'Image Tray Text Color', 'project-huddle' ),
				'description' => __( 'This is a color that is the text color in the image tray.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#ffffff'
			),

			// comments panel
			'comments_panel' => array(
				'id'          => 'comments_panel',
				'label'       => __( 'Comments Panel', 'project-huddle' ),
				'description' => '',
				'type'        => 'divider',
			),
			'comments_panel_bg_color' => array(
				'id'          => 'comments_panel_bg_color',
				'label'       => __( 'Background Color', 'project-huddle' ),
				'description' => __( 'This is a color that is the background of the comments panel.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#191d21'
			),
			'comments_panel_heading_color' => array(
				'id'          => 'comments_panel_heading_color',
				'label'       => __( 'Heading Color', 'project-huddle' ),
				'description' => __( 'This is a color that is the text color of the author in the comments panel.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#ffffff'
			),
			'comments_panel_color' => array(
				'id'          => 'comments_panel_color',
				'label'       => __( 'Text Color', 'project-huddle' ),
				'description' => __( 'This is a color that is the text color in the comments panel.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#6F7C8A'
			),
			'comments_panel_divider_color' => array(
				'id'          => 'comments_panel_divider_color',
				'label'       => __( 'Divider Color', 'project-huddle' ),
				'description' => __( 'This is a color that is used for the border between the comments.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#23282d'
			),

			/* Project Background */
			'project_image_divider' => array(
				'id'          => 'project_image_divider',
				'label'       => __( 'Project Image', 'project-huddle' ),
				'description' => '',
				'type'        => 'divider',
			),
			'image_bg'  => array(
				'id'          => 'image_bg',
				'label'       => __( 'Default Project Background Color', 'project-huddle' ),
				'description' => __( 'The default project image background color. You can overwrite this per image in your individual projects.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#191d21'
			),

			array(
				'id'          => 'approval_button_divider',
				'label'       => __( 'Approvals', 'project-huddle' ),
				'description' => '',
				'type'        => 'divider',
			),
			array(
				'id'          => 'approve_color',
				'label'       => __( 'Approve Button Background Color', 'project-huddle' ),
				'description' => __( 'This is the background color for the "Approve" button.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#7bae54'
			),
			array(
				'id'          => 'unapprove_color',
				'label'       => __( 'UnApprove Button Background Color', 'project-huddle' ),
				'description' => __( 'This is the background color for the "Approve" button.', 'project-huddle' ),
				'type'        => 'color',
				'default'     => '#6F7C8A'
			),
			array(
				'id'          => 'approve_text',
				'label'       => __( 'Approve Text', 'project-huddle' ),
				'description' => __( 'HTML Allowed. Use {{item_name}} to output the name of the image and {{project_name}} for the project.', 'project-huddle' ),
				'type'        => 'textarea',
				'default'     => sprintf( __( 'Are you sure you want to approve %s?', 'project-huddle' ), '<strong>{{item_name}}</strong>' )
			),
			array(
				'id'          => 'unapprove_text',
				'label'       => __( 'Un-Approve Text', 'project-huddle' ),
				'description' => __( 'HTML Allowed. Use {{item_name}} to output the name of the image and {{project_name}} for the project.', 'project-huddle' ),
				'type'        => 'textarea',
				'default'     => sprintf( __( 'Are you sure you want to unapprove %s?', 'project-huddle' ), '<strong>{{item_name}}</strong>' )
			),
			array(
				'id'          => 'approval_type',
				'label'       => __( 'Approval Type', 'project-huddle' ),
				'description' => __( 'Select whether approvals should approve the entire project or just the current image. You may need to change the approve text.', 'project-huddle' ),
				'type'        => 'radio',
				'options'     => array(
					'image'   => __( 'Approve the image only', 'project-huddle' ),
					'project' => __( 'Approve the entire project', 'project-huddle' )
				),
				'default'     => 'image'
			),
			array(
				'id'          => 'require_terms',
				'label'       => __( 'Approval Terms &amp; Conditions Checkbox', 'project-huddle' ),
				'description' => __( 'Option to require terms and conditions checkbox on approvals.', 'project-huddle' ),
				'type'        => 'radio',
				'options'     => array(
					0 => __( 'Don\'t require terms agreement', 'project-huddle' ),
					1 => __( 'Require terms agreement', 'project-huddle' )
				),
				'default'     => 0
			),
			array(
				'id'          => 'approve_terms_checkbox_text',
				'label'       => __( 'Approval Terms Checkbox Text', 'project-huddle' ),
				'description' => __( 'Approval Terms Checkbox Text. Use {{terms}} to place the terms link and {{user_name}} to display the current identified user.', 'project-huddle' ),
				'type'        => 'text',
				'default'     => sprintf( __( 'I, %2$s, read and agree with the %1$s.', 'project-huddle' ), '{{terms}}', '{{user_name}}' ),
				'required'    => array(
					'require_terms' => 1
				)
			),
			array(
				'id'          => 'approve_terms_link_text',
				'label'       => __( 'Approval Terms Link Text', 'project-huddle' ),
				'description' => __( 'Clickable text to show the terms.', 'project-huddle' ),
				'type'        => 'text',
				'default'     => __( 'Terms', 'project-huddle' ),
				'required'    => array(
					'require_terms' => 1
				)
			),
			array(
				'id'          => 'approve_terms',
				'label'       => __( 'Approval Terms', 'project-huddle' ),
				'description' => __( 'Full Terms and Conditions. HTML Allowed.', 'project-huddle' ),
				'type'        => 'textarea',
				'default'     => '',
				'required'    => array(
					'require_terms' => 1
				)
			),
		)
	) );

	$settings['email'] = apply_filters( 'ph_settings_email', array(
		'title'  => __( 'Emails', 'project-huddle' ),
		'fields' => array(
			'admin_emails' => array(
				'id'          => 'admin_emails',
				'label'       => __( 'Admin Emails', 'project-huddle' ),
				'description' => __( 'Additionally send an email to the site admin for new project actions.', 'project-huddle' ),
				'type'        => 'checkbox',
				'default'     => 'on',
			),
			/* Project Background */
			'email_sender_options' => array(
				'id'          => 'email_sender_options',
				'label'       => __( 'Email Sender Options', 'project-huddle' ),
				'description' => '',
				'type'        => 'divider',
			),
			'email_from_name' => array(
				'id'          => 'email_from_name',
				'label'       => __( '"From" Name', 'project-huddle' ),
				'description' => __( 'This is the name of the email sender.', 'project-huddle' ),
				'type'        => 'text',
				'default'     => get_bloginfo( 'name' ),
			),
			'email_from_address' => array(
				'id'          => 'email_from_address',
				'label'       => __( '"From" Address', 'project-huddle' ),
				'description' => __( 'This is the email address of the sender.', 'project-huddle' ),
				'type'        => 'text',
				'default'     => get_option( 'admin_email' ),
			),
			'background_email' => array(
				'id'          => 'background_emails',
				'label'       => __( 'Background Email Processing', 'project-huddle' ),
				'description' => __( 'Check this box to enable sending emails in the background. Uncheck if you\'re having trouble with emails sending.', 'project-huddle' ),
				'type'        => 'checkbox',
				'default'     => '',
			)
		)
	) );

	$settings['updates'] = apply_filters( 'ph_settings_updates', array(
		'title'  => __( 'Updates', 'project-huddle' ),
		'fields' => array(
			'license_key' => array(
				'id'          => 'license_key',
				'label'       => __( 'Project Huddle License Key', 'project-huddle' ),
				'description' => __( 'Enter your product license key for automatic updates of ProjectHuddle and any extensions.', 'project-huddle' ),
				'type'        => 'license',
				'default'     => '',
				'placeholder' => '',
				'callback'    => 'validate_license'
			),
			'beta_version' => array(
				'id'          => 'beta_version',
				'label'       => __( 'Pre-Release Versions', 'project-huddle' ),
				'description' => __( 'Get updates for pre-release versions of ProjectHuddle.', 'project-huddle' ),
				'type'        => 'checkbox',
				'default'     => '',
			),
		)
	) );

	$settings['extensions'] = apply_filters( 'ph_settings_extensions', array(
		'title'  => __( 'Addons', 'project-huddle' ),
		'fields' => array()
	) );

//	$settings['addons'] = apply_filters( 'ph_settings_addons', array(
//		'title'  => __( 'Addons', 'project-huddle' ),
//		'fields' => array(
//			'extension' => array(
//				'id' => 'extension',
//				'label'       => __( 'Be sure to check out the official Addons by ProjectHuddle.', 'project-huddle' ),
//				'type' => 'extensions',
//				'plugins' => array(
//					'file_uploads' => array(
//						'id'          => 'file_uploads',
//						'name'        => 'ProjectHuddle — File Uploads Addon',
//						'label'       => __( 'File Uploads Addon', 'project-huddle' ),
//						'description' => __( 'Upload and share files on mockup and website conversations.', 'project-huddle' ),
//						'type'        => 'extension',
//						'plugin_dir'  => 'ph-file-uploads/ph-file-uploads.php',
//						'url'         => 'https://projecthuddle.io/downloads/file-uploads-addon/'
//					),
//					'file_uploads1' => array(
//						'id'          => 'file_uploads1',
//						'name'        => 'ProjectHuddle — File Uploads Addon1',
//						'label'       => __( 'File Uploads Addon', 'project-huddle' ),
//						'description' => __( 'Upload and share files on mockup and website conversations.', 'project-huddle' ),
//						'type'        => 'extension',
//						'plugin_dir'  => 'ph-file-uploads1/ph-file-uploads1.php',
//						'url'         => 'https://projecthuddle.io/downloads/file-uploads-addon1/'
//					),
//				)
//			)
//		)
//	) );

	$settings['advanced'] = apply_filters( 'ph_settings_advanced', array(
		'title'  => __( 'Advanced', 'project-huddle' ),
		'fields' => array(
			'script_debug' => array(
				'id'          => 'script_debug',
				'label'       => __( 'Turn on script debugging', 'project-huddle' ),
				'description' => __( 'Check this box to turn on helpful script debugging messages.', 'project-huddle' ),
				'type'        => 'checkbox',
				'default'     => '',
			),
			'images_trash_bin' => array(
				'id'          => 'images_trash_bin',
				'label'       => __( 'Restore Trashed Mockup Images', 'project-huddle' ),
				'description' => __( 'Restore trashed images to their original projects.', 'project-huddle' ),
				'type'        => 'button',
				'default'     => admin_url( 'edit.php?post_status=trash&post_type=project_image' ),
			),
			'comment_locations_trash_bin' => array(
				'id'          => 'comment_locations_trash_bin',
				'label'       => __( 'Restore Trashed Mockup Threads', 'project-huddle' ),
				'description' => __( 'Restore trashed comment threads to their original images.', 'project-huddle' ),
				'type'        => 'button',
				'default'     => admin_url( 'edit.php?post_status=trash&post_type=ph_comment_location' ),
			),
			'website_comments_trash_bin' => array(
				'id'          => 'website_comments_trash_bin',
				'label'       => __( 'Restore Trashed Website Threads', 'project-huddle' ),
				'description' => __( 'Restore trashed website comment threads to their original pages.', 'project-huddle' ),
				'type'        => 'button',
				'default'     => admin_url( 'edit.php?post_status=trash&post_type=phw_comment_loc' ),
			),
			'website_pages_trash_bin' => array(
				'id'          => 'website_pages_trash_bin',
				'label'       => __( 'Restore Trashed Website Pages', 'project-huddle' ),
				'description' => __( 'Restore trashed website pages to their original state.', 'project-huddle' ),
				'type'        => 'button',
				'default'     => admin_url( 'edit.php?post_status=trash&post_type=ph-webpage' ),
			),
			'script_shielding' => array(
				'id'          => 'script_shielding',
				'label'       => __( 'Disable Script Shielding', 'project-huddle' ),
				'description' => __( 'Check this box to disable auto-dequeuing of theme styles and scripts on Project and Website pages.', 'project-huddle' ),
				'type'        => 'checkbox',
				'default'     => '',
			),
			'use_php_sessions' => array(
				'id'          => 'use_php_sessions',
				'label'       => __( 'Use Native PHP Sessions', 'project-huddle' ),
				'description' => __( 'Check this box to enable native PHP Sessions (not supported on all servers).', 'project-huddle' ),
				'type'        => 'checkbox',
				'default'     => '',
			),
			'uninstall_on_delete' => array(
				'id'          => 'uninstall_on_delete',
				'label'       => __( 'Remove ProjectHuddle Roles on Delete', 'project-huddle' ),
				'description' => __( 'This will remove all roles when ProjectHuddle is deleted.', 'project-huddle' ),
				'type'        => 'checkbox',
				'default'     => '',
			)
		)
	) );

	// allow filter of fields
	$settings = apply_filters( 'project_huddle_settings_fields', $settings );

	return $settings;
}

/**
 * Empty extensions tab
 * @param $extensions
 *
 * @return mixed
 */
function ph_empty_extensions( $extensions ) {
	if ( empty( $extensions['fields'] ) ) {
		$extensions['fields'] = array(
			/* Comments */
			'no_extensions' => array(
				'id'          => 'no_extensions',
				'label'       => __( 'No extensions installed.', 'project-huddle' ),
				'description' => '',
				'html'        => __( 'Please stay tuned for available extensions!' ),
				'type'        => 'custom',
			),
		);
	}

	return $extensions;
}

add_filter( 'ph_settings_extensions', 'ph_empty_extensions', 9999 );