<?php
/**
 * Contains functions to display wizard fields
 *
 * @author      Andre Gagnon | ProjectHuddle
 * @category    Admin
 * @version     1.0.0
 */

/**
 * Display the field
 *
 * @param $field
 * @param $id
 */
function ph_display_field( $field, $id ) {
	$html = '';

	// handle default
	if ( isset( $field['default'] ) ) {
		$data = $field['default'];
	}

	// handle required
	$required = '';
	if ( ! empty( $field['required'] ) && $field['required'] ) {
		$required = 'required';
	}

	$html .= '<div class="form-group" id="' . $id . '" ' . $required . ' >';

	// label
    if ( ! empty( $field['label'] ) && $field['type'] !== 'divider' ) {
	    $html .= '<label class="form-label text-bold" for="' . esc_attr( $id ) . '">' . esc_html( $field['label'] ) . '</label>';
    }

	// description
	if ( ! empty( $field['description'] ) ) {
		switch ( $field['type'] ) {
			case 'checkbox_multi':
			case 'radio':
			case 'select_multiple':
			case 'license':
				$html .= '<p class="description text-gray">' . $field['description'] . '</p>';
				break;

			case 'intro':
				$html .= '<p>' . $field['description'] . '</p>';
				break;

			case 'switch':
			case 'checkbox':
				break;

			default:
				$html .= '<p class="description text-gray">' . $field['description'] . '</p>' . "\n";
				break;
		}
	}

	switch ( $field['type'] ) {

		case 'text':
		case 'email':
		case 'url':
		case 'tel':
		case 'date':
		case 'password':
		case 'number':
			$placeholder = isset( $field['placeholder'] ) ? esc_attr( $field['placeholder'] ) : false;
			$html        .= '<input class="form-input" id="' . esc_attr( $id ) . '" type="' . $field['type'] . '" name="' . esc_attr( $id ) . '" placeholder="' . $placeholder . '" value="' . esc_attr( $data ) . '" ' . $required . '/>' . "\n";
			break;

		case 'color':
			$html .= '<input type="text" name="' . esc_attr( $id ) . '" class="color-picker" data-default-color="' . esc_attr( $field['default'] ) . '" value="' . esc_attr( $data ) . '"/>';
			break;

		case 'textarea':
			$placeholder = isset( $field['placeholder'] ) ? esc_attr( $field['placeholder'] ) : false;
			$html        .= '<textarea class="form-input" id="' . esc_attr( $id ) . '" rows="3" name="' . esc_attr( $id ) . '" placeholder="' . $placeholder . '">' . $data . '</textarea><br/>' . "\n";
			break;

		case 'checkbox':
			$checked = '';
			if ( $data && 'on' == $data ) {
				$checked = 'checked="checked"';
			}
			$html .= '<label class="form-checkbox">
                <input type="checkbox" id="' . esc_attr( $id ) . '" name="' . esc_attr( $id ) . '" ' . $checked . ' >
                 <i class="form-icon"></i> ' . $field['description'] . '
                </label>';
			break;

		case 'switch':
			$checked = '';
			if ( $data && 'on' == $data ) {
				$checked = 'checked="checked"';
			}
			$html .= '<label class="form-switch">
                <input type="checkbox" id="' . esc_attr( $id ) . '" name="' . esc_attr( $id ) . '" ' . $checked . ' >
                 <i class="form-icon"></i> ' . $field['description'] . '
                </label>';
			break;

		case 'radio':
			foreach ( $field['options'] as $k => $v ) {
				$checked = false;
				if ( $k == $data ) {
					$checked = true;
				}

				$html .= '<label class="form-radio">
                <input type="radio" id="' . esc_attr( $id . '_' . $k ) . '" name="' . esc_attr( $id ) . '" ' . checked( $checked, true, false ) . '>
                <i class="form-icon"></i> ' . $v . '
              </label>';
			}
			break;

		case 'image':
			$image_thumb = '';
			if ( $data ) {
				$image_thumb = wp_get_attachment_thumb_url( $data );
			}
			$html .= '<img id="' . esc_attr( $id ) . '_preview" class="image_preview" src="' . $image_thumb . '" /><br/>' . "\n";
			$html .= '<button id="' . esc_attr( $id ) . '_button" type="button" data-uploader_title="' . __( 'Upload an image', 'project-huddle' ) . '" data-uploader_button_text="' . __( 'Use image', 'project-huddle' ) . '" class="image_upload_button btn" value="' . __( 'New Image', 'project-huddle' ) . '" >' . __( 'Upload an image', 'project-huddle' ) . ' <i class="icon icon-upload"></i></button>' . "\n";
			if ( $data ) {
				$html .= '<input id="' . esc_attr( $id ) . '_delete" type="button" class="image_delete_button btn btn-link" value="' . __( 'Remove image', 'project-huddle' ) . '" />' . "\n";
			}
			$html .= '<input id="' . esc_attr( $id ) . '" class="image_data_field" type="hidden" name="' . esc_attr( $id ) . '" value="' . $data . '"/><br/>' . "\n";
			break;

		case 'select':
			$html .= '<select class="form-select" name="' . esc_attr( $id ) . '" id="' . esc_attr( $id ) . '">';
			foreach ( $field['options'] as $k => $v ) {
				$selected = false;
				if ( $k == $data ) {
					$selected = true;
				}
				$html .= '<option ' . selected( $selected, true, false ) . ' value="' . esc_attr( $k ) . '">' . $v . '</option>';
			}
			$html .= '</select> ';
			break;

		case 'select_multiple':
			$html .= '<select class="form-select" name="' . esc_attr( $id ) . '[]" id="' . esc_attr( $id ) . '" multiple="multiple">';
			foreach ( $field['options'] as $k => $v ) {
				$selected = false;
				if ( in_array( $k, $data ) ) {
					$selected = true;
				}
				$html .= '<option ' . selected( $selected, true, false ) . ' value="' . esc_attr( $k ) . '" />' . $v . '</label> ';
			}
			$html .= '</select> ';
			break;

		case 'divider':
			?>
            <div class="divider text-center" data-content="<?php echo ! empty($field['label']) ? esc_attr( $field['label'] ) : ''; ?>"></div>
			<?php
			break;

		case 'raw':
			echo wp_kses_post( $field['html'] );
			break;
	}

	$html .= '</span></div>';

	echo $html;
}