<?php
/**
 * User
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * PH_Project Class
 *
 * This class handles the project data
 *
 * @since 1.0
 */
class PH_User {

	function __construct() {
		add_action( 'ph_login_user', array( $this, 'login_user' ) );
		add_action( 'ph_get_users', array( $this, 'get_users' ) );

		add_action( 'ph_add_suppression', array( $this, 'add_suppression' ) );
		add_action( 'ph_remove_suppression', array( $this, 'remove_suppression' ) );

		add_filter( 'rest_user_query', array( $this, 'return_all_users' ), 10, 2 );
	}

	/**
	 * Gets current user info stored in WordPress
	 * Adds additional custom properties
	 *
	 * @since 1.0
	 * @return array
	 */
	public function get_current_user_info() {
		global $post;

		$current_user = wp_get_current_user();

		$current_user->capabilities = (object) array();

		if ( is_user_logged_in() ) {
			$current_user->logged_in = true;
		} else {
			$current_user->logged_in = false;
		}

//		if ( current_user_can( 'edit_ph-project', $post->ID ) || current_user_can( 'edit_ph-website', $post->ID ) ) {
//			$current_user->capabilities->moderate_comments = true;
//		} else {
//			$current_user->capabilities->moderate_comments = false;
//		}

		// add caps
		$data = get_userdata( get_current_user_id() );
		if ( is_object( $data ) ) {

			$current_user->capabilities = $data->allcaps;
		}

		// current user avatar
		$current_user->avatar = get_avatar( sanitize_email( $current_user->user_email ), 64 );

		// unset encrypted password
		unset( $current_user->data->user_pass );

		return $current_user->data;
	}

	/**
	 * Get Users
	 *
	 * @return array
	 */
	public function get_users( $data ) {
		$data = $data->get_params();

		if ( ! isset($data['email']) ) {
			return;
		}

		// search for typed fragment wildcard
		$args = array(
			'search' => '*' . $data['email'] . '*',
			'number' => 30 // limit to 30
		);
		$users = get_users( $args );
		// add avatars
		foreach ( $users as $user ) {
			$user->avatar = get_avatar( $user->ID, 22 );
		}
		return $users;
	}

	public function login_user( $data ) {
		$data = $data->get_params();

		$signed_on = wp_signon( array(
			'user_login' => $data['username'],
			'user_password' => $data['password'],
			'remember' => true
		), false );

		$signed_on->id = isset($signed_on->ID) ? $signed_on->ID : false;

		return $signed_on;
	}

	public function add_suppression( $data ) {
		$data = $data->get_params();

		return PH_Meta_Box_Project_Email_Notifications::add_disabled($data['id']);
	}

	public function remove_suppression( $data ) {
		$data = $data->get_params();

		return PH_Meta_Box_Project_Email_Notifications::remove_disabled($data['id']);
	}

	/**
	 * Removes `has_published_posts` from the query args so even users who have not
	 * published content are returned by the request.
	 *
	 * @see https://developer.wordpress.org/reference/classes/wp_user_query/
	 *
	 * @param array           $prepared_args Array of arguments for WP_User_Query.
	 * @param WP_REST_Request $request       The current request.
	 *
	 * @return array
	 */
	public function return_all_users( $prepared_args, $request ) {
		unset( $prepared_args['has_published_posts'] );

		return $prepared_args;
	}
}