<?php
/**
 * Comment Data
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       2.6.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Website Comment Class
 *
 * This class handles all comment data
 *
 * @since 2.6.0
 */
class PH_Comment extends PH_REST_Comments_Controller {
	/**
	 * PH_Website_Comment_New constructor.
	 *
	 * @param array $args
	 */
	public function __construct( array $args = array() ) {
		// parent constructor
		parent::__construct( $args );

		// set rest base
		$this->rest_base = 'comments';

		// register this comment route on construct
		add_action( 'rest_api_init', array( $this, 'register_routes' ) );

		// comment actions for all registered ph comments
		add_action( 'wp_insert_comment', array( $this, 'new_comment' ), 10, 2 );
		add_action( 'edit_comment', array( $this, 'edit_comment' ), 10, 2 );
		add_action( 'trashed_comment', array( $this, 'trash_comment' ), 10, 2 );
	}

	/**
	 * Trigger the correct action
	 *
	 * @param $action  string Action to trigger
	 * @param $id      integer Comment ID
	 * @param $comment WP_Comment Comment Object
	 */
	function do_action( $action, $id, $comment ) {
		if ( in_array( $comment->comment_type, ph_get_comment_types() ) ) {
			// get endpoint type based on parent
			$project_type = ph_get_comment_project_type( $id );
			// comment type name
			$comment_type = ph_comment_type_name( $comment->comment_type );
			// run action
			do_action( "ph_{$project_type}_{$action}_{$comment_type}", $id, $comment );
		}
	}

	/**
	 * New comment notification
	 *
	 * @param            $id
	 * @param WP_Comment $comment
	 */
	function new_comment( $id, $comment ) {
		$this->do_action( 'publish', $id, $comment );
	}

	/**
	 * New comment notification
	 *
	 * @param            $id
	 * @param array $data Comment data
	 */
	function edit_comment( $id, $data ) {
		$comment = get_comment( $id );
		$this->do_action( 'edit', $id, $comment );
	}

	/**
	 * New comment notification
	 *
	 * @param            $id
	 * @param WP_Comment $comment
	 */
	function trash_comment( $id, $comment ) {
		$this->do_action( 'delete', $id, $comment );
	}
}