<?php
/**
 * Scripts
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Register scripts we can use throughout the plugin
 */
function ph_global_scripts() {
	global $post_type;

	$js_dir = PH_PLUGIN_URL . 'assets/js/';
	$css_dir = PH_PLUGIN_URL . 'assets/css/';

	if ( ! in_array( $post_type, ph_get_post_types() ) ) {
		return false;
	}

	// global register scripts
	wp_register_script( 'ph-select2-admin', $js_dir . 'select2-admin.js', array( 'jquery', 'select2' ), PH_VERSION );
	wp_register_script( 'select2', $js_dir . 'includes/select2.full.min.js', array( 'jquery' ), '4.0.2' );
	wp_register_script( 'autosize', $js_dir . 'includes/autosize.min.js', array(), '3.0.2' );
	wp_register_script( 'jquery-placecursoratend', $js_dir . 'includes/jquery.placecursoratend.js', array( 'jquery' ), '1.0', true );
	wp_register_style( 'select2', $css_dir . 'includes/select2.min.css', array(), '4.0.2' );
	wp_register_style( 'ph-select2-admin', $css_dir . 'project-huddle-select2-admin.css', array( 'select2' ), '4.0.2' );

	wp_localize_script('ph-select2-admin', 'phSelect2', array(
		'defaultAvatar' => get_option( 'avatar_default' ),
	) );
}
add_action( 'wp_enqueue_scripts', 'ph_global_scripts', 999999999 );
add_action( 'admin_enqueue_scripts', 'ph_global_scripts', 9999999 );

/**
 * Un-enqueue theme and other plugin styles and loads our plugin styles.
 *
 * Included style handles can be passed via a hook.
 *
 * @since 1.0
 *
 * @return void
 */
function ph_load_styles() {
	global $wp_styles;

	// store css directory
	$css_dir = PH_PLUGIN_URL . 'assets/css/';

	// Use minified libraries if SCRIPT_DEBUG is turned off
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	// return for other pages
	if ( ! is_user_logged_in() ) {
		if ( in_array( get_post_type(), ph_get_post_types() ) || in_array( get_post_type(), ph_get_child_post_types() ) || get_query_var( 'ph_user_settings' ) ) {
			wp_enqueue_style( 'ph-login-style', $css_dir . 'ph-login' . $suffix . '.css', array(), PH_VERSION );
		}
	}

	// return for other pages
	if ( ! in_array( get_post_type(), ph_get_post_types() ) ) {
		return;
	}

	if ( ! get_option( 'ph_script_shielding' ) ) {
		// allowed stylesheets on page
		$allowed['styles_allowed'] = apply_filters( 'ph_allowed_styles', array() );

		// un-enqueue all
		foreach ( $wp_styles->queue as $handle ) :
			if ( ! in_array( $handle, $allowed['styles_allowed'] ) ) {
				wp_dequeue_style( $handle );
			}
		endforeach;
	}

	wp_enqueue_style( 'toastr', $css_dir . 'includes/toastr.min.css', array(), PH_VERSION );
	wp_enqueue_style( 'ionicons', $css_dir . 'includes/ionicons.css', array(), '2.0.0' );
	wp_enqueue_style( 'ph-login-style', $css_dir . 'ph-login' . $suffix . '.css', array(), PH_VERSION );
	wp_enqueue_style( 'project-huddle', $css_dir . 'dist/project-huddle.css', array( 'project-huddle-fonts', 'ionicons' ), PH_VERSION );
	wp_enqueue_style( 'project-huddle-fonts', '//fonts.googleapis.com/css?family=Montserrat:400,700|Lato:300,400,700,900', array(), PH_VERSION );

	// add style options
	wp_add_inline_style( 'project-huddle', apply_filters( 'ph_inline_styles', ph_style_options() ) );
}

add_action( 'wp_enqueue_scripts', 'ph_load_styles', 99999999 );

/**
 * Adds styles and scripts needed on the page
 *
 * @since 1.0
 */
function ph_mockup_admin_scripts( $hook ) {
	// get post type
	global $post_type;

	// store css and javascript directories
	$css_dir = PH_PLUGIN_URL . 'assets/css/';
	$js_dir  = PH_PLUGIN_URL . 'assets/js/';

	// Use minified libraries if SCRIPT_DEBUG is turned off
	$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG  ? '' : '.min';

	if ( $post_type == 'ph-project' || $post_type == 'ph-website' ) {
		wp_deregister_script( 'yoast-seo-select2' );
		wp_dequeue_script( 'yoast-seo-select2' );
		wp_deregister_style( 'select2-css' );
		wp_deregister_script( 'select2-js' );
		wp_dequeue_style('select2');
		wp_deregister_style('select2');
		wp_dequeue_script('select2');
		wp_deregister_script('select2');
	}

	// bail out early if we are not on a project add/edit screen.
	if ( 'ph-project' != $post_type && 'ph-website' != $post_type  ) {
		return false;
	}

	// register reusable scripts
	wp_register_script( 'ph-select2-admin', $js_dir . 'select2-admin.js', array( 'jquery', 'select2' ), PH_VERSION );
	wp_register_script( 'select2', $js_dir . 'includes/select2.full.min.js', array( 'jquery' ), '4.0.2' );
	wp_register_script( 'autosize', $js_dir . 'includes/autosize.min.js', array(), '3.0.2' );
	wp_register_script( 'clipboard.js', $js_dir . 'includes/clipboard.js', array(), '1.7.1', false );


	wp_register_style( 'select2', $css_dir . 'includes/select2.min.css', array(), '4.0.2' );
	wp_register_style( 'ionicons', $css_dir . 'includes/ionicons.css', array(), '2.0.0' );
	wp_register_style( 'ph-select2-admin', $css_dir . 'project-huddle-select2-admin' . $suffix . '.css', array( 'select2' ), '4.0.2' );

	// enqueue media controls
	wp_enqueue_media();

	// enqueue jquery ui style
	wp_enqueue_style( 'jquery-ui-css', $css_dir . 'includes/jquery-ui-fresh.min.css', array(), PH_VERSION );

	// enqueue main style
	wp_enqueue_style( 'project-huddle-admin', $css_dir . 'dist/project-huddle.admin' . $suffix . '.css', array( 'ph-select2-admin', 'ionicons' ), PH_VERSION );

	// color picker
	wp_enqueue_style( 'wp-color-picker' );

	// place cursor at end
	wp_register_script( 'place-cursor-at-end', $js_dir . 'includes/jquery.placecursoratend.js', array( 'jquery' ), '1.0' );
	
	// enqueue needed admin script
	wp_enqueue_script( 'project-huddle-admin-js', $js_dir . 'dist/project-huddle.admin' . $suffix . '.js', array(
		'underscore',
		'backbone',
		'wp-api',
		'wp-backbone',
		'jquery-ui-sortable',
		'jquery-ui-dialog',
		'place-cursor-at-end',
		'wp-color-picker',
		'ph-select2-admin'
	), PH_VERSION );


	// Add nonce
	wp_localize_script( 'project-huddle-admin-js', 'PH', array(
		'nonce'        => wp_create_nonce( 'project-image-nonce' ),
		'site_url'     => get_site_url(),
		'translations' => ph_mockup_translation_strings()
	) );

	wp_localize_script( 'ph-select2-admin', 'PH_Select2', array(
		'options' => array(
			'anon_users' => true
		),
	) );

	wp_localize_script( 'ph-select2-admin', 'wpApiSettings', array(
		'root'          => esc_url_raw( get_rest_url() ),
		'nonce'         => wp_create_nonce( 'wp_rest' ),
		'versionString' => 'projecthuddle/v2/',
	));

	/**
	 * @var WP_REST_Server $wp_rest_server
	 */
	global $wp_rest_server;

	// Ensure the rest server is intiialized.
	if ( empty( $wp_rest_server ) ) {
		/** This filter is documented in wp-includes/rest-api.php */
		$wp_rest_server_class = apply_filters( 'wp_rest_server_class', 'WP_REST_Server' );
		$wp_rest_server       = new $wp_rest_server_class();
		/** This filter is documented in wp-includes/rest-api.php */
		do_action( 'rest_api_init', $wp_rest_server );
	}

	// Load the schema.
	$schema_request  = new WP_REST_Request( 'GET', '/projecthuddle/v2' );
	$schema_response = $wp_rest_server->dispatch( $schema_request );
	$schema          = null;
	if ( ! $schema_response->is_error() ) {
		$schema = $schema_response->get_data();
	}

	// Localize the plugin settings and schema.
	$settings = array(
		'root'          => esc_url_raw( get_rest_url() ),
		'nonce'         => wp_create_nonce( 'wp_rest' ),
		'versionString' => 'projecthuddle/v2/',
		'schema'        => $schema,
		'cacheSchema'   => true,
	);

	/**
	 * Filter the JavaScript Client settings before localizing.
	 *
	 * Enables modifying the config values sent to the JS client.
	 *
	 * @param array  $settings The JS Client settings.
	 */
	$settings = apply_filters( 'rest_js_client_settings', $settings );
	wp_localize_script( 'wp-api', 'wpApiSettings', $settings );
}
add_action( 'admin_enqueue_scripts', 'ph_mockup_admin_scripts', 99 );

/**
 * Un-enqueue theme and other plugin scripts and loads our plugin scripts
 *
 * @since 1.0
 *
 * @return void
 */
function ph_load_scripts(){
	global $wp_scripts;

	// store javascript directory
	$js_dir = PH_PLUGIN_URL . 'assets/js/';

	// Use minified libraries if SCRIPT_DEBUG is turned off
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	// user settings
//	$suffix = get_option( 'ph_script_debug', false ) ? '' : '.min';

	// global register scripts
	wp_register_script( 'autosize', $js_dir . 'includes/autosize.min.js', array(), '3.0.2', true);
	wp_register_script( 'quill', $js_dir . 'includes/quill.min.js', array(), '1.2.0', true);
	wp_register_script( 'js.cookie', $js_dir . 'includes/js.cookie.js', array(), '2.1.4');
	wp_register_script( 'jquery-placecursoratend', $js_dir . 'includes/jquery.placecursoratend.js', array( 'jquery' ), '1.0', true );

	// return for other pages
	if ( ! is_singular('ph-project') ) {
		return;
	}

	if ( ! get_option( 'ph_script_shielding' ) ) {
		$allowed = apply_filters( 'ph_allowed_scripts', array() );

		foreach ( $wp_scripts->queue as $handle ) :
			if ( ! in_array( $handle, $allowed ) ) {
				wp_dequeue_script( $handle );
			}
		endforeach;
	}

	if ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) {
		wp_deregister_script( 'backbone' );
		wp_deregister_script( 'underscore' );
		wp_register_script( 'backbone', 'https://cdnjs.cloudflare.com/ajax/libs/backbone.js/1.2.3/backbone.js' );
		wp_register_script( 'underscore', 'https://cdnjs.cloudflare.com/ajax/libs/underscore.js/1.8.3/underscore.js');
	}

	// enqueue main collaborate script
	wp_register_script( 'modernizr', $js_dir . 'includes/modernizr.custom.js', array(), PH_VERSION );
	wp_register_script( 'project-huddle', $js_dir . 'dist/project-huddle' . $suffix . '.js', array( 'jquery', 'underscore', 'backbone', 'wp-backbone', 'quill', 'wp-api' ), PH_VERSION );
	wp_register_script( 'jquery-scrollbar', $js_dir . 'includes/jquery.scrollbar.min.js', array( 'jquery' ), '0.2.6', true );
	wp_register_script( 'toastr', $js_dir . 'includes/toastr.min.js', array(), '2.1.1', true );
	wp_register_script( 'transformicons', $js_dir . 'includes/transformicons.min.js', array(), '0.4.4', true );
	wp_register_script( 'vex', $js_dir . 'includes/vex.combined.min.js', array( 'jquery' ), '2.3.2', true );
	wp_register_script( 'fastclick', $js_dir . 'includes/fastclick.js', array(), '1.0.6', false );

	wp_enqueue_script( 'modernizr' );
	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'jquery-ui-core');
	wp_enqueue_script( 'jquery-ui-draggable' );
	wp_enqueue_script( 'underscore' );
	wp_enqueue_script( 'backbone' );
	wp_enqueue_script( 'wp-backbone' );
	wp_enqueue_script( 'wp-util' );
	wp_enqueue_script( 'heartbeat' );
	wp_enqueue_script( 'toastr' );
	wp_enqueue_script( 'jquery-scrollbar' );
	wp_enqueue_script( 'transformicons' );
	wp_enqueue_script( 'vex' );
	wp_enqueue_script( 'jquery-placecursoratend' );
	wp_enqueue_script( 'js.cookie' );
	wp_enqueue_script( 'project-huddle' );

	// localize nonce and admin ajax
	wp_localize_script( 'project-huddle', 'ph', array(
		'ajaxurl' => esc_url( admin_url( 'admin-ajax.php' ) ),
		'api_url' => get_rest_url(),
		'nonce'   => wp_create_nonce( 'wp_rest' ),
	) );

	// cache comment id and clear
	$comment_scroll = PH()->session->get( 'ph_comment_id' );
	PH()->session->clear('ph_comment_id');

	// localize our origin
	wp_localize_script( 'project-huddle', 'PH_Settings', array(
		'debug'             => defined( 'SCRIPT_DEBUG' ) ? SCRIPT_DEBUG : false,
		'translations'      => ph_mockup_translation_strings(),
		'comments_per_page' => apply_filters( 'ph_comments_per_page', 25 ),
		'options'           => apply_filters( 'ph_mockup_global_settings', array(
			'auto_close'                => get_option( 'ph_auto_close', 'on' ) == 'on' ? true : false,
			'ph_image_background_color' => get_option( 'ph_image_bg', false ),
			'require_terms'             => get_option( 'ph_require_terms', false ),
			'approval_type'             => get_option( 'ph_approval_type', false )
		) ),
		'comment_scroll'    => $comment_scroll
	) );

	/**
	 * @var WP_REST_Server $wp_rest_server
	 */
	global $wp_rest_server;

	// Ensure the rest server is intiialized.
	if ( empty( $wp_rest_server ) ) {
		/** This filter is documented in wp-includes/rest-api.php */
		$wp_rest_server_class = apply_filters( 'wp_rest_server_class', 'WP_REST_Server' );
		$wp_rest_server       = new $wp_rest_server_class();
		/** This filter is documented in wp-includes/rest-api.php */
		do_action( 'rest_api_init', $wp_rest_server );
	}

	// Load the schema.
	$schema_request  = new WP_REST_Request( 'GET', '/projecthuddle/v2' );
	$schema_response = $wp_rest_server->dispatch( $schema_request );
	$schema          = null;
	if ( ! $schema_response->is_error() ) {
		$schema = $schema_response->get_data();
	}

	// Localize the plugin settings and schema.
	$settings = array(
		'root'          => esc_url_raw( get_rest_url() ),
		'nonce'         => wp_create_nonce( 'wp_rest' ),
		'versionString' => 'projecthuddle/v2/',
		'schema'        => $schema,
		'cacheSchema'   => true,
	);

	/**
	 * Filter the JavaScript Client settings before localizing.
	 *
	 * Enables modifying the config values sent to the JS client.
	 *
	 * @param array  $settings The JS Client settings.
	 */
	$settings = apply_filters( 'rest_js_client_settings', $settings );
	wp_localize_script( 'wp-api', 'wpApiSettings', $settings );
}
add_action( 'wp_enqueue_scripts', 'ph_load_scripts', 999999 );

/**
 * Clear comment scroll session on shutdown
 */
function ph_remove_comment_scroll_session() {
//	PH()->session->clear( 'ph_comment_id' );
}
add_action( 'shutdown', 'ph_remove_comment_scroll_session' );

/**
 * PH Shortcodes script
 */
function ph_shortcode_scripts() {
	wp_register_script( 'ph-shortcodes', PH_PLUGIN_URL . 'assets/js/ph-shortcodes.js', array( 'jquery' ), PH_VERSION );
}

add_action( 'wp_enqueue_scripts', 'ph_shortcode_scripts' );

/**
 * Un-enqueue theme and other plugin styles and loads our plugin styles.
 *
 * Included style handles can be passed via a hook.
 *
 * @since 1.0
 */
function ph_shortcode_styles() {
	// store javascript directory
	$css_dir = PH_PLUGIN_URL . 'assets/css/';

	// Use minified libraries if SCRIPT_DEBUG is turned off
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	wp_register_style( 'project-huddle-shortcodes', $css_dir . 'project-huddle-shortcodes' . $suffix . '.css', array(), PH_VERSION );
}

add_action( 'wp_enqueue_scripts', 'ph_shortcode_styles' );