<?php
/**
 * Functions for the templating system.
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Adds underscore templates via filter action
 *
 * @uses ph_get_project_info to generate json data for project
 *
 * @since 1.0
 */
function ph_output_project_underscore_templates() {
	// project container and data
	ph_get_template( 'mockup/project-image-collection.tmpl.php', array(
		'project_data' => PH()->project->get_item()
	) );

	// project image
	ph_get_template( 'mockup/project-image.tmpl.php' );

	// controls
	ph_get_template( 'mockup/control-bar.tmpl.php' );
	ph_get_template( 'mockup/controls.tmpl.php' );
	ph_get_template( 'mockup/image-thumb.tmpl.php' );

	// approval controls
	ph_get_template('mockup/approve-button.tmpl.php');
	ph_get_template('mockup/approve-filter.tmpl.php');

	// comment threads
	ph_get_template('thread/thread-dot.tmpl.php');
	ph_get_template('thread/thread-bubble-container.tmpl.php');
	ph_get_template('thread/thread-bubble.tmpl.php');
	ph_get_template('thread/thread-form-controls.tmpl.php');
	ph_get_template('thread/thread-header.tmpl.php');
	ph_get_template('thread/thread-submit-button.tmpl.php');
	ph_get_template('thread/thread-cancel-button.tmpl.php');
	ph_get_template('thread/thread-resolve.tmpl.php');
	ph_get_template('thread/thread-close.tmpl.php');

	// thread details
	ph_get_template('thread/thread-comment-details.tmpl.php');
	ph_get_template('thread/thread-detail-link.tmpl.php');
	ph_get_template('thread/thread-share-action.tmpl.php');
	ph_get_template('thread/thread-detail-delete.tmpl.php');
	ph_get_template('thread/thread-detail-delete.tmpl.php');

	// comments
	ph_get_template('comment/comment-avatar.tmpl.php');
	ph_get_template('comment/comment-edit-form.tmpl.php');
	ph_get_template('comment/comment-text.tmpl.php');
	ph_get_template('comment/comment-item.tmpl.php');
	ph_get_template('comment/comment-item-minimal.tmpl.php');
	ph_get_template('comment/comment-controls.tmpl.php');

	ph_get_template('panel/comment-panel.tmpl.php');
	ph_get_template('panel/comment-panel-item.tmpl.php');
	ph_get_template('panel/resolved-toggle.tmpl.php');

	// dialogs
	ph_get_template( 'dialog/popup-register.tmpl.php' );
	ph_get_template( 'dialog/popup-reset.tmpl.php' );
	ph_get_template( 'dialog/popup-login.tmpl.php' );

	ph_get_template( 'dialog/popup-copy-link.tmpl.php' );
	ph_get_template( 'dialog/popup-share.tmpl.php' );
}

// add underscore templates
add_action( 'ph_underscore_templates', 'ph_output_project_underscore_templates' );

/**
 * Output admin underscore templates
 */
function ph_output_project_admin_underscore_templates() {
	global $typenow, $pagenow, $adminpage;

	// check correct post type
	if ( 'ph-project' != $typenow ) {
		return false;
	}

	// check correct page
	if ( 'post.php' != $pagenow && 'post-new.php' != $pagenow ) {
		return false;
	}

	ph_get_template( 'admin/mockup/image-thumb.templ.php' );
	ph_get_template( 'admin/mockup/modal-window.templ.php' );
	ph_get_template( 'admin/mockup/dialog.templ.php' );
	ph_get_template( 'admin/mockup/settings-menu-items.templ.php' );
	ph_get_template( 'admin/mockup/versions-modal.tmpl.php' );
	ph_get_template( 'admin/mockup/versions-menu-items.tmpl.php' );
	ph_get_template( 'admin/mockup/project-metabox.templ.php', array(
		'project_data' => PH()->project->get_item()
	) );
}

// add underscore templates
add_action( 'print_media_templates', 'ph_output_project_admin_underscore_templates', 9 );

/**
 * Output website thread header
 */
function ph_thread_header() { ?>
	<div class="ph-comment-header"></div>
<?php }
add_action( 'ph_thread_content', 'ph_thread_header', 10 );

function ph_thread_loading() { ?>
	<div class="ph-more-loading ph-loading-image light"><div class="ph-loading-image-dots light"></div></div>
<?php }
add_action( 'ph_thread_content', 'ph_thread_loading', 20 );

function ph_thread_text() { ?>
	<div class="ph-comment-text-wrapper"></div>
<?php }
add_action( 'ph_thread_content', 'ph_thread_text', 30 );

function ph_thread_form() { ?>
	<div class="ph-comment-form"></div>
<?php }
add_action( 'ph_thread_content', 'ph_thread_form', 40 );

function ph_thread_submit() { ?>
	<div class="ph-comment-submit"></div>
<?php }
add_action( 'ph_thread_content', 'ph_thread_submit', 50 );