<?php
/**
 * Output System Status
 */
class PH_System_Status {
	public function __construct() {
		define( 'PH_STATUS_DIR', plugin_dir_path( __FILE__ ) );

		add_action( 'admin_menu', array( $this, 'register_submenu_page' ), 100 );
		add_action( 'wp_ajax_download_ph_system_status', array( $this, 'download_info' ) );

		// test endpoint
		add_action( 'rest_api_init', array( $this, 'test_api_route' ) );
	}

	/**
	 * Test route for system status
	 */
	public function test_api_route() {
		register_rest_route( 'projecthuddle/v1', '/test',
			array(
				'methods'  => array( 'GET', 'POST', 'PATCH', 'PUT', 'DELETE' ),
				'callback' => function ( $data ) {
					return true;
				}
			)
		);
	}

	public function register_submenu_page() {
		$page = add_submenu_page(
			"edit.php?post_type=ph-project",
			__( 'System Status', 'simple-system-status' ),
			__( 'System Status', 'simple-system-status' ),
			'manage_options',
			'ph-system-status',
			array( $this, 'render_status' )
		);
	}

	public function render_status() {
		include( PH_STATUS_DIR . 'system-status-output.php' );
	}

	public function display() {
		if ( get_bloginfo( 'version' ) < '3.4' ) {
			$theme_data = get_theme_data( get_stylesheet_directory() . '/style.css' );
			$theme      = $theme_data['Name'] . ' ' . $theme_data['Version'];
		} else {
			$theme_data = wp_get_theme();
			$theme      = $theme_data->Name . ' ' . $theme_data->Version;
		}

		// Try to identify the hosting provider
		$host = false;
		if ( defined( 'WPE_APIKEY' ) ) {
			$host = 'WP Engine';
		} elseif ( defined( 'PAGELYBIN' ) ) {
			$host = 'Pagely';
		}

		$response = wp_remote_post( rest_url( 'projecthuddle/v1/test' ), array(
			'method' => 'PATCH'
		) );

		if ( ! is_wp_error( $response ) && $response['response']['code'] >= 200 && $response['response']['code'] < 300 ) {
			$patch = 'PATCH is working';
		} else {
			$patch = 'PATCH is not working. Please enable PATCH requests on your server.';
			if ( is_wp_error( $response ) ) {
				$patch .= $response->get_error_message();
			}
		}

		$response = wp_remote_post( rest_url( 'projecthuddle/v1/test' ), array(
			'method' => 'PUT'
		) );

		if ( ! is_wp_error( $response ) && $response['response']['code'] >= 200 && $response['response']['code'] < 300 ) {
			$put = 'PUT is working';
		} else {
			$put = 'PUT is not working. Please enable PUT requests on your server.';
			if ( is_wp_error( $response ) ) {
				$put .= $response->get_error_message();
			}
		}

		$response = wp_remote_post( rest_url( 'projecthuddle/v1/test' ), array(
			'method' => 'DELETE'
		) );

		if ( ! is_wp_error( $response ) && $response['response']['code'] >= 200 && $response['response']['code'] < 300 ) {
			$delete = 'DELETE is working';
		} else {
			$delete = 'DELETE is not working. Please enable DELETE requests on your server.';
			if ( is_wp_error( $response ) ) {
				$delete .= $response->get_error_message();
			}
		}

		ob_start();
		include( PH_STATUS_DIR . 'output.php' );

		return ob_get_clean();
	}

	public function download_info() {
		if ( ! isset( $_POST['ph-system-status-text'] ) || empty( $_POST['ph-system-status-text'] ) ) {
			return;
		}

		header( 'Content-type: text/plain' );

		//Text file name marked with Unix timestamp
		header( 'Content-Disposition: attachment; filename=projecthuddle_system_status_' . time() . '.txt' );

		echo $_POST['ph-system-status-text'];
		die();
	}

	public function hooks_reference($tag) {
		global $wp_filter;

		$output = '';
		if ( isset( $wp_filter[$tag]->callbacks ) && is_array( $wp_filter[$tag]->callbacks ) ) {
			foreach($wp_filter[$tag]->callbacks as $priority => $action ) {
				$output .= "Priority: $priority\n";
				if ( isset($action) && is_array($action)) {
					foreach ( $action as $key => $action ) {
						foreach($action as $type => $function_name) {
							$output .= $type . ': ' . $function_name . "\n";
						}
					}
				}
				$output .= "\n";
			}
		}

		return $output;
	}

	/**
	 * Size Conversions
	 *
	 * @author Chris Christoff
	 * @since  1.0
	 *
	 * @param  unknown $v
	 *
	 * @return int|string
	 */
	public function let_to_num( $v ) {
		$l   = substr( $v, - 1 );
		$ret = substr( $v, 0, - 1 );

		switch ( strtoupper( $l ) ) {
			case 'P': // fall-through
			case 'T': // fall-through
			case 'G': // fall-through
			case 'M': // fall-through
			case 'K': // fall-through
				$ret *= 1024;
				break;
			default:
				break;
		}

		return $ret;
	}
}