<?php
/**
 * The Modal Window for individual project image settings
 *
 * @package     ProjectHuddle
 * @subpackage  app/templates
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0
 */
?>

<!-- Underscore Template -->
<script type="text/html" id='tmpl-modal-window'>
	<div class="backbone_modal">

		<div class="backbone_modal-content">
			<section class="backbone_modal-main" role="main">

				<h1>
					{{ data.title.rendered }} <?php _e( 'Image Settings', 'project-huddle' ); ?>
				</h1>

				<button class="media-modal-close backbone_modal-close button-link" href="#">
					<span class="media-modal-icon">
						<span class="screen-reader-text">
							<?php echo __( 'Close', 'project-huddle' ); ?>
						</span>
					</span>
				</button>

				<form>

					<div class="ph-setting">

						<div class="ph-setting-title">
							<h3>
								<?php _e( 'Alignment', 'project-huddle' ); ?>
							</h3>
							<p>
								<?php _e( 'Horizontal Alignment of Image.', 'project-huddle' ); ?>
							</p>
						</div>

						<div class="ph-setting-input ph-button-set" id="alignment">
							<input type="radio" id="align_left" name="alignment" value="left"
								<# if (data.options.alignment == 'left' ) { #> checked="checked" <# } #>>
							<label for="align_left">Left</label>

							<input type="radio" id="align_center" name="alignment" value="center"
								<# if (data.options.alignment == 'center' ) { #> checked="checked" <# } #>>
							<label for="align_center">Center</label>

							<input type="radio" id="align_right" name="alignment" value="right"
								<# if (data.options.alignment == 'right' ) { #> checked="checked" <# } #>>
							<label for="align_right">Right</label>
						</div>

					</div>

					<div class="ph-setting">

						<label for="size" class="ph-setting-title">
							<h3>
								<?php _e( 'Size Behavior', 'project-huddle' ); ?>
							</h3>

							<p>
								<?php _e( 'Choose scaling/zoom of image.', 'project-huddle' ); ?>
							</p>
						</label>

						<div class="ph-setting-input" id="size">
							<select name="size" id="size">
								<option value="normal" <# if (data.options.size == 'normal' ) { #> selected <# } #>>
									<?php _e( 'Normal', 'project-huddle' ); ?>
								</option>
								<option value="scale" <# if (data.options.size == 'scale' ) { #> selected <# } #>>
									<?php _e( 'Scale with Window Width', 'project-huddle' ); ?>
								</option>
							</select>
						</div>

					</div>

					<div class="ph-setting">

						<label for="background_color" class="ph-setting-title">
							<h3>
								<?php _e( 'Background Color', 'project-huddle' ); ?>
							</h3>

							<p>
								<?php _e( 'Choose a background color for the image.', 'project-huddle' ); ?>
							</p>
						</label>

						<div class="ph-setting-input" id="background_color">
							<input type="text" class="colorpicker background_color" name="background_color"
							       data-default-color="<?php echo esc_attr( get_option('bg') ); ?>"
							       <# if (data.options.background_color) { #>
								       value="{{ data.options.background_color }}"
								   <# } else { #>
								       value="<?php echo esc_attr( get_option('bg') ); ?>"
								   <# } #>" />
						</div>

					</div>

					<div class="ph-setting">

						<label for="background_image" class="ph-setting-title">
							<h3>
								<?php _e( 'Background Image', 'project-huddle' ); ?>
							</h3>
							<p>
								<?php _e( 'Enter a background image url.', 'project-huddle' ); ?>
							</p>
						</label>

						<div class="ph-setting-input" id="background_image">
							<input type="url" placeholder="http://" id="background_image" name="background_image"
								<# if ( data.options.background_image && data.options.background_image != 'false' ) { #> value="{{ data.options.background_image }}" <# } #>/>
						</div>

					</div>

					<div class="ph-setting">
						<label for="background_image_position" class="ph-setting-title">
							<h3>
								<?php _e( 'Background Image Position', 'project-huddle' ); ?>
							</h3>

							<p>
								<?php _e( 'Choose the background image position.', 'project-huddle' ); ?>
							</p>
						</label>

						<div class="ph-setting-input" id="background_image_position">
							<select name="background_image_position">
								<option value="center" <# if (data.options.background_image_position == 'center' ) { #> selected <# } #>>
									<?php _e( 'Center', 'project-huddle' ); ?>
								</option>
								<option value="repeat" <# if (data.options.background_image_position == 'repeat' ) { #> selected <# } #>>
									<?php _e( 'Tile', 'project-huddle' ); ?>
								</option>
								<option value="repeat-x" <# if (data.options.background_image_position == 'repeat-x' ) { #> selected <# } #>>
									<?php _e( 'Horizontal Tile', 'project-huddle' ); ?>
								</option>
								<option value="cover" <# if (data.options.background_image_position == 'cover' ) { #> selected <# } #>>
									<?php _e( 'Cover', 'project-huddle' ); ?>
								</option>
							</select>
						</div>

					</div>

				</form>

				<footer>
					<div class="inner text-right">
						<button id="btn-cancel" class="button button-large">
							<?php _e( 'Cancel', 'project-huddle' ); ?>
						</button>
						<button id="btn-ok" class="button button-primary button-large">
							<?php _e( 'Set', 'project-huddle' ); ?>
						</button>
					</div>
				</footer>
			</section>
		</div>

	</div>
	<div class="backbone_modal-backdrop">&nbsp;</div>
</script>
<!-- Underscore Template -->