const path = require("path");
const MiniCssExtractPlugin = require("mini-css-extract-plugin");
const IgnoreAssetsPlugin = require('ignore-assets-webpack-plugin');
const env = process.env.NODE_ENV;

function recursiveIssuer(m) {
  if (m.issuer) {
    return recursiveIssuer(m.issuer);
  } else if (m.name) {
    return m.name;
  } else {
    return false;
  }
}

module.exports = (env, argv) => {
  return {
    entry: {
      // mockups
      "project-huddle": [
        "./assets/js/src/front-end/main.js",
        "./assets/css/sass/project-huddle.scss"
      ],

      "project-huddle.admin": [
        "./assets/js/src/admin/main.js",
        "./assets/css/sass/project-huddle-admin.scss"
      ],

      // websites
      'ph-website-comments': [
        './addons/ph-website-comments/assets/js/src/front-end/main.js',
      ],

      // websites
      'ph-website-comments-admin': [
        './addons/ph-website-comments/assets/js/src/admin/main.js',
        "./addons/ph-website-comments/assets/css/sass/ph-website-admin.scss"
      ],

      // website comment bubble
      'ph-website-comment-bubble': [
        "./addons/ph-website-comments/assets/css/sass/ph-website-comment-bubble.scss"
      ],

      // parent site css
      'ph-website-comments-parent': [
        "./addons/ph-website-comments/assets/css/sass/ph-website-comments-parent.scss"
      ],

      // toolbar
      'ph-website-toolbar': [
        "./addons/ph-website-comments/assets/css/sass/ph-website-toolbar.scss"
      ],

      // website panel
      'ph-website-panel': [
        "./addons/ph-website-comments/assets/css/sass/ph-website-panel.scss"
      ],

      'ph-website-popup': [
        "./addons/ph-website-comments/assets/css/sass/ph-website-popup.scss"
      ],

    },

    optimization: {
      splitChunks: {
        cacheGroups: {
          mockupStyles: {
            name: "project-huddle",
            test: (m, c, entry = "project-huddle") =>
              m.constructor.name === "CssModule" && recursiveIssuer(m) === entry,
            chunks: "all",
            enforce: true
          },
          mockupAdminStyles: {
            name: "project-huddle.admin",
            test: (m, c, entry = "project-huddle.admin") =>
              m.constructor.name === "CssModule" && recursiveIssuer(m) === entry,
            chunks: "all",
            enforce: true
          },


          websiteAdminStyles: {
            name: "ph-website-comments-admin",
            test: (m, c, entry = "ph-website-comments-admin") =>
                m.constructor.name === "CssModule" && recursiveIssuer(m) === entry,
            chunks: "all",
            enforce: true
          },
          websiteCommentBubble: {
            name: "ph-website-comment-bubble",
            test: (m, c, entry = "ph-website-comment-bubble") =>
                m.constructor.name === "CssModule" && recursiveIssuer(m) === entry,
            chunks: "all",
            enforce: true
          },
          websiteToolbar: {
            name: "ph-website-toolbar",
            test: (m, c, entry = "ph-website-toolbar") =>
                m.constructor.name === "CssModule" && recursiveIssuer(m) === entry,
            chunks: "all",
            enforce: true
          },
          websitePanel: {
            name: "ph-website-panel",
            test: (m, c, entry = "ph-website-panel") =>
                m.constructor.name === "CssModule" && recursiveIssuer(m) === entry,
            chunks: "all",
            enforce: true
          },
          websitePopup: {
            name: "ph-website-popup",
            test: (m, c, entry = "ph-website-popup") =>
                m.constructor.name === "CssModule" && recursiveIssuer(m) === entry,
            chunks: "all",
            enforce: true
          },

          websiteCommentParent: {
            name: "ph-website-comments-parent",
            test: (m, c, entry = "ph-website-comments-parent") =>
                m.constructor.name === "CssModule" && recursiveIssuer(m) === entry,
            chunks: "all",
            enforce: true
          }
        }
      }
    },

    output: {
      path: path.resolve(__dirname, "./assets/js/dist"),
      filename: "[name].js"
    },

    resolve: {
      alias: {
        // mockups paths
        "@mockup": path.resolve(__dirname, "./assets/js/src/front-end/"),
        "@mockup-admin": path.resolve(__dirname, "./assets/js/src/admin/"),

        // website paths
        "@website": path.resolve(
          __dirname,
          "./addons/ph-website-comments/assets/js/src/front-end/"
        ),
        // website paths
        "@website-admin": path.resolve(
            __dirname,
            "./addons/ph-website-comments/assets/js/src/admin/"
        )
      }
    },

    module: {
      rules: [
        {
          test: /\.js$/,
          exclude: /node_modules/,
          use: {
            loader: "babel-loader"
          }
        },
        {
          test: /\.s?[ac]ss$/,
          use: [
            MiniCssExtractPlugin.loader,
            //devMode ? 'style-loader' : MiniCssExtractPlugin.loader,
            "css-loader",
            "postcss-loader",
            "sass-loader"
          ]
        }
      ]
    },
    plugins: [
      new MiniCssExtractPlugin({
        filename: argv.mode !== 'production'
          ? "../../css/dist/[name].css"
          : "../../css/dist/[name].min.css"
      }),
      new IgnoreAssetsPlugin({
        ignore: [
          'ph-website-panel.js',
          'ph-website-comment-bubble.js',
          'ph-website-comments-parent.js',
          'ph-website-popup.js',
          'ph-website-toolbar.js',

          'ph-website-panel.min.js',
          'ph-website-comment-bubble.min.js',
          'ph-website-comments-parent.min.js',
          'ph-website-popup.min.js',
          'ph-website-toolbar.min.js',
        ],
      }),
    ]
  }
};
