/*global self, document, DOMException */

/*! @source http://purl.eligrey.com/github/classList.js/blob/master/classList.js */

// Full polyfill for browsers with no classList support
if (!("classList" in document.createElement("_"))) {
    (function (view) {

        "use strict";

        if (!('Element' in view)) return;

        var
            classListProp = "classList"
            , protoProp = "prototype"
            , elemCtrProto = view.Element[protoProp]
            , objCtr = Object
            , strTrim = String[protoProp].trim || function () {
                    return this.replace(/^\s+|\s+$/g, "");
                }
            , arrIndexOf = Array[protoProp].indexOf || function (item) {
                    var
                        i = 0
                        , len = this.length
                    ;
                    for (; i < len; i++) {
                        if (i in this && this[i] === item) {
                            return i;
                        }
                    }
                    return -1;
                }
            // Vendors: please allow content code to instantiate DOMExceptions
            , DOMEx = function (type, message) {
                this.name = type;
                this.code = DOMException[type];
                this.message = message;
            }
            , checkTokenAndGetIndex = function (classList, token) {
                if (token === "") {
                    throw new DOMEx(
                        "SYNTAX_ERR"
                        , "An invalid or illegal string was specified"
                    );
                }
                if (/\s/.test(token)) {
                    throw new DOMEx(
                        "INVALID_CHARACTER_ERR"
                        , "String contains an invalid character"
                    );
                }
                return arrIndexOf.call(classList, token);
            }
            , ClassList = function (elem) {
                var
                    trimmedClasses = strTrim.call(elem.getAttribute("class") || "")
                    , classes = trimmedClasses ? trimmedClasses.split(/\s+/) : []
                    , i = 0
                    , len = classes.length
                ;
                for (; i < len; i++) {
                    this.push(classes[i]);
                }
                this._updateClassName = function () {
                    elem.setAttribute("class", this.toString());
                };
            }
            , classListProto = ClassList[protoProp] = []
            , classListGetter = function () {
                return new ClassList(this);
            }
        ;
        // Most DOMException implementations don't allow calling DOMException's toString()
        // on non-DOMExceptions. Error's toString() is sufficient here.
        DOMEx[protoProp] = Error[protoProp];
        classListProto.item = function (i) {
            return this[i] || null;
        };
        classListProto.contains = function (token) {
            token += "";
            return checkTokenAndGetIndex(this, token) !== -1;
        };
        classListProto.add = function () {
            var
                tokens = arguments
                , i = 0
                , l = tokens.length
                , token
                , updated = false
            ;
            do {
                token = tokens[i] + "";
                if (checkTokenAndGetIndex(this, token) === -1) {
                    this.push(token);
                    updated = true;
                }
            }
            while (++i < l);

            if (updated) {
                this._updateClassName();
            }
        };
        classListProto.remove = function () {
            var
                tokens = arguments
                , i = 0
                , l = tokens.length
                , token
                , updated = false
                , index
            ;
            do {
                token = tokens[i] + "";
                index = checkTokenAndGetIndex(this, token);
                while (index !== -1) {
                    this.splice(index, 1);
                    updated = true;
                    index = checkTokenAndGetIndex(this, token);
                }
            }
            while (++i < l);

            if (updated) {
                this._updateClassName();
            }
        };
        classListProto.toggle = function (token, force) {
            token += "";

            var
                result = this.contains(token)
                , method = result ?
                    force !== true && "remove"
                    :
                    force !== false && "add"
            ;

            if (method) {
                this[method](token);
            }

            if (force === true || force === false) {
                return force;
            } else {
                return !result;
            }
        };
        classListProto.toString = function () {
            return this.join(" ");
        };

        if (objCtr.defineProperty) {
            var classListPropDesc = {
                get: classListGetter
                , enumerable: true
                , configurable: true
            };
            try {
                objCtr.defineProperty(elemCtrProto, classListProp, classListPropDesc);
            } catch (ex) { // IE 8 doesn't support enumerable:true
                if (ex.number === -0x7FF5EC54) {
                    classListPropDesc.enumerable = false;
                    objCtr.defineProperty(elemCtrProto, classListProp, classListPropDesc);
                }
            }
        } else if (objCtr[protoProp].__defineGetter__) {
            elemCtrProto.__defineGetter__(classListProp, classListGetter);
        }

    }(self));
}

/* Blob.js
 * A Blob implementation.
 * 2014-07-24
 *
 * By Eli Grey, http://eligrey.com
 * By Devin Samarin, https://github.com/dsamarin
 * License: X11/MIT
 *   See https://github.com/eligrey/Blob.js/blob/master/LICENSE.md
 */

/*global self, unescape */
/*jslint bitwise: true, regexp: true, confusion: true, es5: true, vars: true, white: true,
 plusplus: true */

/*! @source http://purl.eligrey.com/github/Blob.js/blob/master/Blob.js */

(function (view) {
    "use strict";

    view.URL = view.URL || view.webkitURL;

    if (view.Blob && view.URL) {
        try {
            new Blob;
            return;
        } catch (e) {}
    }

    // Internally we use a BlobBuilder implementation to base Blob off of
    // in order to support older browsers that only have BlobBuilder
    var BlobBuilder = view.BlobBuilder || view.WebKitBlobBuilder || view.MozBlobBuilder || (function(view) {
            var
                get_class = function(object) {
                    return Object.prototype.toString.call(object).match(/^\[object\s(.*)\]$/)[1];
                }
                , FakeBlobBuilder = function BlobBuilder() {
                    this.data = [];
                }
                , FakeBlob = function Blob(data, type, encoding) {
                    this.data = data;
                    this.size = data.length;
                    this.type = type;
                    this.encoding = encoding;
                }
                , FBB_proto = FakeBlobBuilder.prototype
                , FB_proto = FakeBlob.prototype
                , FileReaderSync = view.FileReaderSync
                , FileException = function(type) {
                    this.code = this[this.name = type];
                }
                , file_ex_codes = (
                    "NOT_FOUND_ERR SECURITY_ERR ABORT_ERR NOT_READABLE_ERR ENCODING_ERR "
                    + "NO_MODIFICATION_ALLOWED_ERR INVALID_STATE_ERR SYNTAX_ERR"
                ).split(" ")
                , file_ex_code = file_ex_codes.length
                , real_URL = view.URL || view.webkitURL || view
                , real_create_object_URL = real_URL.createObjectURL
                , real_revoke_object_URL = real_URL.revokeObjectURL
                , URL = real_URL
                , btoa = view.btoa
                , atob = view.atob

                , ArrayBuffer = view.ArrayBuffer
                , Uint8Array = view.Uint8Array

                , origin = /^[\w-]+:\/*\[?[\w\.:-]+\]?(?::[0-9]+)?/
            ;
            FakeBlob.fake = FB_proto.fake = true;
            while (file_ex_code--) {
                FileException.prototype[file_ex_codes[file_ex_code]] = file_ex_code + 1;
            }
            // Polyfill URL
            if (!real_URL.createObjectURL) {
                URL = view.URL = function(uri) {
                    var
                        uri_info = document.createElementNS("http://www.w3.org/1999/xhtml", "a")
                        , uri_origin
                    ;
                    uri_info.href = uri;
                    if (!("origin" in uri_info)) {
                        if (uri_info.protocol.toLowerCase() === "data:") {
                            uri_info.origin = null;
                        } else {
                            uri_origin = uri.match(origin);
                            uri_info.origin = uri_origin && uri_origin[1];
                        }
                    }
                    return uri_info;
                };
            }
            URL.createObjectURL = function(blob) {
                var
                    type = blob.type
                    , data_URI_header
                ;
                if (type === null) {
                    type = "application/octet-stream";
                }
                if (blob instanceof FakeBlob) {
                    data_URI_header = "data:" + type;
                    if (blob.encoding === "base64") {
                        return data_URI_header + ";base64," + blob.data;
                    } else if (blob.encoding === "URI") {
                        return data_URI_header + "," + decodeURIComponent(blob.data);
                    } if (btoa) {
                        return data_URI_header + ";base64," + btoa(blob.data);
                    } else {
                        return data_URI_header + "," + encodeURIComponent(blob.data);
                    }
                } else if (real_create_object_URL) {
                    return real_create_object_URL.call(real_URL, blob);
                }
            };
            URL.revokeObjectURL = function(object_URL) {
                if (object_URL.substring(0, 5) !== "data:" && real_revoke_object_URL) {
                    real_revoke_object_URL.call(real_URL, object_URL);
                }
            };
            FBB_proto.append = function(data/*, endings*/) {
                var bb = this.data;
                // decode data to a binary string
                if (Uint8Array && (data instanceof ArrayBuffer || data instanceof Uint8Array)) {
                    var
                        str = ""
                        , buf = new Uint8Array(data)
                        , i = 0
                        , buf_len = buf.length
                    ;
                    for (; i < buf_len; i++) {
                        str += String.fromCharCode(buf[i]);
                    }
                    bb.push(str);
                } else if (get_class(data) === "Blob" || get_class(data) === "File") {
                    if (FileReaderSync) {
                        var fr = new FileReaderSync;
                        bb.push(fr.readAsBinaryString(data));
                    } else {
                        // async FileReader won't work as BlobBuilder is sync
                        throw new FileException("NOT_READABLE_ERR");
                    }
                } else if (data instanceof FakeBlob) {
                    if (data.encoding === "base64" && atob) {
                        bb.push(atob(data.data));
                    } else if (data.encoding === "URI") {
                        bb.push(decodeURIComponent(data.data));
                    } else if (data.encoding === "raw") {
                        bb.push(data.data);
                    }
                } else {
                    if (typeof data !== "string") {
                        data += ""; // convert unsupported types to strings
                    }
                    // decode UTF-16 to binary string
                    bb.push(unescape(encodeURIComponent(data)));
                }
            };
            FBB_proto.getBlob = function(type) {
                if (!arguments.length) {
                    type = null;
                }
                return new FakeBlob(this.data.join(""), type, "raw");
            };
            FBB_proto.toString = function() {
                return "[object BlobBuilder]";
            };
            FB_proto.slice = function(start, end, type) {
                var args = arguments.length;
                if (args < 3) {
                    type = null;
                }
                return new FakeBlob(
                    this.data.slice(start, args > 1 ? end : this.data.length)
                    , type
                    , this.encoding
                );
            };
            FB_proto.toString = function() {
                return "[object Blob]";
            };
            FB_proto.close = function() {
                this.size = 0;
                delete this.data;
            };
            return FakeBlobBuilder;
        }(view));

    view.Blob = function(blobParts, options) {
        var type = options ? (options.type || "") : "";
        var builder = new BlobBuilder();
        if (blobParts) {
            for (var i = 0, len = blobParts.length; i < len; i++) {
                if (Uint8Array && blobParts[i] instanceof Uint8Array) {
                    builder.append(blobParts[i].buffer);
                }
                else {
                    builder.append(blobParts[i]);
                }
            }
        }
        var blob = builder.getBlob(type);
        if (!blob.slice && blob.webkitSlice) {
            blob.slice = blob.webkitSlice;
        }
        return blob;
    };

    var getPrototypeOf = Object.getPrototypeOf || function(object) {
            return object.__proto__;
        };
    view.Blob.prototype = getPrototypeOf(new view.Blob());
}(typeof self !== "undefined" && self || typeof window !== "undefined" && window || this.content || this));

(function (root, factory) {
    'use strict';
    var isElectron = typeof module === 'object' && typeof process !== 'undefined' && process && process.versions && process.versions.electron;
    if (!isElectron && typeof module === 'object') {
        module.exports = factory;
    } else if (typeof define === 'function' && define.amd) {
        define(function () {
            return factory;
        });
    } else {
        root.MediumEditor = factory;
    }
}(this, function () {

    'use strict';

    function MediumEditor(elements, options) {
        'use strict';
        return this.init(elements, options);
    }

    MediumEditor.extensions = {};
    /*jshint unused: true */
    (function (window) {
        'use strict';

        function copyInto(overwrite, dest) {
            var prop,
                sources = Array.prototype.slice.call(arguments, 2);
            dest = dest || {};
            for (var i = 0; i < sources.length; i++) {
                var source = sources[i];
                if (source) {
                    for (prop in source) {
                        if (source.hasOwnProperty(prop) &&
                            typeof source[prop] !== 'undefined' &&
                            (overwrite || dest.hasOwnProperty(prop) === false)) {
                            dest[prop] = source[prop];
                        }
                    }
                }
            }
            return dest;
        }

        // https://developer.mozilla.org/en-US/docs/Web/API/Node/contains
        // Some browsers (including phantom) don't return true for Node.contains(child)
        // if child is a text node.  Detect these cases here and use a fallback
        // for calls to Util.isDescendant()
        var nodeContainsWorksWithTextNodes = false;
        try {
            var testParent = document.createElement('div'),
                testText = document.createTextNode(' ');
            testParent.appendChild(testText);
            nodeContainsWorksWithTextNodes = testParent.contains(testText);
        } catch (exc) {}

        var Util = {

            // http://stackoverflow.com/questions/17907445/how-to-detect-ie11#comment30165888_17907562
            // by rg89
            isIE: ((navigator.appName === 'Microsoft Internet Explorer') || ((navigator.appName === 'Netscape') && (new RegExp('Trident/.*rv:([0-9]{1,}[.0-9]{0,})').exec(navigator.userAgent) !== null))),

            isEdge: (/Edge\/\d+/).exec(navigator.userAgent) !== null,

            // if firefox
            isFF: (navigator.userAgent.toLowerCase().indexOf('firefox') > -1),

            // http://stackoverflow.com/a/11752084/569101
            isMac: (window.navigator.platform.toUpperCase().indexOf('MAC') >= 0),

            // https://github.com/jashkenas/underscore
            // Lonely letter MUST USE the uppercase code
            keyCode: {
                BACKSPACE: 8,
                TAB: 9,
                ENTER: 13,
                ESCAPE: 27,
                SPACE: 32,
                DELETE: 46,
                K: 75, // K keycode, and not k
                M: 77,
                V: 86
            },

            /**
             * Returns true if it's metaKey on Mac, or ctrlKey on non-Mac.
             * See #591
             */
            isMetaCtrlKey: function (event) {
                if ((Util.isMac && event.metaKey) || (!Util.isMac && event.ctrlKey)) {
                    return true;
                }

                return false;
            },

            /**
             * Returns true if the key associated to the event is inside keys array
             *
             * @see : https://github.com/jquery/jquery/blob/0705be475092aede1eddae01319ec931fb9c65fc/src/event.js#L473-L484
             * @see : http://stackoverflow.com/q/4471582/569101
             */
            isKey: function (event, keys) {
                var keyCode = Util.getKeyCode(event);

                // it's not an array let's just compare strings!
                if (false === Array.isArray(keys)) {
                    return keyCode === keys;
                }

                if (-1 === keys.indexOf(keyCode)) {
                    return false;
                }

                return true;
            },

            getKeyCode: function (event) {
                var keyCode = event.which;

                // getting the key code from event
                if (null === keyCode) {
                    keyCode = event.charCode !== null ? event.charCode : event.keyCode;
                }

                return keyCode;
            },

            blockContainerElementNames: [
                // elements our editor generates
                'p', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'blockquote', 'pre', 'ul', 'li', 'ol',
                // all other known block elements
                'address', 'article', 'aside', 'audio', 'canvas', 'dd', 'dl', 'dt', 'fieldset',
                'figcaption', 'figure', 'footer', 'form', 'header', 'hgroup', 'main', 'nav',
                'noscript', 'output', 'section', 'video',
                'table', 'thead', 'tbody', 'tfoot', 'tr', 'th', 'td'
            ],

            emptyElementNames: ['br', 'col', 'colgroup', 'hr', 'img', 'input', 'source', 'wbr'],

            extend: function extend(/* dest, source1, source2, ...*/) {
                var args = [true].concat(Array.prototype.slice.call(arguments));
                return copyInto.apply(this, args);
            },

            defaults: function defaults(/*dest, source1, source2, ...*/) {
                var args = [false].concat(Array.prototype.slice.call(arguments));
                return copyInto.apply(this, args);
            },

            /*
             * Create a link around the provided text nodes which must be adjacent to each other and all be
             * descendants of the same closest block container. If the preconditions are not met, unexpected
             * behavior will result.
             */
            createLink: function (document, textNodes, href, target) {
                var anchor = document.createElement('a');
                Util.moveTextRangeIntoElement(textNodes[0], textNodes[textNodes.length - 1], anchor);
                anchor.setAttribute('href', href);
                if (target) {
                    anchor.setAttribute('target', target);
                }
                return anchor;
            },

            /*
             * Given the provided match in the format {start: 1, end: 2} where start and end are indices into the
             * textContent of the provided element argument, modify the DOM inside element to ensure that the text
             * identified by the provided match can be returned as text nodes that contain exactly that text, without
             * any additional text at the beginning or end of the returned array of adjacent text nodes.
             *
             * The only DOM manipulation performed by this function is splitting the text nodes, non-text nodes are
             * not affected in any way.
             */
            findOrCreateMatchingTextNodes: function (document, element, match) {
                var treeWalker = document.createTreeWalker(element, NodeFilter.SHOW_ALL, null, false),
                    matchedNodes = [],
                    currentTextIndex = 0,
                    startReached = false,
                    currentNode = null,
                    newNode = null;

                while ((currentNode = treeWalker.nextNode()) !== null) {
                    if (currentNode.nodeType > 3) {
                        continue;
                    } else if (currentNode.nodeType === 3) {
                        if (!startReached && match.start < (currentTextIndex + currentNode.nodeValue.length)) {
                            startReached = true;
                            newNode = Util.splitStartNodeIfNeeded(currentNode, match.start, currentTextIndex);
                        }
                        if (startReached) {
                            Util.splitEndNodeIfNeeded(currentNode, newNode, match.end, currentTextIndex);
                        }
                        if (startReached && currentTextIndex === match.end) {
                            break; // Found the node(s) corresponding to the link. Break out and move on to the next.
                        } else if (startReached && currentTextIndex > (match.end + 1)) {
                            throw new Error('PerformLinking overshot the target!'); // should never happen...
                        }

                        if (startReached) {
                            matchedNodes.push(newNode || currentNode);
                        }

                        currentTextIndex += currentNode.nodeValue.length;
                        if (newNode !== null) {
                            currentTextIndex += newNode.nodeValue.length;
                            // Skip the newNode as we'll already have pushed it to the matches
                            treeWalker.nextNode();
                        }
                        newNode = null;
                    } else if (currentNode.tagName.toLowerCase() === 'img') {
                        if (!startReached && (match.start <= currentTextIndex)) {
                            startReached = true;
                        }
                        if (startReached) {
                            matchedNodes.push(currentNode);
                        }
                    }
                }
                return matchedNodes;
            },

            /*
             * Given the provided text node and text coordinates, split the text node if needed to make it align
             * precisely with the coordinates.
             *
             * This function is intended to be called from Util.findOrCreateMatchingTextNodes.
             */
            splitStartNodeIfNeeded: function (currentNode, matchStartIndex, currentTextIndex) {
                if (matchStartIndex !== currentTextIndex) {
                    return currentNode.splitText(matchStartIndex - currentTextIndex);
                }
                return null;
            },

            /*
             * Given the provided text node and text coordinates, split the text node if needed to make it align
             * precisely with the coordinates. The newNode argument should from the result of Util.splitStartNodeIfNeeded,
             * if that function has been called on the same currentNode.
             *
             * This function is intended to be called from Util.findOrCreateMatchingTextNodes.
             */
            splitEndNodeIfNeeded: function (currentNode, newNode, matchEndIndex, currentTextIndex) {
                var textIndexOfEndOfFarthestNode,
                    endSplitPoint;
                textIndexOfEndOfFarthestNode = currentTextIndex + currentNode.nodeValue.length +
                    (newNode ? newNode.nodeValue.length : 0) - 1;
                endSplitPoint = matchEndIndex - currentTextIndex -
                    (newNode ? currentNode.nodeValue.length : 0);
                if (textIndexOfEndOfFarthestNode >= matchEndIndex &&
                    currentTextIndex !== textIndexOfEndOfFarthestNode &&
                    endSplitPoint !== 0) {
                    (newNode || currentNode).splitText(endSplitPoint);
                }
            },

            /*
             * Take an element, and break up all of its text content into unique pieces such that:
             * 1) All text content of the elements are in separate blocks. No piece of text content should span
             *    across multiple blocks. This means no element return by this function should have
             *    any blocks as children.
             * 2) The union of the textcontent of all of the elements returned here covers all
             *    of the text within the element.
             *
             *
             * EXAMPLE:
             * In the event that we have something like:
             *
             * <blockquote>
             *   <p>Some Text</p>
             *   <ol>
             *     <li>List Item 1</li>
             *     <li>List Item 2</li>
             *   </ol>
             * </blockquote>
             *
             * This function would return these elements as an array:
             *   [ <p>Some Text</p>, <li>List Item 1</li>, <li>List Item 2</li> ]
             *
             * Since the <blockquote> and <ol> elements contain blocks within them they are not returned.
             * Since the <p> and <li>'s don't contain block elements and cover all the text content of the
             * <blockquote> container, they are the elements returned.
             */
            splitByBlockElements: function (element) {
                if (element.nodeType !== 3 && element.nodeType !== 1) {
                    return [];
                }

                var toRet = [],
                    blockElementQuery = MediumEditor.util.blockContainerElementNames.join(',');

                if (element.nodeType === 3 || element.querySelectorAll(blockElementQuery).length === 0) {
                    return [element];
                }

                for (var i = 0; i < element.childNodes.length; i++) {
                    var child = element.childNodes[i];
                    if (child.nodeType === 3) {
                        toRet.push(child);
                    } else if (child.nodeType === 1) {
                        var blockElements = child.querySelectorAll(blockElementQuery);
                        if (blockElements.length === 0) {
                            toRet.push(child);
                        } else {
                            toRet = toRet.concat(MediumEditor.util.splitByBlockElements(child));
                        }
                    }
                }

                return toRet;
            },

            // Find the next node in the DOM tree that represents any text that is being
            // displayed directly next to the targetNode (passed as an argument)
            // Text that appears directly next to the current node can be:
            //  - A sibling text node
            //  - A descendant of a sibling element
            //  - A sibling text node of an ancestor
            //  - A descendant of a sibling element of an ancestor
            findAdjacentTextNodeWithContent: function findAdjacentTextNodeWithContent(rootNode, targetNode, ownerDocument) {
                var pastTarget = false,
                    nextNode,
                    nodeIterator = ownerDocument.createNodeIterator(rootNode, NodeFilter.SHOW_TEXT, null, false);

                // Use a native NodeIterator to iterate over all the text nodes that are descendants
                // of the rootNode.  Once past the targetNode, choose the first non-empty text node
                nextNode = nodeIterator.nextNode();
                while (nextNode) {
                    if (nextNode === targetNode) {
                        pastTarget = true;
                    } else if (pastTarget) {
                        if (nextNode.nodeType === 3 && nextNode.nodeValue && nextNode.nodeValue.trim().length > 0) {
                            break;
                        }
                    }
                    nextNode = nodeIterator.nextNode();
                }

                return nextNode;
            },

            // Find an element's previous sibling within a medium-editor element
            // If one doesn't exist, find the closest ancestor's previous sibling
            findPreviousSibling: function (node) {
                if (!node || Util.isMediumEditorElement(node)) {
                    return false;
                }

                var previousSibling = node.previousSibling;
                while (!previousSibling && !Util.isMediumEditorElement(node.parentNode)) {
                    node = node.parentNode;
                    previousSibling = node.previousSibling;
                }

                return previousSibling;
            },

            isDescendant: function isDescendant(parent, child, checkEquality) {
                if (!parent || !child) {
                    return false;
                }
                if (parent === child) {
                    return !!checkEquality;
                }
                // If parent is not an element, it can't have any descendants
                if (parent.nodeType !== 1) {
                    return false;
                }
                if (nodeContainsWorksWithTextNodes || child.nodeType !== 3) {
                    return parent.contains(child);
                }
                var node = child.parentNode;
                while (node !== null) {
                    if (node === parent) {
                        return true;
                    }
                    node = node.parentNode;
                }
                return false;
            },

            // https://github.com/jashkenas/underscore
            isElement: function isElement(obj) {
                return !!(obj && obj.nodeType === 1);
            },

            // https://github.com/jashkenas/underscore
            throttle: function (func, wait) {
                var THROTTLE_INTERVAL = 50,
                    context,
                    args,
                    result,
                    timeout = null,
                    previous = 0,
                    later = function () {
                        previous = Date.now();
                        timeout = null;
                        result = func.apply(context, args);
                        if (!timeout) {
                            context = args = null;
                        }
                    };

                if (!wait && wait !== 0) {
                    wait = THROTTLE_INTERVAL;
                }

                return function () {
                    var now = Date.now(),
                        remaining = wait - (now - previous);

                    context = this;
                    args = arguments;
                    if (remaining <= 0 || remaining > wait) {
                        if (timeout) {
                            clearTimeout(timeout);
                            timeout = null;
                        }
                        previous = now;
                        result = func.apply(context, args);
                        if (!timeout) {
                            context = args = null;
                        }
                    } else if (!timeout) {
                        timeout = setTimeout(later, remaining);
                    }
                    return result;
                };
            },

            traverseUp: function (current, testElementFunction) {
                if (!current) {
                    return false;
                }

                do {
                    if (current.nodeType === 1) {
                        if (testElementFunction(current)) {
                            return current;
                        }
                        // do not traverse upwards past the nearest containing editor
                        if (Util.isMediumEditorElement(current)) {
                            return false;
                        }
                    }

                    current = current.parentNode;
                } while (current);

                return false;
            },

            htmlEntities: function (str) {
                // converts special characters (like <) into their escaped/encoded values (like &lt;).
                // This allows you to show to display the string without the browser reading it as HTML.
                return String(str).replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;').replace(/"/g, '&quot;');
            },

            // http://stackoverflow.com/questions/6690752/insert-html-at-caret-in-a-contenteditable-div
            insertHTMLCommand: function (doc, html) {
                var selection, range, el, fragment, node, lastNode, toReplace,
                    res = false,
                    ecArgs = ['insertHTML', false, html];

                /* Edge's implementation of insertHTML is just buggy right now:
                 * - Doesn't allow leading white space at the beginning of an element
                 * - Found a case when a <font size="2"> tag was inserted when calling alignCenter inside a blockquote
                 *
                 * There are likely other bugs, these are just the ones we found so far.
                 * For now, let's just use the same fallback we did for IE
                 */
                if (!MediumEditor.util.isEdge && doc.queryCommandSupported('insertHTML')) {
                    try {
                        return doc.execCommand.apply(doc, ecArgs);
                    } catch (ignore) {}
                }

                selection = doc.getSelection();
                if (selection.rangeCount) {
                    range = selection.getRangeAt(0);
                    toReplace = range.commonAncestorContainer;

                    // https://github.com/yabwe/medium-editor/issues/748
                    // If the selection is an empty editor element, create a temporary text node inside of the editor
                    // and select it so that we don't delete the editor element
                    if (Util.isMediumEditorElement(toReplace) && !toReplace.firstChild) {
                        range.selectNode(toReplace.appendChild(doc.createTextNode('')));
                    } else if ((toReplace.nodeType === 3 && range.startOffset === 0 && range.endOffset === toReplace.nodeValue.length) ||
                        (toReplace.nodeType !== 3 && toReplace.innerHTML === range.toString())) {
                        // Ensure range covers maximum amount of nodes as possible
                        // By moving up the DOM and selecting ancestors whose only child is the range
                        while (!Util.isMediumEditorElement(toReplace) &&
                        toReplace.parentNode &&
                        toReplace.parentNode.childNodes.length === 1 &&
                        !Util.isMediumEditorElement(toReplace.parentNode)) {
                            toReplace = toReplace.parentNode;
                        }
                        range.selectNode(toReplace);
                    }
                    range.deleteContents();

                    el = doc.createElement('div');
                    el.innerHTML = html;
                    fragment = doc.createDocumentFragment();
                    while (el.firstChild) {
                        node = el.firstChild;
                        lastNode = fragment.appendChild(node);
                    }
                    range.insertNode(fragment);

                    // Preserve the selection:
                    if (lastNode) {
                        range = range.cloneRange();
                        range.setStartAfter(lastNode);
                        range.collapse(true);
                        MediumEditor.selection.selectRange(doc, range);
                    }
                    res = true;
                }

                // https://github.com/yabwe/medium-editor/issues/992
                // If we're monitoring calls to execCommand, notify listeners as if a real call had happened
                if (doc.execCommand.callListeners) {
                    doc.execCommand.callListeners(ecArgs, res);
                }
                return res;
            },

            execFormatBlock: function (doc, tagName) {
                // Get the top level block element that contains the selection
                var blockContainer = Util.getTopBlockContainer(MediumEditor.selection.getSelectionStart(doc)),
                    childNodes;

                // Special handling for blockquote
                if (tagName === 'blockquote') {
                    if (blockContainer) {
                        childNodes = Array.prototype.slice.call(blockContainer.childNodes);
                        // Check if the blockquote has a block element as a child (nested blocks)
                        if (childNodes.some(function (childNode) {
                                return Util.isBlockContainer(childNode);
                            })) {
                            // FF handles blockquote differently on formatBlock
                            // allowing nesting, we need to use outdent
                            // https://developer.mozilla.org/en-US/docs/Rich-Text_Editing_in_Mozilla
                            return doc.execCommand('outdent', false, null);
                        }
                    }

                    // When IE blockquote needs to be called as indent
                    // http://stackoverflow.com/questions/1816223/rich-text-editor-with-blockquote-function/1821777#1821777
                    if (Util.isIE) {
                        return doc.execCommand('indent', false, tagName);
                    }
                }

                // If the blockContainer is already the element type being passed in
                // treat it as 'undo' formatting and just convert it to a <p>
                if (blockContainer && tagName === blockContainer.nodeName.toLowerCase()) {
                    tagName = 'p';
                }

                // When IE we need to add <> to heading elements
                // http://stackoverflow.com/questions/10741831/execcommand-formatblock-headings-in-ie
                if (Util.isIE) {
                    tagName = '<' + tagName + '>';
                }

                // When FF, IE and Edge, we have to handle blockquote node seperately as 'formatblock' does not work.
                // https://developer.mozilla.org/en-US/docs/Web/API/Document/execCommand#Commands
                if (blockContainer && blockContainer.nodeName.toLowerCase() === 'blockquote') {
                    // For IE, just use outdent
                    if (Util.isIE && tagName === '<p>') {
                        return doc.execCommand('outdent', false, tagName);
                    }

                    // For Firefox and Edge, make sure there's a nested block element before calling outdent
                    if ((Util.isFF || Util.isEdge) && tagName === 'p') {
                        childNodes = Array.prototype.slice.call(blockContainer.childNodes);
                        // If there are some non-block elements we need to wrap everything in a <p> before we outdent
                        if (childNodes.some(function (childNode) {
                                return !Util.isBlockContainer(childNode);
                            })) {
                            doc.execCommand('formatBlock', false, tagName);
                        }
                        return doc.execCommand('outdent', false, tagName);
                    }
                }

                return doc.execCommand('formatBlock', false, tagName);
            },

            /**
             * Set target to blank on the given el element
             *
             * TODO: not sure if this should be here
             *
             * When creating a link (using core -> createLink) the selection returned by Firefox will be the parent of the created link
             * instead of the created link itself (as it is for Chrome for example), so we retrieve all "a" children to grab the good one by
             * using `anchorUrl` to ensure that we are adding target="_blank" on the good one.
             * This isn't a bulletproof solution anyway ..
             */
            setTargetBlank: function (el, anchorUrl) {
                var i, url = anchorUrl || false;
                if (el.nodeName.toLowerCase() === 'a') {
                    el.target = '_blank';
                } else {
                    el = el.getElementsByTagName('a');

                    for (i = 0; i < el.length; i += 1) {
                        if (false === url || url === el[i].attributes.href.value) {
                            el[i].target = '_blank';
                        }
                    }
                }
            },

            /*
             * this function is called to explicitly remove the target='_blank' as FF holds on to _blank value even
             * after unchecking the checkbox on anchor form
             */
            removeTargetBlank: function (el, anchorUrl) {
                var i;
                if (el.nodeName.toLowerCase() === 'a') {
                    el.removeAttribute('target');
                } else {
                    el = el.getElementsByTagName('a');

                    for (i = 0; i < el.length; i += 1) {
                        if (anchorUrl === el[i].attributes.href.value) {
                            el[i].removeAttribute('target');
                        }
                    }
                }
            },

            /*
             * this function adds one or several classes on an a element.
             * if el parameter is not an a, it will look for a children of el.
             * if no a children are found, it will look for the a parent.
             */
            addClassToAnchors: function (el, buttonClass) {
                var classes = buttonClass.split(' '),
                    i,
                    j;
                if (el.nodeName.toLowerCase() === 'a') {
                    for (j = 0; j < classes.length; j += 1) {
                        el.classList.add(classes[j]);
                    }
                } else {
                    var aChildren = el.getElementsByTagName('a');
                    if (aChildren.length === 0) {
                        var parentAnchor = Util.getClosestTag(el, 'a');
                        el = parentAnchor ? [parentAnchor] : [];
                    } else {
                        el = aChildren;
                    }
                    for (i = 0; i < el.length; i += 1) {
                        for (j = 0; j < classes.length; j += 1) {
                            el[i].classList.add(classes[j]);
                        }
                    }
                }
            },

            isListItem: function (node) {
                if (!node) {
                    return false;
                }
                if (node.nodeName.toLowerCase() === 'li') {
                    return true;
                }

                var parentNode = node.parentNode,
                    tagName = parentNode.nodeName.toLowerCase();
                while (tagName === 'li' || (!Util.isBlockContainer(parentNode) && tagName !== 'div')) {
                    if (tagName === 'li') {
                        return true;
                    }
                    parentNode = parentNode.parentNode;
                    if (parentNode) {
                        tagName = parentNode.nodeName.toLowerCase();
                    } else {
                        return false;
                    }
                }
                return false;
            },

            cleanListDOM: function (ownerDocument, element) {
                if (element.nodeName.toLowerCase() !== 'li') {
                    return;
                }

                var list = element.parentElement;

                if (list.parentElement.nodeName.toLowerCase() === 'p') { // yes we need to clean up
                    Util.unwrap(list.parentElement, ownerDocument);

                    // move cursor at the end of the text inside the list
                    // for some unknown reason, the cursor is moved to end of the "visual" line
                    MediumEditor.selection.moveCursor(ownerDocument, element.firstChild, element.firstChild.textContent.length);
                }
            },

            /* splitDOMTree
             *
             * Given a root element some descendant element, split the root element
             * into its own element containing the descendant element and all elements
             * on the left or right side of the descendant ('right' is default)
             *
             * example:
             *
             *         <div>
             *      /    |   \
             *  <span> <span> <span>
             *   / \    / \    / \
             *  1   2  3   4  5   6
             *
             *  If I wanted to split this tree given the <div> as the root and "4" as the leaf
             *  the result would be (the prime ' marks indicates nodes that are created as clones):
             *
             *   SPLITTING OFF 'RIGHT' TREE       SPLITTING OFF 'LEFT' TREE
             *
             *     <div>            <div>'              <div>'      <div>
             *      / \              / \                 / \          |
             * <span> <span>   <span>' <span>       <span> <span>   <span>
             *   / \    |        |      / \           /\     /\       /\
             *  1   2   3        4     5   6         1  2   3  4     5  6
             *
             *  The above example represents splitting off the 'right' or 'left' part of a tree, where
             *  the <div>' would be returned as an element not appended to the DOM, and the <div>
             *  would remain in place where it was
             *
             */
            splitOffDOMTree: function (rootNode, leafNode, splitLeft) {
                var splitOnNode = leafNode,
                    createdNode = null,
                    splitRight = !splitLeft;

                // loop until we hit the root
                while (splitOnNode !== rootNode) {
                    var currParent = splitOnNode.parentNode,
                        newParent = currParent.cloneNode(false),
                        targetNode = (splitRight ? splitOnNode : currParent.firstChild),
                        appendLast;

                    // Create a new parent element which is a clone of the current parent
                    if (createdNode) {
                        if (splitRight) {
                            // If we're splitting right, add previous created element before siblings
                            newParent.appendChild(createdNode);
                        } else {
                            // If we're splitting left, add previous created element last
                            appendLast = createdNode;
                        }
                    }
                    createdNode = newParent;

                    while (targetNode) {
                        var sibling = targetNode.nextSibling;
                        // Special handling for the 'splitNode'
                        if (targetNode === splitOnNode) {
                            if (!targetNode.hasChildNodes()) {
                                targetNode.parentNode.removeChild(targetNode);
                            } else {
                                // For the node we're splitting on, if it has children, we need to clone it
                                // and not just move it
                                targetNode = targetNode.cloneNode(false);
                            }
                            // If the resulting split node has content, add it
                            if (targetNode.textContent) {
                                createdNode.appendChild(targetNode);
                            }

                            targetNode = (splitRight ? sibling : null);
                        } else {
                            // For general case, just remove the element and only
                            // add it to the split tree if it contains something
                            targetNode.parentNode.removeChild(targetNode);
                            if (targetNode.hasChildNodes() || targetNode.textContent) {
                                createdNode.appendChild(targetNode);
                            }

                            targetNode = sibling;
                        }
                    }

                    // If we had an element we wanted to append at the end, do that now
                    if (appendLast) {
                        createdNode.appendChild(appendLast);
                    }

                    splitOnNode = currParent;
                }

                return createdNode;
            },

            moveTextRangeIntoElement: function (startNode, endNode, newElement) {
                if (!startNode || !endNode) {
                    return false;
                }

                var rootNode = Util.findCommonRoot(startNode, endNode);
                if (!rootNode) {
                    return false;
                }

                if (endNode === startNode) {
                    var temp = startNode.parentNode,
                        sibling = startNode.nextSibling;
                    temp.removeChild(startNode);
                    newElement.appendChild(startNode);
                    if (sibling) {
                        temp.insertBefore(newElement, sibling);
                    } else {
                        temp.appendChild(newElement);
                    }
                    return newElement.hasChildNodes();
                }

                // create rootChildren array which includes all the children
                // we care about
                var rootChildren = [],
                    firstChild,
                    lastChild,
                    nextNode;
                for (var i = 0; i < rootNode.childNodes.length; i++) {
                    nextNode = rootNode.childNodes[i];
                    if (!firstChild) {
                        if (Util.isDescendant(nextNode, startNode, true)) {
                            firstChild = nextNode;
                        }
                    } else {
                        if (Util.isDescendant(nextNode, endNode, true)) {
                            lastChild = nextNode;
                            break;
                        } else {
                            rootChildren.push(nextNode);
                        }
                    }
                }

                var afterLast = lastChild.nextSibling,
                    fragment = rootNode.ownerDocument.createDocumentFragment();

                // build up fragment on startNode side of tree
                if (firstChild === startNode) {
                    firstChild.parentNode.removeChild(firstChild);
                    fragment.appendChild(firstChild);
                } else {
                    fragment.appendChild(Util.splitOffDOMTree(firstChild, startNode));
                }

                // add any elements between firstChild & lastChild
                rootChildren.forEach(function (element) {
                    element.parentNode.removeChild(element);
                    fragment.appendChild(element);
                });

                // build up fragment on endNode side of the tree
                if (lastChild === endNode) {
                    lastChild.parentNode.removeChild(lastChild);
                    fragment.appendChild(lastChild);
                } else {
                    fragment.appendChild(Util.splitOffDOMTree(lastChild, endNode, true));
                }

                // Add fragment into passed in element
                newElement.appendChild(fragment);

                if (lastChild.parentNode === rootNode) {
                    // If last child is in the root, insert newElement in front of it
                    rootNode.insertBefore(newElement, lastChild);
                } else if (afterLast) {
                    // If last child was removed, but it had a sibling, insert in front of it
                    rootNode.insertBefore(newElement, afterLast);
                } else {
                    // lastChild was removed and was the last actual element just append
                    rootNode.appendChild(newElement);
                }

                return newElement.hasChildNodes();
            },

            /* based on http://stackoverflow.com/a/6183069 */
            depthOfNode: function (inNode) {
                var theDepth = 0,
                    node = inNode;
                while (node.parentNode !== null) {
                    node = node.parentNode;
                    theDepth++;
                }
                return theDepth;
            },

            findCommonRoot: function (inNode1, inNode2) {
                var depth1 = Util.depthOfNode(inNode1),
                    depth2 = Util.depthOfNode(inNode2),
                    node1 = inNode1,
                    node2 = inNode2;

                while (depth1 !== depth2) {
                    if (depth1 > depth2) {
                        node1 = node1.parentNode;
                        depth1 -= 1;
                    } else {
                        node2 = node2.parentNode;
                        depth2 -= 1;
                    }
                }

                while (node1 !== node2) {
                    node1 = node1.parentNode;
                    node2 = node2.parentNode;
                }

                return node1;
            },
            /* END - based on http://stackoverflow.com/a/6183069 */

            isElementAtBeginningOfBlock: function (node) {
                var textVal,
                    sibling;
                while (!Util.isBlockContainer(node) && !Util.isMediumEditorElement(node)) {
                    sibling = node;
                    while (sibling = sibling.previousSibling) {
                        textVal = sibling.nodeType === 3 ? sibling.nodeValue : sibling.textContent;
                        if (textVal.length > 0) {
                            return false;
                        }
                    }
                    node = node.parentNode;
                }
                return true;
            },

            isMediumEditorElement: function (element) {
                return element && element.getAttribute && !!element.getAttribute('data-medium-editor-element');
            },

            getContainerEditorElement: function (element) {
                return Util.traverseUp(element, function (node) {
                    return Util.isMediumEditorElement(node);
                });
            },

            isBlockContainer: function (element) {
                return element && element.nodeType !== 3 && Util.blockContainerElementNames.indexOf(element.nodeName.toLowerCase()) !== -1;
            },

            /* Finds the closest ancestor which is a block container element
             * If element is within editor element but not within any other block element,
             * the editor element is returned
             */
            getClosestBlockContainer: function (node) {
                return Util.traverseUp(node, function (node) {
                    return Util.isBlockContainer(node) || Util.isMediumEditorElement(node);
                });
            },

            /* Finds highest level ancestor element which is a block container element
             * If element is within editor element but not within any other block element,
             * the editor element is returned
             */
            getTopBlockContainer: function (element) {
                var topBlock = Util.isBlockContainer(element) ? element : false;
                Util.traverseUp(element, function (el) {
                    if (Util.isBlockContainer(el)) {
                        topBlock = el;
                    }
                    if (!topBlock && Util.isMediumEditorElement(el)) {
                        topBlock = el;
                        return true;
                    }
                    return false;
                });
                return topBlock;
            },

            getFirstSelectableLeafNode: function (element) {
                while (element && element.firstChild) {
                    element = element.firstChild;
                }

                // We don't want to set the selection to an element that can't have children, this messes up Gecko.
                element = Util.traverseUp(element, function (el) {
                    return Util.emptyElementNames.indexOf(el.nodeName.toLowerCase()) === -1;
                });
                // Selecting at the beginning of a table doesn't work in PhantomJS.
                if (element.nodeName.toLowerCase() === 'table') {
                    var firstCell = element.querySelector('th, td');
                    if (firstCell) {
                        element = firstCell;
                    }
                }
                return element;
            },

            // TODO: remove getFirstTextNode AND _getFirstTextNode when jumping in 6.0.0 (no code references)
            getFirstTextNode: function (element) {
                Util.warn('getFirstTextNode is deprecated and will be removed in version 6.0.0');
                return Util._getFirstTextNode(element);
            },

            _getFirstTextNode: function (element) {
                if (element.nodeType === 3) {
                    return element;
                }

                for (var i = 0; i < element.childNodes.length; i++) {
                    var textNode = Util._getFirstTextNode(element.childNodes[i]);
                    if (textNode !== null) {
                        return textNode;
                    }
                }
                return null;
            },

            ensureUrlHasProtocol: function (url) {
                if (url.indexOf('://') === -1) {
                    return 'http://' + url;
                }
                return url;
            },

            warn: function () {
                if (window.console !== undefined && typeof window.console.warn === 'function') {
                    window.console.warn.apply(window.console, arguments);
                }
            },

            deprecated: function (oldName, newName, version) {
                // simple deprecation warning mechanism.
                var m = oldName + ' is deprecated, please use ' + newName + ' instead.';
                if (version) {
                    m += ' Will be removed in ' + version;
                }
                Util.warn(m);
            },

            deprecatedMethod: function (oldName, newName, args, version) {
                // run the replacement and warn when someone calls a deprecated method
                Util.deprecated(oldName, newName, version);
                if (typeof this[newName] === 'function') {
                    this[newName].apply(this, args);
                }
            },

            cleanupAttrs: function (el, attrs) {
                attrs.forEach(function (attr) {
                    el.removeAttribute(attr);
                });
            },

            cleanupTags: function (el, tags) {
                if (tags.indexOf(el.nodeName.toLowerCase()) !== -1) {
                    el.parentNode.removeChild(el);
                }
            },

            unwrapTags: function (el, tags) {
                if (tags.indexOf(el.nodeName.toLowerCase()) !== -1) {
                    MediumEditor.util.unwrap(el, document);
                }
            },

            // get the closest parent
            getClosestTag: function (el, tag) {
                return Util.traverseUp(el, function (element) {
                    return element.nodeName.toLowerCase() === tag.toLowerCase();
                });
            },

            unwrap: function (el, doc) {
                var fragment = doc.createDocumentFragment(),
                    nodes = Array.prototype.slice.call(el.childNodes);

                // cast nodeList to array since appending child
                // to a different node will alter length of el.childNodes
                for (var i = 0; i < nodes.length; i++) {
                    fragment.appendChild(nodes[i]);
                }

                if (fragment.childNodes.length) {
                    el.parentNode.replaceChild(fragment, el);
                } else {
                    el.parentNode.removeChild(el);
                }
            },

            guid: function () {
                function _s4() {
                    return Math
                        .floor((1 + Math.random()) * 0x10000)
                        .toString(16)
                        .substring(1);
                }

                return _s4() + _s4() + '-' + _s4() + '-' + _s4() + '-' + _s4() + '-' + _s4() + _s4() + _s4();
            }
        };

        MediumEditor.util = Util;
    }(window));

    (function () {
        'use strict';

        var Extension = function (options) {
            MediumEditor.util.extend(this, options);
        };

        Extension.extend = function (protoProps) {
            // magic extender thinger. mostly borrowed from backbone/goog.inherits
            // place this function on some thing you want extend-able.
            //
            // example:
            //
            //      function Thing(args){
            //          this.options = args;
            //      }
            //
            //      Thing.prototype = { foo: "bar" };
            //      Thing.extend = extenderify;
            //
            //      var ThingTwo = Thing.extend({ foo: "baz" });
            //
            //      var thingOne = new Thing(); // foo === "bar"
            //      var thingTwo = new ThingTwo(); // foo === "baz"
            //
            //      which seems like some simply shallow copy nonsense
            //      at first, but a lot more is going on there.
            //
            //      passing a `constructor` to the extend props
            //      will cause the instance to instantiate through that
            //      instead of the parent's constructor.

            var parent = this,
                child;

            // The constructor function for the new subclass is either defined by you
            // (the "constructor" property in your `extend` definition), or defaulted
            // by us to simply call the parent's constructor.

            if (protoProps && protoProps.hasOwnProperty('constructor')) {
                child = protoProps.constructor;
            } else {
                child = function () {
                    return parent.apply(this, arguments);
                };
            }

            // das statics (.extend comes over, so your subclass can have subclasses too)
            MediumEditor.util.extend(child, parent);

            // Set the prototype chain to inherit from `parent`, without calling
            // `parent`'s constructor function.
            var Surrogate = function () {
                this.constructor = child;
            };
            Surrogate.prototype = parent.prototype;
            child.prototype = new Surrogate();

            if (protoProps) {
                MediumEditor.util.extend(child.prototype, protoProps);
            }

            // todo: $super?

            return child;
        };

        Extension.prototype = {
            /* init: [function]
             *
             * Called by MediumEditor during initialization.
             * The .base property will already have been set to
             * current instance of MediumEditor when this is called.
             * All helper methods will exist as well
             */
            init: function () {},

            /* base: [MediumEditor instance]
             *
             * If not overriden, this will be set to the current instance
             * of MediumEditor, before the init method is called
             */
            base: undefined,

            /* name: [string]
             *
             * 'name' of the extension, used for retrieving the extension.
             * If not set, MediumEditor will set this to be the key
             * used when passing the extension into MediumEditor via the
             * 'extensions' option
             */
            name: undefined,

            /* checkState: [function (node)]
             *
             * If implemented, this function will be called one or more times
             * the state of the editor & toolbar are updated.
             * When the state is updated, the editor does the following:
             *
             * 1) Find the parent node containing the current selection
             * 2) Call checkState on the extension, passing the node as an argument
             * 3) Get the parent node of the previous node
             * 4) Repeat steps #2 and #3 until we move outside the parent contenteditable
             */
            checkState: undefined,

            /* destroy: [function ()]
             *
             * This method should remove any created html, custom event handlers
             * or any other cleanup tasks that should be performed.
             * If implemented, this function will be called when MediumEditor's
             * destroy method has been called.
             */
            destroy: undefined,

            /* As alternatives to checkState, these functions provide a more structured
             * path to updating the state of an extension (usually a button) whenever
             * the state of the editor & toolbar are updated.
             */

            /* queryCommandState: [function ()]
             *
             * If implemented, this function will be called once on each extension
             * when the state of the editor/toolbar is being updated.
             *
             * If this function returns a non-null value, the extension will
             * be ignored as the code climbs the dom tree.
             *
             * If this function returns true, and the setActive() function is defined
             * setActive() will be called
             */
            queryCommandState: undefined,

            /* isActive: [function ()]
             *
             * If implemented, this function will be called when MediumEditor
             * has determined that this extension is 'active' for the current selection.
             * This may be called when the editor & toolbar are being updated,
             * but only if queryCommandState() or isAlreadyApplied() functions
             * are implemented, and when called, return true.
             */
            isActive: undefined,

            /* isAlreadyApplied: [function (node)]
             *
             * If implemented, this function is similar to checkState() in
             * that it will be called repeatedly as MediumEditor moves up
             * the DOM to update the editor & toolbar after a state change.
             *
             * NOTE: This function will NOT be called if checkState() has
             * been implemented. This function will NOT be called if
             * queryCommandState() is implemented and returns a non-null
             * value when called
             */
            isAlreadyApplied: undefined,

            /* setActive: [function ()]
             *
             * If implemented, this function is called when MediumEditor knows
             * that this extension is currently enabled.  Currently, this
             * function is called when updating the editor & toolbar, and
             * only if queryCommandState() or isAlreadyApplied(node) return
             * true when called
             */
            setActive: undefined,

            /* setInactive: [function ()]
             *
             * If implemented, this function is called when MediumEditor knows
             * that this extension is currently disabled.  Curently, this
             * is called at the beginning of each state change for
             * the editor & toolbar. After calling this, MediumEditor
             * will attempt to update the extension, either via checkState()
             * or the combination of queryCommandState(), isAlreadyApplied(node),
             * isActive(), and setActive()
             */
            setInactive: undefined,

            /* getInteractionElements: [function ()]
             *
             * If the extension renders any elements that the user can interact with,
             * this method should be implemented and return the root element or an array
             * containing all of the root elements. MediumEditor will call this function
             * during interaction to see if the user clicked on something outside of the editor.
             * The elements are used to check if the target element of a click or
             * other user event is a descendant of any extension elements.
             * This way, the editor can also count user interaction within editor elements as
             * interactions with the editor, and thus not trigger 'blur'
             */
            getInteractionElements: undefined,

            /************************ Helpers ************************
             * The following are helpers that are either set by MediumEditor
             * during initialization, or are helper methods which either
             * route calls to the MediumEditor instance or provide common
             * functionality for all extensions
             *********************************************************/

            /* window: [Window]
             *
             * If not overriden, this will be set to the window object
             * to be used by MediumEditor and its extensions.  This is
             * passed via the 'contentWindow' option to MediumEditor
             * and is the global 'window' object by default
             */
            'window': undefined,

            /* document: [Document]
             *
             * If not overriden, this will be set to the document object
             * to be used by MediumEditor and its extensions. This is
             * passed via the 'ownerDocument' optin to MediumEditor
             * and is the global 'document' object by default
             */
            'document': undefined,

            /* getEditorElements: [function ()]
             *
             * Helper function which returns an array containing
             * all the contenteditable elements for this instance
             * of MediumEditor
             */
            getEditorElements: function () {
                return this.base.elements;
            },

            /* getEditorId: [function ()]
             *
             * Helper function which returns a unique identifier
             * for this instance of MediumEditor
             */
            getEditorId: function () {
                return this.base.id;
            },

            /* getEditorOptions: [function (option)]
             *
             * Helper function which returns the value of an option
             * used to initialize this instance of MediumEditor
             */
            getEditorOption: function (option) {
                return this.base.options[option];
            }
        };

        /* List of method names to add to the prototype of Extension
         * Each of these methods will be defined as helpers that
         * just call directly into the MediumEditor instance.
         *
         * example for 'on' method:
         * Extension.prototype.on = function () {
         *     return this.base.on.apply(this.base, arguments);
         * }
         */
        [
            // general helpers
            'execAction',

            // event handling
            'on',
            'off',
            'subscribe',
            'trigger'

        ].forEach(function (helper) {
            Extension.prototype[helper] = function () {
                return this.base[helper].apply(this.base, arguments);
            };
        });

        MediumEditor.Extension = Extension;
    })();

    (function () {
        'use strict';

        function filterOnlyParentElements(node) {
            if (MediumEditor.util.isBlockContainer(node)) {
                return NodeFilter.FILTER_ACCEPT;
            } else {
                return NodeFilter.FILTER_SKIP;
            }
        }

        var Selection = {
            findMatchingSelectionParent: function (testElementFunction, contentWindow) {
                var selection = contentWindow.getSelection(),
                    range,
                    current;

                if (selection.rangeCount === 0) {
                    return false;
                }

                range = selection.getRangeAt(0);
                current = range.commonAncestorContainer;

                return MediumEditor.util.traverseUp(current, testElementFunction);
            },

            getSelectionElement: function (contentWindow) {
                return this.findMatchingSelectionParent(function (el) {
                    return MediumEditor.util.isMediumEditorElement(el);
                }, contentWindow);
            },

            // http://stackoverflow.com/questions/17678843/cant-restore-selection-after-html-modify-even-if-its-the-same-html
            // Tim Down
            exportSelection: function (root, doc) {
                if (!root) {
                    return null;
                }

                var selectionState = null,
                    selection = doc.getSelection();

                if (selection.rangeCount > 0) {
                    var range = selection.getRangeAt(0),
                        preSelectionRange = range.cloneRange(),
                        start;

                    preSelectionRange.selectNodeContents(root);
                    preSelectionRange.setEnd(range.startContainer, range.startOffset);
                    start = preSelectionRange.toString().length;

                    selectionState = {
                        start: start,
                        end: start + range.toString().length
                    };

                    // Check to see if the selection starts with any images
                    // if so we need to make sure the the beginning of the selection is
                    // set correctly when importing selection
                    if (this.doesRangeStartWithImages(range, doc)) {
                        selectionState.startsWithImage = true;
                    }

                    // Check to see if the selection has any trailing images
                    // if so, this this means we need to look for them when we import selection
                    var trailingImageCount = this.getTrailingImageCount(root, selectionState, range.endContainer, range.endOffset);
                    if (trailingImageCount) {
                        selectionState.trailingImageCount = trailingImageCount;
                    }

                    // If start = 0 there may still be an empty paragraph before it, but we don't care.
                    if (start !== 0) {
                        var emptyBlocksIndex = this.getIndexRelativeToAdjacentEmptyBlocks(doc, root, range.startContainer, range.startOffset);
                        if (emptyBlocksIndex !== -1) {
                            selectionState.emptyBlocksIndex = emptyBlocksIndex;
                        }
                    }
                }

                return selectionState;
            },

            // http://stackoverflow.com/questions/17678843/cant-restore-selection-after-html-modify-even-if-its-the-same-html
            // Tim Down
            //
            // {object} selectionState - the selection to import
            // {DOMElement} root - the root element the selection is being restored inside of
            // {Document} doc - the document to use for managing selection
            // {boolean} [favorLaterSelectionAnchor] - defaults to false. If true, import the cursor immediately
            //      subsequent to an anchor tag if it would otherwise be placed right at the trailing edge inside the
            //      anchor. This cursor positioning, even though visually equivalent to the user, can affect behavior
            //      in MS IE.
            importSelection: function (selectionState, root, doc, favorLaterSelectionAnchor) {
                if (!selectionState || !root) {
                    return;
                }

                var range = doc.createRange();
                range.setStart(root, 0);
                range.collapse(true);

                var node = root,
                    nodeStack = [],
                    charIndex = 0,
                    foundStart = false,
                    foundEnd = false,
                    trailingImageCount = 0,
                    stop = false,
                    nextCharIndex,
                    allowRangeToStartAtEndOfNode = false,
                    lastTextNode = null;

                // When importing selection, the start of the selection may lie at the end of an element
                // or at the beginning of an element.  Since visually there is no difference between these 2
                // we will try to move the selection to the beginning of an element since this is generally
                // what users will expect and it's a more predictable behavior.
                //
                // However, there are some specific cases when we don't want to do this:
                //  1) We're attempting to move the cursor outside of the end of an anchor [favorLaterSelectionAnchor = true]
                //  2) The selection starts with an image, which is special since an image doesn't have any 'content'
                //     as far as selection and ranges are concerned
                //  3) The selection starts after a specified number of empty block elements (selectionState.emptyBlocksIndex)
                //
                // For these cases, we want the selection to start at a very specific location, so we should NOT
                // automatically move the cursor to the beginning of the first actual chunk of text
                if (favorLaterSelectionAnchor || selectionState.startsWithImage || typeof selectionState.emptyBlocksIndex !== 'undefined') {
                    allowRangeToStartAtEndOfNode = true;
                }

                while (!stop && node) {
                    // Only iterate over elements and text nodes
                    if (node.nodeType > 3) {
                        node = nodeStack.pop();
                        continue;
                    }

                    // If we hit a text node, we need to add the amount of characters to the overall count
                    if (node.nodeType === 3 && !foundEnd) {
                        nextCharIndex = charIndex + node.length;
                        // Check if we're at or beyond the start of the selection we're importing
                        if (!foundStart && selectionState.start >= charIndex && selectionState.start <= nextCharIndex) {
                            // NOTE: We only want to allow a selection to start at the END of an element if
                            //  allowRangeToStartAtEndOfNode is true
                            if (allowRangeToStartAtEndOfNode || selectionState.start < nextCharIndex) {
                                range.setStart(node, selectionState.start - charIndex);
                                foundStart = true;
                            }
                            // We're at the end of a text node where the selection could start but we shouldn't
                            // make the selection start here because allowRangeToStartAtEndOfNode is false.
                            // However, we should keep a reference to this node in case there aren't any more
                            // text nodes after this, so that we have somewhere to import the selection to
                            else {
                                lastTextNode = node;
                            }
                        }
                        // We've found the start of the selection, check if we're at or beyond the end of the selection we're importing
                        if (foundStart && selectionState.end >= charIndex && selectionState.end <= nextCharIndex) {
                            if (!selectionState.trailingImageCount) {
                                range.setEnd(node, selectionState.end - charIndex);
                                stop = true;
                            } else {
                                foundEnd = true;
                            }
                        }
                        charIndex = nextCharIndex;
                    } else {
                        if (selectionState.trailingImageCount && foundEnd) {
                            if (node.nodeName.toLowerCase() === 'img') {
                                trailingImageCount++;
                            }
                            if (trailingImageCount === selectionState.trailingImageCount) {
                                // Find which index the image is in its parent's children
                                var endIndex = 0;
                                while (node.parentNode.childNodes[endIndex] !== node) {
                                    endIndex++;
                                }
                                range.setEnd(node.parentNode, endIndex + 1);
                                stop = true;
                            }
                        }

                        if (!stop && node.nodeType === 1) {
                            // this is an element
                            // add all its children to the stack
                            var i = node.childNodes.length - 1;
                            while (i >= 0) {
                                nodeStack.push(node.childNodes[i]);
                                i -= 1;
                            }
                        }
                    }

                    if (!stop) {
                        node = nodeStack.pop();
                    }
                }

                // If we've gone through the entire text but didn't find the beginning of a text node
                // to make the selection start at, we should fall back to starting the selection
                // at the END of the last text node we found
                if (!foundStart && lastTextNode) {
                    range.setStart(lastTextNode, lastTextNode.length);
                    range.setEnd(lastTextNode, lastTextNode.length);
                }

                if (typeof selectionState.emptyBlocksIndex !== 'undefined') {
                    range = this.importSelectionMoveCursorPastBlocks(doc, root, selectionState.emptyBlocksIndex, range);
                }

                // If the selection is right at the ending edge of a link, put it outside the anchor tag instead of inside.
                if (favorLaterSelectionAnchor) {
                    range = this.importSelectionMoveCursorPastAnchor(selectionState, range);
                }

                this.selectRange(doc, range);
            },

            // Utility method called from importSelection only
            importSelectionMoveCursorPastAnchor: function (selectionState, range) {
                var nodeInsideAnchorTagFunction = function (node) {
                    return node.nodeName.toLowerCase() === 'a';
                };
                if (selectionState.start === selectionState.end &&
                    range.startContainer.nodeType === 3 &&
                    range.startOffset === range.startContainer.nodeValue.length &&
                    MediumEditor.util.traverseUp(range.startContainer, nodeInsideAnchorTagFunction)) {
                    var prevNode = range.startContainer,
                        currentNode = range.startContainer.parentNode;
                    while (currentNode !== null && currentNode.nodeName.toLowerCase() !== 'a') {
                        if (currentNode.childNodes[currentNode.childNodes.length - 1] !== prevNode) {
                            currentNode = null;
                        } else {
                            prevNode = currentNode;
                            currentNode = currentNode.parentNode;
                        }
                    }
                    if (currentNode !== null && currentNode.nodeName.toLowerCase() === 'a') {
                        var currentNodeIndex = null;
                        for (var i = 0; currentNodeIndex === null && i < currentNode.parentNode.childNodes.length; i++) {
                            if (currentNode.parentNode.childNodes[i] === currentNode) {
                                currentNodeIndex = i;
                            }
                        }
                        range.setStart(currentNode.parentNode, currentNodeIndex + 1);
                        range.collapse(true);
                    }
                }
                return range;
            },

            // Uses the emptyBlocksIndex calculated by getIndexRelativeToAdjacentEmptyBlocks
            // to move the cursor back to the start of the correct paragraph
            importSelectionMoveCursorPastBlocks: function (doc, root, index, range) {
                var treeWalker = doc.createTreeWalker(root, NodeFilter.SHOW_ELEMENT, filterOnlyParentElements, false),
                    startContainer = range.startContainer,
                    startBlock,
                    targetNode,
                    currIndex = 0;
                index = index || 1; // If index is 0, we still want to move to the next block

                // Chrome counts newlines and spaces that separate block elements as actual elements.
                // If the selection is inside one of these text nodes, and it has a previous sibling
                // which is a block element, we want the treewalker to start at the previous sibling
                // and NOT at the parent of the textnode
                if (startContainer.nodeType === 3 && MediumEditor.util.isBlockContainer(startContainer.previousSibling)) {
                    startBlock = startContainer.previousSibling;
                } else {
                    startBlock = MediumEditor.util.getClosestBlockContainer(startContainer);
                }

                // Skip over empty blocks until we hit the block we want the selection to be in
                while (treeWalker.nextNode()) {
                    if (!targetNode) {
                        // Loop through all blocks until we hit the starting block element
                        if (startBlock === treeWalker.currentNode) {
                            targetNode = treeWalker.currentNode;
                        }
                    } else {
                        targetNode = treeWalker.currentNode;
                        currIndex++;
                        // We hit the target index, bail
                        if (currIndex === index) {
                            break;
                        }
                        // If we find a non-empty block, ignore the emptyBlocksIndex and just put selection here
                        if (targetNode.textContent.length > 0) {
                            break;
                        }
                    }
                }

                if (!targetNode) {
                    targetNode = startBlock;
                }

                // We're selecting a high-level block node, so make sure the cursor gets moved into the deepest
                // element at the beginning of the block
                range.setStart(MediumEditor.util.getFirstSelectableLeafNode(targetNode), 0);

                return range;
            },

            // Returns -1 unless the cursor is at the beginning of a paragraph/block
            // If the paragraph/block is preceeded by empty paragraphs/block (with no text)
            // it will return the number of empty paragraphs before the cursor.
            // Otherwise, it will return 0, which indicates the cursor is at the beginning
            // of a paragraph/block, and not at the end of the paragraph/block before it
            getIndexRelativeToAdjacentEmptyBlocks: function (doc, root, cursorContainer, cursorOffset) {
                // If there is text in front of the cursor, that means there isn't only empty blocks before it
                if (cursorContainer.textContent.length > 0 && cursorOffset > 0) {
                    return -1;
                }

                // Check if the block that contains the cursor has any other text in front of the cursor
                var node = cursorContainer;
                if (node.nodeType !== 3) {
                    node = cursorContainer.childNodes[cursorOffset];
                }
                if (node) {
                    // The element isn't at the beginning of a block, so it has content before it
                    if (!MediumEditor.util.isElementAtBeginningOfBlock(node)) {
                        return -1;
                    }

                    var previousSibling = MediumEditor.util.findPreviousSibling(node);
                    // If there is no previous sibling, this is the first text element in the editor
                    if (!previousSibling) {
                        return -1;
                    }
                    // If the previous sibling has text, then there are no empty blocks before this
                    else if (previousSibling.nodeValue) {
                        return -1;
                    }
                }

                // Walk over block elements, counting number of empty blocks between last piece of text
                // and the block the cursor is in
                var closestBlock = MediumEditor.util.getClosestBlockContainer(cursorContainer),
                    treeWalker = doc.createTreeWalker(root, NodeFilter.SHOW_ELEMENT, filterOnlyParentElements, false),
                    emptyBlocksCount = 0;
                while (treeWalker.nextNode()) {
                    var blockIsEmpty = treeWalker.currentNode.textContent === '';
                    if (blockIsEmpty || emptyBlocksCount > 0) {
                        emptyBlocksCount += 1;
                    }
                    if (treeWalker.currentNode === closestBlock) {
                        return emptyBlocksCount;
                    }
                    if (!blockIsEmpty) {
                        emptyBlocksCount = 0;
                    }
                }

                return emptyBlocksCount;
            },

            // Returns true if the selection range begins with an image tag
            // Returns false if the range starts with any non empty text nodes
            doesRangeStartWithImages: function (range, doc) {
                if (range.startOffset !== 0 || range.startContainer.nodeType !== 1) {
                    return false;
                }

                if (range.startContainer.nodeName.toLowerCase() === 'img') {
                    return true;
                }

                var img = range.startContainer.querySelector('img');
                if (!img) {
                    return false;
                }

                var treeWalker = doc.createTreeWalker(range.startContainer, NodeFilter.SHOW_ALL, null, false);
                while (treeWalker.nextNode()) {
                    var next = treeWalker.currentNode;
                    // If we hit the image, then there isn't any text before the image so
                    // the image is at the beginning of the range
                    if (next === img) {
                        break;
                    }
                    // If we haven't hit the iamge, but found text that contains content
                    // then the range doesn't start with an image
                    if (next.nodeValue) {
                        return false;
                    }
                }

                return true;
            },

            getTrailingImageCount: function (root, selectionState, endContainer, endOffset) {
                // If the endOffset of a range is 0, the endContainer doesn't contain images
                // If the endContainer is a text node, there are no trailing images
                if (endOffset === 0 || endContainer.nodeType !== 1) {
                    return 0;
                }

                // If the endContainer isn't an image, and doesn't have an image descendants
                // there are no trailing images
                if (endContainer.nodeName.toLowerCase() !== 'img' && !endContainer.querySelector('img')) {
                    return 0;
                }

                var lastNode = endContainer.childNodes[endOffset - 1];
                while (lastNode.hasChildNodes()) {
                    lastNode = lastNode.lastChild;
                }

                var node = root,
                    nodeStack = [],
                    charIndex = 0,
                    foundStart = false,
                    foundEnd = false,
                    stop = false,
                    nextCharIndex,
                    trailingImages = 0;

                while (!stop && node) {
                    // Only iterate over elements and text nodes
                    if (node.nodeType > 3) {
                        node = nodeStack.pop();
                        continue;
                    }

                    if (node.nodeType === 3 && !foundEnd) {
                        trailingImages = 0;
                        nextCharIndex = charIndex + node.length;
                        if (!foundStart && selectionState.start >= charIndex && selectionState.start <= nextCharIndex) {
                            foundStart = true;
                        }
                        if (foundStart && selectionState.end >= charIndex && selectionState.end <= nextCharIndex) {
                            foundEnd = true;
                        }
                        charIndex = nextCharIndex;
                    } else {
                        if (node.nodeName.toLowerCase() === 'img') {
                            trailingImages++;
                        }

                        if (node === lastNode) {
                            stop = true;
                        } else if (node.nodeType === 1) {
                            // this is an element
                            // add all its children to the stack
                            var i = node.childNodes.length - 1;
                            while (i >= 0) {
                                nodeStack.push(node.childNodes[i]);
                                i -= 1;
                            }
                        }
                    }

                    if (!stop) {
                        node = nodeStack.pop();
                    }
                }

                return trailingImages;
            },

            // determine if the current selection contains any 'content'
            // content being any non-white space text or an image
            selectionContainsContent: function (doc) {
                var sel = doc.getSelection();

                // collapsed selection or selection withour range doesn't contain content
                if (!sel || sel.isCollapsed || !sel.rangeCount) {
                    return false;
                }

                // if toString() contains any text, the selection contains some content
                if (sel.toString().trim() !== '') {
                    return true;
                }

                // if selection contains only image(s), it will return empty for toString()
                // so check for an image manually
                var selectionNode = this.getSelectedParentElement(sel.getRangeAt(0));
                if (selectionNode) {
                    if (selectionNode.nodeName.toLowerCase() === 'img' ||
                        (selectionNode.nodeType === 1 && selectionNode.querySelector('img'))) {
                        return true;
                    }
                }

                return false;
            },

            selectionInContentEditableFalse: function (contentWindow) {
                // determine if the current selection is exclusively inside
                // a contenteditable="false", though treat the case of an
                // explicit contenteditable="true" inside a "false" as false.
                var sawtrue,
                    sawfalse = this.findMatchingSelectionParent(function (el) {
                        var ce = el && el.getAttribute('contenteditable');
                        if (ce === 'true') {
                            sawtrue = true;
                        }
                        return el.nodeName !== '#text' && ce === 'false';
                    }, contentWindow);

                return !sawtrue && sawfalse;
            },

            // http://stackoverflow.com/questions/4176923/html-of-selected-text
            // by Tim Down
            getSelectionHtml: function getSelectionHtml(doc) {
                var i,
                    html = '',
                    sel = doc.getSelection(),
                    len,
                    container;
                if (sel.rangeCount) {
                    container = doc.createElement('div');
                    for (i = 0, len = sel.rangeCount; i < len; i += 1) {
                        container.appendChild(sel.getRangeAt(i).cloneContents());
                    }
                    html = container.innerHTML;
                }
                return html;
            },

            /**
             *  Find the caret position within an element irrespective of any inline tags it may contain.
             *
             *  @param {DOMElement} An element containing the cursor to find offsets relative to.
             *  @param {Range} A Range representing cursor position. Will window.getSelection if none is passed.
             *  @return {Object} 'left' and 'right' attributes contain offsets from begining and end of Element
             */
            getCaretOffsets: function getCaretOffsets(element, range) {
                var preCaretRange, postCaretRange;

                if (!range) {
                    range = window.getSelection().getRangeAt(0);
                }

                preCaretRange = range.cloneRange();
                postCaretRange = range.cloneRange();

                preCaretRange.selectNodeContents(element);
                preCaretRange.setEnd(range.endContainer, range.endOffset);

                postCaretRange.selectNodeContents(element);
                postCaretRange.setStart(range.endContainer, range.endOffset);

                return {
                    left: preCaretRange.toString().length,
                    right: postCaretRange.toString().length
                };
            },

            // http://stackoverflow.com/questions/15867542/range-object-get-selection-parent-node-chrome-vs-firefox
            rangeSelectsSingleNode: function (range) {
                var startNode = range.startContainer;
                return startNode === range.endContainer &&
                    startNode.hasChildNodes() &&
                    range.endOffset === range.startOffset + 1;
            },

            getSelectedParentElement: function (range) {
                if (!range) {
                    return null;
                }

                // Selection encompasses a single element
                if (this.rangeSelectsSingleNode(range) && range.startContainer.childNodes[range.startOffset].nodeType !== 3) {
                    return range.startContainer.childNodes[range.startOffset];
                }

                // Selection range starts inside a text node, so get its parent
                if (range.startContainer.nodeType === 3) {
                    return range.startContainer.parentNode;
                }

                // Selection starts inside an element
                return range.startContainer;
            },

            getSelectedElements: function (doc) {
                var selection = doc.getSelection(),
                    range,
                    toRet,
                    currNode;

                if (!selection.rangeCount || selection.isCollapsed || !selection.getRangeAt(0).commonAncestorContainer) {
                    return [];
                }

                range = selection.getRangeAt(0);

                if (range.commonAncestorContainer.nodeType === 3) {
                    toRet = [];
                    currNode = range.commonAncestorContainer;
                    while (currNode.parentNode && currNode.parentNode.childNodes.length === 1) {
                        toRet.push(currNode.parentNode);
                        currNode = currNode.parentNode;
                    }

                    return toRet;
                }

                return [].filter.call(range.commonAncestorContainer.getElementsByTagName('*'), function (el) {
                    return (typeof selection.containsNode === 'function') ? selection.containsNode(el, true) : true;
                });
            },

            selectNode: function (node, doc) {
                var range = doc.createRange();
                range.selectNodeContents(node);
                this.selectRange(doc, range);
            },

            select: function (doc, startNode, startOffset, endNode, endOffset) {
                var range = doc.createRange();
                range.setStart(startNode, startOffset);
                if (endNode) {
                    range.setEnd(endNode, endOffset);
                } else {
                    range.collapse(true);
                }
                this.selectRange(doc, range);
                return range;
            },

            /**
             *  Clear the current highlighted selection and set the caret to the start or the end of that prior selection, defaults to end.
             *
             *  @param {DomDocument} doc            Current document
             *  @param {boolean} moveCursorToStart  A boolean representing whether or not to set the caret to the beginning of the prior selection.
             */
            clearSelection: function (doc, moveCursorToStart) {
                if (moveCursorToStart) {
                    doc.getSelection().collapseToStart();
                } else {
                    doc.getSelection().collapseToEnd();
                }
            },

            /**
             * Move cursor to the given node with the given offset.
             *
             * @param  {DomDocument} doc     Current document
             * @param  {DomElement}  node    Element where to jump
             * @param  {integer}     offset  Where in the element should we jump, 0 by default
             */
            moveCursor: function (doc, node, offset) {
                this.select(doc, node, offset);
            },

            getSelectionRange: function (ownerDocument) {
                var selection = ownerDocument.getSelection();
                if (selection.rangeCount === 0) {
                    return null;
                }
                return selection.getRangeAt(0);
            },

            selectRange: function (ownerDocument, range) {
                var selection = ownerDocument.getSelection();

                selection.removeAllRanges();
                selection.addRange(range);
            },

            // http://stackoverflow.com/questions/1197401/how-can-i-get-the-element-the-caret-is-in-with-javascript-when-using-contentedi
            // by You
            getSelectionStart: function (ownerDocument) {
                var node = ownerDocument.getSelection().anchorNode,
                    startNode = (node && node.nodeType === 3 ? node.parentNode : node);

                return startNode;
            }
        };

        MediumEditor.selection = Selection;
    }());

    (function () {
        'use strict';

        function isElementDescendantOfExtension(extensions, element) {
            return extensions.some(function (extension) {
                if (typeof extension.getInteractionElements !== 'function') {
                    return false;
                }

                var extensionElements = extension.getInteractionElements();
                if (!extensionElements) {
                    return false;
                }

                if (!Array.isArray(extensionElements)) {
                    extensionElements = [extensionElements];
                }
                return extensionElements.some(function (el) {
                    return MediumEditor.util.isDescendant(el, element, true);
                });
            });
        }

        var Events = function (instance) {
            this.base = instance;
            this.options = this.base.options;
            this.events = [];
            this.disabledEvents = {};
            this.customEvents = {};
            this.listeners = {};
        };

        Events.prototype = {
            InputEventOnContenteditableSupported: !MediumEditor.util.isIE && !MediumEditor.util.isEdge,

            // Helpers for event handling

            attachDOMEvent: function (targets, event, listener, useCapture) {
                var win = this.base.options.contentWindow,
                    doc = this.base.options.ownerDocument;

                targets = MediumEditor.util.isElement(targets) || [win, doc].indexOf(targets) > -1 ? [targets] : targets;

                Array.prototype.forEach.call(targets, function (target) {
                    target.addEventListener(event, listener, useCapture);
                    this.events.push([target, event, listener, useCapture]);
                }.bind(this));
            },

            detachDOMEvent: function (targets, event, listener, useCapture) {
                var index, e,
                    win = this.base.options.contentWindow,
                    doc = this.base.options.ownerDocument;

                if (targets !== null) {
                    targets = MediumEditor.util.isElement(targets) || [win, doc].indexOf(targets) > -1 ? [targets] : targets;

                    Array.prototype.forEach.call(targets, function (target) {
                        index = this.indexOfListener(target, event, listener, useCapture);
                        if (index !== -1) {
                            e = this.events.splice(index, 1)[0];
                            e[0].removeEventListener(e[1], e[2], e[3]);
                        }
                    }.bind(this));
                }
            },

            indexOfListener: function (target, event, listener, useCapture) {
                var i, n, item;
                for (i = 0, n = this.events.length; i < n; i = i + 1) {
                    item = this.events[i];
                    if (item[0] === target && item[1] === event && item[2] === listener && item[3] === useCapture) {
                        return i;
                    }
                }
                return -1;
            },

            detachAllDOMEvents: function () {
                var e = this.events.pop();
                while (e) {
                    e[0].removeEventListener(e[1], e[2], e[3]);
                    e = this.events.pop();
                }
            },

            detachAllEventsFromElement: function (element) {
                var filtered = this.events.filter(function (e) {
                    return e && e[0].getAttribute && e[0].getAttribute('medium-editor-index') === element.getAttribute('medium-editor-index');
                });

                for (var i = 0, len = filtered.length; i < len; i++) {
                    var e = filtered[i];
                    this.detachDOMEvent(e[0], e[1], e[2], e[3]);
                }
            },

            // Attach all existing handlers to a new element
            attachAllEventsToElement: function (element) {
                if (this.listeners['editableInput']) {
                    this.contentCache[element.getAttribute('medium-editor-index')] = element.innerHTML;
                }

                if (this.eventsCache) {
                    this.eventsCache.forEach(function (e) {
                        this.attachDOMEvent(element, e['name'], e['handler'].bind(this));
                    }, this);
                }
            },

            enableCustomEvent: function (event) {
                if (this.disabledEvents[event] !== undefined) {
                    delete this.disabledEvents[event];
                }
            },

            disableCustomEvent: function (event) {
                this.disabledEvents[event] = true;
            },

            // custom events
            attachCustomEvent: function (event, listener) {
                this.setupListener(event);
                if (!this.customEvents[event]) {
                    this.customEvents[event] = [];
                }
                this.customEvents[event].push(listener);
            },

            detachCustomEvent: function (event, listener) {
                var index = this.indexOfCustomListener(event, listener);
                if (index !== -1) {
                    this.customEvents[event].splice(index, 1);
                    // TODO: If array is empty, should detach internal listeners via destroyListener()
                }
            },

            indexOfCustomListener: function (event, listener) {
                if (!this.customEvents[event] || !this.customEvents[event].length) {
                    return -1;
                }

                return this.customEvents[event].indexOf(listener);
            },

            detachAllCustomEvents: function () {
                this.customEvents = {};
                // TODO: Should detach internal listeners here via destroyListener()
            },

            triggerCustomEvent: function (name, data, editable) {
                if (this.customEvents[name] && !this.disabledEvents[name]) {
                    this.customEvents[name].forEach(function (listener) {
                        listener(data, editable);
                    });
                }
            },

            // Cleaning up

            destroy: function () {
                this.detachAllDOMEvents();
                this.detachAllCustomEvents();
                this.detachExecCommand();

                if (this.base.elements) {
                    this.base.elements.forEach(function (element) {
                        element.removeAttribute('data-medium-focused');
                    });
                }
            },

            // Listening to calls to document.execCommand

            // Attach a listener to be notified when document.execCommand is called
            attachToExecCommand: function () {
                if (this.execCommandListener) {
                    return;
                }

                // Store an instance of the listener so:
                // 1) We only attach to execCommand once
                // 2) We can remove the listener later
                this.execCommandListener = function (execInfo) {
                    this.handleDocumentExecCommand(execInfo);
                }.bind(this);

                // Ensure that execCommand has been wrapped correctly
                this.wrapExecCommand();

                // Add listener to list of execCommand listeners
                this.options.ownerDocument.execCommand.listeners.push(this.execCommandListener);
            },

            // Remove our listener for calls to document.execCommand
            detachExecCommand: function () {
                var doc = this.options.ownerDocument;
                if (!this.execCommandListener || !doc.execCommand.listeners) {
                    return;
                }

                // Find the index of this listener in the array of listeners so it can be removed
                var index = doc.execCommand.listeners.indexOf(this.execCommandListener);
                if (index !== -1) {
                    doc.execCommand.listeners.splice(index, 1);
                }

                // If the list of listeners is now empty, put execCommand back to its original state
                if (!doc.execCommand.listeners.length) {
                    this.unwrapExecCommand();
                }
            },

            // Wrap document.execCommand in a custom method so we can listen to calls to it
            wrapExecCommand: function () {
                var doc = this.options.ownerDocument;

                // Ensure all instance of MediumEditor only wrap execCommand once
                if (doc.execCommand.listeners) {
                    return;
                }

                // Helper method to call all listeners to execCommand
                var callListeners = function (args, result) {
                        if (doc.execCommand.listeners) {
                            doc.execCommand.listeners.forEach(function (listener) {
                                listener({
                                    command: args[0],
                                    value: args[2],
                                    args: args,
                                    result: result
                                });
                            });
                        }
                    },

                    // Create a wrapper method for execCommand which will:
                    // 1) Call document.execCommand with the correct arguments
                    // 2) Loop through any listeners and notify them that execCommand was called
                    //    passing extra info on the call
                    // 3) Return the result
                    wrapper = function () {
                        var result = doc.execCommand.orig.apply(this, arguments);

                        if (!doc.execCommand.listeners) {
                            return result;
                        }

                        var args = Array.prototype.slice.call(arguments);
                        callListeners(args, result);

                        return result;
                    };

                // Store a reference to the original execCommand
                wrapper.orig = doc.execCommand;

                // Attach an array for storing listeners
                wrapper.listeners = [];

                // Helper for notifying listeners
                wrapper.callListeners = callListeners;

                // Overwrite execCommand
                doc.execCommand = wrapper;
            },

            // Revert document.execCommand back to its original self
            unwrapExecCommand: function () {
                var doc = this.options.ownerDocument;
                if (!doc.execCommand.orig) {
                    return;
                }

                // Use the reference to the original execCommand to revert back
                doc.execCommand = doc.execCommand.orig;
            },

            // Listening to browser events to emit events medium-editor cares about
            setupListener: function (name) {
                if (this.listeners[name]) {
                    return;
                }

                switch (name) {
                    case 'externalInteraction':
                        // Detecting when user has interacted with elements outside of MediumEditor
                        this.attachDOMEvent(this.options.ownerDocument.body, 'mousedown', this.handleBodyMousedown.bind(this), true);
                        this.attachDOMEvent(this.options.ownerDocument.body, 'click', this.handleBodyClick.bind(this), true);
                        this.attachDOMEvent(this.options.ownerDocument.body, 'focus', this.handleBodyFocus.bind(this), true);
                        break;
                    case 'blur':
                        // Detecting when focus is lost
                        this.setupListener('externalInteraction');
                        break;
                    case 'focus':
                        // Detecting when focus moves into some part of MediumEditor
                        this.setupListener('externalInteraction');
                        break;
                    case 'editableInput':
                        // setup cache for knowing when the content has changed
                        this.contentCache = {};
                        this.base.elements.forEach(function (element) {
                            this.contentCache[element.getAttribute('medium-editor-index')] = element.innerHTML;
                        }, this);

                        // Attach to the 'oninput' event, handled correctly by most browsers
                        if (this.InputEventOnContenteditableSupported) {
                            this.attachToEachElement('input', this.handleInput);
                        }

                        // For browsers which don't support the input event on contenteditable (IE)
                        // we'll attach to 'selectionchange' on the document and 'keypress' on the editables
                        if (!this.InputEventOnContenteditableSupported) {
                            this.setupListener('editableKeypress');
                            this.keypressUpdateInput = true;
                            this.attachDOMEvent(document, 'selectionchange', this.handleDocumentSelectionChange.bind(this));
                            // Listen to calls to execCommand
                            this.attachToExecCommand();
                        }
                        break;
                    case 'editableClick':
                        // Detecting click in the contenteditables
                        this.attachToEachElement('click', this.handleClick);
                        break;
                    case 'editableBlur':
                        // Detecting blur in the contenteditables
                        this.attachToEachElement('blur', this.handleBlur);
                        break;
                    case 'editableKeypress':
                        // Detecting keypress in the contenteditables
                        this.attachToEachElement('keypress', this.handleKeypress);
                        break;
                    case 'editableKeyup':
                        // Detecting keyup in the contenteditables
                        this.attachToEachElement('keyup', this.handleKeyup);
                        break;
                    case 'editableKeydown':
                        // Detecting keydown on the contenteditables
                        this.attachToEachElement('keydown', this.handleKeydown);
                        break;
                    case 'editableKeydownSpace':
                        // Detecting keydown for SPACE on the contenteditables
                        this.setupListener('editableKeydown');
                        break;
                    case 'editableKeydownEnter':
                        // Detecting keydown for ENTER on the contenteditables
                        this.setupListener('editableKeydown');
                        break;
                    case 'editableKeydownTab':
                        // Detecting keydown for TAB on the contenteditable
                        this.setupListener('editableKeydown');
                        break;
                    case 'editableKeydownDelete':
                        // Detecting keydown for DELETE/BACKSPACE on the contenteditables
                        this.setupListener('editableKeydown');
                        break;
                    case 'editableMouseover':
                        // Detecting mouseover on the contenteditables
                        this.attachToEachElement('mouseover', this.handleMouseover);
                        break;
                    case 'editableDrag':
                        // Detecting dragover and dragleave on the contenteditables
                        this.attachToEachElement('dragover', this.handleDragging);
                        this.attachToEachElement('dragleave', this.handleDragging);
                        break;
                    case 'editableDrop':
                        // Detecting drop on the contenteditables
                        this.attachToEachElement('drop', this.handleDrop);
                        break;
                    // TODO: We need to have a custom 'paste' event separate from 'editablePaste'
                    // Need to think about the way to introduce this without breaking folks
                    case 'editablePaste':
                        // Detecting paste on the contenteditables
                        this.attachToEachElement('paste', this.handlePaste);
                        break;
                }
                this.listeners[name] = true;
            },

            attachToEachElement: function (name, handler) {
                // build our internal cache to know which element got already what handler attached
                if (!this.eventsCache) {
                    this.eventsCache = [];
                }

                this.base.elements.forEach(function (element) {
                    this.attachDOMEvent(element, name, handler.bind(this));
                }, this);

                this.eventsCache.push({ 'name': name, 'handler': handler });
            },

            cleanupElement: function (element) {
                var index = element.getAttribute('medium-editor-index');
                if (index) {
                    this.detachAllEventsFromElement(element);
                    if (this.contentCache) {
                        delete this.contentCache[index];
                    }
                }
            },

            focusElement: function (element) {
                element.focus();
                this.updateFocus(element, { target: element, type: 'focus' });
            },

            updateFocus: function (target, eventObj) {
                var hadFocus = this.base.getFocusedElement(),
                    toFocus;

                // For clicks, we need to know if the mousedown that caused the click happened inside the existing focused element
                // or one of the extension elements.  If so, we don't want to focus another element
                if (hadFocus &&
                    eventObj.type === 'click' &&
                    this.lastMousedownTarget &&
                    (MediumEditor.util.isDescendant(hadFocus, this.lastMousedownTarget, true) ||
                    isElementDescendantOfExtension(this.base.extensions, this.lastMousedownTarget))) {
                    toFocus = hadFocus;
                }

                if (!toFocus) {
                    this.base.elements.some(function (element) {
                        // If the target is part of an editor element, this is the element getting focus
                        if (!toFocus && (MediumEditor.util.isDescendant(element, target, true))) {
                            toFocus = element;
                        }

                        // bail if we found an element that's getting focus
                        return !!toFocus;
                    }, this);
                }

                // Check if the target is external (not part of the editor, toolbar, or any other extension)
                var externalEvent = !MediumEditor.util.isDescendant(hadFocus, target, true) &&
                    !isElementDescendantOfExtension(this.base.extensions, target);

                if (toFocus !== hadFocus) {
                    // If element has focus, and focus is going outside of editor
                    // Don't blur focused element if clicking on editor, toolbar, or anchorpreview
                    if (hadFocus && externalEvent) {
                        // Trigger blur on the editable that has lost focus
                        hadFocus.removeAttribute('data-medium-focused');
                        this.triggerCustomEvent('blur', eventObj, hadFocus);
                    }

                    // If focus is going into an editor element
                    if (toFocus) {
                        // Trigger focus on the editable that now has focus
                        toFocus.setAttribute('data-medium-focused', true);
                        this.triggerCustomEvent('focus', eventObj, toFocus);
                    }
                }

                if (externalEvent) {
                    this.triggerCustomEvent('externalInteraction', eventObj);
                }
            },

            updateInput: function (target, eventObj) {
                if (!this.contentCache) {
                    return;
                }
                // An event triggered which signifies that the user may have changed someting
                // Look in our cache of input for the contenteditables to see if something changed
                var index = target.getAttribute('medium-editor-index'),
                    html = target.innerHTML;

                if (html !== this.contentCache[index]) {
                    // The content has changed since the last time we checked, fire the event
                    this.triggerCustomEvent('editableInput', eventObj, target);
                }
                this.contentCache[index] = html;
            },

            handleDocumentSelectionChange: function (event) {
                // When selectionchange fires, target and current target are set
                // to document, since this is where the event is handled
                // However, currentTarget will have an 'activeElement' property
                // which will point to whatever element has focus.
                if (event.currentTarget && event.currentTarget.activeElement) {
                    var activeElement = event.currentTarget.activeElement,
                        currentTarget;
                    // We can look at the 'activeElement' to determine if the selectionchange has
                    // happened within a contenteditable owned by this instance of MediumEditor
                    this.base.elements.some(function (element) {
                        if (MediumEditor.util.isDescendant(element, activeElement, true)) {
                            currentTarget = element;
                            return true;
                        }
                        return false;
                    }, this);

                    // We know selectionchange fired within one of our contenteditables
                    if (currentTarget) {
                        this.updateInput(currentTarget, { target: activeElement, currentTarget: currentTarget });
                    }
                }
            },

            handleDocumentExecCommand: function () {
                // document.execCommand has been called
                // If one of our contenteditables currently has focus, we should
                // attempt to trigger the 'editableInput' event
                var target = this.base.getFocusedElement();
                if (target) {
                    this.updateInput(target, { target: target, currentTarget: target });
                }
            },

            handleBodyClick: function (event) {
                this.updateFocus(event.target, event);
            },

            handleBodyFocus: function (event) {
                this.updateFocus(event.target, event);
            },

            handleBodyMousedown: function (event) {
                this.lastMousedownTarget = event.target;
            },

            handleInput: function (event) {
                this.updateInput(event.currentTarget, event);
            },

            handleClick: function (event) {
                this.triggerCustomEvent('editableClick', event, event.currentTarget);
            },

            handleBlur: function (event) {
                this.triggerCustomEvent('editableBlur', event, event.currentTarget);
            },

            handleKeypress: function (event) {
                this.triggerCustomEvent('editableKeypress', event, event.currentTarget);

                // If we're doing manual detection of the editableInput event we need
                // to check for input changes during 'keypress'
                if (this.keypressUpdateInput) {
                    var eventObj = { target: event.target, currentTarget: event.currentTarget };

                    // In IE, we need to let the rest of the event stack complete before we detect
                    // changes to input, so using setTimeout here
                    setTimeout(function () {
                        this.updateInput(eventObj.currentTarget, eventObj);
                    }.bind(this), 0);
                }
            },

            handleKeyup: function (event) {
                this.triggerCustomEvent('editableKeyup', event, event.currentTarget);
            },

            handleMouseover: function (event) {
                this.triggerCustomEvent('editableMouseover', event, event.currentTarget);
            },

            handleDragging: function (event) {
                this.triggerCustomEvent('editableDrag', event, event.currentTarget);
            },

            handleDrop: function (event) {
                this.triggerCustomEvent('editableDrop', event, event.currentTarget);
            },

            handlePaste: function (event) {
                this.triggerCustomEvent('editablePaste', event, event.currentTarget);
            },

            handleKeydown: function (event) {

                this.triggerCustomEvent('editableKeydown', event, event.currentTarget);

                if (MediumEditor.util.isKey(event, MediumEditor.util.keyCode.SPACE)) {
                    return this.triggerCustomEvent('editableKeydownSpace', event, event.currentTarget);
                }

                if (MediumEditor.util.isKey(event, MediumEditor.util.keyCode.ENTER) || (event.ctrlKey && MediumEditor.util.isKey(event, MediumEditor.util.keyCode.M))) {
                    return this.triggerCustomEvent('editableKeydownEnter', event, event.currentTarget);
                }

                if (MediumEditor.util.isKey(event, MediumEditor.util.keyCode.TAB)) {
                    return this.triggerCustomEvent('editableKeydownTab', event, event.currentTarget);
                }

                if (MediumEditor.util.isKey(event, [MediumEditor.util.keyCode.DELETE, MediumEditor.util.keyCode.BACKSPACE])) {
                    return this.triggerCustomEvent('editableKeydownDelete', event, event.currentTarget);
                }
            }
        };

        MediumEditor.Events = Events;
    }());

    (function () {
        'use strict';

        var Button = MediumEditor.Extension.extend({

            /* Button Options */

            /* action: [string]
             * The action argument to pass to MediumEditor.execAction()
             * when the button is clicked
             */
            action: undefined,

            /* aria: [string]
             * The value to add as the aria-label attribute of the button
             * element displayed in the toolbar.
             * This is also used as the tooltip for the button
             */
            aria: undefined,

            /* tagNames: [Array]
             * NOTE: This is not used if useQueryState is set to true.
             *
             * Array of element tag names that would indicate that this
             * button has already been applied. If this action has already
             * been applied, the button will be displayed as 'active' in the toolbar
             *
             * Example:
             * For 'bold', if the text is ever within a <b> or <strong>
             * tag that indicates the text is already bold. So the array
             * of tagNames for bold would be: ['b', 'strong']
             */
            tagNames: undefined,

            /* style: [Object]
             * NOTE: This is not used if useQueryState is set to true.
             *
             * A pair of css property & value(s) that indicate that this
             * button has already been applied. If this action has already
             * been applied, the button will be displayed as 'active' in the toolbar
             * Properties of the object:
             *   prop [String]: name of the css property
             *   value [String]: value(s) of the css property
             *                   multiple values can be separated by a '|'
             *
             * Example:
             * For 'bold', if the text is ever within an element with a 'font-weight'
             * style property set to '700' or 'bold', that indicates the text
             * is already bold.  So the style object for bold would be:
             * { prop: 'font-weight', value: '700|bold' }
             */
            style: undefined,

            /* useQueryState: [boolean]
             * Enables/disables whether this button should use the built-in
             * document.queryCommandState() method to determine whether
             * the action has already been applied.  If the action has already
             * been applied, the button will be displayed as 'active' in the toolbar
             *
             * Example:
             * For 'bold', if this is set to true, the code will call:
             * document.queryCommandState('bold') which will return true if the
             * browser thinks the text is already bold, and false otherwise
             */
            useQueryState: undefined,

            /* contentDefault: [string]
             * Default innerHTML to put inside the button
             */
            contentDefault: undefined,

            /* contentFA: [string]
             * The innerHTML to use for the content of the button
             * if the `buttonLabels` option for MediumEditor is set to 'fontawesome'
             */
            contentFA: undefined,

            /* classList: [Array]
             * An array of classNames (strings) to be added to the button
             */
            classList: undefined,

            /* attrs: [object]
             * A set of key-value pairs to add to the button as custom attributes
             */
            attrs: undefined,

            // The button constructor can optionally accept the name of a built-in button
            // (ie 'bold', 'italic', etc.)
            // When the name of a button is passed, it will initialize itself with the
            // configuration for that button
            constructor: function (options) {
                if (Button.isBuiltInButton(options)) {
                    MediumEditor.Extension.call(this, this.defaults[options]);
                } else {
                    MediumEditor.Extension.call(this, options);
                }
            },

            init: function () {
                MediumEditor.Extension.prototype.init.apply(this, arguments);

                this.button = this.createButton();
                this.on(this.button, 'click', this.handleClick.bind(this));
            },

            /* getButton: [function ()]
             *
             * If implemented, this function will be called when
             * the toolbar is being created.  The DOM Element returned
             * by this function will be appended to the toolbar along
             * with any other buttons.
             */
            getButton: function () {
                return this.button;
            },

            getAction: function () {
                return (typeof this.action === 'function') ? this.action(this.base.options) : this.action;
            },

            getAria: function () {
                return (typeof this.aria === 'function') ? this.aria(this.base.options) : this.aria;
            },

            getTagNames: function () {
                return (typeof this.tagNames === 'function') ? this.tagNames(this.base.options) : this.tagNames;
            },

            createButton: function () {
                var button = this.document.createElement('button'),
                    content = this.contentDefault,
                    ariaLabel = this.getAria(),
                    buttonLabels = this.getEditorOption('buttonLabels');
                // Add class names
                button.classList.add('medium-editor-action');
                button.classList.add('medium-editor-action-' + this.name);
                if (this.classList) {
                    this.classList.forEach(function (className) {
                        button.classList.add(className);
                    });
                }

                // Add attributes
                button.setAttribute('data-action', this.getAction());
                if (ariaLabel) {
                    button.setAttribute('title', ariaLabel);
                    button.setAttribute('aria-label', ariaLabel);
                }
                if (this.attrs) {
                    Object.keys(this.attrs).forEach(function (attr) {
                        button.setAttribute(attr, this.attrs[attr]);
                    }, this);
                }

                if (buttonLabels === 'fontawesome' && this.contentFA) {
                    content = this.contentFA;
                }
                button.innerHTML = content;
                return button;
            },

            handleClick: function (event) {
                event.preventDefault();
                event.stopPropagation();

                var action = this.getAction();

                if (action) {
                    this.execAction(action);
                }
            },

            isActive: function () {
                return this.button.classList.contains(this.getEditorOption('activeButtonClass'));
            },

            setInactive: function () {
                this.button.classList.remove(this.getEditorOption('activeButtonClass'));
                delete this.knownState;
            },

            setActive: function () {
                this.button.classList.add(this.getEditorOption('activeButtonClass'));
                delete this.knownState;
            },

            queryCommandState: function () {
                var queryState = null;
                if (this.useQueryState) {
                    queryState = this.base.queryCommandState(this.getAction());
                }
                return queryState;
            },

            isAlreadyApplied: function (node) {
                var isMatch = false,
                    tagNames = this.getTagNames(),
                    styleVals,
                    computedStyle;

                if (this.knownState === false || this.knownState === true) {
                    return this.knownState;
                }

                if (tagNames && tagNames.length > 0) {
                    isMatch = tagNames.indexOf(node.nodeName.toLowerCase()) !== -1;
                }

                if (!isMatch && this.style) {
                    styleVals = this.style.value.split('|');
                    computedStyle = this.window.getComputedStyle(node, null).getPropertyValue(this.style.prop);
                    styleVals.forEach(function (val) {
                        if (!this.knownState) {
                            isMatch = (computedStyle.indexOf(val) !== -1);
                            // text-decoration is not inherited by default
                            // so if the computed style for text-decoration doesn't match
                            // don't write to knownState so we can fallback to other checks
                            if (isMatch || this.style.prop !== 'text-decoration') {
                                this.knownState = isMatch;
                            }
                        }
                    }, this);
                }

                return isMatch;
            }
        });

        Button.isBuiltInButton = function (name) {
            return (typeof name === 'string') && MediumEditor.extensions.button.prototype.defaults.hasOwnProperty(name);
        };

        MediumEditor.extensions.button = Button;
    }());

    (function () {
        'use strict';

        /* MediumEditor.extensions.button.defaults: [Object]
         * Set of default config options for all of the built-in MediumEditor buttons
         */
        MediumEditor.extensions.button.prototype.defaults = {
            'bold': {
                name: 'bold',
                action: 'bold',
                aria: 'bold',
                tagNames: ['b', 'strong'],
                style: {
                    prop: 'font-weight',
                    value: '700|bold'
                },
                useQueryState: true,
                contentDefault: '<b>B</b>',
                contentFA: '<i class="fa fa-bold"></i>'
            },
            'italic': {
                name: 'italic',
                action: 'italic',
                aria: 'italic',
                tagNames: ['i', 'em'],
                style: {
                    prop: 'font-style',
                    value: 'italic'
                },
                useQueryState: true,
                contentDefault: '<b><i>I</i></b>',
                contentFA: '<i class="fa fa-italic"></i>'
            },
            'underline': {
                name: 'underline',
                action: 'underline',
                aria: 'underline',
                tagNames: ['u'],
                style: {
                    prop: 'text-decoration',
                    value: 'underline'
                },
                useQueryState: true,
                contentDefault: '<b><u>U</u></b>',
                contentFA: '<i class="fa fa-underline"></i>'
            },
            'strikethrough': {
                name: 'strikethrough',
                action: 'strikethrough',
                aria: 'strike through',
                tagNames: ['strike'],
                style: {
                    prop: 'text-decoration',
                    value: 'line-through'
                },
                useQueryState: true,
                contentDefault: '<s>A</s>',
                contentFA: '<i class="fa fa-strikethrough"></i>'
            },
            'superscript': {
                name: 'superscript',
                action: 'superscript',
                aria: 'superscript',
                tagNames: ['sup'],
                /* firefox doesn't behave the way we want it to, so we CAN'T use queryCommandState for superscript
                 https://github.com/guardian/scribe/blob/master/BROWSERINCONSISTENCIES.md#documentquerycommandstate */
                // useQueryState: true
                contentDefault: '<b>x<sup>1</sup></b>',
                contentFA: '<i class="fa fa-superscript"></i>'
            },
            'subscript': {
                name: 'subscript',
                action: 'subscript',
                aria: 'subscript',
                tagNames: ['sub'],
                /* firefox doesn't behave the way we want it to, so we CAN'T use queryCommandState for subscript
                 https://github.com/guardian/scribe/blob/master/BROWSERINCONSISTENCIES.md#documentquerycommandstate */
                // useQueryState: true
                contentDefault: '<b>x<sub>1</sub></b>',
                contentFA: '<i class="fa fa-subscript"></i>'
            },
            'image': {
                name: 'image',
                action: 'image',
                aria: 'image',
                tagNames: ['img'],
                contentDefault: '<b>image</b>',
                contentFA: '<i class="fa fa-picture-o"></i>'
            },
            'html': {
                name: 'html',
                action: 'html',
                aria: 'evaluate html',
                tagNames: ['iframe', 'object'],
                contentDefault: '<b>html</b>',
                contentFA: '<i class="fa fa-code"></i>'
            },
            'orderedlist': {
                name: 'orderedlist',
                action: 'insertorderedlist',
                aria: 'ordered list',
                tagNames: ['ol'],
                useQueryState: true,
                contentDefault: '<b>1.</b>',
                contentFA: '<i class="fa fa-list-ol"></i>'
            },
            'unorderedlist': {
                name: 'unorderedlist',
                action: 'insertunorderedlist',
                aria: 'unordered list',
                tagNames: ['ul'],
                useQueryState: true,
                contentDefault: '<b>&bull;</b>',
                contentFA: '<i class="fa fa-list-ul"></i>'
            },
            'indent': {
                name: 'indent',
                action: 'indent',
                aria: 'indent',
                tagNames: [],
                contentDefault: '<b>&rarr;</b>',
                contentFA: '<i class="fa fa-indent"></i>'
            },
            'outdent': {
                name: 'outdent',
                action: 'outdent',
                aria: 'outdent',
                tagNames: [],
                contentDefault: '<b>&larr;</b>',
                contentFA: '<i class="fa fa-outdent"></i>'
            },
            'justifyCenter': {
                name: 'justifyCenter',
                action: 'justifyCenter',
                aria: 'center justify',
                tagNames: [],
                style: {
                    prop: 'text-align',
                    value: 'center'
                },
                contentDefault: '<b>C</b>',
                contentFA: '<i class="fa fa-align-center"></i>'
            },
            'justifyFull': {
                name: 'justifyFull',
                action: 'justifyFull',
                aria: 'full justify',
                tagNames: [],
                style: {
                    prop: 'text-align',
                    value: 'justify'
                },
                contentDefault: '<b>J</b>',
                contentFA: '<i class="fa fa-align-justify"></i>'
            },
            'justifyLeft': {
                name: 'justifyLeft',
                action: 'justifyLeft',
                aria: 'left justify',
                tagNames: [],
                style: {
                    prop: 'text-align',
                    value: 'left'
                },
                contentDefault: '<b>L</b>',
                contentFA: '<i class="fa fa-align-left"></i>'
            },
            'justifyRight': {
                name: 'justifyRight',
                action: 'justifyRight',
                aria: 'right justify',
                tagNames: [],
                style: {
                    prop: 'text-align',
                    value: 'right'
                },
                contentDefault: '<b>R</b>',
                contentFA: '<i class="fa fa-align-right"></i>'
            },
            // Known inline elements that are not removed, or not removed consistantly across browsers:
            // <span>, <label>, <br>
            'removeFormat': {
                name: 'removeFormat',
                aria: 'remove formatting',
                action: 'removeFormat',
                contentDefault: '<b>X</b>',
                contentFA: '<i class="fa fa-eraser"></i>'
            },

            /***** Buttons for appending block elements (append-<element> action) *****/

            'quote': {
                name: 'quote',
                action: 'append-blockquote',
                aria: 'blockquote',
                tagNames: ['blockquote'],
                contentDefault: '<b>&ldquo;</b>',
                contentFA: '<i class="fa fa-quote-right"></i>'
            },
            'pre': {
                name: 'pre',
                action: 'append-pre',
                aria: 'preformatted text',
                tagNames: ['pre'],
                contentDefault: '<b>0101</b>',
                contentFA: '<i class="fa fa-code fa-lg"></i>'
            },
            'h1': {
                name: 'h1',
                action: 'append-h1',
                aria: 'header type one',
                tagNames: ['h1'],
                contentDefault: '<b>H1</b>',
                contentFA: '<i class="fa fa-header"><sup>1</sup>'
            },
            'h2': {
                name: 'h2',
                action: 'append-h2',
                aria: 'header type two',
                tagNames: ['h2'],
                contentDefault: '<b>H2</b>',
                contentFA: '<i class="fa fa-header"><sup>2</sup>'
            },
            'h3': {
                name: 'h3',
                action: 'append-h3',
                aria: 'header type three',
                tagNames: ['h3'],
                contentDefault: '<b>H3</b>',
                contentFA: '<i class="fa fa-header"><sup>3</sup>'
            },
            'h4': {
                name: 'h4',
                action: 'append-h4',
                aria: 'header type four',
                tagNames: ['h4'],
                contentDefault: '<b>H4</b>',
                contentFA: '<i class="fa fa-header"><sup>4</sup>'
            },
            'h5': {
                name: 'h5',
                action: 'append-h5',
                aria: 'header type five',
                tagNames: ['h5'],
                contentDefault: '<b>H5</b>',
                contentFA: '<i class="fa fa-header"><sup>5</sup>'
            },
            'h6': {
                name: 'h6',
                action: 'append-h6',
                aria: 'header type six',
                tagNames: ['h6'],
                contentDefault: '<b>H6</b>',
                contentFA: '<i class="fa fa-header"><sup>6</sup>'
            }
        };

    })();

    (function () {
        'use strict';

        /* Base functionality for an extension which will display
         * a 'form' inside the toolbar
         */
        var FormExtension = MediumEditor.extensions.button.extend({

            init: function () {
                MediumEditor.extensions.button.prototype.init.apply(this, arguments);
            },

            // default labels for the form buttons
            formSaveLabel: '&#10003;',
            formCloseLabel: '&times;',

            /* activeClass: [string]
             * set class which added to shown form
             */
            activeClass: 'medium-editor-toolbar-form-active',

            /* hasForm: [boolean]
             *
             * Setting this to true will cause getForm() to be called
             * when the toolbar is created, so the form can be appended
             * inside the toolbar container
             */
            hasForm: true,

            /* getForm: [function ()]
             *
             * When hasForm is true, this function must be implemented
             * and return a DOM Element which will be appended to
             * the toolbar container. The form should start hidden, and
             * the extension can choose when to hide/show it
             */
            getForm: function () {},

            /* isDisplayed: [function ()]
             *
             * This function should return true/false reflecting
             * whether the form is currently displayed
             */
            isDisplayed: function () {
                if (this.hasForm) {
                    return this.getForm().classList.contains(this.activeClass);
                }
                return false;
            },

            /* hideForm: [function ()]
             *
             * This function should show the form element inside
             * the toolbar container
             */
            showForm: function () {
                if (this.hasForm) {
                    this.getForm().classList.add(this.activeClass);
                }
            },

            /* hideForm: [function ()]
             *
             * This function should hide the form element inside
             * the toolbar container
             */
            hideForm: function () {
                if (this.hasForm) {
                    this.getForm().classList.remove(this.activeClass);
                }
            },

            /************************ Helpers ************************
             * The following are helpers that are either set by MediumEditor
             * during initialization, or are helper methods which either
             * route calls to the MediumEditor instance or provide common
             * functionality for all form extensions
             *********************************************************/

            /* showToolbarDefaultActions: [function ()]
             *
             * Helper method which will turn back the toolbar after canceling
             * the customized form
             */
            showToolbarDefaultActions: function () {
                var toolbar = this.base.getExtensionByName('toolbar');
                if (toolbar) {
                    toolbar.showToolbarDefaultActions();
                }
            },

            /* hideToolbarDefaultActions: [function ()]
             *
             * Helper function which will hide the default contents of the
             * toolbar, but leave the toolbar container in the same state
             * to allow a form to display its custom contents inside the toolbar
             */
            hideToolbarDefaultActions: function () {
                var toolbar = this.base.getExtensionByName('toolbar');
                if (toolbar) {
                    toolbar.hideToolbarDefaultActions();
                }
            },

            /* setToolbarPosition: [function ()]
             *
             * Helper function which will update the size and position
             * of the toolbar based on the toolbar content and the current
             * position of the user's selection
             */
            setToolbarPosition: function () {
                var toolbar = this.base.getExtensionByName('toolbar');
                if (toolbar) {
                    toolbar.setToolbarPosition();
                }
            }
        });

        MediumEditor.extensions.form = FormExtension;
    })();
    (function () {
        'use strict';

        var AnchorForm = MediumEditor.extensions.form.extend({
            /* Anchor Form Options */

            /* customClassOption: [string]  (previously options.anchorButton + options.anchorButtonClass)
             * Custom class name the user can optionally have added to their created links (ie 'button').
             * If passed as a non-empty string, a checkbox will be displayed allowing the user to choose
             * whether to have the class added to the created link or not.
             */
            customClassOption: null,

            /* customClassOptionText: [string]
             * text to be shown in the checkbox when the __customClassOption__ is being used.
             */
            customClassOptionText: 'Button',

            /* linkValidation: [boolean]  (previously options.checkLinkFormat)
             * enables/disables check for common URL protocols on anchor links.
             */
            linkValidation: false,

            /* placeholderText: [string]  (previously options.anchorInputPlaceholder)
             * text to be shown as placeholder of the anchor input.
             */
            placeholderText: 'Paste or type a link',

            /* targetCheckbox: [boolean]  (previously options.anchorTarget)
             * enables/disables displaying a "Open in new window" checkbox, which when checked
             * changes the `target` attribute of the created link.
             */
            targetCheckbox: false,

            /* targetCheckboxText: [string]  (previously options.anchorInputCheckboxLabel)
             * text to be shown in the checkbox enabled via the __targetCheckbox__ option.
             */
            targetCheckboxText: 'Open in new window',

            // Options for the Button base class
            name: 'anchor',
            action: 'createLink',
            aria: 'link',
            tagNames: ['a'],
            contentDefault: '<b>#</b>',
            contentFA: '<i class="fa fa-link"></i>',

            init: function () {
                MediumEditor.extensions.form.prototype.init.apply(this, arguments);

                this.subscribe('editableKeydown', this.handleKeydown.bind(this));
            },

            // Called when the button the toolbar is clicked
            // Overrides ButtonExtension.handleClick
            handleClick: function (event) {
                event.preventDefault();
                event.stopPropagation();

                var range = MediumEditor.selection.getSelectionRange(this.document);

                if (range.startContainer.nodeName.toLowerCase() === 'a' ||
                    range.endContainer.nodeName.toLowerCase() === 'a' ||
                    MediumEditor.util.getClosestTag(MediumEditor.selection.getSelectedParentElement(range), 'a')) {
                    return this.execAction('unlink');
                }

                if (!this.isDisplayed()) {
                    this.showForm();
                }

                return false;
            },

            // Called when user hits the defined shortcut (CTRL / COMMAND + K)
            handleKeydown: function (event) {
                if (MediumEditor.util.isKey(event, MediumEditor.util.keyCode.K) && MediumEditor.util.isMetaCtrlKey(event) && !event.shiftKey) {
                    this.handleClick(event);
                }
            },

            // Called by medium-editor to append form to the toolbar
            getForm: function () {
                if (!this.form) {
                    this.form = this.createForm();
                }
                return this.form;
            },

            getTemplate: function () {
                var template = [
                    '<input type="text" class="medium-editor-toolbar-input" placeholder="', this.placeholderText, '">'
                ];

                template.push(
                    '<a href="#" class="medium-editor-toolbar-save">',
                    this.getEditorOption('buttonLabels') === 'fontawesome' ? '<i class="fa fa-check"></i>' : this.formSaveLabel,
                    '</a>'
                );

                template.push('<a href="#" class="medium-editor-toolbar-close">',
                    this.getEditorOption('buttonLabels') === 'fontawesome' ? '<i class="fa fa-times"></i>' : this.formCloseLabel,
                    '</a>');

                // both of these options are slightly moot with the ability to
                // override the various form buildup/serialize functions.

                if (this.targetCheckbox) {
                    // fixme: ideally, this targetCheckboxText would be a formLabel too,
                    // figure out how to deprecate? also consider `fa-` icon default implcations.
                    template.push(
                        '<div class="medium-editor-toolbar-form-row">',
                        '<input type="checkbox" class="medium-editor-toolbar-anchor-target" id="medium-editor-toolbar-anchor-target-field-' + this.getEditorId() + '">',
                        '<label for="medium-editor-toolbar-anchor-target-field-' + this.getEditorId() + '">',
                        this.targetCheckboxText,
                        '</label>',
                        '</div>'
                    );
                }

                if (this.customClassOption) {
                    // fixme: expose this `Button` text as a formLabel property, too
                    // and provide similar access to a `fa-` icon default.
                    template.push(
                        '<div class="medium-editor-toolbar-form-row">',
                        '<input type="checkbox" class="medium-editor-toolbar-anchor-button">',
                        '<label>',
                        this.customClassOptionText,
                        '</label>',
                        '</div>'
                    );
                }

                return template.join('');

            },

            // Used by medium-editor when the default toolbar is to be displayed
            isDisplayed: function () {
                return MediumEditor.extensions.form.prototype.isDisplayed.apply(this);
            },

            hideForm: function () {
                MediumEditor.extensions.form.prototype.hideForm.apply(this);
                this.getInput().value = '';
            },

            showForm: function (opts) {
                var input = this.getInput(),
                    targetCheckbox = this.getAnchorTargetCheckbox(),
                    buttonCheckbox = this.getAnchorButtonCheckbox();

                opts = opts || { value: '' };
                // TODO: This is for backwards compatability
                // We don't need to support the 'string' argument in 6.0.0
                if (typeof opts === 'string') {
                    opts = {
                        value: opts
                    };
                }

                this.base.saveSelection();
                this.hideToolbarDefaultActions();
                MediumEditor.extensions.form.prototype.showForm.apply(this);
                this.setToolbarPosition();

                input.value = opts.value;
                input.focus();

                // If we have a target checkbox, we want it to be checked/unchecked
                // based on whether the existing link has target=_blank
                if (targetCheckbox) {
                    targetCheckbox.checked = opts.target === '_blank';
                }

                // If we have a custom class checkbox, we want it to be checked/unchecked
                // based on whether an existing link already has the class
                if (buttonCheckbox) {
                    var classList = opts.buttonClass ? opts.buttonClass.split(' ') : [];
                    buttonCheckbox.checked = (classList.indexOf(this.customClassOption) !== -1);
                }
            },

            // Called by core when tearing down medium-editor (destroy)
            destroy: function () {
                if (!this.form) {
                    return false;
                }

                if (this.form.parentNode) {
                    this.form.parentNode.removeChild(this.form);
                }

                delete this.form;
            },

            // core methods

            getFormOpts: function () {
                // no notion of private functions? wanted `_getFormOpts`
                var targetCheckbox = this.getAnchorTargetCheckbox(),
                    buttonCheckbox = this.getAnchorButtonCheckbox(),
                    opts = {
                        value: this.getInput().value.trim()
                    };

                if (this.linkValidation) {
                    opts.value = this.checkLinkFormat(opts.value);
                }

                opts.target = '_self';
                if (targetCheckbox && targetCheckbox.checked) {
                    opts.target = '_blank';
                }

                if (buttonCheckbox && buttonCheckbox.checked) {
                    opts.buttonClass = this.customClassOption;
                }

                return opts;
            },

            doFormSave: function () {
                var opts = this.getFormOpts();
                this.completeFormSave(opts);
            },

            completeFormSave: function (opts) {
                this.base.restoreSelection();
                this.execAction(this.action, opts);
                this.base.checkSelection();
            },

            ensureEncodedUri: function (str) {
                return str === decodeURI(str) ? encodeURI(str) : str;
            },

            ensureEncodedUriComponent: function (str) {
                return str === decodeURIComponent(str) ? encodeURIComponent(str) : str;
            },

            ensureEncodedParam: function (param) {
                var split = param.split('='),
                    key = split[0],
                    val = split[1];

                return key + (val === undefined ? '' : '=' + this.ensureEncodedUriComponent(val));
            },

            ensureEncodedQuery: function (queryString) {
                return queryString.split('&').map(this.ensureEncodedParam.bind(this)).join('&');
            },

            checkLinkFormat: function (value) {
                // Matches any alphabetical characters followed by ://
                // Matches protocol relative "//"
                // Matches common external protocols "mailto:" "tel:" "maps:"
                // Matches relative hash link, begins with "#"
                var urlSchemeRegex = /^([a-z]+:)?\/\/|^(mailto|tel|maps):|^\#/i,
                    hasScheme = urlSchemeRegex.test(value),
                    scheme = '',
                    // telRegex is a regex for checking if the string is a telephone number
                    telRegex = /^\+?\s?\(?(?:\d\s?\-?\)?){3,20}$/,
                    urlParts = value.match(/^(.*?)(?:\?(.*?))?(?:#(.*))?$/),
                    path = urlParts[1],
                    query = urlParts[2],
                    fragment = urlParts[3];

                if (telRegex.test(value)) {
                    return 'tel:' + value;
                }

                if (!hasScheme) {
                    var host = path.split('/')[0];
                    // if the host part of the path looks like a hostname
                    if (host.match(/.+(\.|:).+/) || host === 'localhost') {
                        scheme = 'http://';
                    }
                }

                return scheme +
                    // Ensure path is encoded
                    this.ensureEncodedUri(path) +
                    // Ensure query is encoded
                    (query === undefined ? '' : '?' + this.ensureEncodedQuery(query)) +
                    // Include fragment unencoded as encodeUriComponent is too
                    // heavy handed for the many characters allowed in a fragment
                    (fragment === undefined ? '' : '#' + fragment);
            },

            doFormCancel: function () {
                this.base.restoreSelection();
                this.base.checkSelection();
            },

            // form creation and event handling
            attachFormEvents: function (form) {
                var close = form.querySelector('.medium-editor-toolbar-close'),
                    save = form.querySelector('.medium-editor-toolbar-save'),
                    input = form.querySelector('.medium-editor-toolbar-input');

                // Handle clicks on the form itself
                this.on(form, 'click', this.handleFormClick.bind(this));

                // Handle typing in the textbox
                this.on(input, 'keyup', this.handleTextboxKeyup.bind(this));

                // Handle close button clicks
                this.on(close, 'click', this.handleCloseClick.bind(this));

                // Handle save button clicks (capture)
                this.on(save, 'click', this.handleSaveClick.bind(this), true);

            },

            createForm: function () {
                var doc = this.document,
                    form = doc.createElement('div');

                // Anchor Form (div)
                form.className = 'medium-editor-toolbar-form';
                form.id = 'medium-editor-toolbar-form-anchor-' + this.getEditorId();
                form.innerHTML = this.getTemplate();
                this.attachFormEvents(form);

                return form;
            },

            getInput: function () {
                return this.getForm().querySelector('input.medium-editor-toolbar-input');
            },

            getAnchorTargetCheckbox: function () {
                return this.getForm().querySelector('.medium-editor-toolbar-anchor-target');
            },

            getAnchorButtonCheckbox: function () {
                return this.getForm().querySelector('.medium-editor-toolbar-anchor-button');
            },

            handleTextboxKeyup: function (event) {
                // For ENTER -> create the anchor
                if (event.keyCode === MediumEditor.util.keyCode.ENTER) {
                    event.preventDefault();
                    this.doFormSave();
                    return;
                }

                // For ESCAPE -> close the form
                if (event.keyCode === MediumEditor.util.keyCode.ESCAPE) {
                    event.preventDefault();
                    this.doFormCancel();
                }
            },

            handleFormClick: function (event) {
                // make sure not to hide form when clicking inside the form
                event.stopPropagation();
            },

            handleSaveClick: function (event) {
                // Clicking Save -> create the anchor
                event.preventDefault();
                this.doFormSave();
            },

            handleCloseClick: function (event) {
                // Click Close -> close the form
                event.preventDefault();
                this.doFormCancel();
            }
        });

        MediumEditor.extensions.anchor = AnchorForm;
    }());

    (function () {
        'use strict';

        var AnchorPreview = MediumEditor.Extension.extend({
            name: 'anchor-preview',

            // Anchor Preview Options

            /* hideDelay: [number]  (previously options.anchorPreviewHideDelay)
             * time in milliseconds to show the anchor tag preview after the mouse has left the anchor tag.
             */
            hideDelay: 500,

            /* previewValueSelector: [string]
             * the default selector to locate where to put the activeAnchor value in the preview
             */
            previewValueSelector: 'a',

            /* showWhenToolbarIsVisible: [boolean]
             * determines whether the anchor tag preview shows up when the toolbar is visible
             */
            showWhenToolbarIsVisible: false,

            /* showOnEmptyLinks: [boolean]
             * determines whether the anchor tag preview shows up on links with href="" or href="#something"
             */
            showOnEmptyLinks: true,

            init: function () {
                this.anchorPreview = this.createPreview();

                this.getEditorOption('elementsContainer').appendChild(this.anchorPreview);

                this.attachToEditables();
            },

            getInteractionElements: function () {
                return this.getPreviewElement();
            },

            // TODO: Remove this function in 6.0.0
            getPreviewElement: function () {
                return this.anchorPreview;
            },

            createPreview: function () {
                var el = this.document.createElement('div');

                el.id = 'medium-editor-anchor-preview-' + this.getEditorId();
                el.className = 'medium-editor-anchor-preview';
                el.innerHTML = this.getTemplate();

                this.on(el, 'click', this.handleClick.bind(this));

                return el;
            },

            getTemplate: function () {
                return '<div class="medium-editor-toolbar-anchor-preview" id="medium-editor-toolbar-anchor-preview">' +
                    '    <a class="medium-editor-toolbar-anchor-preview-inner"></a>' +
                    '</div>';
            },

            destroy: function () {
                if (this.anchorPreview) {
                    if (this.anchorPreview.parentNode) {
                        this.anchorPreview.parentNode.removeChild(this.anchorPreview);
                    }
                    delete this.anchorPreview;
                }
            },

            hidePreview: function () {
                if (this.anchorPreview) {
                    this.anchorPreview.classList.remove('medium-editor-anchor-preview-active');
                }
                this.activeAnchor = null;
            },

            showPreview: function (anchorEl) {
                if (this.anchorPreview.classList.contains('medium-editor-anchor-preview-active') ||
                    anchorEl.getAttribute('data-disable-preview')) {
                    return true;
                }

                if (this.previewValueSelector) {
                    this.anchorPreview.querySelector(this.previewValueSelector).textContent = anchorEl.attributes.href.value;
                    this.anchorPreview.querySelector(this.previewValueSelector).href = anchorEl.attributes.href.value;
                }

                this.anchorPreview.classList.add('medium-toolbar-arrow-over');
                this.anchorPreview.classList.remove('medium-toolbar-arrow-under');

                if (!this.anchorPreview.classList.contains('medium-editor-anchor-preview-active')) {
                    this.anchorPreview.classList.add('medium-editor-anchor-preview-active');
                }

                this.activeAnchor = anchorEl;

                this.positionPreview();
                this.attachPreviewHandlers();

                return this;
            },

            positionPreview: function (activeAnchor) {
                activeAnchor = activeAnchor || this.activeAnchor;
                var containerWidth = this.window.innerWidth,
                    buttonHeight = this.anchorPreview.offsetHeight,
                    boundary = activeAnchor.getBoundingClientRect(),
                    diffLeft = this.diffLeft,
                    diffTop = this.diffTop,
                    elementsContainer = this.getEditorOption('elementsContainer'),
                    elementsContainerAbsolute = 'absolute', //['absolute', 'fixed'].indexOf(window.getComputedStyle(elementsContainer).getPropertyValue('position')) > -1,
                    relativeBoundary = {},
                    halfOffsetWidth, defaultLeft, middleBoundary, elementsContainerBoundary, top;

                halfOffsetWidth = this.anchorPreview.offsetWidth / 2;
                var toolbarExtension = this.base.getExtensionByName('toolbar');
                if (toolbarExtension) {
                    diffLeft = toolbarExtension.diffLeft;
                    diffTop = toolbarExtension.diffTop;
                }
                defaultLeft = diffLeft - halfOffsetWidth;

                // If container element is absolute / fixed, recalculate boundaries to be relative to the container
                if (elementsContainerAbsolute) {
                    elementsContainerBoundary = elementsContainer.getBoundingClientRect();
                    ['top', 'left'].forEach(function (key) {
                        relativeBoundary[key] = boundary[key] - elementsContainerBoundary[key];
                    });

                    relativeBoundary.width = boundary.width;
                    relativeBoundary.height = boundary.height;
                    boundary = relativeBoundary;

                    containerWidth = elementsContainerBoundary.width;

                    // Adjust top position according to container scroll position
                    top = elementsContainer.scrollTop;
                } else {
                    // Adjust top position according to window scroll position
                    top = this.window.pageYOffset;
                }

                middleBoundary = boundary.left + boundary.width / 2;
                top += buttonHeight + boundary.top + boundary.height - diffTop - this.anchorPreview.offsetHeight;

                this.anchorPreview.style.top = Math.round(top) + 'px';
                this.anchorPreview.style.right = 'initial';
                if (middleBoundary < halfOffsetWidth) {
                    this.anchorPreview.style.left = defaultLeft + halfOffsetWidth + 'px';
                    this.anchorPreview.style.right = 'initial';
                } else if ((containerWidth - middleBoundary) < halfOffsetWidth) {
                    this.anchorPreview.style.left = 'auto';
                    this.anchorPreview.style.right = 0;
                } else {
                    this.anchorPreview.style.left = defaultLeft + middleBoundary + 'px';
                    this.anchorPreview.style.right = 'initial';
                }
            },

            attachToEditables: function () {
                this.subscribe('editableMouseover', this.handleEditableMouseover.bind(this));
                this.subscribe('positionedToolbar', this.handlePositionedToolbar.bind(this));
            },

            handlePositionedToolbar: function () {
                // If the toolbar is visible and positioned, we don't need to hide the preview
                // when showWhenToolbarIsVisible is true
                if (!this.showWhenToolbarIsVisible) {
                    this.hidePreview();
                }
            },

            handleClick: function (event) {
                var anchorExtension = this.base.getExtensionByName('anchor'),
                    activeAnchor = this.activeAnchor;

                if (anchorExtension && activeAnchor) {
                    event.preventDefault();

                    this.base.selectElement(this.activeAnchor);

                    // Using setTimeout + delay because:
                    // We may actually be displaying the anchor form, which should be controlled by delay
                    this.base.delay(function () {
                        if (activeAnchor) {
                            var opts = {
                                value: activeAnchor.attributes.href.value,
                                target: activeAnchor.getAttribute('target'),
                                buttonClass: activeAnchor.getAttribute('class')
                            };
                            anchorExtension.showForm(opts);
                            activeAnchor = null;
                        }
                    }.bind(this));
                }

                this.hidePreview();
            },

            handleAnchorMouseout: function () {
                this.anchorToPreview = null;
                this.off(this.activeAnchor, 'mouseout', this.instanceHandleAnchorMouseout);
                this.instanceHandleAnchorMouseout = null;
            },

            handleEditableMouseover: function (event) {
                var target = MediumEditor.util.getClosestTag(event.target, 'a');

                if (false === target) {
                    return;
                }

                // Detect empty href attributes
                // The browser will make href="" or href="#top"
                // into absolute urls when accessed as event.target.href, so check the html
                if (!this.showOnEmptyLinks &&
                    (!/href=["']\S+["']/.test(target.outerHTML) || /href=["']#\S+["']/.test(target.outerHTML))) {
                    return true;
                }

                // only show when toolbar is not present
                var toolbar = this.base.getExtensionByName('toolbar');
                if (!this.showWhenToolbarIsVisible && toolbar && toolbar.isDisplayed && toolbar.isDisplayed()) {
                    return true;
                }

                // detach handler for other anchor in case we hovered multiple anchors quickly
                if (this.activeAnchor && this.activeAnchor !== target) {
                    this.detachPreviewHandlers();
                }

                this.anchorToPreview = target;

                this.instanceHandleAnchorMouseout = this.handleAnchorMouseout.bind(this);
                this.on(this.anchorToPreview, 'mouseout', this.instanceHandleAnchorMouseout);
                // Using setTimeout + delay because:
                // - We're going to show the anchor preview according to the configured delay
                //   if the mouse has not left the anchor tag in that time
                this.base.delay(function () {
                    if (this.anchorToPreview) {
                        this.showPreview(this.anchorToPreview);
                    }
                }.bind(this));
            },

            handlePreviewMouseover: function () {
                this.lastOver = (new Date()).getTime();
                this.hovering = true;
            },

            handlePreviewMouseout: function (event) {
                if (!event.relatedTarget || !/anchor-preview/.test(event.relatedTarget.className)) {
                    this.hovering = false;
                }
            },

            updatePreview: function () {
                if (this.hovering) {
                    return true;
                }
                var durr = (new Date()).getTime() - this.lastOver;
                if (durr > this.hideDelay) {
                    // hide the preview 1/2 second after mouse leaves the link
                    this.detachPreviewHandlers();
                }
            },

            detachPreviewHandlers: function () {
                // cleanup
                clearInterval(this.intervalTimer);
                if (this.instanceHandlePreviewMouseover) {
                    this.off(this.anchorPreview, 'mouseover', this.instanceHandlePreviewMouseover);
                    this.off(this.anchorPreview, 'mouseout', this.instanceHandlePreviewMouseout);
                    if (this.activeAnchor) {
                        this.off(this.activeAnchor, 'mouseover', this.instanceHandlePreviewMouseover);
                        this.off(this.activeAnchor, 'mouseout', this.instanceHandlePreviewMouseout);
                    }
                }

                this.hidePreview();

                this.hovering = this.instanceHandlePreviewMouseover = this.instanceHandlePreviewMouseout = null;
            },

            // TODO: break up method and extract out handlers
            attachPreviewHandlers: function () {
                this.lastOver = (new Date()).getTime();
                this.hovering = true;

                this.instanceHandlePreviewMouseover = this.handlePreviewMouseover.bind(this);
                this.instanceHandlePreviewMouseout = this.handlePreviewMouseout.bind(this);

                this.intervalTimer = setInterval(this.updatePreview.bind(this), 200);

                this.on(this.anchorPreview, 'mouseover', this.instanceHandlePreviewMouseover);
                this.on(this.anchorPreview, 'mouseout', this.instanceHandlePreviewMouseout);
                this.on(this.activeAnchor, 'mouseover', this.instanceHandlePreviewMouseover);
                this.on(this.activeAnchor, 'mouseout', this.instanceHandlePreviewMouseout);
            }
        });

        MediumEditor.extensions.anchorPreview = AnchorPreview;
    }());

    (function () {
        'use strict';

        var WHITESPACE_CHARS,
            KNOWN_TLDS_FRAGMENT,
            LINK_REGEXP_TEXT,
            KNOWN_TLDS_REGEXP,
            LINK_REGEXP;

        WHITESPACE_CHARS = [' ', '\t', '\n', '\r', '\u00A0', '\u2000', '\u2001', '\u2002', '\u2003',
            '\u2028', '\u2029'];
        KNOWN_TLDS_FRAGMENT = 'com|net|org|edu|gov|mil|aero|asia|biz|cat|coop|info|int|jobs|mobi|museum|name|post|pro|tel|travel|' +
            'xxx|ac|ad|ae|af|ag|ai|al|am|an|ao|aq|ar|as|at|au|aw|ax|az|ba|bb|bd|be|bf|bg|bh|bi|bj|bm|bn|bo|br|bs|bt|bv|bw|by|' +
            'bz|ca|cc|cd|cf|cg|ch|ci|ck|cl|cm|cn|co|cr|cs|cu|cv|cx|cy|cz|dd|de|dj|dk|dm|do|dz|ec|ee|eg|eh|er|es|et|eu|fi|fj|' +
            'fk|fm|fo|fr|ga|gb|gd|ge|gf|gg|gh|gi|gl|gm|gn|gp|gq|gr|gs|gt|gu|gw|gy|hk|hm|hn|hr|ht|hu|id|ie|il|im|in|io|iq|ir|' +
            'is|it|je|jm|jo|jp|ke|kg|kh|ki|km|kn|kp|kr|kw|ky|kz|la|lb|lc|li|lk|lr|ls|lt|lu|lv|ly|ma|mc|md|me|mg|mh|mk|ml|mm|' +
            'mn|mo|mp|mq|mr|ms|mt|mu|mv|mw|mx|my|mz|na|nc|ne|nf|ng|ni|nl|no|np|nr|nu|nz|om|pa|pe|pf|pg|ph|pk|pl|pm|pn|pr|ps|' +
            'pt|pw|py|qa|re|ro|rs|ru|rw|sa|sb|sc|sd|se|sg|sh|si|sj|ja|sk|sl|sm|sn|so|sr|ss|st|su|sv|sx|sy|sz|tc|td|tf|tg|th|' +
            'tj|tk|tl|tm|tn|to|tp|tr|tt|tv|tw|tz|ua|ug|uk|us|uy|uz|va|vc|ve|vg|vi|vn|vu|wf|ws|ye|yt|yu|za|zm|zw';

        LINK_REGEXP_TEXT =
            '(' +
            // Version of Gruber URL Regexp optimized for JS: http://stackoverflow.com/a/17733640
            '((?:(https?://|ftps?://|nntp://)|www\\d{0,3}[.]|[a-z0-9.\\-]+[.](' + KNOWN_TLDS_FRAGMENT + ')\\\/)\\S+(?:[^\\s`!\\[\\]{};:\'\".,?\u00AB\u00BB\u201C\u201D\u2018\u2019]))' +
            // Addition to above Regexp to support bare domains/one level subdomains with common non-i18n TLDs and without www prefix:
            ')|(([a-z0-9\\-]+\\.)?[a-z0-9\\-]+\\.(' + KNOWN_TLDS_FRAGMENT + '))';

        KNOWN_TLDS_REGEXP = new RegExp('^(' + KNOWN_TLDS_FRAGMENT + ')$', 'i');

        LINK_REGEXP = new RegExp(LINK_REGEXP_TEXT, 'gi');

        function nodeIsNotInsideAnchorTag(node) {
            return !MediumEditor.util.getClosestTag(node, 'a');
        }

        var AutoLink = MediumEditor.Extension.extend({
            init: function () {
                MediumEditor.Extension.prototype.init.apply(this, arguments);

                this.disableEventHandling = false;
                this.subscribe('editableKeypress', this.onKeypress.bind(this));
                this.subscribe('editableBlur', this.onBlur.bind(this));
                // MS IE has it's own auto-URL detect feature but ours is better in some ways. Be consistent.
                this.document.execCommand('AutoUrlDetect', false, false);
            },

            isLastInstance: function () {
                var activeInstances = 0;
                for (var i = 0; i < this.window._mediumEditors.length; i++) {
                    var editor = this.window._mediumEditors[i];
                    if (editor !== null && editor.getExtensionByName('autoLink') !== undefined) {
                        activeInstances++;
                    }
                }
                return activeInstances === 1;
            },

            destroy: function () {
                // Turn AutoUrlDetect back on
                if (this.document.queryCommandSupported('AutoUrlDetect') && this.isLastInstance()) {
                    this.document.execCommand('AutoUrlDetect', false, true);
                }
            },

            onBlur: function (blurEvent, editable) {
                this.performLinking(editable);
            },

            onKeypress: function (keyPressEvent) {
                if (this.disableEventHandling) {
                    return;
                }

                if (MediumEditor.util.isKey(keyPressEvent, [MediumEditor.util.keyCode.SPACE, MediumEditor.util.keyCode.ENTER])) {
                    clearTimeout(this.performLinkingTimeout);
                    // Saving/restoring the selection in the middle of a keypress doesn't work well...
                    this.performLinkingTimeout = setTimeout(function () {
                        try {
                            var sel = this.base.exportSelection();
                            if (this.performLinking(keyPressEvent.target)) {
                                // pass true for favorLaterSelectionAnchor - this is needed for links at the end of a
                                // paragraph in MS IE, or MS IE causes the link to be deleted right after adding it.
                                this.base.importSelection(sel, true);
                            }
                        } catch (e) {
                            if (window.console) {
                                window.console.error('Failed to perform linking', e);
                            }
                            this.disableEventHandling = true;
                        }
                    }.bind(this), 0);
                }
            },

            performLinking: function (contenteditable) {
                /*
                 Perform linking on blockElement basis, blockElements are HTML elements with text content and without
                 child element.

                 Example:
                 - HTML content
                 <blockquote>
                 <p>link.</p>
                 <p>my</p>
                 </blockquote>

                 - blockElements
                 [<p>link.</p>, <p>my</p>]

                 otherwise the detection can wrongly find the end of one paragraph and the beginning of another paragraph
                 to constitute a link, such as a paragraph ending "link." and the next paragraph beginning with "my" is
                 interpreted into "link.my" and the code tries to create a link across blockElements - which doesn't work
                 and is terrible.
                 (Medium deletes the spaces/returns between P tags so the textContent ends up without paragraph spacing)
                 */
                var blockElements = MediumEditor.util.splitByBlockElements(contenteditable),
                    documentModified = false;
                if (blockElements.length === 0) {
                    blockElements = [contenteditable];
                }
                for (var i = 0; i < blockElements.length; i++) {
                    documentModified = this.removeObsoleteAutoLinkSpans(blockElements[i]) || documentModified;
                    documentModified = this.performLinkingWithinElement(blockElements[i]) || documentModified;
                }
                this.base.events.updateInput(contenteditable, { target: contenteditable, currentTarget: contenteditable });
                return documentModified;
            },

            removeObsoleteAutoLinkSpans: function (element) {
                if (!element || element.nodeType === 3) {
                    return false;
                }

                var spans = element.querySelectorAll('span[data-auto-link="true"]'),
                    documentModified = false;

                for (var i = 0; i < spans.length; i++) {
                    var textContent = spans[i].textContent;
                    if (textContent.indexOf('://') === -1) {
                        textContent = MediumEditor.util.ensureUrlHasProtocol(textContent);
                    }
                    if (spans[i].getAttribute('data-href') !== textContent && nodeIsNotInsideAnchorTag(spans[i])) {
                        documentModified = true;
                        var trimmedTextContent = textContent.replace(/\s+$/, '');
                        if (spans[i].getAttribute('data-href') === trimmedTextContent) {
                            var charactersTrimmed = textContent.length - trimmedTextContent.length,
                                subtree = MediumEditor.util.splitOffDOMTree(spans[i], this.splitTextBeforeEnd(spans[i], charactersTrimmed));
                            spans[i].parentNode.insertBefore(subtree, spans[i].nextSibling);
                        } else {
                            // Some editing has happened to the span, so just remove it entirely. The user can put it back
                            // around just the href content if they need to prevent it from linking
                            MediumEditor.util.unwrap(spans[i], this.document);
                        }
                    }
                }
                return documentModified;
            },

            splitTextBeforeEnd: function (element, characterCount) {
                var treeWalker = this.document.createTreeWalker(element, NodeFilter.SHOW_TEXT, null, false),
                    lastChildNotExhausted = true;

                // Start the tree walker at the last descendant of the span
                while (lastChildNotExhausted) {
                    lastChildNotExhausted = treeWalker.lastChild() !== null;
                }

                var currentNode,
                    currentNodeValue,
                    previousNode;
                while (characterCount > 0 && previousNode !== null) {
                    currentNode = treeWalker.currentNode;
                    currentNodeValue = currentNode.nodeValue;
                    if (currentNodeValue.length > characterCount) {
                        previousNode = currentNode.splitText(currentNodeValue.length - characterCount);
                        characterCount = 0;
                    } else {
                        previousNode = treeWalker.previousNode();
                        characterCount -= currentNodeValue.length;
                    }
                }
                return previousNode;
            },

            performLinkingWithinElement: function (element) {
                var matches = this.findLinkableText(element),
                    linkCreated = false;

                for (var matchIndex = 0; matchIndex < matches.length; matchIndex++) {
                    var matchingTextNodes = MediumEditor.util.findOrCreateMatchingTextNodes(this.document, element,
                        matches[matchIndex]);
                    if (this.shouldNotLink(matchingTextNodes)) {
                        continue;
                    }
                    this.createAutoLink(matchingTextNodes, matches[matchIndex].href);
                }
                return linkCreated;
            },

            shouldNotLink: function (textNodes) {
                var shouldNotLink = false;
                for (var i = 0; i < textNodes.length && shouldNotLink === false; i++) {
                    // Do not link if the text node is either inside an anchor or inside span[data-auto-link]
                    shouldNotLink = !!MediumEditor.util.traverseUp(textNodes[i], function (node) {
                        return node.nodeName.toLowerCase() === 'a' ||
                            (node.getAttribute && node.getAttribute('data-auto-link') === 'true');
                    });
                }
                return shouldNotLink;
            },

            findLinkableText: function (contenteditable) {
                var textContent = contenteditable.textContent,
                    match = null,
                    matches = [];

                while ((match = LINK_REGEXP.exec(textContent)) !== null) {
                    var matchOk = true,
                        matchEnd = match.index + match[0].length;
                    // If the regexp detected something as a link that has text immediately preceding/following it, bail out.
                    matchOk = (match.index === 0 || WHITESPACE_CHARS.indexOf(textContent[match.index - 1]) !== -1) &&
                        (matchEnd === textContent.length || WHITESPACE_CHARS.indexOf(textContent[matchEnd]) !== -1);
                    // If the regexp detected a bare domain that doesn't use one of our expected TLDs, bail out.
                    matchOk = matchOk && (match[0].indexOf('/') !== -1 ||
                        KNOWN_TLDS_REGEXP.test(match[0].split('.').pop().split('?').shift()));

                    if (matchOk) {
                        matches.push({
                            href: match[0],
                            start: match.index,
                            end: matchEnd
                        });
                    }
                }
                return matches;
            },

            createAutoLink: function (textNodes, href) {
                href = MediumEditor.util.ensureUrlHasProtocol(href);
                var anchor = MediumEditor.util.createLink(this.document, textNodes, href, this.getEditorOption('targetBlank') ? '_blank' : null),
                    span = this.document.createElement('span');
                span.setAttribute('data-auto-link', 'true');
                span.setAttribute('data-href', href);
                anchor.insertBefore(span, anchor.firstChild);
                while (anchor.childNodes.length > 1) {
                    span.appendChild(anchor.childNodes[1]);
                }
            }

        });

        MediumEditor.extensions.autoLink = AutoLink;
    }());

    (function () {
        'use strict';

        var CLASS_DRAG_OVER = 'medium-editor-dragover';

        function clearClassNames(element) {
            var editable = MediumEditor.util.getContainerEditorElement(element),
                existing = Array.prototype.slice.call(editable.parentElement.querySelectorAll('.' + CLASS_DRAG_OVER));

            existing.forEach(function (el) {
                el.classList.remove(CLASS_DRAG_OVER);
            });
        }

        var FileDragging = MediumEditor.Extension.extend({
            name: 'fileDragging',

            allowedTypes: ['image'],

            init: function () {
                MediumEditor.Extension.prototype.init.apply(this, arguments);

                this.subscribe('editableDrag', this.handleDrag.bind(this));
                this.subscribe('editableDrop', this.handleDrop.bind(this));
            },

            handleDrag: function (event) {
                event.preventDefault();
                event.dataTransfer.dropEffect = 'copy';

                var target = event.target.classList ? event.target : event.target.parentElement;

                // Ensure the class gets removed from anything that had it before
                clearClassNames(target);

                if (event.type === 'dragover') {
                    target.classList.add(CLASS_DRAG_OVER);
                }
            },

            handleDrop: function (event) {
                // Prevent file from opening in the current window
                event.preventDefault();
                event.stopPropagation();
                // Select the dropping target, and set the selection to the end of the target
                // https://github.com/yabwe/medium-editor/issues/980
                this.base.selectElement(event.target);
                var selection = this.base.exportSelection();
                selection.start = selection.end;
                this.base.importSelection(selection);
                // IE9 does not support the File API, so prevent file from opening in the window
                // but also don't try to actually get the file
                if (event.dataTransfer.files) {
                    Array.prototype.slice.call(event.dataTransfer.files).forEach(function (file) {
                        if (this.isAllowedFile(file)) {
                            if (file.type.match('image')) {
                                this.insertImageFile(file);
                            }
                        }
                    }, this);
                }

                // Make sure we remove our class from everything
                clearClassNames(event.target);
            },

            isAllowedFile: function (file) {
                return this.allowedTypes.some(function (fileType) {
                    return !!file.type.match(fileType);
                });
            },

            insertImageFile: function (file) {
                if (typeof FileReader !== 'function') {
                    return;
                }
                var fileReader = new FileReader();
                fileReader.readAsDataURL(file);

                // attach the onload event handler, makes it easier to listen in with jasmine
                fileReader.addEventListener('load', function (e) {
                    var addImageElement = this.document.createElement('img');
                    addImageElement.src = e.target.result;
                    MediumEditor.util.insertHTMLCommand(this.document, addImageElement.outerHTML);
                }.bind(this));
            }
        });

        MediumEditor.extensions.fileDragging = FileDragging;
    }());

    (function () {
        'use strict';

        var KeyboardCommands = MediumEditor.Extension.extend({
            name: 'keyboard-commands',

            /* KeyboardCommands Options */

            /* commands: [Array]
             * Array of objects describing each command and the combination of keys that will trigger it
             * Required for each object:
             *   command [String] (argument passed to editor.execAction())
             *   key [String] (keyboard character that triggers this command)
             *   meta [boolean] (whether the ctrl/meta key has to be active or inactive)
             *   shift [boolean] (whether the shift key has to be active or inactive)
             *   alt [boolean] (whether the alt key has to be active or inactive)
             */
            commands: [
                {
                    command: 'bold',
                    key: 'B',
                    meta: true,
                    shift: false,
                    alt: false
                },
                {
                    command: 'italic',
                    key: 'I',
                    meta: true,
                    shift: false,
                    alt: false
                },
                {
                    command: 'underline',
                    key: 'U',
                    meta: true,
                    shift: false,
                    alt: false
                }
            ],

            init: function () {
                MediumEditor.Extension.prototype.init.apply(this, arguments);

                this.subscribe('editableKeydown', this.handleKeydown.bind(this));
                this.keys = {};
                this.commands.forEach(function (command) {
                    var keyCode = command.key.charCodeAt(0);
                    if (!this.keys[keyCode]) {
                        this.keys[keyCode] = [];
                    }
                    this.keys[keyCode].push(command);
                }, this);
            },

            handleKeydown: function (event) {
                var keyCode = MediumEditor.util.getKeyCode(event);
                if (!this.keys[keyCode]) {
                    return;
                }

                var isMeta = MediumEditor.util.isMetaCtrlKey(event),
                    isShift = !!event.shiftKey,
                    isAlt = !!event.altKey;

                this.keys[keyCode].forEach(function (data) {
                    if (data.meta === isMeta &&
                        data.shift === isShift &&
                        (data.alt === isAlt ||
                        undefined === data.alt)) { // TODO deprecated: remove check for undefined === data.alt when jumping to 6.0.0
                        event.preventDefault();
                        event.stopPropagation();

                        // command can be a function to execute
                        if (typeof data.command === 'function') {
                            data.command.apply(this);
                        }
                        // command can be false so the shortcut is just disabled
                        else if (false !== data.command) {
                            this.execAction(data.command);
                        }
                    }
                }, this);
            }
        });

        MediumEditor.extensions.keyboardCommands = KeyboardCommands;
    }());

    (function () {
        'use strict';

        var FontNameForm = MediumEditor.extensions.form.extend({

            name: 'fontname',
            action: 'fontName',
            aria: 'change font name',
            contentDefault: '&#xB1;', // ±
            contentFA: '<i class="fa fa-font"></i>',

            fonts: ['', 'Arial', 'Verdana', 'Times New Roman'],

            init: function () {
                MediumEditor.extensions.form.prototype.init.apply(this, arguments);
            },

            // Called when the button the toolbar is clicked
            // Overrides ButtonExtension.handleClick
            handleClick: function (event) {
                event.preventDefault();
                event.stopPropagation();

                if (!this.isDisplayed()) {
                    // Get FontName of current selection (convert to string since IE returns this as number)
                    var fontName = this.document.queryCommandValue('fontName') + '';
                    this.showForm(fontName);
                }

                return false;
            },

            // Called by medium-editor to append form to the toolbar
            getForm: function () {
                if (!this.form) {
                    this.form = this.createForm();
                }
                return this.form;
            },

            // Used by medium-editor when the default toolbar is to be displayed
            isDisplayed: function () {
                return this.getForm().style.display === 'block';
            },

            hideForm: function () {
                this.getForm().style.display = 'none';
                this.getSelect().value = '';
            },

            showForm: function (fontName) {
                var select = this.getSelect();

                this.base.saveSelection();
                this.hideToolbarDefaultActions();
                this.getForm().style.display = 'block';
                this.setToolbarPosition();

                select.value = fontName || '';
                select.focus();
            },

            // Called by core when tearing down medium-editor (destroy)
            destroy: function () {
                if (!this.form) {
                    return false;
                }

                if (this.form.parentNode) {
                    this.form.parentNode.removeChild(this.form);
                }

                delete this.form;
            },

            // core methods

            doFormSave: function () {
                this.base.restoreSelection();
                this.base.checkSelection();
            },

            doFormCancel: function () {
                this.base.restoreSelection();
                this.clearFontName();
                this.base.checkSelection();
            },

            // form creation and event handling
            createForm: function () {
                var doc = this.document,
                    form = doc.createElement('div'),
                    select = doc.createElement('select'),
                    close = doc.createElement('a'),
                    save = doc.createElement('a'),
                    option;

                // Font Name Form (div)
                form.className = 'medium-editor-toolbar-form';
                form.id = 'medium-editor-toolbar-form-fontname-' + this.getEditorId();

                // Handle clicks on the form itself
                this.on(form, 'click', this.handleFormClick.bind(this));

                // Add font names
                for (var i = 0; i<this.fonts.length; i++) {
                    option = doc.createElement('option');
                    option.innerHTML = this.fonts[i];
                    option.value = this.fonts[i];
                    select.appendChild(option);
                }

                select.className = 'medium-editor-toolbar-select';
                form.appendChild(select);

                // Handle typing in the textbox
                this.on(select, 'change', this.handleFontChange.bind(this));

                // Add save buton
                save.setAttribute('href', '#');
                save.className = 'medium-editor-toobar-save';
                save.innerHTML = this.getEditorOption('buttonLabels') === 'fontawesome' ?
                    '<i class="fa fa-check"></i>' :
                    '&#10003;';
                form.appendChild(save);

                // Handle save button clicks (capture)
                this.on(save, 'click', this.handleSaveClick.bind(this), true);

                // Add close button
                close.setAttribute('href', '#');
                close.className = 'medium-editor-toobar-close';
                close.innerHTML = this.getEditorOption('buttonLabels') === 'fontawesome' ?
                    '<i class="fa fa-times"></i>' :
                    '&times;';
                form.appendChild(close);

                // Handle close button clicks
                this.on(close, 'click', this.handleCloseClick.bind(this));

                return form;
            },

            getSelect: function () {
                return this.getForm().querySelector('select.medium-editor-toolbar-select');
            },

            clearFontName: function () {
                MediumEditor.selection.getSelectedElements(this.document).forEach(function (el) {
                    if (el.nodeName.toLowerCase() === 'font' && el.hasAttribute('face')) {
                        el.removeAttribute('face');
                    }
                });
            },

            handleFontChange: function () {
                var font = this.getSelect().value;
                if (font === '') {
                    this.clearFontName();
                } else {
                    this.execAction('fontName', { value: font });
                }
            },

            handleFormClick: function (event) {
                // make sure not to hide form when clicking inside the form
                event.stopPropagation();
            },

            handleSaveClick: function (event) {
                // Clicking Save -> create the font size
                event.preventDefault();
                this.doFormSave();
            },

            handleCloseClick: function (event) {
                // Click Close -> close the form
                event.preventDefault();
                this.doFormCancel();
            }
        });

        MediumEditor.extensions.fontName = FontNameForm;
    }());

    (function () {
        'use strict';

        var FontSizeForm = MediumEditor.extensions.form.extend({

            name: 'fontsize',
            action: 'fontSize',
            aria: 'increase/decrease font size',
            contentDefault: '&#xB1;', // ±
            contentFA: '<i class="fa fa-text-height"></i>',

            init: function () {
                MediumEditor.extensions.form.prototype.init.apply(this, arguments);
            },

            // Called when the button the toolbar is clicked
            // Overrides ButtonExtension.handleClick
            handleClick: function (event) {
                event.preventDefault();
                event.stopPropagation();

                if (!this.isDisplayed()) {
                    // Get fontsize of current selection (convert to string since IE returns this as number)
                    var fontSize = this.document.queryCommandValue('fontSize') + '';
                    this.showForm(fontSize);
                }

                return false;
            },

            // Called by medium-editor to append form to the toolbar
            getForm: function () {
                if (!this.form) {
                    this.form = this.createForm();
                }
                return this.form;
            },

            // Used by medium-editor when the default toolbar is to be displayed
            isDisplayed: function () {
                return this.getForm().style.display === 'block';
            },

            hideForm: function () {
                this.getForm().style.display = 'none';
                this.getInput().value = '';
            },

            showForm: function (fontSize) {
                var input = this.getInput();

                this.base.saveSelection();
                this.hideToolbarDefaultActions();
                this.getForm().style.display = 'block';
                this.setToolbarPosition();

                input.value = fontSize || '';
                input.focus();
            },

            // Called by core when tearing down medium-editor (destroy)
            destroy: function () {
                if (!this.form) {
                    return false;
                }

                if (this.form.parentNode) {
                    this.form.parentNode.removeChild(this.form);
                }

                delete this.form;
            },

            // core methods

            doFormSave: function () {
                this.base.restoreSelection();
                this.base.checkSelection();
            },

            doFormCancel: function () {
                this.base.restoreSelection();
                this.clearFontSize();
                this.base.checkSelection();
            },

            // form creation and event handling
            createForm: function () {
                var doc = this.document,
                    form = doc.createElement('div'),
                    input = doc.createElement('input'),
                    close = doc.createElement('a'),
                    save = doc.createElement('a');

                // Font Size Form (div)
                form.className = 'medium-editor-toolbar-form';
                form.id = 'medium-editor-toolbar-form-fontsize-' + this.getEditorId();

                // Handle clicks on the form itself
                this.on(form, 'click', this.handleFormClick.bind(this));

                // Add font size slider
                input.setAttribute('type', 'range');
                input.setAttribute('min', '1');
                input.setAttribute('max', '7');
                input.className = 'medium-editor-toolbar-input';
                form.appendChild(input);

                // Handle typing in the textbox
                this.on(input, 'change', this.handleSliderChange.bind(this));

                // Add save buton
                save.setAttribute('href', '#');
                save.className = 'medium-editor-toobar-save';
                save.innerHTML = this.getEditorOption('buttonLabels') === 'fontawesome' ?
                    '<i class="fa fa-check"></i>' :
                    '&#10003;';
                form.appendChild(save);

                // Handle save button clicks (capture)
                this.on(save, 'click', this.handleSaveClick.bind(this), true);

                // Add close button
                close.setAttribute('href', '#');
                close.className = 'medium-editor-toobar-close';
                close.innerHTML = this.getEditorOption('buttonLabels') === 'fontawesome' ?
                    '<i class="fa fa-times"></i>' :
                    '&times;';
                form.appendChild(close);

                // Handle close button clicks
                this.on(close, 'click', this.handleCloseClick.bind(this));

                return form;
            },

            getInput: function () {
                return this.getForm().querySelector('input.medium-editor-toolbar-input');
            },

            clearFontSize: function () {
                MediumEditor.selection.getSelectedElements(this.document).forEach(function (el) {
                    if (el.nodeName.toLowerCase() === 'font' && el.hasAttribute('size')) {
                        el.removeAttribute('size');
                    }
                });
            },

            handleSliderChange: function () {
                var size = this.getInput().value;
                if (size === '4') {
                    this.clearFontSize();
                } else {
                    this.execAction('fontSize', { value: size });
                }
            },

            handleFormClick: function (event) {
                // make sure not to hide form when clicking inside the form
                event.stopPropagation();
            },

            handleSaveClick: function (event) {
                // Clicking Save -> create the font size
                event.preventDefault();
                this.doFormSave();
            },

            handleCloseClick: function (event) {
                // Click Close -> close the form
                event.preventDefault();
                this.doFormCancel();
            }
        });

        MediumEditor.extensions.fontSize = FontSizeForm;
    }());
    (function () {
        'use strict';

        /* Helpers and internal variables that don't need to be members of actual paste handler */

        var pasteBinDefaultContent = '%ME_PASTEBIN%',
            lastRange = null,
            keyboardPasteEditable = null,
            stopProp = function (event) {
                event.stopPropagation();
            };

        /*jslint regexp: true*/
        /*
         jslint does not allow character negation, because the negation
         will not match any unicode characters. In the regexes in this
         block, negation is used specifically to match the end of an html
         tag, and in fact unicode characters *should* be allowed.
         */
        function createReplacements() {
            return [
                // Remove anything but the contents within the BODY element
                [new RegExp(/^[\s\S]*<body[^>]*>\s*|\s*<\/body[^>]*>[\s\S]*$/g), ''],

                // cleanup comments added by Chrome when pasting html
                [new RegExp(/<!--StartFragment-->|<!--EndFragment-->/g), ''],

                // Trailing BR elements
                [new RegExp(/<br>$/i), ''],

                // replace two bogus tags that begin pastes from google docs
                [new RegExp(/<[^>]*docs-internal-guid[^>]*>/gi), ''],
                [new RegExp(/<\/b>(<br[^>]*>)?$/gi), ''],

                // un-html spaces and newlines inserted by OS X
                [new RegExp(/<span class="Apple-converted-space">\s+<\/span>/g), ' '],
                [new RegExp(/<br class="Apple-interchange-newline">/g), '<br>'],

                // replace google docs italics+bold with a span to be replaced once the html is inserted
                [new RegExp(/<span[^>]*(font-style:italic;font-weight:(bold|700)|font-weight:(bold|700);font-style:italic)[^>]*>/gi), '<span class="replace-with italic bold">'],

                // replace google docs italics with a span to be replaced once the html is inserted
                [new RegExp(/<span[^>]*font-style:italic[^>]*>/gi), '<span class="replace-with italic">'],

                //[replace google docs bolds with a span to be replaced once the html is inserted
                [new RegExp(/<span[^>]*font-weight:(bold|700)[^>]*>/gi), '<span class="replace-with bold">'],

                // replace manually entered b/i/a tags with real ones
                [new RegExp(/&lt;(\/?)(i|b|a)&gt;/gi), '<$1$2>'],

                // replace manually a tags with real ones, converting smart-quotes from google docs
                [new RegExp(/&lt;a(?:(?!href).)+href=(?:&quot;|&rdquo;|&ldquo;|"|“|”)(((?!&quot;|&rdquo;|&ldquo;|"|“|”).)*)(?:&quot;|&rdquo;|&ldquo;|"|“|”)(?:(?!&gt;).)*&gt;/gi), '<a href="$1">'],

                // Newlines between paragraphs in html have no syntactic value,
                // but then have a tendency to accidentally become additional paragraphs down the line
                [new RegExp(/<\/p>\n+/gi), '</p>'],
                [new RegExp(/\n+<p/gi), '<p'],

                // Microsoft Word makes these odd tags, like <o:p></o:p>
                [new RegExp(/<\/?o:[a-z]*>/gi), ''],

                // Microsoft Word adds some special elements around list items
                [new RegExp(/<!\[if !supportLists\]>(((?!<!).)*)<!\[endif]\>/gi), '$1']
            ];
        }
        /*jslint regexp: false*/

        /**
         * Gets various content types out of the Clipboard API. It will also get the
         * plain text using older IE and WebKit API.
         *
         * @param {event} event Event fired on paste.
         * @param {win} reference to window
         * @param {doc} reference to document
         * @return {Object} Object with mime types and data for those mime types.
         */
        function getClipboardContent(event, win, doc) {
            var dataTransfer = event.clipboardData || win.clipboardData || doc.dataTransfer,
                data = {};

            if (!dataTransfer) {
                return data;
            }

            // Use old WebKit/IE API
            if (dataTransfer.getData) {
                var legacyText = dataTransfer.getData('Text');
                if (legacyText && legacyText.length > 0) {
                    data['text/plain'] = legacyText;
                }
            }

            if (dataTransfer.types) {
                for (var i = 0; i < dataTransfer.types.length; i++) {
                    var contentType = dataTransfer.types[i];
                    data[contentType] = dataTransfer.getData(contentType);
                }
            }

            return data;
        }

        var PasteHandler = MediumEditor.Extension.extend({
            /* Paste Options */

            /* forcePlainText: [boolean]
             * Forces pasting as plain text.
             */
            forcePlainText: true,

            /* cleanPastedHTML: [boolean]
             * cleans pasted content from different sources, like google docs etc.
             */
            cleanPastedHTML: false,

            /* preCleanReplacements: [Array]
             * custom pairs (2 element arrays) of RegExp and replacement text to use during past when
             * __forcePlainText__ or __cleanPastedHTML__ are `true` OR when calling `cleanPaste(text)` helper method.
             * These replacements are executed before any medium editor defined replacements.
             */
            preCleanReplacements: [],

            /* cleanReplacements: [Array]
             * custom pairs (2 element arrays) of RegExp and replacement text to use during paste when
             * __forcePlainText__ or __cleanPastedHTML__ are `true` OR when calling `cleanPaste(text)` helper method.
             * These replacements are executed after any medium editor defined replacements.
             */
            cleanReplacements: [],

            /* cleanAttrs:: [Array]
             * list of element attributes to remove during paste when __cleanPastedHTML__ is `true` or when
             * calling `cleanPaste(text)` or `pasteHTML(html, options)` helper methods.
             */
            cleanAttrs: ['class', 'style', 'dir'],

            /* cleanTags: [Array]
             * list of element tag names to remove during paste when __cleanPastedHTML__ is `true` or when
             * calling `cleanPaste(text)` or `pasteHTML(html, options)` helper methods.
             */
            cleanTags: ['meta'],

            /* unwrapTags: [Array]
             * list of element tag names to unwrap (remove the element tag but retain its child elements)
             * during paste when __cleanPastedHTML__ is `true` or when
             * calling `cleanPaste(text)` or `pasteHTML(html, options)` helper methods.
             */
            unwrapTags: [],

            init: function () {
                MediumEditor.Extension.prototype.init.apply(this, arguments);

                if (this.forcePlainText || this.cleanPastedHTML) {
                    this.subscribe('editableKeydown', this.handleKeydown.bind(this));
                    // We need access to the full event data in paste
                    // so we can't use the editablePaste event here
                    this.getEditorElements().forEach(function (element) {
                        this.on(element, 'paste', this.handlePaste.bind(this));
                    }, this);
                    this.subscribe('addElement', this.handleAddElement.bind(this));
                }
            },

            handleAddElement: function (event, editable) {
                this.on(editable, 'paste', this.handlePaste.bind(this));
            },

            destroy: function () {
                // Make sure pastebin is destroyed in case it's still around for some reason
                if (this.forcePlainText || this.cleanPastedHTML) {
                    this.removePasteBin();
                }
            },

            handlePaste: function (event, editable) {
                if (event.defaultPrevented) {
                    return;
                }

                var clipboardContent = getClipboardContent(event, this.window, this.document),
                    pastedHTML = clipboardContent['text/html'],
                    pastedPlain = clipboardContent['text/plain'];

                if (this.window.clipboardData && event.clipboardData === undefined && !pastedHTML) {
                    // If window.clipboardData exists, but event.clipboardData doesn't exist,
                    // we're probably in IE. IE only has two possibilities for clipboard
                    // data format: 'Text' and 'URL'.
                    //
                    // For IE, we'll fallback to 'Text' for text/html
                    pastedHTML = pastedPlain;
                }

                if (pastedHTML || pastedPlain) {
                    event.preventDefault();

                    this.doPaste(pastedHTML, pastedPlain, editable);
                }
            },

            doPaste: function (pastedHTML, pastedPlain, editable) {
                var paragraphs,
                    html = '',
                    p;

                if (this.cleanPastedHTML && pastedHTML) {
                    return this.cleanPaste(pastedHTML);
                }

                if (!(this.getEditorOption('disableReturn') || (editable && editable.getAttribute('data-disable-return')))) {
                    paragraphs = pastedPlain.split(/[\r\n]+/g);
                    // If there are no \r\n in data, don't wrap in <p>
                    if (paragraphs.length > 1) {
                        for (p = 0; p < paragraphs.length; p += 1) {
                            if (paragraphs[p] !== '') {
                                html += '<p>' + MediumEditor.util.htmlEntities(paragraphs[p]) + '</p>';
                            }
                        }
                    } else {
                        html = MediumEditor.util.htmlEntities(paragraphs[0]);
                    }
                } else {
                    html = MediumEditor.util.htmlEntities(pastedPlain);
                }
                MediumEditor.util.insertHTMLCommand(this.document, html);
            },

            handlePasteBinPaste: function (event) {
                if (event.defaultPrevented) {
                    this.removePasteBin();
                    return;
                }

                var clipboardContent = getClipboardContent(event, this.window, this.document),
                    pastedHTML = clipboardContent['text/html'],
                    pastedPlain = clipboardContent['text/plain'],
                    editable = keyboardPasteEditable;

                // If we have valid html already, or we're not in cleanPastedHTML mode
                // we can ignore the paste bin and just paste now
                if (!this.cleanPastedHTML || pastedHTML) {
                    event.preventDefault();
                    this.removePasteBin();
                    this.doPaste(pastedHTML, pastedPlain, editable);

                    // The event handling code listens for paste on the editable element
                    // in order to trigger the editablePaste event.  Since this paste event
                    // is happening on the pastebin, the event handling code never knows about it
                    // So, we have to trigger editablePaste manually
                    this.trigger('editablePaste', { currentTarget: editable, target: editable }, editable);
                    return;
                }

                // We need to look at the paste bin, so do a setTimeout to let the paste
                // fall through into the paste bin
                setTimeout(function () {
                    // Only look for HTML if we're in cleanPastedHTML mode
                    if (this.cleanPastedHTML) {
                        // If clipboard didn't have HTML, try the paste bin
                        pastedHTML = this.getPasteBinHtml();
                    }

                    // If we needed the paste bin, we're done with it now, remove it
                    this.removePasteBin();

                    // Handle the paste with the html from the paste bin
                    this.doPaste(pastedHTML, pastedPlain, editable);

                    // The event handling code listens for paste on the editable element
                    // in order to trigger the editablePaste event.  Since this paste event
                    // is happening on the pastebin, the event handling code never knows about it
                    // So, we have to trigger editablePaste manually
                    this.trigger('editablePaste', { currentTarget: editable, target: editable }, editable);
                }.bind(this), 0);
            },

            handleKeydown: function (event, editable) {
                // if it's not Ctrl+V, do nothing
                if (!(MediumEditor.util.isKey(event, MediumEditor.util.keyCode.V) && MediumEditor.util.isMetaCtrlKey(event))) {
                    return;
                }

                event.stopImmediatePropagation();

                this.removePasteBin();
                this.createPasteBin(editable);
            },

            createPasteBin: function (editable) {
                var rects,
                    range = MediumEditor.selection.getSelectionRange(this.document),
                    top = this.window.pageYOffset;

                keyboardPasteEditable = editable;

                if (range) {
                    rects = range.getClientRects();

                    // on empty line, rects is empty so we grab information from the first container of the range
                    if (rects.length) {
                        top += rects[0].top;
                    } else {
                        top += range.startContainer.getBoundingClientRect().top;
                    }
                }

                lastRange = range;

                var pasteBinElm = this.document.createElement('div');
                pasteBinElm.id = this.pasteBinId = 'medium-editor-pastebin-' + (+Date.now());
                pasteBinElm.setAttribute('style', 'border: 1px red solid; position: absolute; top: ' + top + 'px; width: 10px; height: 10px; overflow: hidden; opacity: 0');
                pasteBinElm.setAttribute('contentEditable', true);
                pasteBinElm.innerHTML = pasteBinDefaultContent;

                this.document.body.appendChild(pasteBinElm);

                // avoid .focus() to stop other event (actually the paste event)
                this.on(pasteBinElm, 'focus', stopProp);
                this.on(pasteBinElm, 'focusin', stopProp);
                this.on(pasteBinElm, 'focusout', stopProp);

                pasteBinElm.focus();

                MediumEditor.selection.selectNode(pasteBinElm, this.document);

                if (!this.boundHandlePaste) {
                    this.boundHandlePaste = this.handlePasteBinPaste.bind(this);
                }

                this.on(pasteBinElm, 'paste', this.boundHandlePaste);
            },

            removePasteBin: function () {
                if (null !== lastRange) {
                    MediumEditor.selection.selectRange(this.document, lastRange);
                    lastRange = null;
                }

                if (null !== keyboardPasteEditable) {
                    keyboardPasteEditable = null;
                }

                var pasteBinElm = this.getPasteBin();
                if (!pasteBinElm) {
                    return;
                }

                if (pasteBinElm) {
                    this.off(pasteBinElm, 'focus', stopProp);
                    this.off(pasteBinElm, 'focusin', stopProp);
                    this.off(pasteBinElm, 'focusout', stopProp);
                    this.off(pasteBinElm, 'paste', this.boundHandlePaste);
                    pasteBinElm.parentElement.removeChild(pasteBinElm);
                }
            },

            getPasteBin: function () {
                return this.document.getElementById(this.pasteBinId);
            },

            getPasteBinHtml: function () {
                var pasteBinElm = this.getPasteBin();

                if (!pasteBinElm) {
                    return false;
                }

                // WebKit has a nice bug where it clones the paste bin if you paste from for example notepad
                // so we need to force plain text mode in this case
                if (pasteBinElm.firstChild && pasteBinElm.firstChild.id === 'mcepastebin') {
                    return false;
                }

                var pasteBinHtml = pasteBinElm.innerHTML;

                // If paste bin is empty try using plain text mode
                // since that is better than nothing right
                if (!pasteBinHtml || pasteBinHtml === pasteBinDefaultContent) {
                    return false;
                }

                return pasteBinHtml;
            },

            cleanPaste: function (text) {
                var i, elList, tmp, workEl,
                    multiline = /<p|<br|<div/.test(text),
                    replacements = [].concat(
                        this.preCleanReplacements || [],
                        createReplacements(),
                        this.cleanReplacements || []);

                for (i = 0; i < replacements.length; i += 1) {
                    text = text.replace(replacements[i][0], replacements[i][1]);
                }

                if (!multiline) {
                    return this.pasteHTML(text);
                }

                // create a temporary div to cleanup block elements
                tmp = this.document.createElement('div');

                // double br's aren't converted to p tags, but we want paragraphs.
                tmp.innerHTML = '<p>' + text.split('<br><br>').join('</p><p>') + '</p>';

                // block element cleanup
                elList = tmp.querySelectorAll('a,p,div,br');
                for (i = 0; i < elList.length; i += 1) {
                    workEl = elList[i];

                    // Microsoft Word replaces some spaces with newlines.
                    // While newlines between block elements are meaningless, newlines within
                    // elements are sometimes actually spaces.
                    workEl.innerHTML = workEl.innerHTML.replace(/\n/gi, ' ');

                    switch (workEl.nodeName.toLowerCase()) {
                        case 'p':
                        case 'div':
                            this.filterCommonBlocks(workEl);
                            break;
                        case 'br':
                            this.filterLineBreak(workEl);
                            break;
                    }
                }

                this.pasteHTML(tmp.innerHTML);
            },

            pasteHTML: function (html, options) {
                options = MediumEditor.util.defaults({}, options, {
                    cleanAttrs: this.cleanAttrs,
                    cleanTags: this.cleanTags,
                    unwrapTags: this.unwrapTags
                });

                var elList, workEl, i, fragmentBody, pasteBlock = this.document.createDocumentFragment();

                pasteBlock.appendChild(this.document.createElement('body'));

                fragmentBody = pasteBlock.querySelector('body');
                fragmentBody.innerHTML = html;

                this.cleanupSpans(fragmentBody);

                elList = fragmentBody.querySelectorAll('*');
                for (i = 0; i < elList.length; i += 1) {
                    workEl = elList[i];

                    if ('a' === workEl.nodeName.toLowerCase() && this.getEditorOption('targetBlank')) {
                        MediumEditor.util.setTargetBlank(workEl);
                    }

                    MediumEditor.util.cleanupAttrs(workEl, options.cleanAttrs);
                    MediumEditor.util.cleanupTags(workEl, options.cleanTags);
                    MediumEditor.util.unwrapTags(workEl, options.unwrapTags);
                }

                MediumEditor.util.insertHTMLCommand(this.document, fragmentBody.innerHTML.replace(/&nbsp;/g, ' '));
            },

            // TODO (6.0): Make this an internal helper instead of member of paste handler
            isCommonBlock: function (el) {
                return (el && (el.nodeName.toLowerCase() === 'p' || el.nodeName.toLowerCase() === 'div'));
            },

            // TODO (6.0): Make this an internal helper instead of member of paste handler
            filterCommonBlocks: function (el) {
                if (/^\s*$/.test(el.textContent) && el.parentNode) {
                    el.parentNode.removeChild(el);
                }
            },

            // TODO (6.0): Make this an internal helper instead of member of paste handler
            filterLineBreak: function (el) {
                if (this.isCommonBlock(el.previousElementSibling)) {
                    // remove stray br's following common block elements
                    this.removeWithParent(el);
                } else if (this.isCommonBlock(el.parentNode) && (el.parentNode.firstChild === el || el.parentNode.lastChild === el)) {
                    // remove br's just inside open or close tags of a div/p
                    this.removeWithParent(el);
                } else if (el.parentNode && el.parentNode.childElementCount === 1 && el.parentNode.textContent === '') {
                    // and br's that are the only child of elements other than div/p
                    this.removeWithParent(el);
                }
            },

            // TODO (6.0): Make this an internal helper instead of member of paste handler
            // remove an element, including its parent, if it is the only element within its parent
            removeWithParent: function (el) {
                if (el && el.parentNode) {
                    if (el.parentNode.parentNode && el.parentNode.childElementCount === 1) {
                        el.parentNode.parentNode.removeChild(el.parentNode);
                    } else {
                        el.parentNode.removeChild(el);
                    }
                }
            },

            // TODO (6.0): Make this an internal helper instead of member of paste handler
            cleanupSpans: function (containerEl) {
                var i,
                    el,
                    newEl,
                    spans = containerEl.querySelectorAll('.replace-with'),
                    isCEF = function (el) {
                        return (el && el.nodeName !== '#text' && el.getAttribute('contenteditable') === 'false');
                    };

                for (i = 0; i < spans.length; i += 1) {
                    el = spans[i];
                    newEl = this.document.createElement(el.classList.contains('bold') ? 'b' : 'i');

                    if (el.classList.contains('bold') && el.classList.contains('italic')) {
                        // add an i tag as well if this has both italics and bold
                        newEl.innerHTML = '<i>' + el.innerHTML + '</i>';
                    } else {
                        newEl.innerHTML = el.innerHTML;
                    }
                    el.parentNode.replaceChild(newEl, el);
                }

                spans = containerEl.querySelectorAll('span');
                for (i = 0; i < spans.length; i += 1) {
                    el = spans[i];

                    // bail if span is in contenteditable = false
                    if (MediumEditor.util.traverseUp(el, isCEF)) {
                        return false;
                    }

                    // remove empty spans, replace others with their contents
                    MediumEditor.util.unwrap(el, this.document);
                }
            }
        });

        MediumEditor.extensions.paste = PasteHandler;
    }());

    (function () {
        'use strict';

        var Placeholder = MediumEditor.Extension.extend({
            name: 'placeholder',

            /* Placeholder Options */

            /* text: [string]
             * Text to display in the placeholder
             */
            text: 'Type your text',

            /* hideOnClick: [boolean]
             * Should we hide the placeholder on click (true) or when user starts typing (false)
             */
            hideOnClick: true,

            init: function () {
                MediumEditor.Extension.prototype.init.apply(this, arguments);

                this.initPlaceholders();
                this.attachEventHandlers();
            },

            initPlaceholders: function () {
                this.getEditorElements().forEach(this.initElement, this);
            },

            handleAddElement: function (event, editable) {
                this.initElement(editable);
            },

            initElement: function (el) {
                if (!el.getAttribute('data-placeholder')) {
                    el.setAttribute('data-placeholder', this.text);
                }
                this.updatePlaceholder(el);
            },

            destroy: function () {
                this.getEditorElements().forEach(this.cleanupElement, this);
            },

            handleRemoveElement: function (event, editable) {
                this.cleanupElement(editable);
            },

            cleanupElement: function (el) {
                if (el.getAttribute('data-placeholder') === this.text) {
                    el.removeAttribute('data-placeholder');
                }
            },

            showPlaceholder: function (el) {
                if (el) {
                    // https://github.com/yabwe/medium-editor/issues/234
                    // In firefox, styling the placeholder with an absolutely positioned
                    // pseudo element causes the cursor to appear in a bad location
                    // when the element is completely empty, so apply a different class to
                    // style it with a relatively positioned pseudo element
                    if (MediumEditor.util.isFF && el.childNodes.length === 0) {
                        el.classList.add('medium-editor-placeholder-relative');
                        el.classList.remove('medium-editor-placeholder');
                    } else {
                        el.classList.add('medium-editor-placeholder');
                        el.classList.remove('medium-editor-placeholder-relative');
                    }
                }
            },

            hidePlaceholder: function (el) {
                if (el) {
                    el.classList.remove('medium-editor-placeholder');
                    el.classList.remove('medium-editor-placeholder-relative');
                }
            },

            updatePlaceholder: function (el, dontShow) {
                // If the element has content, hide the placeholder
                if (el.querySelector('img, blockquote, ul, ol, table') || (el.textContent.replace(/^\s+|\s+$/g, '') !== '')) {
                    return this.hidePlaceholder(el);
                }

                if (!dontShow) {
                    this.showPlaceholder(el);
                }
            },

            attachEventHandlers: function () {
                if (this.hideOnClick) {
                    // For the 'hideOnClick' option, the placeholder should always be hidden on focus
                    this.subscribe('focus', this.handleFocus.bind(this));
                }

                // If the editor has content, it should always hide the placeholder
                this.subscribe('editableInput', this.handleInput.bind(this));

                // When the editor loses focus, check if the placeholder should be visible
                this.subscribe('blur', this.handleBlur.bind(this));

                // Need to know when elements are added/removed from the editor
                this.subscribe('addElement', this.handleAddElement.bind(this));
                this.subscribe('removeElement', this.handleRemoveElement.bind(this));
            },

            handleInput: function (event, element) {
                // If the placeholder should be hidden on focus and the
                // element has focus, don't show the placeholder
                var dontShow = this.hideOnClick && (element === this.base.getFocusedElement());

                // Editor's content has changed, check if the placeholder should be hidden
                this.updatePlaceholder(element, dontShow);
            },

            handleFocus: function (event, element) {
                // Editor has focus, hide the placeholder
                this.hidePlaceholder(element);
            },

            handleBlur: function (event, element) {
                // Editor has lost focus, check if the placeholder should be shown
                this.updatePlaceholder(element);
            }
        });

        MediumEditor.extensions.placeholder = Placeholder;
    }());

    (function () {
        'use strict';

        var Toolbar = MediumEditor.Extension.extend({
            name: 'toolbar',

            /* Toolbar Options */

            /* align: ['left'|'center'|'right']
             * When the __static__ option is true, this aligns the static toolbar
             * relative to the medium-editor element.
             */
            align: 'center',

            /* allowMultiParagraphSelection: [boolean]
             * enables/disables whether the toolbar should be displayed when
             * selecting multiple paragraphs/block elements
             */
            allowMultiParagraphSelection: true,

            /* buttons: [Array]
             * the names of the set of buttons to display on the toolbar.
             */
            buttons: ['bold', 'italic', 'underline', 'anchor', 'h2', 'h3', 'quote'],

            /* diffLeft: [Number]
             * value in pixels to be added to the X axis positioning of the toolbar.
             */
            diffLeft: 0,

            /* diffTop: [Number]
             * value in pixels to be added to the Y axis positioning of the toolbar.
             */
            diffTop: -10,

            /* firstButtonClass: [string]
             * CSS class added to the first button in the toolbar.
             */
            firstButtonClass: 'medium-editor-button-first',

            /* lastButtonClass: [string]
             * CSS class added to the last button in the toolbar.
             */
            lastButtonClass: 'medium-editor-button-last',

            /* standardizeSelectionStart: [boolean]
             * enables/disables standardizing how the beginning of a range is decided
             * between browsers whenever the selected text is analyzed for updating toolbar buttons status.
             */
            standardizeSelectionStart: false,

            /* static: [boolean]
             * enable/disable the toolbar always displaying in the same location
             * relative to the medium-editor element.
             */
            static: false,

            /* sticky: [boolean]
             * When the __static__ option is true, this enables/disables the toolbar
             * "sticking" to the viewport and staying visible on the screen while
             * the page scrolls.
             */
            sticky: false,

            /* stickyTopOffset: [Number]
             * Value in pixel of the top offset above the toolbar
             */
            stickyTopOffset: 0,

            /* updateOnEmptySelection: [boolean]
             * When the __static__ option is true, this enables/disables updating
             * the state of the toolbar buttons even when the selection is collapsed
             * (there is no selection, just a cursor).
             */
            updateOnEmptySelection: false,

            /* relativeContainer: [node]
             * appending the toolbar to a given node instead of body
             */
            relativeContainer: null,

            init: function () {
                MediumEditor.Extension.prototype.init.apply(this, arguments);

                this.initThrottledMethods();

                if (!this.relativeContainer) {
                    this.getEditorOption('elementsContainer').appendChild(this.getToolbarElement());
                } else {
                    this.relativeContainer.appendChild(this.getToolbarElement());
                }
            },

            // Helper method to execute method for every extension, but ignoring the toolbar extension
            forEachExtension: function (iterator, context) {
                return this.base.extensions.forEach(function (command) {
                    if (command === this) {
                        return;
                    }
                    return iterator.apply(context || this, arguments);
                }, this);
            },

            // Toolbar creation/deletion

            createToolbar: function () {
                var toolbar = this.document.createElement('div');

                toolbar.id = 'medium-editor-toolbar-' + this.getEditorId();
                toolbar.className = 'medium-editor-toolbar';

                if (this.static) {
                    toolbar.className += ' static-toolbar';
                } else if (this.relativeContainer) {
                    toolbar.className += ' medium-editor-relative-toolbar';
                } else {
                    toolbar.className += ' medium-editor-stalker-toolbar';
                }

                toolbar.appendChild(this.createToolbarButtons());

                // Add any forms that extensions may have
                this.forEachExtension(function (extension) {
                    if (extension.hasForm) {
                        toolbar.appendChild(extension.getForm());
                    }
                });

                this.attachEventHandlers();

                return toolbar;
            },

            createToolbarButtons: function () {
                var ul = this.document.createElement('ul'),
                    li,
                    btn,
                    buttons,
                    extension,
                    buttonName,
                    buttonOpts;

                ul.id = 'medium-editor-toolbar-actions' + this.getEditorId();
                ul.className = 'medium-editor-toolbar-actions';
                ul.style.display = 'block';

                this.buttons.forEach(function (button) {
                    if (typeof button === 'string') {
                        buttonName = button;
                        buttonOpts = null;
                    } else {
                        buttonName = button.name;
                        buttonOpts = button;
                    }

                    // If the button already exists as an extension, it'll be returned
                    // othwerise it'll create the default built-in button
                    extension = this.base.addBuiltInExtension(buttonName, buttonOpts);

                    if (extension && typeof extension.getButton === 'function') {
                        btn = extension.getButton(this.base);
                        li = this.document.createElement('li');
                        if (MediumEditor.util.isElement(btn)) {
                            li.appendChild(btn);
                        } else {
                            li.innerHTML = btn;
                        }
                        ul.appendChild(li);
                    }
                }, this);

                buttons = ul.querySelectorAll('button');
                if (buttons.length > 0) {
                    buttons[0].classList.add(this.firstButtonClass);
                    buttons[buttons.length - 1].classList.add(this.lastButtonClass);
                }

                return ul;
            },

            destroy: function () {
                if (this.toolbar) {
                    if (this.toolbar.parentNode) {
                        this.toolbar.parentNode.removeChild(this.toolbar);
                    }
                    delete this.toolbar;
                }
            },

            // Toolbar accessors

            getInteractionElements: function () {
                return this.getToolbarElement();
            },

            getToolbarElement: function () {
                if (!this.toolbar) {
                    this.toolbar = this.createToolbar();
                }

                return this.toolbar;
            },

            getToolbarActionsElement: function () {
                return this.getToolbarElement().querySelector('.medium-editor-toolbar-actions');
            },

            // Toolbar event handlers

            initThrottledMethods: function () {
                // throttledPositionToolbar is throttled because:
                // - It will be called when the browser is resizing, which can fire many times very quickly
                // - For some event (like resize) a slight lag in UI responsiveness is OK and provides performance benefits
                this.throttledPositionToolbar = MediumEditor.util.throttle(function () {
                    if (this.base.isActive) {
                        this.positionToolbarIfShown();
                    }
                }.bind(this));
            },

            attachEventHandlers: function () {
                // MediumEditor custom events for when user beings and ends interaction with a contenteditable and its elements
                this.subscribe('blur', this.handleBlur.bind(this));
                this.subscribe('focus', this.handleFocus.bind(this));

                // Updating the state of the toolbar as things change
                this.subscribe('editableClick', this.handleEditableClick.bind(this));
                this.subscribe('editableKeyup', this.handleEditableKeyup.bind(this));

                // Handle mouseup on document for updating the selection in the toolbar
                this.on(this.document.documentElement, 'mouseup', this.handleDocumentMouseup.bind(this));

                // Add a scroll event for sticky toolbar
                if (this.static && this.sticky) {
                    // On scroll (capture), re-position the toolbar
                    this.on(this.window, 'scroll', this.handleWindowScroll.bind(this), true);
                }

                // On resize, re-position the toolbar
                this.on(this.window, 'resize', this.handleWindowResize.bind(this));
            },

            handleWindowScroll: function () {
                this.positionToolbarIfShown();
            },

            handleWindowResize: function () {
                this.throttledPositionToolbar();
            },

            handleDocumentMouseup: function (event) {
                // Do not trigger checkState when mouseup fires over the toolbar
                if (event &&
                    event.target &&
                    MediumEditor.util.isDescendant(this.getToolbarElement(), event.target)) {
                    return false;
                }
                this.checkState();
            },

            handleEditableClick: function () {
                // Delay the call to checkState to handle bug where selection is empty
                // immediately after clicking inside a pre-existing selection
                setTimeout(function () {
                    this.checkState();
                }.bind(this), 0);
            },

            handleEditableKeyup: function () {
                this.checkState();
            },

            handleBlur: function () {
                // Kill any previously delayed calls to hide the toolbar
                clearTimeout(this.hideTimeout);

                // Blur may fire even if we have a selection, so we want to prevent any delayed showToolbar
                // calls from happening in this specific case
                clearTimeout(this.delayShowTimeout);

                // Delay the call to hideToolbar to handle bug with multiple editors on the page at once
                this.hideTimeout = setTimeout(function () {
                    this.hideToolbar();
                }.bind(this), 1);
            },

            handleFocus: function () {
                this.checkState();
            },

            // Hiding/showing toolbar

            isDisplayed: function () {
                return this.getToolbarElement().classList.contains('medium-editor-toolbar-active');
            },

            showToolbar: function () {
                clearTimeout(this.hideTimeout);
                if (!this.isDisplayed()) {
                    this.getToolbarElement().classList.add('medium-editor-toolbar-active');
                    this.trigger('showToolbar', {}, this.base.getFocusedElement());
                }
            },

            hideToolbar: function () {
                if (this.isDisplayed()) {
                    this.getToolbarElement().classList.remove('medium-editor-toolbar-active');
                    this.trigger('hideToolbar', {}, this.base.getFocusedElement());
                }
            },

            isToolbarDefaultActionsDisplayed: function () {
                return this.getToolbarActionsElement().style.display === 'block';
            },

            hideToolbarDefaultActions: function () {
                if (this.isToolbarDefaultActionsDisplayed()) {
                    this.getToolbarActionsElement().style.display = 'none';
                }
            },

            showToolbarDefaultActions: function () {
                this.hideExtensionForms();

                if (!this.isToolbarDefaultActionsDisplayed()) {
                    this.getToolbarActionsElement().style.display = 'block';
                }

                // Using setTimeout + options.delay because:
                // We will actually be displaying the toolbar, which should be controlled by options.delay
                this.delayShowTimeout = this.base.delay(function () {
                    this.showToolbar();
                }.bind(this));
            },

            hideExtensionForms: function () {
                // Hide all extension forms
                this.forEachExtension(function (extension) {
                    if (extension.hasForm && extension.isDisplayed()) {
                        extension.hideForm();
                    }
                });
            },

            // Responding to changes in user selection

            // Checks for existance of multiple block elements in the current selection
            multipleBlockElementsSelected: function () {
                var regexEmptyHTMLTags = /<[^\/>][^>]*><\/[^>]+>/gim, // http://stackoverflow.com/questions/3129738/remove-empty-tags-using-regex
                    regexBlockElements = new RegExp('<(' + MediumEditor.util.blockContainerElementNames.join('|') + ')[^>]*>', 'g'),
                    selectionHTML = MediumEditor.selection.getSelectionHtml(this.document).replace(regexEmptyHTMLTags, ''), // Filter out empty blocks from selection
                    hasMultiParagraphs = selectionHTML.match(regexBlockElements); // Find how many block elements are within the html

                return !!hasMultiParagraphs && hasMultiParagraphs.length > 1;
            },

            modifySelection: function () {
                var selection = this.window.getSelection(),
                    selectionRange = selection.getRangeAt(0);

                /*
                 * In firefox, there are cases (ie doubleclick of a word) where the selectionRange start
                 * will be at the very end of an element.  In other browsers, the selectionRange start
                 * would instead be at the very beginning of an element that actually has content.
                 * example:
                 *   <span>foo</span><span>bar</span>
                 *
                 * If the text 'bar' is selected, most browsers will have the selectionRange start at the beginning
                 * of the 'bar' span.  However, there are cases where firefox will have the selectionRange start
                 * at the end of the 'foo' span.  The contenteditable behavior will be ok, but if there are any
                 * properties on the 'bar' span, they won't be reflected accurately in the toolbar
                 * (ie 'Bold' button wouldn't be active)
                 *
                 * So, for cases where the selectionRange start is at the end of an element/node, find the next
                 * adjacent text node that actually has content in it, and move the selectionRange start there.
                 */
                if (this.standardizeSelectionStart &&
                    selectionRange.startContainer.nodeValue &&
                    (selectionRange.startOffset === selectionRange.startContainer.nodeValue.length)) {
                    var adjacentNode = MediumEditor.util.findAdjacentTextNodeWithContent(MediumEditor.selection.getSelectionElement(this.window), selectionRange.startContainer, this.document);
                    if (adjacentNode) {
                        var offset = 0;
                        while (adjacentNode.nodeValue.substr(offset, 1).trim().length === 0) {
                            offset = offset + 1;
                        }
                        selectionRange = MediumEditor.selection.select(this.document, adjacentNode, offset,
                            selectionRange.endContainer, selectionRange.endOffset);
                    }
                }
            },

            checkState: function () {
                if (this.base.preventSelectionUpdates) {
                    return;
                }

                // If no editable has focus OR selection is inside contenteditable = false
                // hide toolbar
                if (!this.base.getFocusedElement() ||
                    MediumEditor.selection.selectionInContentEditableFalse(this.window)) {
                    return this.hideToolbar();
                }

                // If there's no selection element, selection element doesn't belong to this editor
                // or toolbar is disabled for this selection element
                // hide toolbar
                var selectionElement = MediumEditor.selection.getSelectionElement(this.window);
                if (!selectionElement ||
                    this.getEditorElements().indexOf(selectionElement) === -1 ||
                    selectionElement.getAttribute('data-disable-toolbar')) {
                    return this.hideToolbar();
                }

                // Now we know there's a focused editable with a selection

                // If the updateOnEmptySelection option is true, show the toolbar
                if (this.updateOnEmptySelection && this.static) {
                    return this.showAndUpdateToolbar();
                }

                // If we don't have a 'valid' selection -> hide toolbar
                if (!MediumEditor.selection.selectionContainsContent(this.document) ||
                    (this.allowMultiParagraphSelection === false && this.multipleBlockElementsSelected())) {
                    return this.hideToolbar();
                }

                this.showAndUpdateToolbar();
            },

            // Updating the toolbar

            showAndUpdateToolbar: function () {
                this.modifySelection();
                this.setToolbarButtonStates();
                this.trigger('positionToolbar', {}, this.base.getFocusedElement());
                this.showToolbarDefaultActions();
                this.setToolbarPosition();
            },

            setToolbarButtonStates: function () {
                this.forEachExtension(function (extension) {
                    if (typeof extension.isActive === 'function' &&
                        typeof extension.setInactive === 'function') {
                        extension.setInactive();
                    }
                });

                this.checkActiveButtons();
            },

            checkActiveButtons: function () {
                var manualStateChecks = [],
                    queryState = null,
                    selectionRange = MediumEditor.selection.getSelectionRange(this.document),
                    parentNode,
                    updateExtensionState = function (extension) {
                        if (typeof extension.checkState === 'function') {
                            extension.checkState(parentNode);
                        } else if (typeof extension.isActive === 'function' &&
                            typeof extension.isAlreadyApplied === 'function' &&
                            typeof extension.setActive === 'function') {
                            if (!extension.isActive() && extension.isAlreadyApplied(parentNode)) {
                                extension.setActive();
                            }
                        }
                    };

                if (!selectionRange) {
                    return;
                }

                // Loop through all extensions
                this.forEachExtension(function (extension) {
                    // For those extensions where we can use document.queryCommandState(), do so
                    if (typeof extension.queryCommandState === 'function') {
                        queryState = extension.queryCommandState();
                        // If queryCommandState returns a valid value, we can trust the browser
                        // and don't need to do our manual checks
                        if (queryState !== null) {
                            if (queryState && typeof extension.setActive === 'function') {
                                extension.setActive();
                            }
                            return;
                        }
                    }
                    // We can't use queryCommandState for this extension, so add to manualStateChecks
                    manualStateChecks.push(extension);
                });

                parentNode = MediumEditor.selection.getSelectedParentElement(selectionRange);

                // Make sure the selection parent isn't outside of the contenteditable
                if (!this.getEditorElements().some(function (element) {
                        return MediumEditor.util.isDescendant(element, parentNode, true);
                    })) {
                    return;
                }

                // Climb up the DOM and do manual checks for whether a certain extension is currently enabled for this node
                while (parentNode) {
                    manualStateChecks.forEach(updateExtensionState);

                    // we can abort the search upwards if we leave the contentEditable element
                    if (MediumEditor.util.isMediumEditorElement(parentNode)) {
                        break;
                    }
                    parentNode = parentNode.parentNode;
                }
            },

            // Positioning toolbar

            positionToolbarIfShown: function () {
                if (this.isDisplayed()) {
                    this.setToolbarPosition();
                }
            },

            setToolbarPosition: function () {
                var container = this.base.getFocusedElement(),
                    selection = this.window.getSelection();

                // If there isn't a valid selection, bail
                if (!container) {
                    return this;
                }

                if (this.static || !selection.isCollapsed) {
                    this.showToolbar();

                    // we don't need any absolute positioning if relativeContainer is set
                    if (!this.relativeContainer) {
                        if (this.static) {
                            this.positionStaticToolbar(container);
                        } else {
                            this.positionToolbar(selection);
                        }
                    }

                    this.trigger('positionedToolbar', {}, this.base.getFocusedElement());
                }
            },

            positionStaticToolbar: function (container) {
                // position the toolbar at left 0, so we can get the real width of the toolbar
                this.getToolbarElement().style.left = '0';

                // document.documentElement for IE 9
                var scrollTop = (this.document.documentElement && this.document.documentElement.scrollTop) || this.document.body.scrollTop,
                    windowWidth = this.window.innerWidth,
                    toolbarElement = this.getToolbarElement(),
                    containerRect = container.getBoundingClientRect(),
                    containerTop = containerRect.top + scrollTop,
                    containerCenter = (containerRect.left + (containerRect.width / 2)),
                    toolbarHeight = toolbarElement.offsetHeight,
                    toolbarWidth = toolbarElement.offsetWidth,
                    halfOffsetWidth = toolbarWidth / 2,
                    targetLeft;

                if (this.sticky) {
                    // If it's beyond the height of the editor, position it at the bottom of the editor
                    if (scrollTop > (containerTop + container.offsetHeight - toolbarHeight - this.stickyTopOffset)) {
                        toolbarElement.style.top = (containerTop + container.offsetHeight - toolbarHeight) + 'px';
                        toolbarElement.classList.remove('medium-editor-sticky-toolbar');
                        // Stick the toolbar to the top of the window
                    } else if (scrollTop > (containerTop - toolbarHeight - this.stickyTopOffset)) {
                        toolbarElement.classList.add('medium-editor-sticky-toolbar');
                        toolbarElement.style.top = this.stickyTopOffset + 'px';
                        // Normal static toolbar position
                    } else {
                        toolbarElement.classList.remove('medium-editor-sticky-toolbar');
                        toolbarElement.style.top = containerTop - toolbarHeight + 'px';
                    }
                } else {
                    toolbarElement.style.top = containerTop - toolbarHeight + 'px';
                }

                switch (this.align) {
                    case 'left':
                        targetLeft = containerRect.left;
                        break;

                    case 'right':
                        targetLeft = containerRect.right - toolbarWidth;
                        break;

                    case 'center':
                        targetLeft = containerCenter - halfOffsetWidth;
                        break;
                }

                if (targetLeft < 0) {
                    targetLeft = 0;
                } else if ((targetLeft + toolbarWidth) > windowWidth) {
                    targetLeft = (windowWidth - Math.ceil(toolbarWidth) - 1);
                }

                toolbarElement.style.left = targetLeft + 'px';
            },

            positionToolbar: function (selection) {
                // position the toolbar at left 0, so we can get the real width of the toolbar
                this.getToolbarElement().style.left = '0';
                this.getToolbarElement().style.right = 'initial';

                var range = selection.getRangeAt(0),
                    boundary = range.getBoundingClientRect();

                // Handle selections with just images
                if (!boundary || ((boundary.height === 0 && boundary.width === 0) && range.startContainer === range.endContainer)) {
                    // If there's a nested image, use that for the bounding rectangle
                    if (range.startContainer.nodeType === 1 && range.startContainer.querySelector('img')) {
                        boundary = range.startContainer.querySelector('img').getBoundingClientRect();
                    } else {
                        boundary = range.startContainer.getBoundingClientRect();
                    }
                }

                var containerWidth = this.window.innerWidth,
                    toolbarElement = this.getToolbarElement(),
                    toolbarHeight = toolbarElement.offsetHeight,
                    toolbarWidth = toolbarElement.offsetWidth,
                    halfOffsetWidth = toolbarWidth / 2,
                    buttonHeight = 50,
                    defaultLeft = this.diffLeft - halfOffsetWidth,
                    elementsContainer = this.getEditorOption('elementsContainer'),
                    elementsContainerAbsolute = 'absolute', //['absolute', 'fixed'].indexOf(window.getComputedStyle(elementsContainer).getPropertyValue('position')) > -1,
                    positions = {},
                    relativeBoundary = {},
                    middleBoundary, elementsContainerBoundary;

                // If container element is absolute / fixed, recalculate boundaries to be relative to the container
                if (elementsContainerAbsolute) {
                    elementsContainerBoundary = elementsContainer.getBoundingClientRect();
                    ['top', 'left'].forEach(function (key) {
                        relativeBoundary[key] = boundary[key] - elementsContainerBoundary[key];
                    });

                    relativeBoundary.width = boundary.width;
                    relativeBoundary.height = boundary.height;
                    boundary = relativeBoundary;

                    containerWidth = elementsContainerBoundary.width;

                    // Adjust top position according to container scroll position
                    positions.top = elementsContainer.scrollTop;
                } else {
                    // Adjust top position according to window scroll position
                    positions.top = this.window.pageYOffset;
                }

                middleBoundary = boundary.left + boundary.width / 2;
                positions.top += boundary.top - toolbarHeight;

                if (boundary.top < buttonHeight) {
                    toolbarElement.classList.add('medium-toolbar-arrow-over');
                    toolbarElement.classList.remove('medium-toolbar-arrow-under');
                    positions.top += buttonHeight + boundary.height - this.diffTop;
                } else {
                    toolbarElement.classList.add('medium-toolbar-arrow-under');
                    toolbarElement.classList.remove('medium-toolbar-arrow-over');
                    positions.top += this.diffTop;
                }

                if (middleBoundary < halfOffsetWidth) {
                    positions.left = defaultLeft + halfOffsetWidth;
                    positions.right = 'initial';
                } else if ((containerWidth - middleBoundary) < halfOffsetWidth) {
                    positions.left = 'auto';
                    positions.right = 0;
                } else {
                    positions.left = defaultLeft + middleBoundary;
                    positions.right = 'initial';
                }

                ['top', 'left', 'right'].forEach(function (key) {
                    toolbarElement.style[key] = positions[key] + (isNaN(positions[key]) ? '' : 'px');
                });
            }
        });

        MediumEditor.extensions.toolbar = Toolbar;
    }());

    (function () {
        'use strict';

        var ImageDragging = MediumEditor.Extension.extend({
            init: function () {
                MediumEditor.Extension.prototype.init.apply(this, arguments);

                this.subscribe('editableDrag', this.handleDrag.bind(this));
                this.subscribe('editableDrop', this.handleDrop.bind(this));
            },

            handleDrag: function (event) {
                var className = 'medium-editor-dragover';
                event.preventDefault();
                event.dataTransfer.dropEffect = 'copy';

                if (event.type === 'dragover') {
                    event.target.classList.add(className);
                } else if (event.type === 'dragleave') {
                    event.target.classList.remove(className);
                }
            },

            handleDrop: function (event) {
                var className = 'medium-editor-dragover',
                    files;
                event.preventDefault();
                event.stopPropagation();

                // IE9 does not support the File API, so prevent file from opening in a new window
                // but also don't try to actually get the file
                if (event.dataTransfer.files) {
                    files = Array.prototype.slice.call(event.dataTransfer.files, 0);
                    files.some(function (file) {
                        if (file.type.match('image')) {
                            var fileReader, id;
                            fileReader = new FileReader();
                            fileReader.readAsDataURL(file);

                            id = 'medium-img-' + (+new Date());
                            MediumEditor.util.insertHTMLCommand(this.document, '<img class="medium-editor-image-loading" id="' + id + '" />');

                            fileReader.onload = function () {
                                var img = this.document.getElementById(id);
                                if (img) {
                                    img.removeAttribute('id');
                                    img.removeAttribute('class');
                                    img.src = fileReader.result;
                                }
                            }.bind(this);
                        }
                    }.bind(this));
                }
                event.target.classList.remove(className);
            }
        });

        MediumEditor.extensions.imageDragging = ImageDragging;
    }());

    (function () {
        'use strict';

        // Event handlers that shouldn't be exposed externally

        function handleDisableExtraSpaces(event) {
            var node = MediumEditor.selection.getSelectionStart(this.options.ownerDocument),
                textContent = node.textContent,
                caretPositions = MediumEditor.selection.getCaretOffsets(node);

            if ((textContent[caretPositions.left - 1] === undefined) || (textContent[caretPositions.left - 1].trim() === '') || (textContent[caretPositions.left] !== undefined && textContent[caretPositions.left].trim() === '')) {
                event.preventDefault();
            }
        }

        function handleDisabledEnterKeydown(event, element) {
            if (this.options.disableReturn || element.getAttribute('data-disable-return')) {
                event.preventDefault();
            } else if (this.options.disableDoubleReturn || element.getAttribute('data-disable-double-return')) {
                var node = MediumEditor.selection.getSelectionStart(this.options.ownerDocument);

                // if current text selection is empty OR previous sibling text is empty OR it is not a list
                if ((node && node.textContent.trim() === '' && node.nodeName.toLowerCase() !== 'li') ||
                    (node.previousElementSibling && node.previousElementSibling.nodeName.toLowerCase() !== 'br' &&
                    node.previousElementSibling.textContent.trim() === '')) {
                    event.preventDefault();
                }
            }
        }

        function handleTabKeydown(event) {
            // Override tab only for pre nodes
            var node = MediumEditor.selection.getSelectionStart(this.options.ownerDocument),
                tag = node && node.nodeName.toLowerCase();

            if (tag === 'pre') {
                event.preventDefault();
                MediumEditor.util.insertHTMLCommand(this.options.ownerDocument, '    ');
            }

            // Tab to indent list structures!
            if (MediumEditor.util.isListItem(node)) {
                event.preventDefault();

                // If Shift is down, outdent, otherwise indent
                if (event.shiftKey) {
                    this.options.ownerDocument.execCommand('outdent', false, null);
                } else {
                    this.options.ownerDocument.execCommand('indent', false, null);
                }
            }
        }

        function handleBlockDeleteKeydowns(event) {
            var p, node = MediumEditor.selection.getSelectionStart(this.options.ownerDocument),
                tagName = node.nodeName.toLowerCase(),
                isEmpty = /^(\s+|<br\/?>)?$/i,
                isHeader = /h\d/i;

            if (MediumEditor.util.isKey(event, [MediumEditor.util.keyCode.BACKSPACE, MediumEditor.util.keyCode.ENTER]) &&
                // has a preceeding sibling
                node.previousElementSibling &&
                // in a header
                isHeader.test(tagName) &&
                // at the very end of the block
                MediumEditor.selection.getCaretOffsets(node).left === 0) {
                if (MediumEditor.util.isKey(event, MediumEditor.util.keyCode.BACKSPACE) && isEmpty.test(node.previousElementSibling.innerHTML)) {
                    // backspacing the begining of a header into an empty previous element will
                    // change the tagName of the current node to prevent one
                    // instead delete previous node and cancel the event.
                    node.previousElementSibling.parentNode.removeChild(node.previousElementSibling);
                    event.preventDefault();
                } else if (!this.options.disableDoubleReturn && MediumEditor.util.isKey(event, MediumEditor.util.keyCode.ENTER)) {
                    // hitting return in the begining of a header will create empty header elements before the current one
                    // instead, make "<p><br></p>" element, which are what happens if you hit return in an empty paragraph
                    p = this.options.ownerDocument.createElement('p');
                    p.innerHTML = '<br>';
                    node.previousElementSibling.parentNode.insertBefore(p, node);
                    event.preventDefault();
                }
            } else if (MediumEditor.util.isKey(event, MediumEditor.util.keyCode.DELETE) &&
                // between two sibling elements
                node.nextElementSibling &&
                node.previousElementSibling &&
                // not in a header
                !isHeader.test(tagName) &&
                // in an empty tag
                isEmpty.test(node.innerHTML) &&
                // when the next tag *is* a header
                isHeader.test(node.nextElementSibling.nodeName.toLowerCase())) {
                // hitting delete in an empty element preceding a header, ex:
                //  <p>[CURSOR]</p><h1>Header</h1>
                // Will cause the h1 to become a paragraph.
                // Instead, delete the paragraph node and move the cursor to the begining of the h1

                // remove node and move cursor to start of header
                MediumEditor.selection.moveCursor(this.options.ownerDocument, node.nextElementSibling);

                node.previousElementSibling.parentNode.removeChild(node);

                event.preventDefault();
            } else if (MediumEditor.util.isKey(event, MediumEditor.util.keyCode.BACKSPACE) &&
                tagName === 'li' &&
                // hitting backspace inside an empty li
                isEmpty.test(node.innerHTML) &&
                // is first element (no preceeding siblings)
                !node.previousElementSibling &&
                // parent also does not have a sibling
                !node.parentElement.previousElementSibling &&
                // is not the only li in a list
                node.nextElementSibling &&
                node.nextElementSibling.nodeName.toLowerCase() === 'li') {
                // backspacing in an empty first list element in the first list (with more elements) ex:
                //  <ul><li>[CURSOR]</li><li>List Item 2</li></ul>
                // will remove the first <li> but add some extra element before (varies based on browser)
                // Instead, this will:
                // 1) remove the list element
                // 2) create a paragraph before the list
                // 3) move the cursor into the paragraph

                // create a paragraph before the list
                p = this.options.ownerDocument.createElement('p');
                p.innerHTML = '<br>';
                node.parentElement.parentElement.insertBefore(p, node.parentElement);

                // move the cursor into the new paragraph
                MediumEditor.selection.moveCursor(this.options.ownerDocument, p);

                // remove the list element
                node.parentElement.removeChild(node);

                event.preventDefault();
            } else if (MediumEditor.util.isKey(event, MediumEditor.util.keyCode.BACKSPACE) &&
                (MediumEditor.util.getClosestTag(node, 'blockquote') !== false) &&
                MediumEditor.selection.getCaretOffsets(node).left === 0) {

                // when cursor is at the begining of the element and the element is <blockquote>
                // then pressing backspace key should change the <blockquote> to a <p> tag
                event.preventDefault();
                MediumEditor.util.execFormatBlock(this.options.ownerDocument, 'p');
            } else if (MediumEditor.util.isKey(event, MediumEditor.util.keyCode.ENTER) &&
                (MediumEditor.util.getClosestTag(node, 'blockquote') !== false) &&
                MediumEditor.selection.getCaretOffsets(node).right === 0) {

                // when cursor is at the end of <blockquote>,
                // then pressing enter key should create <p> tag, not <blockquote>
                p = this.options.ownerDocument.createElement('p');
                p.innerHTML = '<br>';
                node.parentElement.insertBefore(p, node.nextSibling);

                // move the cursor into the new paragraph
                MediumEditor.selection.moveCursor(this.options.ownerDocument, p);

                event.preventDefault();
            } else if (MediumEditor.util.isKey(event, MediumEditor.util.keyCode.BACKSPACE) &&
                MediumEditor.util.isMediumEditorElement(node.parentElement) &&
                !node.previousElementSibling &&
                node.nextElementSibling &&
                isEmpty.test(node.innerHTML)) {

                // when cursor is in the first element, it's empty and user presses backspace,
                // do delete action instead to get rid of the first element and move caret to 2nd
                event.preventDefault();
                MediumEditor.selection.moveCursor(this.options.ownerDocument, node.nextSibling);
                node.parentElement.removeChild(node);
            }
        }

        function handleKeyup(event) {
            var node = MediumEditor.selection.getSelectionStart(this.options.ownerDocument),
                tagName;

            if (!node) {
                return;
            }

            // https://github.com/yabwe/medium-editor/issues/994
            // Firefox thrown an error when calling `formatBlock` on an empty editable blockContainer that's not a <div>
            if (MediumEditor.util.isMediumEditorElement(node) && node.children.length === 0 && !MediumEditor.util.isBlockContainer(node)) {
                this.options.ownerDocument.execCommand('formatBlock', false, 'p');
            }

            // https://github.com/yabwe/medium-editor/issues/834
            // https://github.com/yabwe/medium-editor/pull/382
            // Don't call format block if this is a block element (ie h1, figCaption, etc.)
            if (MediumEditor.util.isKey(event, MediumEditor.util.keyCode.ENTER) &&
                !MediumEditor.util.isListItem(node) &&
                !MediumEditor.util.isBlockContainer(node)) {

                tagName = node.nodeName.toLowerCase();
                // For anchor tags, unlink
                if (tagName === 'a') {
                    this.options.ownerDocument.execCommand('unlink', false, null);
                } else if (!event.shiftKey && !event.ctrlKey) {
                    this.options.ownerDocument.execCommand('formatBlock', false, 'p');
                }
            }
        }

        function handleEditableInput(event, editable) {
            var textarea = editable.parentNode.querySelector('textarea[medium-editor-textarea-id="' + editable.getAttribute('medium-editor-textarea-id') + '"]');
            if (textarea) {
                textarea.value = editable.innerHTML.trim();
            }
        }

        // Internal helper methods which shouldn't be exposed externally

        function addToEditors(win) {
            if (!win._mediumEditors) {
                // To avoid breaking users who are assuming that the unique id on
                // medium-editor elements will start at 1, inserting a 'null' in the
                // array so the unique-id can always map to the index of the editor instance
                win._mediumEditors = [null];
            }

            // If this already has a unique id, re-use it
            if (!this.id) {
                this.id = win._mediumEditors.length;
            }

            win._mediumEditors[this.id] = this;
        }

        function removeFromEditors(win) {
            if (!win._mediumEditors || !win._mediumEditors[this.id]) {
                return;
            }

            /* Setting the instance to null in the array instead of deleting it allows:
             * 1) Each instance to preserve its own unique-id, even after being destroyed
             *    and initialized again
             * 2) The unique-id to always correspond to an index in the array of medium-editor
             *    instances. Thus, we will be able to look at a contenteditable, and determine
             *    which instance it belongs to, by indexing into the global array.
             */
            win._mediumEditors[this.id] = null;
        }

        function createElementsArray(selector, doc, filterEditorElements) {
            var elements = [];

            if (!selector) {
                selector = [];
            }
            // If string, use as query selector
            if (typeof selector === 'string') {
                selector = doc.querySelectorAll(selector);
            }
            // If element, put into array
            if (MediumEditor.util.isElement(selector)) {
                selector = [selector];
            }

            if (filterEditorElements) {
                // Remove elements that have already been initialized by the editor
                // selecotr might not be an array (ie NodeList) so use for loop
                for (var i = 0; i < selector.length; i++) {
                    var el = selector[i];
                    if (MediumEditor.util.isElement(el) &&
                        !el.getAttribute('data-medium-editor-element') &&
                        !el.getAttribute('medium-editor-textarea-id')) {
                        elements.push(el);
                    }
                }
            } else {
                // Convert NodeList (or other array like object) into an array
                elements = Array.prototype.slice.apply(selector);
            }

            return elements;
        }

        function cleanupTextareaElement(element) {
            var textarea = element.parentNode.querySelector('textarea[medium-editor-textarea-id="' + element.getAttribute('medium-editor-textarea-id') + '"]');
            if (textarea) {
                // Un-hide the textarea
                textarea.classList.remove('medium-editor-hidden');
                textarea.removeAttribute('medium-editor-textarea-id');
            }
            if (element.parentNode) {
                element.parentNode.removeChild(element);
            }
        }

        function setExtensionDefaults(extension, defaults) {
            Object.keys(defaults).forEach(function (prop) {
                if (extension[prop] === undefined) {
                    extension[prop] = defaults[prop];
                }
            });
            return extension;
        }

        function initExtension(extension, name, instance) {
            var extensionDefaults = {
                'window': instance.options.contentWindow,
                'document': instance.options.ownerDocument,
                'base': instance
            };

            // Add default options into the extension
            extension = setExtensionDefaults(extension, extensionDefaults);

            // Call init on the extension
            if (typeof extension.init === 'function') {
                extension.init();
            }

            // Set extension name (if not already set)
            if (!extension.name) {
                extension.name = name;
            }
            return extension;
        }

        function isToolbarEnabled() {
            // If any of the elements don't have the toolbar disabled
            // We need a toolbar
            if (this.elements.every(function (element) {
                    return !!element.getAttribute('data-disable-toolbar');
                })) {
                return false;
            }

            return this.options.toolbar !== false;
        }

        function isAnchorPreviewEnabled() {
            // If toolbar is disabled, don't add
            if (!isToolbarEnabled.call(this)) {
                return false;
            }

            return this.options.anchorPreview !== false;
        }

        function isPlaceholderEnabled() {
            return this.options.placeholder !== false;
        }

        function isAutoLinkEnabled() {
            return this.options.autoLink !== false;
        }

        function isImageDraggingEnabled() {
            return this.options.imageDragging !== false;
        }

        function isKeyboardCommandsEnabled() {
            return this.options.keyboardCommands !== false;
        }

        function shouldUseFileDraggingExtension() {
            // Since the file-dragging extension replaces the image-dragging extension,
            // we need to check if the user passed an overrided image-dragging extension.
            // If they have, to avoid breaking users, we won't use file-dragging extension.
            return !this.options.extensions['imageDragging'];
        }

        function createContentEditable(textarea) {
            var div = this.options.ownerDocument.createElement('div'),
                now = Date.now(),
                uniqueId = 'medium-editor-' + now,
                atts = textarea.attributes;

            // Some browsers can move pretty fast, since we're using a timestamp
            // to make a unique-id, ensure that the id is actually unique on the page
            while (this.options.ownerDocument.getElementById(uniqueId)) {
                now++;
                uniqueId = 'medium-editor-' + now;
            }

            div.className = textarea.className;
            div.id = uniqueId;
            div.innerHTML = textarea.value;

            textarea.setAttribute('medium-editor-textarea-id', uniqueId);

            // re-create all attributes from the textearea to the new created div
            for (var i = 0, n = atts.length; i < n; i++) {
                // do not re-create existing attributes
                if (!div.hasAttribute(atts[i].nodeName)) {
                    div.setAttribute(atts[i].nodeName, atts[i].nodeValue);
                }
            }

            // If textarea has a form, listen for reset on the form to clear
            // the content of the created div
            if (textarea.form) {
                this.on(textarea.form, 'reset', function (event) {
                    if (!event.defaultPrevented) {
                        this.resetContent(this.options.ownerDocument.getElementById(uniqueId));
                    }
                }.bind(this));
            }

            textarea.classList.add('medium-editor-hidden');
            textarea.parentNode.insertBefore(
                div,
                textarea
            );

            return div;
        }

        function initElement(element, editorId) {
            if (!element.getAttribute('data-medium-editor-element')) {
                if (element.nodeName.toLowerCase() === 'textarea') {
                    element = createContentEditable.call(this, element);

                    // Make sure we only attach to editableInput once for <textarea> elements
                    if (!this.instanceHandleEditableInput) {
                        this.instanceHandleEditableInput = handleEditableInput.bind(this);
                        this.subscribe('editableInput', this.instanceHandleEditableInput);
                    }
                }

                if (!this.options.disableEditing && !element.getAttribute('data-disable-editing')) {
                    element.setAttribute('contentEditable', true);
                    element.setAttribute('spellcheck', this.options.spellcheck);
                }

                // Make sure we only attach to editableKeydownEnter once for disable-return options
                if (!this.instanceHandleEditableKeydownEnter) {
                    if (element.getAttribute('data-disable-return') || element.getAttribute('data-disable-double-return')) {
                        this.instanceHandleEditableKeydownEnter = handleDisabledEnterKeydown.bind(this);
                        this.subscribe('editableKeydownEnter', this.instanceHandleEditableKeydownEnter);
                    }
                }

                // if we're not disabling return, add a handler to help handle cleanup
                // for certain cases when enter is pressed
                if (!this.options.disableReturn && !element.getAttribute('data-disable-return')) {
                    this.on(element, 'keyup', handleKeyup.bind(this));
                }

                var elementId = MediumEditor.util.guid();

                element.setAttribute('data-medium-editor-element', true);
                element.classList.add('medium-editor-element');
                element.setAttribute('role', 'textbox');
                element.setAttribute('aria-multiline', true);
                element.setAttribute('data-medium-editor-editor-index', editorId);
                // TODO: Merge data-medium-editor-element and medium-editor-index attributes for 6.0.0
                // medium-editor-index is not named correctly anymore and can be re-purposed to signify
                // whether the element has been initialized or not
                element.setAttribute('medium-editor-index', elementId);
                initialContent[elementId] = element.innerHTML;

                this.events.attachAllEventsToElement(element);
            }

            return element;
        }

        function attachHandlers() {
            // attach to tabs
            this.subscribe('editableKeydownTab', handleTabKeydown.bind(this));

            // Bind keys which can create or destroy a block element: backspace, delete, return
            this.subscribe('editableKeydownDelete', handleBlockDeleteKeydowns.bind(this));
            this.subscribe('editableKeydownEnter', handleBlockDeleteKeydowns.bind(this));

            // Bind double space event
            if (this.options.disableExtraSpaces) {
                this.subscribe('editableKeydownSpace', handleDisableExtraSpaces.bind(this));
            }

            // Make sure we only attach to editableKeydownEnter once for disable-return options
            if (!this.instanceHandleEditableKeydownEnter) {
                // disabling return or double return
                if (this.options.disableReturn || this.options.disableDoubleReturn) {
                    this.instanceHandleEditableKeydownEnter = handleDisabledEnterKeydown.bind(this);
                    this.subscribe('editableKeydownEnter', this.instanceHandleEditableKeydownEnter);
                }
            }
        }

        function initExtensions() {

            this.extensions = [];

            // Passed in extensions
            Object.keys(this.options.extensions).forEach(function (name) {
                // Always save the toolbar extension for last
                if (name !== 'toolbar' && this.options.extensions[name]) {
                    this.extensions.push(initExtension(this.options.extensions[name], name, this));
                }
            }, this);

            // 4 Cases for imageDragging + fileDragging extensons:
            //
            // 1. ImageDragging ON + No Custom Image Dragging Extension:
            //    * Use fileDragging extension (default options)
            // 2. ImageDragging OFF + No Custom Image Dragging Extension:
            //    * Use fileDragging extension w/ images turned off
            // 3. ImageDragging ON + Custom Image Dragging Extension:
            //    * Don't use fileDragging (could interfere with custom image dragging extension)
            // 4. ImageDragging OFF + Custom Image Dragging:
            //    * Don't use fileDragging (could interfere with custom image dragging extension)
            if (shouldUseFileDraggingExtension.call(this)) {
                var opts = this.options.fileDragging;
                if (!opts) {
                    opts = {};

                    // Image is in the 'allowedTypes' list by default.
                    // If imageDragging is off override the 'allowedTypes' list with an empty one
                    if (!isImageDraggingEnabled.call(this)) {
                        opts.allowedTypes = [];
                    }
                }
                this.addBuiltInExtension('fileDragging', opts);
            }

            // Built-in extensions
            var builtIns = {
                paste: true,
                'anchor-preview': isAnchorPreviewEnabled.call(this),
                autoLink: isAutoLinkEnabled.call(this),
                keyboardCommands: isKeyboardCommandsEnabled.call(this),
                placeholder: isPlaceholderEnabled.call(this)
            };
            Object.keys(builtIns).forEach(function (name) {
                if (builtIns[name]) {
                    this.addBuiltInExtension(name);
                }
            }, this);

            // Users can pass in a custom toolbar extension
            // so check for that first and if it's not present
            // just create the default toolbar
            var toolbarExtension = this.options.extensions['toolbar'];
            if (!toolbarExtension && isToolbarEnabled.call(this)) {
                // Backwards compatability
                var toolbarOptions = MediumEditor.util.extend({}, this.options.toolbar, {
                    allowMultiParagraphSelection: this.options.allowMultiParagraphSelection // deprecated
                });
                toolbarExtension = new MediumEditor.extensions.toolbar(toolbarOptions);
            }

            // If the toolbar is not disabled, so we actually have an extension
            // initialize it and add it to the extensions array
            if (toolbarExtension) {
                this.extensions.push(initExtension(toolbarExtension, 'toolbar', this));
            }
        }

        function mergeOptions(defaults, options) {
            var deprecatedProperties = [
                ['allowMultiParagraphSelection', 'toolbar.allowMultiParagraphSelection']
            ];
            // warn about using deprecated properties
            if (options) {
                deprecatedProperties.forEach(function (pair) {
                    if (options.hasOwnProperty(pair[0]) && options[pair[0]] !== undefined) {
                        MediumEditor.util.deprecated(pair[0], pair[1], 'v6.0.0');
                    }
                });
            }

            return MediumEditor.util.defaults({}, options, defaults);
        }

        function execActionInternal(action, opts) {
            /*jslint regexp: true*/
            var appendAction = /^append-(.+)$/gi,
                justifyAction = /justify([A-Za-z]*)$/g, /* Detecting if is justifyCenter|Right|Left */
                match,
                cmdValueArgument;
            /*jslint regexp: false*/

            // Actions starting with 'append-' should attempt to format a block of text ('formatBlock') using a specific
            // type of block element (ie append-blockquote, append-h1, append-pre, etc.)
            match = appendAction.exec(action);
            if (match) {
                return MediumEditor.util.execFormatBlock(this.options.ownerDocument, match[1]);
            }

            if (action === 'fontSize') {
                // TODO: Deprecate support for opts.size in 6.0.0
                if (opts.size) {
                    MediumEditor.util.deprecated('.size option for fontSize command', '.value', '6.0.0');
                }
                cmdValueArgument = opts.value || opts.size;
                return this.options.ownerDocument.execCommand('fontSize', false, cmdValueArgument);
            }

            if (action === 'fontName') {
                // TODO: Deprecate support for opts.name in 6.0.0
                if (opts.name) {
                    MediumEditor.util.deprecated('.name option for fontName command', '.value', '6.0.0');
                }
                cmdValueArgument = opts.value || opts.name;
                return this.options.ownerDocument.execCommand('fontName', false, cmdValueArgument);
            }

            if (action === 'createLink') {
                return this.createLink(opts);
            }

            if (action === 'image') {
                var src = this.options.contentWindow.getSelection().toString().trim();
                return this.options.ownerDocument.execCommand('insertImage', false, src);
            }

            if (action === 'html') {
                var html = this.options.contentWindow.getSelection().toString().trim();
                return MediumEditor.util.insertHTMLCommand(this.options.ownerDocument, html);
            }

            /* Issue: https://github.com/yabwe/medium-editor/issues/595
             * If the action is to justify the text */
            if (justifyAction.exec(action)) {
                var result = this.options.ownerDocument.execCommand(action, false, null),
                    parentNode = MediumEditor.selection.getSelectedParentElement(MediumEditor.selection.getSelectionRange(this.options.ownerDocument));
                if (parentNode) {
                    cleanupJustifyDivFragments.call(this, MediumEditor.util.getTopBlockContainer(parentNode));
                }

                return result;
            }

            cmdValueArgument = opts && opts.value;
            return this.options.ownerDocument.execCommand(action, false, cmdValueArgument);
        }

        /* If we've just justified text within a container block
         * Chrome may have removed <br> elements and instead wrapped lines in <div> elements
         * with a text-align property.  If so, we want to fix this
         */
        function cleanupJustifyDivFragments(blockContainer) {
            if (!blockContainer) {
                return;
            }

            var textAlign,
                childDivs = Array.prototype.slice.call(blockContainer.childNodes).filter(function (element) {
                    var isDiv = element.nodeName.toLowerCase() === 'div';
                    if (isDiv && !textAlign) {
                        textAlign = element.style.textAlign;
                    }
                    return isDiv;
                });

            /* If we found child <div> elements with text-align style attributes
             * we should fix this by:
             *
             * 1) Unwrapping each <div> which has a text-align style
             * 2) Insert a <br> element after each set of 'unwrapped' div children
             * 3) Set the text-align style of the parent block element
             */
            if (childDivs.length) {
                // Since we're mucking with the HTML, preserve selection
                this.saveSelection();
                childDivs.forEach(function (div) {
                    if (div.style.textAlign === textAlign) {
                        var lastChild = div.lastChild;
                        if (lastChild) {
                            // Instead of a div, extract the child elements and add a <br>
                            MediumEditor.util.unwrap(div, this.options.ownerDocument);
                            var br = this.options.ownerDocument.createElement('BR');
                            lastChild.parentNode.insertBefore(br, lastChild.nextSibling);
                        }
                    }
                }, this);
                blockContainer.style.textAlign = textAlign;
                // We're done, so restore selection
                this.restoreSelection();
            }
        }

        var initialContent = {};

        MediumEditor.prototype = {
            // NOT DOCUMENTED - exposed for backwards compatability
            init: function (elements, options) {
                this.options = mergeOptions.call(this, this.defaults, options);
                this.origElements = elements;

                if (!this.options.elementsContainer) {
                    this.options.elementsContainer = this.options.ownerDocument.body;
                }

                return this.setup();
            },

            setup: function () {
                if (this.isActive) {
                    return;
                }

                addToEditors.call(this, this.options.contentWindow);
                this.events = new MediumEditor.Events(this);
                this.elements = [];

                this.addElements(this.origElements);

                if (this.elements.length === 0) {
                    return;
                }

                this.isActive = true;

                // Call initialization helpers
                initExtensions.call(this);
                attachHandlers.call(this);
            },

            destroy: function () {
                if (!this.isActive) {
                    return;
                }

                this.isActive = false;

                this.extensions.forEach(function (extension) {
                    if (typeof extension.destroy === 'function') {
                        extension.destroy();
                    }
                }, this);

                this.events.destroy();

                this.elements.forEach(function (element) {
                    // Reset elements content, fix for issue where after editor destroyed the red underlines on spelling errors are left
                    if (this.options.spellcheck) {
                        element.innerHTML = element.innerHTML;
                    }

                    // cleanup extra added attributes
                    element.removeAttribute('contentEditable');
                    element.removeAttribute('spellcheck');
                    element.removeAttribute('data-medium-editor-element');
                    element.classList.remove('medium-editor-element');
                    element.removeAttribute('role');
                    element.removeAttribute('aria-multiline');
                    element.removeAttribute('medium-editor-index');
                    element.removeAttribute('data-medium-editor-editor-index');

                    // Remove any elements created for textareas
                    if (element.getAttribute('medium-editor-textarea-id')) {
                        cleanupTextareaElement(element);
                    }
                }, this);
                this.elements = [];
                this.instanceHandleEditableKeydownEnter = null;
                this.instanceHandleEditableInput = null;

                removeFromEditors.call(this, this.options.contentWindow);
            },

            on: function (target, event, listener, useCapture) {
                this.events.attachDOMEvent(target, event, listener, useCapture);

                return this;
            },

            off: function (target, event, listener, useCapture) {
                this.events.detachDOMEvent(target, event, listener, useCapture);

                return this;
            },

            subscribe: function (event, listener) {
                this.events.attachCustomEvent(event, listener);

                return this;
            },

            unsubscribe: function (event, listener) {
                this.events.detachCustomEvent(event, listener);

                return this;
            },

            trigger: function (name, data, editable) {
                this.events.triggerCustomEvent(name, data, editable);

                return this;
            },

            delay: function (fn) {
                var self = this;
                return setTimeout(function () {
                    if (self.isActive) {
                        fn();
                    }
                }, this.options.delay);
            },

            serialize: function () {
                var i,
                    elementid,
                    content = {},
                    len = this.elements.length;

                for (i = 0; i < len; i += 1) {
                    elementid = (this.elements[i].id !== '') ? this.elements[i].id : 'element-' + i;
                    content[elementid] = {
                        value: this.elements[i].innerHTML.trim()
                    };
                }
                return content;
            },

            getExtensionByName: function (name) {
                var extension;
                if (this.extensions && this.extensions.length) {
                    this.extensions.some(function (ext) {
                        if (ext.name === name) {
                            extension = ext;
                            return true;
                        }
                        return false;
                    });
                }
                return extension;
            },

            /**
             * NOT DOCUMENTED - exposed as a helper for other extensions to use
             */
            addBuiltInExtension: function (name, opts) {
                var extension = this.getExtensionByName(name),
                    merged;
                if (extension) {
                    return extension;
                }

                switch (name) {
                    case 'anchor':
                        merged = MediumEditor.util.extend({}, this.options.anchor, opts);
                        extension = new MediumEditor.extensions.anchor(merged);
                        break;
                    case 'anchor-preview':
                        extension = new MediumEditor.extensions.anchorPreview(this.options.anchorPreview);
                        break;
                    case 'autoLink':
                        extension = new MediumEditor.extensions.autoLink();
                        break;
                    case 'fileDragging':
                        extension = new MediumEditor.extensions.fileDragging(opts);
                        break;
                    case 'fontname':
                        extension = new MediumEditor.extensions.fontName(this.options.fontName);
                        break;
                    case 'fontsize':
                        extension = new MediumEditor.extensions.fontSize(opts);
                        break;
                    case 'keyboardCommands':
                        extension = new MediumEditor.extensions.keyboardCommands(this.options.keyboardCommands);
                        break;
                    case 'paste':
                        extension = new MediumEditor.extensions.paste(this.options.paste);
                        break;
                    case 'placeholder':
                        extension = new MediumEditor.extensions.placeholder(this.options.placeholder);
                        break;
                    default:
                        // All of the built-in buttons for MediumEditor are extensions
                        // so check to see if the extension we're creating is a built-in button
                        if (MediumEditor.extensions.button.isBuiltInButton(name)) {
                            if (opts) {
                                merged = MediumEditor.util.defaults({}, opts, MediumEditor.extensions.button.prototype.defaults[name]);
                                extension = new MediumEditor.extensions.button(merged);
                            } else {
                                extension = new MediumEditor.extensions.button(name);
                            }
                        }
                }

                if (extension) {
                    this.extensions.push(initExtension(extension, name, this));
                }

                return extension;
            },

            stopSelectionUpdates: function () {
                this.preventSelectionUpdates = true;
            },

            startSelectionUpdates: function () {
                this.preventSelectionUpdates = false;
            },

            checkSelection: function () {
                var toolbar = this.getExtensionByName('toolbar');
                if (toolbar) {
                    toolbar.checkState();
                }
                return this;
            },

            // Wrapper around document.queryCommandState for checking whether an action has already
            // been applied to the current selection
            queryCommandState: function (action) {
                var fullAction = /^full-(.+)$/gi,
                    match,
                    queryState = null;

                // Actions starting with 'full-' need to be modified since this is a medium-editor concept
                match = fullAction.exec(action);
                if (match) {
                    action = match[1];
                }

                try {
                    queryState = this.options.ownerDocument.queryCommandState(action);
                } catch (exc) {
                    queryState = null;
                }

                return queryState;
            },

            execAction: function (action, opts) {
                /*jslint regexp: true*/
                var fullAction = /^full-(.+)$/gi,
                    match,
                    result;
                /*jslint regexp: false*/

                // Actions starting with 'full-' should be applied to to the entire contents of the editable element
                // (ie full-bold, full-append-pre, etc.)
                match = fullAction.exec(action);
                if (match) {
                    // Store the current selection to be restored after applying the action
                    this.saveSelection();
                    // Select all of the contents before calling the action
                    this.selectAllContents();
                    result = execActionInternal.call(this, match[1], opts);
                    // Restore the previous selection
                    this.restoreSelection();
                } else {
                    result = execActionInternal.call(this, action, opts);
                }

                // do some DOM clean-up for known browser issues after the action
                if (action === 'insertunorderedlist' || action === 'insertorderedlist') {
                    MediumEditor.util.cleanListDOM(this.options.ownerDocument, this.getSelectedParentElement());
                }

                this.checkSelection();
                return result;
            },

            getSelectedParentElement: function (range) {
                if (range === undefined) {
                    range = this.options.contentWindow.getSelection().getRangeAt(0);
                }
                return MediumEditor.selection.getSelectedParentElement(range);
            },

            selectAllContents: function () {
                var currNode = MediumEditor.selection.getSelectionElement(this.options.contentWindow);

                if (currNode) {
                    // Move to the lowest descendant node that still selects all of the contents
                    while (currNode.children.length === 1) {
                        currNode = currNode.children[0];
                    }

                    this.selectElement(currNode);
                }
            },

            selectElement: function (element) {
                MediumEditor.selection.selectNode(element, this.options.ownerDocument);

                var selElement = MediumEditor.selection.getSelectionElement(this.options.contentWindow);
                if (selElement) {
                    this.events.focusElement(selElement);
                }
            },

            getFocusedElement: function () {
                var focused;
                this.elements.some(function (element) {
                    // Find the element that has focus
                    if (!focused && element.getAttribute('data-medium-focused')) {
                        focused = element;
                    }

                    // bail if we found the element that had focus
                    return !!focused;
                }, this);

                return focused;
            },

            // Export the state of the selection in respect to one of this
            // instance of MediumEditor's elements
            exportSelection: function () {
                var selectionElement = MediumEditor.selection.getSelectionElement(this.options.contentWindow),
                    editableElementIndex = this.elements.indexOf(selectionElement),
                    selectionState = null;

                if (editableElementIndex >= 0) {
                    selectionState = MediumEditor.selection.exportSelection(selectionElement, this.options.ownerDocument);
                }

                if (selectionState !== null && editableElementIndex !== 0) {
                    selectionState.editableElementIndex = editableElementIndex;
                }

                return selectionState;
            },

            saveSelection: function () {
                this.selectionState = this.exportSelection();
            },

            // Restore a selection based on a selectionState returned by a call
            // to MediumEditor.exportSelection
            importSelection: function (selectionState, favorLaterSelectionAnchor) {
                if (!selectionState) {
                    return;
                }

                var editableElement = this.elements[selectionState.editableElementIndex || 0];
                MediumEditor.selection.importSelection(selectionState, editableElement, this.options.ownerDocument, favorLaterSelectionAnchor);
            },

            restoreSelection: function () {
                this.importSelection(this.selectionState);
            },

            createLink: function (opts) {
                var currentEditor = MediumEditor.selection.getSelectionElement(this.options.contentWindow),
                    customEvent = {},
                    targetUrl;

                // Make sure the selection is within an element this editor is tracking
                if (this.elements.indexOf(currentEditor) === -1) {
                    return;
                }

                try {
                    this.events.disableCustomEvent('editableInput');
                    // TODO: Deprecate support for opts.url in 6.0.0
                    if (opts.url) {
                        MediumEditor.util.deprecated('.url option for createLink', '.value', '6.0.0');
                    }
                    targetUrl = opts.url || opts.value;
                    if (targetUrl && targetUrl.trim().length > 0) {
                        var currentSelection = this.options.contentWindow.getSelection();
                        if (currentSelection) {
                            var currRange = currentSelection.getRangeAt(0),
                                commonAncestorContainer = currRange.commonAncestorContainer,
                                exportedSelection,
                                startContainerParentElement,
                                endContainerParentElement,
                                textNodes;

                            // If the selection is contained within a single text node
                            // and the selection starts at the beginning of the text node,
                            // MSIE still says the startContainer is the parent of the text node.
                            // If the selection is contained within a single text node, we
                            // want to just use the default browser 'createLink', so we need
                            // to account for this case and adjust the commonAncestorContainer accordingly
                            if (currRange.endContainer.nodeType === 3 &&
                                currRange.startContainer.nodeType !== 3 &&
                                currRange.startOffset === 0 &&
                                currRange.startContainer.firstChild === currRange.endContainer) {
                                commonAncestorContainer = currRange.endContainer;
                            }

                            startContainerParentElement = MediumEditor.util.getClosestBlockContainer(currRange.startContainer);
                            endContainerParentElement = MediumEditor.util.getClosestBlockContainer(currRange.endContainer);

                            // If the selection is not contained within a single text node
                            // but the selection is contained within the same block element
                            // we want to make sure we create a single link, and not multiple links
                            // which can happen with the built in browser functionality
                            if (commonAncestorContainer.nodeType !== 3 && commonAncestorContainer.textContent.length !== 0 && startContainerParentElement === endContainerParentElement) {
                                var parentElement = (startContainerParentElement || currentEditor),
                                    fragment = this.options.ownerDocument.createDocumentFragment();

                                // since we are going to create a link from an extracted text,
                                // be sure that if we are updating a link, we won't let an empty link behind (see #754)
                                // (Workaroung for Chrome)
                                this.execAction('unlink');

                                exportedSelection = this.exportSelection();
                                fragment.appendChild(parentElement.cloneNode(true));

                                if (currentEditor === parentElement) {
                                    // We have to avoid the editor itself being wiped out when it's the only block element,
                                    // as our reference inside this.elements gets detached from the page when insertHTML runs.
                                    // If we just use [parentElement, 0] and [parentElement, parentElement.childNodes.length]
                                    // as the range boundaries, this happens whenever parentElement === currentEditor.
                                    // The tradeoff to this workaround is that a orphaned tag can sometimes be left behind at
                                    // the end of the editor's content.
                                    // In Gecko:
                                    // as an empty <strong></strong> if parentElement.lastChild is a <strong> tag.
                                    // In WebKit:
                                    // an invented <br /> tag at the end in the same situation
                                    MediumEditor.selection.select(
                                        this.options.ownerDocument,
                                        parentElement.firstChild,
                                        0,
                                        parentElement.lastChild,
                                        parentElement.lastChild.nodeType === 3 ?
                                            parentElement.lastChild.nodeValue.length : parentElement.lastChild.childNodes.length
                                    );
                                } else {
                                    MediumEditor.selection.select(
                                        this.options.ownerDocument,
                                        parentElement,
                                        0,
                                        parentElement,
                                        parentElement.childNodes.length
                                    );
                                }

                                var modifiedExportedSelection = this.exportSelection();

                                textNodes = MediumEditor.util.findOrCreateMatchingTextNodes(
                                    this.options.ownerDocument,
                                    fragment,
                                    {
                                        start: exportedSelection.start - modifiedExportedSelection.start,
                                        end: exportedSelection.end - modifiedExportedSelection.start,
                                        editableElementIndex: exportedSelection.editableElementIndex
                                    }
                                );
                                // If textNodes are not present, when changing link on images
                                // ex: <a><img src="http://image.test.com"></a>, change fragment to currRange.startContainer
                                // and set textNodes array to [imageElement, imageElement]
                                if (textNodes.length === 0) {
                                    fragment = this.options.ownerDocument.createDocumentFragment();
                                    fragment.appendChild(commonAncestorContainer.cloneNode(true));
                                    textNodes = [fragment.firstChild.firstChild, fragment.firstChild.lastChild];
                                }

                                // Creates the link in the document fragment
                                MediumEditor.util.createLink(this.options.ownerDocument, textNodes, targetUrl.trim());

                                // Chrome trims the leading whitespaces when inserting HTML, which messes up restoring the selection.
                                var leadingWhitespacesCount = (fragment.firstChild.innerHTML.match(/^\s+/) || [''])[0].length;

                                // Now move the created link back into the original document in a way to preserve undo/redo history
                                MediumEditor.util.insertHTMLCommand(this.options.ownerDocument, fragment.firstChild.innerHTML.replace(/^\s+/, ''));
                                exportedSelection.start -= leadingWhitespacesCount;
                                exportedSelection.end -= leadingWhitespacesCount;

                                this.importSelection(exportedSelection);
                            } else {
                                this.options.ownerDocument.execCommand('createLink', false, targetUrl);
                            }

                            if (this.options.targetBlank || opts.target === '_blank') {
                                MediumEditor.util.setTargetBlank(MediumEditor.selection.getSelectionStart(this.options.ownerDocument), targetUrl);
                            } else {
                                MediumEditor.util.removeTargetBlank(MediumEditor.selection.getSelectionStart(this.options.ownerDocument), targetUrl);
                            }

                            if (opts.buttonClass) {
                                MediumEditor.util.addClassToAnchors(MediumEditor.selection.getSelectionStart(this.options.ownerDocument), opts.buttonClass);
                            }
                        }
                    }
                    // Fire input event for backwards compatibility if anyone was listening directly to the DOM input event
                    if (this.options.targetBlank || opts.target === '_blank' || opts.buttonClass) {
                        customEvent = this.options.ownerDocument.createEvent('HTMLEvents');
                        customEvent.initEvent('input', true, true, this.options.contentWindow);
                        for (var i = 0, len = this.elements.length; i < len; i += 1) {
                            this.elements[i].dispatchEvent(customEvent);
                        }
                    }
                } finally {
                    this.events.enableCustomEvent('editableInput');
                }
                // Fire our custom editableInput event
                this.events.triggerCustomEvent('editableInput', customEvent, currentEditor);
            },

            cleanPaste: function (text) {
                this.getExtensionByName('paste').cleanPaste(text);
            },

            pasteHTML: function (html, options) {
                this.getExtensionByName('paste').pasteHTML(html, options);
            },

            setContent: function (html, index) {
                index = index || 0;

                if (this.elements[index]) {
                    var target = this.elements[index];
                    target.innerHTML = html;
                    this.checkContentChanged(target);
                }
            },

            getContent: function (index) {
                index = index || 0;

                if (this.elements[index]) {
                    return this.elements[index].innerHTML.trim();
                }
                return null;
            },

            checkContentChanged: function (editable) {
                editable = editable || MediumEditor.selection.getSelectionElement(this.options.contentWindow);
                this.events.updateInput(editable, { target: editable, currentTarget: editable });
            },

            resetContent: function (element) {
                // For all elements that exist in the this.elements array, we can assume:
                // - Its initial content has been set in the initialContent object
                // - It has a medium-editor-index attribute which is the key value in the initialContent object

                if (element) {
                    var index = this.elements.indexOf(element);
                    if (index !== -1) {
                        this.setContent(initialContent[element.getAttribute('medium-editor-index')], index);
                    }
                    return;
                }

                this.elements.forEach(function (el, idx) {
                    this.setContent(initialContent[el.getAttribute('medium-editor-index')], idx);
                }, this);
            },

            addElements: function (selector) {
                // Convert elements into an array
                var elements = createElementsArray(selector, this.options.ownerDocument, true);

                // Do we have elements to add now?
                if (elements.length === 0) {
                    return false;
                }

                elements.forEach(function (element) {
                    // Initialize all new elements (we check that in those functions don't worry)
                    element = initElement.call(this, element, this.id);

                    // Add new elements to our internal elements array
                    this.elements.push(element);

                    // Trigger event so extensions can know when an element has been added
                    this.trigger('addElement', { target: element, currentTarget: element }, element);
                }, this);
            },

            removeElements: function (selector) {
                // Convert elements into an array
                var elements = createElementsArray(selector, this.options.ownerDocument),
                    toRemove = elements.map(function (el) {
                        // For textareas, make sure we're looking at the editor div and not the textarea itself
                        if (el.getAttribute('medium-editor-textarea-id') && el.parentNode) {
                            return el.parentNode.querySelector('div[medium-editor-textarea-id="' + el.getAttribute('medium-editor-textarea-id') + '"]');
                        } else {
                            return el;
                        }
                    });

                this.elements = this.elements.filter(function (element) {
                    // If this is an element we want to remove
                    if (toRemove.indexOf(element) !== -1) {
                        this.events.cleanupElement(element);
                        if (element.getAttribute('medium-editor-textarea-id')) {
                            cleanupTextareaElement(element);
                        }
                        // Trigger event so extensions can clean-up elements that are being removed
                        this.trigger('removeElement', { target: element, currentTarget: element }, element);
                        return false;
                    }
                    return true;
                }, this);
            }
        };

        MediumEditor.getEditorFromElement = function (element) {
            var index = element.getAttribute('data-medium-editor-editor-index'),
                win = element && element.ownerDocument && (element.ownerDocument.defaultView || element.ownerDocument.parentWindow);
            if (win && win._mediumEditors && win._mediumEditors[index]) {
                return win._mediumEditors[index];
            }
            return null;
        };
    }());

    (function () {
        // summary: The default options hash used by the Editor

        MediumEditor.prototype.defaults = {
            activeButtonClass: 'medium-editor-button-active',
            buttonLabels: false,
            delay: 0,
            disableReturn: false,
            disableDoubleReturn: false,
            disableExtraSpaces: false,
            disableEditing: false,
            autoLink: false,
            elementsContainer: false,
            contentWindow: window,
            ownerDocument: document,
            targetBlank: false,
            extensions: {},
            spellcheck: true
        };
    })();

    MediumEditor.parseVersionString = function (release) {
        var split = release.split('-'),
            version = split[0].split('.'),
            preRelease = (split.length > 1) ? split[1] : '';
        return {
            major: parseInt(version[0], 10),
            minor: parseInt(version[1], 10),
            revision: parseInt(version[2], 10),
            preRelease: preRelease,
            toString: function () {
                return [version[0], version[1], version[2]].join('.') + (preRelease ? '-' + preRelease : '');
            }
        };
    };

    MediumEditor.version = MediumEditor.parseVersionString.call(this, ({
        // grunt-bump looks for this:
        'version': '5.23.1'
    }).version);

    return MediumEditor;
}()));
( function( window, undefined ) {
	'use strict';

	/**
	 * Handles managing all events for whatever you plug it into. Priorities for hooks are based on lowest to highest in
	 * that, lowest priority hooks are fired first.
	 */
	var EventManager = function() {
		var slice = Array.prototype.slice;

		/**
		 * Maintain a reference to the object scope so our public methods never get confusing.
		 */
		var MethodsAvailable = {
			removeFilter : removeFilter,
			applyFilters : applyFilters,
			addFilter : addFilter,
			removeAction : removeAction,
			doAction : doAction,
			addAction : addAction
		};

		/**
		 * Contains the hooks that get registered with this EventManager. The array for storage utilizes a "flat"
		 * object literal such that looking up the hook utilizes the native object literal hash.
		 */
		var STORAGE = {
			actions : {},
			filters : {}
		};

		/**
		 * Adds an action to the event manager.
		 *
		 * @param action Must contain namespace.identifier
		 * @param callback Must be a valid callback function before this action is added
		 * @param [priority=10] Used to control when the function is executed in relation to other callbacks bound to the same hook
		 * @param [context] Supply a value to be used for this
		 */
		function addAction( action, callback, priority, context ) {
			if( typeof action === 'string' && typeof callback === 'function' ) {
				priority = parseInt( ( priority || 10 ), 10 );
				_addHook( 'actions', action, callback, priority, context );
			}

			return MethodsAvailable;
		}

		/**
		 * Performs an action if it exists. You can pass as many arguments as you want to this function; the only rule is
		 * that the first argument must always be the action.
		 */
		function doAction( /* action, arg1, arg2, ... */ ) {
			var args = slice.call( arguments );
			var action = args.shift();

			if( typeof action === 'string' ) {
				_runHook( 'actions', action, args );
			}

			return MethodsAvailable;
		}

		/**
		 * Removes the specified action if it contains a namespace.identifier & exists.
		 *
		 * @param action The action to remove
		 * @param [callback] Callback function to remove
		 */
		function removeAction( action, callback ) {
			if( typeof action === 'string' ) {
				_removeHook( 'actions', action, callback );
			}

			return MethodsAvailable;
		}

		/**
		 * Adds a filter to the event manager.
		 *
		 * @param filter Must contain namespace.identifier
		 * @param callback Must be a valid callback function before this action is added
		 * @param [priority=10] Used to control when the function is executed in relation to other callbacks bound to the same hook
		 * @param [context] Supply a value to be used for this
		 */
		function addFilter( filter, callback, priority, context ) {
			if( typeof filter === 'string' && typeof callback === 'function' ) {
				priority = parseInt( ( priority || 10 ), 10 );
				_addHook( 'filters', filter, callback, priority, context );
			}

			return MethodsAvailable;
		}

		/**
		 * Performs a filter if it exists. You should only ever pass 1 argument to be filtered. The only rule is that
		 * the first argument must always be the filter.
		 */
		function applyFilters( /* filter, filtered arg, arg2, ... */ ) {
			var args = slice.call( arguments );
			var filter = args.shift();

			if( typeof filter === 'string' ) {
				return _runHook( 'filters', filter, args );
			}

			return MethodsAvailable;
		}

		/**
		 * Removes the specified filter if it contains a namespace.identifier & exists.
		 *
		 * @param filter The action to remove
		 * @param [callback] Callback function to remove
		 */
		function removeFilter( filter, callback ) {
			if( typeof filter === 'string') {
				_removeHook( 'filters', filter, callback );
			}

			return MethodsAvailable;
		}

		/**
		 * Removes the specified hook by resetting the value of it.
		 *
		 * @param type Type of hook, either 'actions' or 'filters'
		 * @param hook The hook (namespace.identifier) to remove
		 * @private
		 */
		function _removeHook( type, hook, callback, context ) {
			var handlers, handler, i;

			if ( !STORAGE[ type ][ hook ] ) {
				return;
			}
			if ( !callback ) {
				STORAGE[ type ][ hook ] = [];
			} else {
				handlers = STORAGE[ type ][ hook ];
				if ( !context ) {
					for ( i = handlers.length; i--; ) {
						if ( handlers[i].callback === callback ) {
							handlers.splice( i, 1 );
						}
					}
				}
				else {
					for ( i = handlers.length; i--; ) {
						handler = handlers[i];
						if ( handler.callback === callback && handler.context === context) {
							handlers.splice( i, 1 );
						}
					}
				}
			}
		}

		/**
		 * Adds the hook to the appropriate storage container
		 *
		 * @param type 'actions' or 'filters'
		 * @param hook The hook (namespace.identifier) to add to our event manager
		 * @param callback The function that will be called when the hook is executed.
		 * @param priority The priority of this hook. Must be an integer.
		 * @param [context] A value to be used for this
		 * @private
		 */
		function _addHook( type, hook, callback, priority, context ) {
			var hookObject = {
				callback : callback,
				priority : priority,
				context : context
			};

			// Utilize 'prop itself' : http://jsperf.com/hasownproperty-vs-in-vs-undefined/19
			var hooks = STORAGE[ type ][ hook ];
			if( hooks ) {
				hooks.push( hookObject );
				hooks = _hookInsertSort( hooks );
			}
			else {
				hooks = [ hookObject ];
			}

			STORAGE[ type ][ hook ] = hooks;
		}

		/**
		 * Use an insert sort for keeping our hooks organized based on priority. This function is ridiculously faster
		 * than bubble sort, etc: http://jsperf.com/javascript-sort
		 *
		 * @param hooks The custom array containing all of the appropriate hooks to perform an insert sort on.
		 * @private
		 */
		function _hookInsertSort( hooks ) {
			var tmpHook, j, prevHook;
			for( var i = 1, len = hooks.length; i < len; i++ ) {
				tmpHook = hooks[ i ];
				j = i;
				while( ( prevHook = hooks[ j - 1 ] ) &&  prevHook.priority > tmpHook.priority ) {
					hooks[ j ] = hooks[ j - 1 ];
					--j;
				}
				hooks[ j ] = tmpHook;
			}

			return hooks;
		}

		/**
		 * Runs the specified hook. If it is an action, the value is not modified but if it is a filter, it is.
		 *
		 * @param type 'actions' or 'filters'
		 * @param hook The hook ( namespace.identifier ) to be ran.
		 * @param args Arguments to pass to the action/filter. If it's a filter, args is actually a single parameter.
		 * @private
		 */
		function _runHook( type, hook, args ) {
			var handlers = STORAGE[ type ][ hook ], i, len;

			if ( !handlers ) {
				return (type === 'filters') ? args[0] : false;
			}

			len = handlers.length;
			if ( type === 'filters' ) {
				for ( i = 0; i < len; i++ ) {
					args[ 0 ] = handlers[ i ].callback.apply( handlers[ i ].context, args );
				}
			} else {
				for ( i = 0; i < len; i++ ) {
					handlers[ i ].callback.apply( handlers[ i ].context, args );
				}
			}

			return ( type === 'filters' ) ? args[ 0 ] : true;
		}

		// return all of the publicly available methods
		return MethodsAvailable;

	};

	window.wp = window.wp || {};
	window.wp.hooks = new EventManager();

} )( window );
/*!
 * element-resize-detector 1.1.12
 * Copyright (c) 2016 Lucas Wiener
 * https://github.com/wnr/element-resize-detector
 * Licensed under MIT
 */

(function(f){if(typeof exports==="object"&&typeof module!=="undefined"){module.exports=f()}else if(typeof define==="function"&&define.amd){define([],f)}else{var g;if(typeof window!=="undefined"){g=window}else if(typeof global!=="undefined"){g=global}else if(typeof self!=="undefined"){g=self}else{g=this}g.elementResizeDetectorMaker = f()}})(function(){var define,module,exports;return (function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
    "use strict";

    var utils = require("./utils");

    module.exports = function batchProcessorMaker(options) {
        options             = options || {};
        var reporter        = options.reporter;
        var asyncProcess    = utils.getOption(options, "async", true);
        var autoProcess     = utils.getOption(options, "auto", true);

        if(autoProcess && !asyncProcess) {
            reporter && reporter.warn("Invalid options combination. auto=true and async=false is invalid. Setting async=true.");
            asyncProcess = true;
        }

        var batch = Batch();
        var asyncFrameHandler;
        var isProcessing = false;

        function addFunction(level, fn) {
            if(!isProcessing && autoProcess && asyncProcess && batch.size() === 0) {
                // Since this is async, it is guaranteed to be executed after that the fn is added to the batch.
                // This needs to be done before, since we're checking the size of the batch to be 0.
                processBatchAsync();
            }

            batch.add(level, fn);
        }

        function processBatch() {
            // Save the current batch, and create a new batch so that incoming functions are not added into the currently processing batch.
            // Continue processing until the top-level batch is empty (functions may be added to the new batch while processing, and so on).
            isProcessing = true;
            while (batch.size()) {
                var processingBatch = batch;
                batch = Batch();
                processingBatch.process();
            }
            isProcessing = false;
        }

        function forceProcessBatch(localAsyncProcess) {
            if (isProcessing) {
                return;
            }

            if(localAsyncProcess === undefined) {
                localAsyncProcess = asyncProcess;
            }

            if(asyncFrameHandler) {
                cancelFrame(asyncFrameHandler);
                asyncFrameHandler = null;
            }

            if(localAsyncProcess) {
                processBatchAsync();
            } else {
                processBatch();
            }
        }

        function processBatchAsync() {
            asyncFrameHandler = requestFrame(processBatch);
        }

        function clearBatch() {
            batch           = {};
            batchSize       = 0;
            topLevel        = 0;
            bottomLevel     = 0;
        }

        function cancelFrame(listener) {
            // var cancel = window.cancelAnimationFrame || window.mozCancelAnimationFrame || window.webkitCancelAnimationFrame || window.clearTimeout;
            var cancel = clearTimeout;
            return cancel(listener);
        }

        function requestFrame(callback) {
            // var raf = window.requestAnimationFrame || window.mozRequestAnimationFrame || window.webkitRequestAnimationFrame || function(fn) { return window.setTimeout(fn, 20); };
            var raf = function(fn) { return setTimeout(fn, 0); };
            return raf(callback);
        }

        return {
            add: addFunction,
            force: forceProcessBatch
        };
    };

    function Batch() {
        var batch       = {};
        var size        = 0;
        var topLevel    = 0;
        var bottomLevel = 0;

        function add(level, fn) {
            if(!fn) {
                fn = level;
                level = 0;
            }

            if(level > topLevel) {
                topLevel = level;
            } else if(level < bottomLevel) {
                bottomLevel = level;
            }

            if(!batch[level]) {
                batch[level] = [];
            }

            batch[level].push(fn);
            size++;
        }

        function process() {
            for(var level = bottomLevel; level <= topLevel; level++) {
                var fns = batch[level];

                for(var i = 0; i < fns.length; i++) {
                    var fn = fns[i];
                    fn();
                }
            }
        }

        function getSize() {
            return size;
        }

        return {
            add: add,
            process: process,
            size: getSize
        };
    }

},{"./utils":2}],2:[function(require,module,exports){
    "use strict";

    var utils = module.exports = {};

    utils.getOption = getOption;

    function getOption(options, name, defaultValue) {
        var value = options[name];

        if((value === undefined || value === null) && defaultValue !== undefined) {
            return defaultValue;
        }

        return value;
    }

},{}],3:[function(require,module,exports){
    "use strict";

    var detector = module.exports = {};

    detector.isIE = function(version) {
        function isAnyIeVersion() {
            var agent = navigator.userAgent.toLowerCase();
            return agent.indexOf("msie") !== -1 || agent.indexOf("trident") !== -1 || agent.indexOf(" edge/") !== -1;
        }

        if(!isAnyIeVersion()) {
            return false;
        }

        if(!version) {
            return true;
        }

        //Shamelessly stolen from https://gist.github.com/padolsey/527683
        var ieVersion = (function(){
            var undef,
                v = 3,
                div = document.createElement("div"),
                all = div.getElementsByTagName("i");

            do {
                div.innerHTML = "<!--[if gt IE " + (++v) + "]><i></i><![endif]-->";
            }
            while (all[0]);

            return v > 4 ? v : undef;
        }());

        return version === ieVersion;
    };

    detector.isLegacyOpera = function() {
        return !!window.opera;
    };

},{}],4:[function(require,module,exports){
    "use strict";

    var utils = module.exports = {};

    /**
     * Loops through the collection and calls the callback for each element. if the callback returns truthy, the loop is broken and returns the same value.
     * @public
     * @param {*} collection The collection to loop through. Needs to have a length property set and have indices set from 0 to length - 1.
     * @param {function} callback The callback to be called for each element. The element will be given as a parameter to the callback. If this callback returns truthy, the loop is broken and the same value is returned.
     * @returns {*} The value that a callback has returned (if truthy). Otherwise nothing.
     */
    utils.forEach = function(collection, callback) {
        for(var i = 0; i < collection.length; i++) {
            var result = callback(collection[i]);
            if(result) {
                return result;
            }
        }
    };

},{}],5:[function(require,module,exports){
    /**
     * Resize detection strategy that injects objects to elements in order to detect resize events.
     * Heavily inspired by: http://www.backalleycoder.com/2013/03/18/cross-browser-event-based-element-resize-detection/
     */

    "use strict";

    var browserDetector = require("../browser-detector");

    module.exports = function(options) {
        options             = options || {};
        var reporter        = options.reporter;
        var batchProcessor  = options.batchProcessor;
        var getState        = options.stateHandler.getState;

        if(!reporter) {
            throw new Error("Missing required dependency: reporter.");
        }

        /**
         * Adds a resize event listener to the element.
         * @public
         * @param {element} element The element that should have the listener added.
         * @param {function} listener The listener callback to be called for each resize event of the element. The element will be given as a parameter to the listener callback.
         */
        function addListener(element, listener) {
            if(!getObject(element)) {
                throw new Error("Element is not detectable by this strategy.");
            }

            function listenerProxy() {
                listener(element);
            }

            if(browserDetector.isIE(8)) {
                //IE 8 does not support object, but supports the resize event directly on elements.
                getState(element).object = {
                    proxy: listenerProxy
                };
                element.attachEvent("onresize", listenerProxy);
            } else {
                var object = getObject(element);
                object.contentDocument.defaultView.addEventListener("resize", listenerProxy);
            }
        }

        /**
         * Makes an element detectable and ready to be listened for resize events. Will call the callback when the element is ready to be listened for resize changes.
         * @private
         * @param {object} options Optional options object.
         * @param {element} element The element to make detectable
         * @param {function} callback The callback to be called when the element is ready to be listened for resize changes. Will be called with the element as first parameter.
         */
        function makeDetectable(options, element, callback) {
            if (!callback) {
                callback = element;
                element = options;
                options = null;
            }

            options = options || {};
            var debug = options.debug;

            function injectObject(element, callback) {
                var OBJECT_STYLE = "display: block; position: absolute; top: 0; left: 0; width: 100%; height: 100%; border: none; padding: 0; margin: 0; opacity: 0; z-index: -1000; pointer-events: none;";

                //The target element needs to be positioned (everything except static) so the absolute positioned object will be positioned relative to the target element.

                // Position altering may be performed directly or on object load, depending on if style resolution is possible directly or not.
                var positionCheckPerformed = false;

                // The element may not yet be attached to the DOM, and therefore the style object may be empty in some browsers.
                // Since the style object is a reference, it will be updated as soon as the element is attached to the DOM.
                var style = window.getComputedStyle(element);
                var width = element.offsetWidth;
                var height = element.offsetHeight;

                getState(element).startSize = {
                    width: width,
                    height: height
                };

                function mutateDom() {
                    function alterPositionStyles() {
                        if(style.position === "static") {
                            element.style.position = "relative";

                            var removeRelativeStyles = function(reporter, element, style, property) {
                                function getNumericalValue(value) {
                                    return value.replace(/[^-\d\.]/g, "");
                                }

                                var value = style[property];

                                if(value !== "auto" && getNumericalValue(value) !== "0") {
                                    reporter.warn("An element that is positioned static has style." + property + "=" + value + " which is ignored due to the static positioning. The element will need to be positioned relative, so the style." + property + " will be set to 0. Element: ", element);
                                    element.style[property] = 0;
                                }
                            };

                            //Check so that there are no accidental styles that will make the element styled differently now that is is relative.
                            //If there are any, set them to 0 (this should be okay with the user since the style properties did nothing before [since the element was positioned static] anyway).
                            removeRelativeStyles(reporter, element, style, "top");
                            removeRelativeStyles(reporter, element, style, "right");
                            removeRelativeStyles(reporter, element, style, "bottom");
                            removeRelativeStyles(reporter, element, style, "left");
                        }
                    }

                    function onObjectLoad() {
                        // The object has been loaded, which means that the element now is guaranteed to be attached to the DOM.
                        if (!positionCheckPerformed) {
                            alterPositionStyles();
                        }

                        /*jshint validthis: true */

                        function getDocument(element, callback) {
                            //Opera 12 seem to call the object.onload before the actual document has been created.
                            //So if it is not present, poll it with an timeout until it is present.
                            //TODO: Could maybe be handled better with object.onreadystatechange or similar.
                            if(!element.contentDocument) {
                                setTimeout(function checkForObjectDocument() {
                                    getDocument(element, callback);
                                }, 100);

                                return;
                            }

                            callback(element.contentDocument);
                        }

                        //Mutating the object element here seems to fire another load event.
                        //Mutating the inner document of the object element is fine though.
                        var objectElement = this;

                        //Create the style element to be added to the object.
                        getDocument(objectElement, function onObjectDocumentReady(objectDocument) {
                            //Notify that the element is ready to be listened to.
                            callback(element);
                        });
                    }

                    // The element may be detached from the DOM, and some browsers does not support style resolving of detached elements.
                    // The alterPositionStyles needs to be delayed until we know the element has been attached to the DOM (which we are sure of when the onObjectLoad has been fired), if style resolution is not possible.
                    if (style && style.position !== "") {
                        alterPositionStyles(style);
                        positionCheckPerformed = true;
                    }

                    //Add an object element as a child to the target element that will be listened to for resize events.
                    var object = document.createElement("object");
                    object.style.cssText = OBJECT_STYLE;
                    object.tabIndex = -1;
                    object.type = "text/html";
                    object.onload = onObjectLoad;

                    //Safari: This must occur before adding the object to the DOM.
                    //IE: Does not like that this happens before, even if it is also added after.
                    if(!browserDetector.isIE()) {
                        object.data = "about:blank";
                    }

                    element.appendChild(object);
                    getState(element).object = object;

                    //IE: This must occur after adding the object to the DOM.
                    if(browserDetector.isIE()) {
                        object.data = "about:blank";
                    }
                }

                if(batchProcessor) {
                    batchProcessor.add(mutateDom);
                } else {
                    mutateDom();
                }
            }

            if(browserDetector.isIE(8)) {
                //IE 8 does not support objects properly. Luckily they do support the resize event.
                //So do not inject the object and notify that the element is already ready to be listened to.
                //The event handler for the resize event is attached in the utils.addListener instead.
                callback(element);
            } else {
                injectObject(element, callback);
            }
        }

        /**
         * Returns the child object of the target element.
         * @private
         * @param {element} element The target element.
         * @returns The object element of the target.
         */
        function getObject(element) {
            return getState(element).object;
        }

        function uninstall(element) {
            if(browserDetector.isIE(8)) {
                element.detachEvent("onresize", getState(element).object.proxy);
            } else {
                element.removeChild(getObject(element));
            }
            delete getState(element).object;
        }

        return {
            makeDetectable: makeDetectable,
            addListener: addListener,
            uninstall: uninstall
        };
    };

},{"../browser-detector":3}],6:[function(require,module,exports){
    /**
     * Resize detection strategy that injects divs to elements in order to detect resize events on scroll events.
     * Heavily inspired by: https://github.com/marcj/css-element-queries/blob/master/src/ResizeSensor.js
     */

    "use strict";

    var forEach = require("../collection-utils").forEach;

    module.exports = function(options) {
        options             = options || {};
        var reporter        = options.reporter;
        var batchProcessor  = options.batchProcessor;
        var getState        = options.stateHandler.getState;
        var hasState        = options.stateHandler.hasState;
        var idHandler       = options.idHandler;

        if (!batchProcessor) {
            throw new Error("Missing required dependency: batchProcessor");
        }

        if (!reporter) {
            throw new Error("Missing required dependency: reporter.");
        }

        //TODO: Could this perhaps be done at installation time?
        var scrollbarSizes = getScrollbarSizes();

        // Inject the scrollbar styling that prevents them from appearing sometimes in Chrome.
        // The injected container needs to have a class, so that it may be styled with CSS (pseudo elements).
        var styleId = "erd_scroll_detection_scrollbar_style";
        var detectionContainerClass = "erd_scroll_detection_container";
        injectScrollStyle(styleId, detectionContainerClass);

        function getScrollbarSizes() {
            var width = 500;
            var height = 500;

            var child = document.createElement("div");
            child.style.cssText = "position: absolute; width: " + width*2 + "px; height: " + height*2 + "px; visibility: hidden; margin: 0; padding: 0;";

            var container = document.createElement("div");
            container.style.cssText = "position: absolute; width: " + width + "px; height: " + height + "px; overflow: scroll; visibility: none; top: " + -width*3 + "px; left: " + -height*3 + "px; visibility: hidden; margin: 0; padding: 0;";

            container.appendChild(child);

            document.body.insertBefore(container, document.body.firstChild);

            var widthSize = width - container.clientWidth;
            var heightSize = height - container.clientHeight;

            document.body.removeChild(container);

            return {
                width: widthSize,
                height: heightSize
            };
        }

        function injectScrollStyle(styleId, containerClass) {
            function injectStyle(style, method) {
                method = method || function (element) {
                    document.head.appendChild(element);
                };

                var styleElement = document.createElement("style");
                styleElement.innerHTML = style;
                styleElement.id = styleId;
                method(styleElement);
                return styleElement;
            }

            if (!document.getElementById(styleId)) {
                var containerAnimationClass = containerClass + "_animation";
                var containerAnimationActiveClass = containerClass + "_animation_active";
                var style = "/* Created by the element-resize-detector library. */\n";
                style += "." + containerClass + " > div::-webkit-scrollbar { display: none; }\n\n";
                style += "." + containerAnimationActiveClass + " { -webkit-animation-duration: 0.1s; animation-duration: 0.1s; -webkit-animation-name: " + containerAnimationClass + "; animation-name: " + containerAnimationClass + "; }\n";
                style += "@-webkit-keyframes " + containerAnimationClass +  " { 0% { opacity: 1; } 50% { opacity: 0; } 100% { opacity: 1; } }\n";
                style += "@keyframes " + containerAnimationClass +          " { 0% { opacity: 1; } 50% { opacity: 0; } 100% { opacity: 1; } }";
                injectStyle(style);
            }
        }

        function addAnimationClass(element) {
            element.className += " " + detectionContainerClass + "_animation_active";
        }

        function addEvent(el, name, cb) {
            if (el.addEventListener) {
                el.addEventListener(name, cb);
            } else if(el.attachEvent) {
                el.attachEvent("on" + name, cb);
            } else {
                return reporter.error("[scroll] Don't know how to add event listeners.");
            }
        }

        function removeEvent(el, name, cb) {
            if (el.removeEventListener) {
                el.removeEventListener(name, cb);
            } else if(el.detachEvent) {
                el.detachEvent("on" + name, cb);
            } else {
                return reporter.error("[scroll] Don't know how to remove event listeners.");
            }
        }

        function getExpandElement(element) {
            return getState(element).container.childNodes[0].childNodes[0].childNodes[0];
        }

        function getShrinkElement(element) {
            return getState(element).container.childNodes[0].childNodes[0].childNodes[1];
        }

        /**
         * Adds a resize event listener to the element.
         * @public
         * @param {element} element The element that should have the listener added.
         * @param {function} listener The listener callback to be called for each resize event of the element. The element will be given as a parameter to the listener callback.
         */
        function addListener(element, listener) {
            var listeners = getState(element).listeners;

            if (!listeners.push) {
                throw new Error("Cannot add listener to an element that is not detectable.");
            }

            getState(element).listeners.push(listener);
        }

        /**
         * Makes an element detectable and ready to be listened for resize events. Will call the callback when the element is ready to be listened for resize changes.
         * @private
         * @param {object} options Optional options object.
         * @param {element} element The element to make detectable
         * @param {function} callback The callback to be called when the element is ready to be listened for resize changes. Will be called with the element as first parameter.
         */
        function makeDetectable(options, element, callback) {
            if (!callback) {
                callback = element;
                element = options;
                options = null;
            }

            options = options || {};

            function debug() {
                if (options.debug) {
                    var args = Array.prototype.slice.call(arguments);
                    args.unshift(idHandler.get(element), "Scroll: ");
                    if (reporter.log.apply) {
                        reporter.log.apply(null, args);
                    } else {
                        for (var i = 0; i < args.length; i++) {
                            reporter.log(args[i]);
                        }
                    }
                }
            }

            function isDetached(element) {
                function isInDocument(element) {
                    return element === element.ownerDocument.body || element.ownerDocument.body.contains(element);
                }

                if (!isInDocument(element)) {
                    return true;
                }

                // FireFox returns null style in hidden iframes. See https://github.com/wnr/element-resize-detector/issues/68 and https://bugzilla.mozilla.org/show_bug.cgi?id=795520
                if (getComputedStyle(element) === null) {
                    return true;
                }

                return false;
            }

            function isUnrendered(element) {
                // Check the absolute positioned container since the top level container is display: inline.
                var container = getState(element).container.childNodes[0];
                var style = getComputedStyle(container);
                return !style.width || style.width.indexOf("px") === -1; //Can only compute pixel value when rendered.
            }

            function getStyle() {
                // Some browsers only force layouts when actually reading the style properties of the style object, so make sure that they are all read here,
                // so that the user of the function can be sure that it will perform the layout here, instead of later (important for batching).
                var elementStyle            = getComputedStyle(element);
                var style                   = {};
                style.position              = elementStyle.position;
                style.width                 = element.offsetWidth;
                style.height                = element.offsetHeight;
                style.top                   = elementStyle.top;
                style.right                 = elementStyle.right;
                style.bottom                = elementStyle.bottom;
                style.left                  = elementStyle.left;
                style.widthCSS              = elementStyle.width;
                style.heightCSS             = elementStyle.height;
                return style;
            }

            function storeStartSize() {
                var style = getStyle();
                getState(element).startSize = {
                    width: style.width,
                    height: style.height
                };
                debug("Element start size", getState(element).startSize);
            }

            function initListeners() {
                getState(element).listeners = [];
            }

            function storeStyle() {
                debug("storeStyle invoked.");
                if (!getState(element)) {
                    debug("Aborting because element has been uninstalled");
                    return;
                }

                var style = getStyle();
                getState(element).style = style;
            }

            function storeCurrentSize(element, width, height) {
                getState(element).lastWidth = width;
                getState(element).lastHeight  = height;
            }

            function getExpandChildElement(element) {
                return getExpandElement(element).childNodes[0];
            }

            function getWidthOffset() {
                return 2 * scrollbarSizes.width + 1;
            }

            function getHeightOffset() {
                return 2 * scrollbarSizes.height + 1;
            }

            function getExpandWidth(width) {
                return width + 10 + getWidthOffset();
            }

            function getExpandHeight(height) {
                return height + 10 + getHeightOffset();
            }

            function getShrinkWidth(width) {
                return width * 2 + getWidthOffset();
            }

            function getShrinkHeight(height) {
                return height * 2 + getHeightOffset();
            }

            function positionScrollbars(element, width, height) {
                var expand          = getExpandElement(element);
                var shrink          = getShrinkElement(element);
                var expandWidth     = getExpandWidth(width);
                var expandHeight    = getExpandHeight(height);
                var shrinkWidth     = getShrinkWidth(width);
                var shrinkHeight    = getShrinkHeight(height);
                expand.scrollLeft   = expandWidth;
                expand.scrollTop    = expandHeight;
                shrink.scrollLeft   = shrinkWidth;
                shrink.scrollTop    = shrinkHeight;
            }

            function injectContainerElement() {
                var container = getState(element).container;

                if (!container) {
                    container                   = document.createElement("div");
                    container.className         = detectionContainerClass;
                    container.style.cssText     = "visibility: hidden; display: inline; width: 0px; height: 0px; z-index: -1; overflow: hidden; margin: 0; padding: 0;";
                    getState(element).container = container;
                    addAnimationClass(container);
                    element.appendChild(container);

                    var onAnimationStart = function () {
                        getState(element).onRendered && getState(element).onRendered();
                    };

                    addEvent(container, "animationstart", onAnimationStart);

                    // Store the event handler here so that they may be removed when uninstall is called.
                    // See uninstall function for an explanation why it is needed.
                    getState(element).onAnimationStart = onAnimationStart;
                }

                return container;
            }

            function injectScrollElements() {
                function alterPositionStyles() {
                    var style = getState(element).style;

                    if(style.position === "static") {
                        element.style.position = "relative";

                        var removeRelativeStyles = function(reporter, element, style, property) {
                            function getNumericalValue(value) {
                                return value.replace(/[^-\d\.]/g, "");
                            }

                            var value = style[property];

                            if(value !== "auto" && getNumericalValue(value) !== "0") {
                                reporter.warn("An element that is positioned static has style." + property + "=" + value + " which is ignored due to the static positioning. The element will need to be positioned relative, so the style." + property + " will be set to 0. Element: ", element);
                                element.style[property] = 0;
                            }
                        };

                        //Check so that there are no accidental styles that will make the element styled differently now that is is relative.
                        //If there are any, set them to 0 (this should be okay with the user since the style properties did nothing before [since the element was positioned static] anyway).
                        removeRelativeStyles(reporter, element, style, "top");
                        removeRelativeStyles(reporter, element, style, "right");
                        removeRelativeStyles(reporter, element, style, "bottom");
                        removeRelativeStyles(reporter, element, style, "left");
                    }
                }

                function getLeftTopBottomRightCssText(left, top, bottom, right) {
                    left = (!left ? "0" : (left + "px"));
                    top = (!top ? "0" : (top + "px"));
                    bottom = (!bottom ? "0" : (bottom + "px"));
                    right = (!right ? "0" : (right + "px"));

                    return "left: " + left + "; top: " + top + "; right: " + right + "; bottom: " + bottom + ";";
                }

                debug("Injecting elements");

                if (!getState(element)) {
                    debug("Aborting because element has been uninstalled");
                    return;
                }

                alterPositionStyles();

                var rootContainer = getState(element).container;

                if (!rootContainer) {
                    rootContainer = injectContainerElement();
                }

                // Due to this WebKit bug https://bugs.webkit.org/show_bug.cgi?id=80808 (currently fixed in Blink, but still present in WebKit browsers such as Safari),
                // we need to inject two containers, one that is width/height 100% and another that is left/top -1px so that the final container always is 1x1 pixels bigger than
                // the targeted element.
                // When the bug is resolved, "containerContainer" may be removed.

                // The outer container can occasionally be less wide than the targeted when inside inline elements element in WebKit (see https://bugs.webkit.org/show_bug.cgi?id=152980).
                // This should be no problem since the inner container either way makes sure the injected scroll elements are at least 1x1 px.

                var scrollbarWidth          = scrollbarSizes.width;
                var scrollbarHeight         = scrollbarSizes.height;
                var containerContainerStyle = "position: absolute; flex: none; overflow: hidden; z-index: -1; visibility: hidden; width: 100%; height: 100%; left: 0px; top: 0px;";
                var containerStyle          = "position: absolute; flex: none; overflow: hidden; z-index: -1; visibility: hidden; " + getLeftTopBottomRightCssText(-(1 + scrollbarWidth), -(1 + scrollbarHeight), -scrollbarHeight, -scrollbarWidth);
                var expandStyle             = "position: absolute; flex: none; overflow: scroll; z-index: -1; visibility: hidden; width: 100%; height: 100%;";
                var shrinkStyle             = "position: absolute; flex: none; overflow: scroll; z-index: -1; visibility: hidden; width: 100%; height: 100%;";
                var expandChildStyle        = "position: absolute; left: 0; top: 0;";
                var shrinkChildStyle        = "position: absolute; width: 200%; height: 200%;";

                var containerContainer      = document.createElement("div");
                var container               = document.createElement("div");
                var expand                  = document.createElement("div");
                var expandChild             = document.createElement("div");
                var shrink                  = document.createElement("div");
                var shrinkChild             = document.createElement("div");

                // Some browsers choke on the resize system being rtl, so force it to ltr. https://github.com/wnr/element-resize-detector/issues/56
                // However, dir should not be set on the top level container as it alters the dimensions of the target element in some browsers.
                containerContainer.dir              = "ltr";

                containerContainer.style.cssText    = containerContainerStyle;
                containerContainer.className        = detectionContainerClass;
                container.className                 = detectionContainerClass;
                container.style.cssText             = containerStyle;
                expand.style.cssText                = expandStyle;
                expandChild.style.cssText           = expandChildStyle;
                shrink.style.cssText                = shrinkStyle;
                shrinkChild.style.cssText           = shrinkChildStyle;

                expand.appendChild(expandChild);
                shrink.appendChild(shrinkChild);
                container.appendChild(expand);
                container.appendChild(shrink);
                containerContainer.appendChild(container);
                rootContainer.appendChild(containerContainer);

                function onExpandScroll() {
                    getState(element).onExpand && getState(element).onExpand();
                }

                function onShrinkScroll() {
                    getState(element).onShrink && getState(element).onShrink();
                }

                addEvent(expand, "scroll", onExpandScroll);
                addEvent(shrink, "scroll", onShrinkScroll);

                // Store the event handlers here so that they may be removed when uninstall is called.
                // See uninstall function for an explanation why it is needed.
                getState(element).onExpandScroll = onExpandScroll;
                getState(element).onShrinkScroll = onShrinkScroll;
            }

            function registerListenersAndPositionElements() {
                function updateChildSizes(element, width, height) {
                    var expandChild             = getExpandChildElement(element);
                    var expandWidth             = getExpandWidth(width);
                    var expandHeight            = getExpandHeight(height);
                    expandChild.style.width     = expandWidth + "px";
                    expandChild.style.height    = expandHeight + "px";
                }

                function updateDetectorElements(done) {
                    var width           = element.offsetWidth;
                    var height          = element.offsetHeight;

                    debug("Storing current size", width, height);

                    // Store the size of the element sync here, so that multiple scroll events may be ignored in the event listeners.
                    // Otherwise the if-check in handleScroll is useless.
                    storeCurrentSize(element, width, height);

                    // Since we delay the processing of the batch, there is a risk that uninstall has been called before the batch gets to execute.
                    // Since there is no way to cancel the fn executions, we need to add an uninstall guard to all fns of the batch.

                    batchProcessor.add(0, function performUpdateChildSizes() {
                        if (!getState(element)) {
                            debug("Aborting because element has been uninstalled");
                            return;
                        }

                        if (!areElementsInjected()) {
                            debug("Aborting because element container has not been initialized");
                            return;
                        }

                        if (options.debug) {
                            var w = element.offsetWidth;
                            var h = element.offsetHeight;

                            if (w !== width || h !== height) {
                                reporter.warn(idHandler.get(element), "Scroll: Size changed before updating detector elements.");
                            }
                        }

                        updateChildSizes(element, width, height);
                    });

                    batchProcessor.add(1, function updateScrollbars() {
                        if (!getState(element)) {
                            debug("Aborting because element has been uninstalled");
                            return;
                        }

                        if (!areElementsInjected()) {
                            debug("Aborting because element container has not been initialized");
                            return;
                        }

                        positionScrollbars(element, width, height);
                    });

                    if (done) {
                        batchProcessor.add(2, function () {
                            if (!getState(element)) {
                                debug("Aborting because element has been uninstalled");
                                return;
                            }

                            if (!areElementsInjected()) {
                                debug("Aborting because element container has not been initialized");
                                return;
                            }

                            done();
                        });
                    }
                }

                function areElementsInjected() {
                    return !!getState(element).container;
                }

                function notifyListenersIfNeeded() {
                    function isFirstNotify() {
                        return getState(element).lastNotifiedWidth === undefined;
                    }

                    debug("notifyListenersIfNeeded invoked");

                    var state = getState(element);

                    // Don't notify the if the current size is the start size, and this is the first notification.
                    if (isFirstNotify() && state.lastWidth === state.startSize.width && state.lastHeight === state.startSize.height) {
                        return debug("Not notifying: Size is the same as the start size, and there has been no notification yet.");
                    }

                    // Don't notify if the size already has been notified.
                    if (state.lastWidth === state.lastNotifiedWidth && state.lastHeight === state.lastNotifiedHeight) {
                        return debug("Not notifying: Size already notified");
                    }


                    debug("Current size not notified, notifying...");
                    state.lastNotifiedWidth = state.lastWidth;
                    state.lastNotifiedHeight = state.lastHeight;
                    forEach(getState(element).listeners, function (listener) {
                        listener(element);
                    });
                }

                function handleRender() {
                    debug("startanimation triggered.");

                    if (isUnrendered(element)) {
                        debug("Ignoring since element is still unrendered...");
                        return;
                    }

                    debug("Element rendered.");
                    var expand = getExpandElement(element);
                    var shrink = getShrinkElement(element);
                    if (expand.scrollLeft === 0 || expand.scrollTop === 0 || shrink.scrollLeft === 0 || shrink.scrollTop === 0) {
                        debug("Scrollbars out of sync. Updating detector elements...");
                        updateDetectorElements(notifyListenersIfNeeded);
                    }
                }

                function handleScroll() {
                    debug("Scroll detected.");

                    if (isUnrendered(element)) {
                        // Element is still unrendered. Skip this scroll event.
                        debug("Scroll event fired while unrendered. Ignoring...");
                        return;
                    }

                    var width = element.offsetWidth;
                    var height = element.offsetHeight;

                    if (width !== element.lastWidth || height !== element.lastHeight) {
                        debug("Element size changed.");
                        updateDetectorElements(notifyListenersIfNeeded);
                    } else {
                        debug("Element size has not changed (" + width + "x" + height + ").");
                    }
                }

                debug("registerListenersAndPositionElements invoked.");

                if (!getState(element)) {
                    debug("Aborting because element has been uninstalled");
                    return;
                }

                getState(element).onRendered = handleRender;
                getState(element).onExpand = handleScroll;
                getState(element).onShrink = handleScroll;

                var style = getState(element).style;
                updateChildSizes(element, style.width, style.height);
            }

            function finalizeDomMutation() {
                debug("finalizeDomMutation invoked.");

                if (!getState(element)) {
                    debug("Aborting because element has been uninstalled");
                    return;
                }

                var style = getState(element).style;
                storeCurrentSize(element, style.width, style.height);
                positionScrollbars(element, style.width, style.height);
            }

            function ready() {
                callback(element);
            }

            function install() {
                debug("Installing...");
                initListeners();
                storeStartSize();

                batchProcessor.add(0, storeStyle);
                batchProcessor.add(1, injectScrollElements);
                batchProcessor.add(2, registerListenersAndPositionElements);
                batchProcessor.add(3, finalizeDomMutation);
                batchProcessor.add(4, ready);
            }

            debug("Making detectable...");

            if (isDetached(element)) {
                debug("Element is detached");

                injectContainerElement();

                debug("Waiting until element is attached...");

                getState(element).onRendered = function () {
                    debug("Element is now attached");
                    install();
                };
            } else {
                install();
            }
        }

        function uninstall(element) {
            var state = getState(element);

            if (!state) {
                // Uninstall has been called on a non-erd element.
                return;
            }

            // Uninstall may have been called in the following scenarios:
            // (1) Right between the sync code and async batch (here state.busy = true, but nothing have been registered or injected).
            // (2) In the ready callback of the last level of the batch by another element (here, state.busy = true, but all the stuff has been injected).
            // (3) After the installation process (here, state.busy = false and all the stuff has been injected).
            // So to be on the safe side, let's check for each thing before removing.

            // We need to remove the event listeners, because otherwise the event might fire on an uninstall element which results in an error when trying to get the state of the element.
            state.onExpandScroll && removeEvent(getExpandElement(element), "scroll", state.onExpandScroll);
            state.onShrinkScroll && removeEvent(getShrinkElement(element), "scroll", state.onShrinkScroll);
            state.onAnimationStart && removeEvent(state.container, "animationstart", state.onAnimationStart);

            state.container && element.removeChild(state.container);
        }

        return {
            makeDetectable: makeDetectable,
            addListener: addListener,
            uninstall: uninstall
        };
    };

},{"../collection-utils":4}],7:[function(require,module,exports){
    "use strict";

    var forEach                 = require("./collection-utils").forEach;
    var elementUtilsMaker       = require("./element-utils");
    var listenerHandlerMaker    = require("./listener-handler");
    var idGeneratorMaker        = require("./id-generator");
    var idHandlerMaker          = require("./id-handler");
    var reporterMaker           = require("./reporter");
    var browserDetector         = require("./browser-detector");
    var batchProcessorMaker     = require("batch-processor");
    var stateHandler            = require("./state-handler");

//Detection strategies.
    var objectStrategyMaker     = require("./detection-strategy/object.js");
    var scrollStrategyMaker     = require("./detection-strategy/scroll.js");

    function isCollection(obj) {
        return Array.isArray(obj) || obj.length !== undefined;
    }

    function toArray(collection) {
        if (!Array.isArray(collection)) {
            var array = [];
            forEach(collection, function (obj) {
                array.push(obj);
            });
            return array;
        } else {
            return collection;
        }
    }

    function isElement(obj) {
        return obj && obj.nodeType === 1;
    }

    /**
     * @typedef idHandler
     * @type {object}
     * @property {function} get Gets the resize detector id of the element.
     * @property {function} set Generate and sets the resize detector id of the element.
     */

    /**
     * @typedef Options
     * @type {object}
     * @property {boolean} callOnAdd    Determines if listeners should be called when they are getting added.
     Default is true. If true, the listener is guaranteed to be called when it has been added.
     If false, the listener will not be guarenteed to be called when it has been added (does not prevent it from being called).
     * @property {idHandler} idHandler  A custom id handler that is responsible for generating, setting and retrieving id's for elements.
     If not provided, a default id handler will be used.
     * @property {reporter} reporter    A custom reporter that handles reporting logs, warnings and errors.
     If not provided, a default id handler will be used.
     If set to false, then nothing will be reported.
     * @property {boolean} debug        If set to true, the the system will report debug messages as default for the listenTo method.
     */

    /**
     * Creates an element resize detector instance.
     * @public
     * @param {Options?} options Optional global options object that will decide how this instance will work.
     */
    module.exports = function(options) {
        options = options || {};

        //idHandler is currently not an option to the listenTo function, so it should not be added to globalOptions.
        var idHandler;

        if (options.idHandler) {
            // To maintain compatability with idHandler.get(element, readonly), make sure to wrap the given idHandler
            // so that readonly flag always is true when it's used here. This may be removed next major version bump.
            idHandler = {
                get: function (element) { return options.idHandler.get(element, true); },
                set: options.idHandler.set
            };
        } else {
            var idGenerator = idGeneratorMaker();
            var defaultIdHandler = idHandlerMaker({
                idGenerator: idGenerator,
                stateHandler: stateHandler
            });
            idHandler = defaultIdHandler;
        }

        //reporter is currently not an option to the listenTo function, so it should not be added to globalOptions.
        var reporter = options.reporter;

        if(!reporter) {
            //If options.reporter is false, then the reporter should be quiet.
            var quiet = reporter === false;
            reporter = reporterMaker(quiet);
        }

        //batchProcessor is currently not an option to the listenTo function, so it should not be added to globalOptions.
        var batchProcessor = getOption(options, "batchProcessor", batchProcessorMaker({ reporter: reporter }));

        //Options to be used as default for the listenTo function.
        var globalOptions = {};
        globalOptions.callOnAdd     = !!getOption(options, "callOnAdd", true);
        globalOptions.debug         = !!getOption(options, "debug", false);

        var eventListenerHandler    = listenerHandlerMaker(idHandler);
        var elementUtils            = elementUtilsMaker({
            stateHandler: stateHandler
        });

        //The detection strategy to be used.
        var detectionStrategy;
        var desiredStrategy = getOption(options, "strategy", "object");
        var strategyOptions = {
            reporter: reporter,
            batchProcessor: batchProcessor,
            stateHandler: stateHandler,
            idHandler: idHandler
        };

        if(desiredStrategy === "scroll") {
            if (browserDetector.isLegacyOpera()) {
                reporter.warn("Scroll strategy is not supported on legacy Opera. Changing to object strategy.");
                desiredStrategy = "object";
            } else if (browserDetector.isIE(9)) {
                reporter.warn("Scroll strategy is not supported on IE9. Changing to object strategy.");
                desiredStrategy = "object";
            }
        }

        if(desiredStrategy === "scroll") {
            detectionStrategy = scrollStrategyMaker(strategyOptions);
        } else if(desiredStrategy === "object") {
            detectionStrategy = objectStrategyMaker(strategyOptions);
        } else {
            throw new Error("Invalid strategy name: " + desiredStrategy);
        }

        //Calls can be made to listenTo with elements that are still being installed.
        //Also, same elements can occur in the elements list in the listenTo function.
        //With this map, the ready callbacks can be synchronized between the calls
        //so that the ready callback can always be called when an element is ready - even if
        //it wasn't installed from the function itself.
        var onReadyCallbacks = {};

        /**
         * Makes the given elements resize-detectable and starts listening to resize events on the elements. Calls the event callback for each event for each element.
         * @public
         * @param {Options?} options Optional options object. These options will override the global options. Some options may not be overriden, such as idHandler.
         * @param {element[]|element} elements The given array of elements to detect resize events of. Single element is also valid.
         * @param {function} listener The callback to be executed for each resize event for each element.
         */
        function listenTo(options, elements, listener) {
            function onResizeCallback(element) {
                var listeners = eventListenerHandler.get(element);
                forEach(listeners, function callListenerProxy(listener) {
                    listener(element);
                });
            }

            function addListener(callOnAdd, element, listener) {
                eventListenerHandler.add(element, listener);

                if(callOnAdd) {
                    listener(element);
                }
            }

            //Options object may be omitted.
            if(!listener) {
                listener = elements;
                elements = options;
                options = {};
            }

            if(!elements) {
                throw new Error("At least one element required.");
            }

            if(!listener) {
                throw new Error("Listener required.");
            }

            if (isElement(elements)) {
                // A single element has been passed in.
                elements = [elements];
            } else if (isCollection(elements)) {
                // Convert collection to array for plugins.
                // TODO: May want to check so that all the elements in the collection are valid elements.
                elements = toArray(elements);
            } else {
                return reporter.error("Invalid arguments. Must be a DOM element or a collection of DOM elements.");
            }

            var elementsReady = 0;

            var callOnAdd = getOption(options, "callOnAdd", globalOptions.callOnAdd);
            var onReadyCallback = getOption(options, "onReady", function noop() {});
            var debug = getOption(options, "debug", globalOptions.debug);

            forEach(elements, function attachListenerToElement(element) {
                if (!stateHandler.getState(element)) {
                    stateHandler.initState(element);
                    idHandler.set(element);
                }

                var id = idHandler.get(element);

                debug && reporter.log("Attaching listener to element", id, element);

                if(!elementUtils.isDetectable(element)) {
                    debug && reporter.log(id, "Not detectable.");
                    if(elementUtils.isBusy(element)) {
                        debug && reporter.log(id, "System busy making it detectable");

                        //The element is being prepared to be detectable. Do not make it detectable.
                        //Just add the listener, because the element will soon be detectable.
                        addListener(callOnAdd, element, listener);
                        onReadyCallbacks[id] = onReadyCallbacks[id] || [];
                        onReadyCallbacks[id].push(function onReady() {
                            elementsReady++;

                            if(elementsReady === elements.length) {
                                onReadyCallback();
                            }
                        });
                        return;
                    }

                    debug && reporter.log(id, "Making detectable...");
                    //The element is not prepared to be detectable, so do prepare it and add a listener to it.
                    elementUtils.markBusy(element, true);
                    return detectionStrategy.makeDetectable({ debug: debug }, element, function onElementDetectable(element) {
                        debug && reporter.log(id, "onElementDetectable");

                        if (stateHandler.getState(element)) {
                            elementUtils.markAsDetectable(element);
                            elementUtils.markBusy(element, false);
                            detectionStrategy.addListener(element, onResizeCallback);
                            addListener(callOnAdd, element, listener);

                            // Since the element size might have changed since the call to "listenTo", we need to check for this change,
                            // so that a resize event may be emitted.
                            // Having the startSize object is optional (since it does not make sense in some cases such as unrendered elements), so check for its existance before.
                            // Also, check the state existance before since the element may have been uninstalled in the installation process.
                            var state = stateHandler.getState(element);
                            if (state && state.startSize) {
                                var width = element.offsetWidth;
                                var height = element.offsetHeight;
                                if (state.startSize.width !== width || state.startSize.height !== height) {
                                    onResizeCallback(element);
                                }
                            }

                            if(onReadyCallbacks[id]) {
                                forEach(onReadyCallbacks[id], function(callback) {
                                    callback();
                                });
                            }
                        } else {
                            // The element has been unisntalled before being detectable.
                            debug && reporter.log(id, "Element uninstalled before being detectable.");
                        }

                        delete onReadyCallbacks[id];

                        elementsReady++;
                        if(elementsReady === elements.length) {
                            onReadyCallback();
                        }
                    });
                }

                debug && reporter.log(id, "Already detecable, adding listener.");

                //The element has been prepared to be detectable and is ready to be listened to.
                addListener(callOnAdd, element, listener);
                elementsReady++;
            });

            if(elementsReady === elements.length) {
                onReadyCallback();
            }
        }

        function uninstall(elements) {
            if(!elements) {
                return reporter.error("At least one element is required.");
            }

            if (isElement(elements)) {
                // A single element has been passed in.
                elements = [elements];
            } else if (isCollection(elements)) {
                // Convert collection to array for plugins.
                // TODO: May want to check so that all the elements in the collection are valid elements.
                elements = toArray(elements);
            } else {
                return reporter.error("Invalid arguments. Must be a DOM element or a collection of DOM elements.");
            }

            forEach(elements, function (element) {
                eventListenerHandler.removeAllListeners(element);
                detectionStrategy.uninstall(element);
                stateHandler.cleanState(element);
            });
        }

        return {
            listenTo: listenTo,
            removeListener: eventListenerHandler.removeListener,
            removeAllListeners: eventListenerHandler.removeAllListeners,
            uninstall: uninstall
        };
    };

    function getOption(options, name, defaultValue) {
        var value = options[name];

        if((value === undefined || value === null) && defaultValue !== undefined) {
            return defaultValue;
        }

        return value;
    }

},{"./browser-detector":3,"./collection-utils":4,"./detection-strategy/object.js":5,"./detection-strategy/scroll.js":6,"./element-utils":8,"./id-generator":9,"./id-handler":10,"./listener-handler":11,"./reporter":12,"./state-handler":13,"batch-processor":1}],8:[function(require,module,exports){
    "use strict";

    module.exports = function(options) {
        var getState = options.stateHandler.getState;

        /**
         * Tells if the element has been made detectable and ready to be listened for resize events.
         * @public
         * @param {element} The element to check.
         * @returns {boolean} True or false depending on if the element is detectable or not.
         */
        function isDetectable(element) {
            var state = getState(element);
            return state && !!state.isDetectable;
        }

        /**
         * Marks the element that it has been made detectable and ready to be listened for resize events.
         * @public
         * @param {element} The element to mark.
         */
        function markAsDetectable(element) {
            getState(element).isDetectable = true;
        }

        /**
         * Tells if the element is busy or not.
         * @public
         * @param {element} The element to check.
         * @returns {boolean} True or false depending on if the element is busy or not.
         */
        function isBusy(element) {
            return !!getState(element).busy;
        }

        /**
         * Marks the object is busy and should not be made detectable.
         * @public
         * @param {element} element The element to mark.
         * @param {boolean} busy If the element is busy or not.
         */
        function markBusy(element, busy) {
            getState(element).busy = !!busy;
        }

        return {
            isDetectable: isDetectable,
            markAsDetectable: markAsDetectable,
            isBusy: isBusy,
            markBusy: markBusy
        };
    };

},{}],9:[function(require,module,exports){
    "use strict";

    module.exports = function() {
        var idCount = 1;

        /**
         * Generates a new unique id in the context.
         * @public
         * @returns {number} A unique id in the context.
         */
        function generate() {
            return idCount++;
        }

        return {
            generate: generate
        };
    };

},{}],10:[function(require,module,exports){
    "use strict";

    module.exports = function(options) {
        var idGenerator     = options.idGenerator;
        var getState        = options.stateHandler.getState;

        /**
         * Gets the resize detector id of the element.
         * @public
         * @param {element} element The target element to get the id of.
         * @returns {string|number|null} The id of the element. Null if it has no id.
         */
        function getId(element) {
            var state = getState(element);

            if (state && state.id !== undefined) {
                return state.id;
            }

            return null;
        }

        /**
         * Sets the resize detector id of the element. Requires the element to have a resize detector state initialized.
         * @public
         * @param {element} element The target element to set the id of.
         * @returns {string|number|null} The id of the element.
         */
        function setId(element) {
            var state = getState(element);

            if (!state) {
                throw new Error("setId required the element to have a resize detection state.");
            }

            var id = idGenerator.generate();

            state.id = id;

            return id;
        }

        return {
            get: getId,
            set: setId
        };
    };

},{}],11:[function(require,module,exports){
    "use strict";

    module.exports = function(idHandler) {
        var eventListeners = {};

        /**
         * Gets all listeners for the given element.
         * @public
         * @param {element} element The element to get all listeners for.
         * @returns All listeners for the given element.
         */
        function getListeners(element) {
            var id = idHandler.get(element);

            if (id === undefined) {
                return [];
            }

            return eventListeners[id] || [];
        }

        /**
         * Stores the given listener for the given element. Will not actually add the listener to the element.
         * @public
         * @param {element} element The element that should have the listener added.
         * @param {function} listener The callback that the element has added.
         */
        function addListener(element, listener) {
            var id = idHandler.get(element);

            if(!eventListeners[id]) {
                eventListeners[id] = [];
            }

            eventListeners[id].push(listener);
        }

        function removeListener(element, listener) {
            var listeners = getListeners(element);
            for (var i = 0, len = listeners.length; i < len; ++i) {
                if (listeners[i] === listener) {
                    listeners.splice(i, 1);
                    break;
                }
            }
        }

        function removeAllListeners(element) {
            var listeners = getListeners(element);
            if (!listeners) { return; }
            listeners.length = 0;
        }

        return {
            get: getListeners,
            add: addListener,
            removeListener: removeListener,
            removeAllListeners: removeAllListeners
        };
    };

},{}],12:[function(require,module,exports){
    "use strict";

    /* global console: false */

    /**
     * Reporter that handles the reporting of logs, warnings and errors.
     * @public
     * @param {boolean} quiet Tells if the reporter should be quiet or not.
     */
    module.exports = function(quiet) {
        function noop() {
            //Does nothing.
        }

        var reporter = {
            log: noop,
            warn: noop,
            error: noop
        };

        if(!quiet && window.console) {
            var attachFunction = function(reporter, name) {
                //The proxy is needed to be able to call the method with the console context,
                //since we cannot use bind.
                reporter[name] = function reporterProxy() {
                    var f = console[name];
                    if (f.apply) { //IE9 does not support console.log.apply :)
                        f.apply(console, arguments);
                    } else {
                        for (var i = 0; i < arguments.length; i++) {
                            f(arguments[i]);
                        }
                    }
                };
            };

            attachFunction(reporter, "log");
            attachFunction(reporter, "warn");
            attachFunction(reporter, "error");
        }

        return reporter;
    };
},{}],13:[function(require,module,exports){
    "use strict";

    var prop = "_erd";

    function initState(element) {
        element[prop] = {};
        return getState(element);
    }

    function getState(element) {
        return element[prop];
    }

    function cleanState(element) {
        delete element[prop];
    }

    module.exports = {
        initState: initState,
        getState: getState,
        cleanState: cleanState
    };

},{}]},{},[7])(7)
});
/*!
 * Platform.js <https://mths.be/platform>
 * Copyright 2014-2016 Benjamin Tan <https://d10.github.io/>
 * Copyright 2011-2013 John-David Dalton <http://allyoucanleet.com/>
 * Available under MIT license <https://mths.be/mit>
 */
;(function() {
  'use strict';

  /** Used to determine if values are of the language type `Object`. */
  var objectTypes = {
    'function': true,
    'object': true
  };

  /** Used as a reference to the global object. */
  var root = (objectTypes[typeof window] && window) || this;

  /** Backup possible global object. */
  var oldRoot = root;

  /** Detect free variable `exports`. */
  var freeExports = objectTypes[typeof exports] && exports;

  /** Detect free variable `module`. */
  var freeModule = objectTypes[typeof module] && module && !module.nodeType && module;

  /** Detect free variable `global` from Node.js or Browserified code and use it as `root`. */
  var freeGlobal = freeExports && freeModule && typeof global == 'object' && global;
  if (freeGlobal && (freeGlobal.global === freeGlobal || freeGlobal.window === freeGlobal || freeGlobal.self === freeGlobal)) {
    root = freeGlobal;
  }

  /**
   * Used as the maximum length of an array-like object.
   * See the [ES6 spec](http://people.mozilla.org/~jorendorff/es6-draft.html#sec-tolength)
   * for more details.
   */
  var maxSafeInteger = Math.pow(2, 53) - 1;

  /** Regular expression to detect Opera. */
  var reOpera = /\bOpera/;

  /** Possible global object. */
  var thisBinding = this;

  /** Used for native method references. */
  var objectProto = Object.prototype;

  /** Used to check for own properties of an object. */
  var hasOwnProperty = objectProto.hasOwnProperty;

  /** Used to resolve the internal `[[Class]]` of values. */
  var toString = objectProto.toString;

  /*--------------------------------------------------------------------------*/

  /**
   * Capitalizes a string value.
   *
   * @private
   * @param {string} string The string to capitalize.
   * @returns {string} The capitalized string.
   */
  function capitalize(string) {
    string = String(string);
    return string.charAt(0).toUpperCase() + string.slice(1);
  }

  /**
   * A utility function to clean up the OS name.
   *
   * @private
   * @param {string} os The OS name to clean up.
   * @param {string} [pattern] A `RegExp` pattern matching the OS name.
   * @param {string} [label] A label for the OS.
   */
  function cleanupOS(os, pattern, label) {
    // Platform tokens are defined at:
    // http://msdn.microsoft.com/en-us/library/ms537503(VS.85).aspx
    // http://web.archive.org/web/20081122053950/http://msdn.microsoft.com/en-us/library/ms537503(VS.85).aspx
    var data = {
      '10.0': '10',
      '6.4':  '10 Technical Preview',
      '6.3':  '8.1',
      '6.2':  '8',
      '6.1':  '7 / Server 2008 R2',
      '6.0':  'Vista / Server 2008',
      '5.2':  'XP 64-bit / Server 2003',
      '5.1':  'XP',
      '5.01': '2000 SP1',
      '5.0':  '2000',
      '4.0':  'NT',
      '4.90': 'ME'
    };
    // Detect Windows version from platform tokens.
    if (pattern && label && /^Win/i.test(os) && !/^Windows Phone /i.test(os) &&
        (data = data[/[\d.]+$/.exec(os)])) {
      os = 'Windows ' + data;
    }
    // Correct character case and cleanup string.
    os = String(os);

    if (pattern && label) {
      os = os.replace(RegExp(pattern, 'i'), label);
    }

    os = format(
      os.replace(/ ce$/i, ' CE')
        .replace(/\bhpw/i, 'web')
        .replace(/\bMacintosh\b/, 'Mac OS')
        .replace(/_PowerPC\b/i, ' OS')
        .replace(/\b(OS X) [^ \d]+/i, '$1')
        .replace(/\bMac (OS X)\b/, '$1')
        .replace(/\/(\d)/, ' $1')
        .replace(/_/g, '.')
        .replace(/(?: BePC|[ .]*fc[ \d.]+)$/i, '')
        .replace(/\bx86\.64\b/gi, 'x86_64')
        .replace(/\b(Windows Phone) OS\b/, '$1')
        .replace(/\b(Chrome OS \w+) [\d.]+\b/, '$1')
        .split(' on ')[0]
    );

    return os;
  }

  /**
   * An iteration utility for arrays and objects.
   *
   * @private
   * @param {Array|Object} object The object to iterate over.
   * @param {Function} callback The function called per iteration.
   */
  function each(object, callback) {
    var index = -1,
        length = object ? object.length : 0;

    if (typeof length == 'number' && length > -1 && length <= maxSafeInteger) {
      while (++index < length) {
        callback(object[index], index, object);
      }
    } else {
      forOwn(object, callback);
    }
  }

  /**
   * Trim and conditionally capitalize string values.
   *
   * @private
   * @param {string} string The string to format.
   * @returns {string} The formatted string.
   */
  function format(string) {
    string = trim(string);
    return /^(?:webOS|i(?:OS|P))/.test(string)
      ? string
      : capitalize(string);
  }

  /**
   * Iterates over an object's own properties, executing the `callback` for each.
   *
   * @private
   * @param {Object} object The object to iterate over.
   * @param {Function} callback The function executed per own property.
   */
  function forOwn(object, callback) {
    for (var key in object) {
      if (hasOwnProperty.call(object, key)) {
        callback(object[key], key, object);
      }
    }
  }

  /**
   * Gets the internal `[[Class]]` of a value.
   *
   * @private
   * @param {*} value The value.
   * @returns {string} The `[[Class]]`.
   */
  function getClassOf(value) {
    return value == null
      ? capitalize(value)
      : toString.call(value).slice(8, -1);
  }

  /**
   * Host objects can return type values that are different from their actual
   * data type. The objects we are concerned with usually return non-primitive
   * types of "object", "function", or "unknown".
   *
   * @private
   * @param {*} object The owner of the property.
   * @param {string} property The property to check.
   * @returns {boolean} Returns `true` if the property value is a non-primitive, else `false`.
   */
  function isHostType(object, property) {
    var type = object != null ? typeof object[property] : 'number';
    return !/^(?:boolean|number|string|undefined)$/.test(type) &&
      (type == 'object' ? !!object[property] : true);
  }

  /**
   * Prepares a string for use in a `RegExp` by making hyphens and spaces optional.
   *
   * @private
   * @param {string} string The string to qualify.
   * @returns {string} The qualified string.
   */
  function qualify(string) {
    return String(string).replace(/([ -])(?!$)/g, '$1?');
  }

  /**
   * A bare-bones `Array#reduce` like utility function.
   *
   * @private
   * @param {Array} array The array to iterate over.
   * @param {Function} callback The function called per iteration.
   * @returns {*} The accumulated result.
   */
  function reduce(array, callback) {
    var accumulator = null;
    each(array, function(value, index) {
      accumulator = callback(accumulator, value, index, array);
    });
    return accumulator;
  }

  /**
   * Removes leading and trailing whitespace from a string.
   *
   * @private
   * @param {string} string The string to trim.
   * @returns {string} The trimmed string.
   */
  function trim(string) {
    return String(string).replace(/^ +| +$/g, '');
  }

  /*--------------------------------------------------------------------------*/

  /**
   * Creates a new platform object.
   *
   * @memberOf platform
   * @param {Object|string} [ua=navigator.userAgent] The user agent string or
   *  context object.
   * @returns {Object} A platform object.
   */
  function parse(ua) {

    /** The environment context object. */
    var context = root;

    /** Used to flag when a custom context is provided. */
    var isCustomContext = ua && typeof ua == 'object' && getClassOf(ua) != 'String';

    // Juggle arguments.
    if (isCustomContext) {
      context = ua;
      ua = null;
    }

    /** Browser navigator object. */
    var nav = context.navigator || {};

    /** Browser user agent string. */
    var userAgent = nav.userAgent || '';

    ua || (ua = userAgent);

    /** Used to flag when `thisBinding` is the [ModuleScope]. */
    var isModuleScope = isCustomContext || thisBinding == oldRoot;

    /** Used to detect if browser is like Chrome. */
    var likeChrome = isCustomContext
      ? !!nav.likeChrome
      : /\bChrome\b/.test(ua) && !/internal|\n/i.test(toString.toString());

    /** Internal `[[Class]]` value shortcuts. */
    var objectClass = 'Object',
        airRuntimeClass = isCustomContext ? objectClass : 'ScriptBridgingProxyObject',
        enviroClass = isCustomContext ? objectClass : 'Environment',
        javaClass = (isCustomContext && context.java) ? 'JavaPackage' : getClassOf(context.java),
        phantomClass = isCustomContext ? objectClass : 'RuntimeObject';

    /** Detect Java environments. */
    var java = /\bJava/.test(javaClass) && context.java;

    /** Detect Rhino. */
    var rhino = java && getClassOf(context.environment) == enviroClass;

    /** A character to represent alpha. */
    var alpha = java ? 'a' : '\u03b1';

    /** A character to represent beta. */
    var beta = java ? 'b' : '\u03b2';

    /** Browser document object. */
    var doc = context.document || {};

    /**
     * Detect Opera browser (Presto-based).
     * http://www.howtocreate.co.uk/operaStuff/operaObject.html
     * http://dev.opera.com/articles/view/opera-mini-web-content-authoring-guidelines/#operamini
     */
    var opera = context.operamini || context.opera;

    /** Opera `[[Class]]`. */
    var operaClass = reOpera.test(operaClass = (isCustomContext && opera) ? opera['[[Class]]'] : getClassOf(opera))
      ? operaClass
      : (opera = null);

    /*------------------------------------------------------------------------*/

    /** Temporary variable used over the script's lifetime. */
    var data;

    /** The CPU architecture. */
    var arch = ua;

    /** Platform description array. */
    var description = [];

    /** Platform alpha/beta indicator. */
    var prerelease = null;

    /** A flag to indicate that environment features should be used to resolve the platform. */
    var useFeatures = ua == userAgent;

    /** The browser/environment version. */
    var version = useFeatures && opera && typeof opera.version == 'function' && opera.version();

    /** A flag to indicate if the OS begins with "Name Version /". */
    var isSpecialCasedOS;

    /* Detectable layout engines (order is important). */
    var layout = getLayout([
      { 'label': 'EdgeHTML', 'pattern': 'Edge' },
      'Trident',
      { 'label': 'WebKit', 'pattern': 'AppleWebKit' },
      'iCab',
      'Presto',
      'NetFront',
      'Tasman',
      'KHTML',
      'Gecko'
    ]);

    /* Detectable browser names (order is important). */
    var name = getName([
      'Adobe AIR',
      'Arora',
      'Avant Browser',
      'Breach',
      'Camino',
      'Epiphany',
      'Fennec',
      'Flock',
      'Galeon',
      'GreenBrowser',
      'iCab',
      'Iceweasel',
      'K-Meleon',
      'Konqueror',
      'Lunascape',
      'Maxthon',
      { 'label': 'Microsoft Edge', 'pattern': 'Edge' },
      'Midori',
      'Nook Browser',
      'PaleMoon',
      'PhantomJS',
      'Raven',
      'Rekonq',
      'RockMelt',
      'SeaMonkey',
      { 'label': 'Silk', 'pattern': '(?:Cloud9|Silk-Accelerated)' },
      'Sleipnir',
      'SlimBrowser',
      { 'label': 'SRWare Iron', 'pattern': 'Iron' },
      'Sunrise',
      'Swiftfox',
      'WebPositive',
      'Opera Mini',
      { 'label': 'Opera Mini', 'pattern': 'OPiOS' },
      'Opera',
      { 'label': 'Opera', 'pattern': 'OPR' },
      'Chrome',
      { 'label': 'Chrome Mobile', 'pattern': '(?:CriOS|CrMo)' },
      { 'label': 'Firefox', 'pattern': '(?:Firefox|Minefield)' },
      { 'label': 'Firefox Mobile', 'pattern': 'FxiOS' },
      { 'label': 'IE', 'pattern': 'IEMobile' },
      { 'label': 'IE', 'pattern': 'MSIE' },
      'Safari'
    ]);

    /* Detectable products (order is important). */
    var product = getProduct([
      { 'label': 'BlackBerry', 'pattern': 'BB10' },
      'BlackBerry',
      { 'label': 'Galaxy S', 'pattern': 'GT-I9000' },
      { 'label': 'Galaxy S2', 'pattern': 'GT-I9100' },
      { 'label': 'Galaxy S3', 'pattern': 'GT-I9300' },
      { 'label': 'Galaxy S4', 'pattern': 'GT-I9500' },
      'Google TV',
      'Lumia',
      'iPad',
      'iPod',
      'iPhone',
      'Kindle',
      { 'label': 'Kindle Fire', 'pattern': '(?:Cloud9|Silk-Accelerated)' },
      'Nexus',
      'Nook',
      'PlayBook',
      'PlayStation 3',
      'PlayStation 4',
      'PlayStation Vita',
      'TouchPad',
      'Transformer',
      { 'label': 'Wii U', 'pattern': 'WiiU' },
      'Wii',
      'Xbox One',
      { 'label': 'Xbox 360', 'pattern': 'Xbox' },
      'Xoom'
    ]);

    /* Detectable manufacturers. */
    var manufacturer = getManufacturer({
      'Apple': { 'iPad': 1, 'iPhone': 1, 'iPod': 1 },
      'Amazon': { 'Kindle': 1, 'Kindle Fire': 1 },
      'Asus': { 'Transformer': 1 },
      'Barnes & Noble': { 'Nook': 1 },
      'BlackBerry': { 'PlayBook': 1 },
      'Google': { 'Google TV': 1, 'Nexus': 1 },
      'HP': { 'TouchPad': 1 },
      'HTC': {},
      'LG': {},
      'Microsoft': { 'Xbox': 1, 'Xbox One': 1 },
      'Motorola': { 'Xoom': 1 },
      'Nintendo': { 'Wii U': 1,  'Wii': 1 },
      'Nokia': { 'Lumia': 1 },
      'Samsung': { 'Galaxy S': 1, 'Galaxy S2': 1, 'Galaxy S3': 1, 'Galaxy S4': 1 },
      'Sony': { 'PlayStation 4': 1, 'PlayStation 3': 1, 'PlayStation Vita': 1 }
    });

    /* Detectable operating systems (order is important). */
    var os = getOS([
      'Windows Phone ',
      'Android',
      'CentOS',
      { 'label': 'Chrome OS', 'pattern': 'CrOS' },
      'Debian',
      'Fedora',
      'FreeBSD',
      'Gentoo',
      'Haiku',
      'Kubuntu',
      'Linux Mint',
      'OpenBSD',
      'Red Hat',
      'SuSE',
      'Ubuntu',
      'Xubuntu',
      'Cygwin',
      'Symbian OS',
      'hpwOS',
      'webOS ',
      'webOS',
      'Tablet OS',
      'Linux',
      'Mac OS X',
      'Macintosh',
      'Mac',
      'Windows 98;',
      'Windows '
    ]);

    /*------------------------------------------------------------------------*/

    /**
     * Picks the layout engine from an array of guesses.
     *
     * @private
     * @param {Array} guesses An array of guesses.
     * @returns {null|string} The detected layout engine.
     */
    function getLayout(guesses) {
      return reduce(guesses, function(result, guess) {
        return result || RegExp('\\b' + (
          guess.pattern || qualify(guess)
        ) + '\\b', 'i').exec(ua) && (guess.label || guess);
      });
    }

    /**
     * Picks the manufacturer from an array of guesses.
     *
     * @private
     * @param {Array} guesses An object of guesses.
     * @returns {null|string} The detected manufacturer.
     */
    function getManufacturer(guesses) {
      return reduce(guesses, function(result, value, key) {
        // Lookup the manufacturer by product or scan the UA for the manufacturer.
        return result || (
          value[product] ||
          value[/^[a-z]+(?: +[a-z]+\b)*/i.exec(product)] ||
          RegExp('\\b' + qualify(key) + '(?:\\b|\\w*\\d)', 'i').exec(ua)
        ) && key;
      });
    }

    /**
     * Picks the browser name from an array of guesses.
     *
     * @private
     * @param {Array} guesses An array of guesses.
     * @returns {null|string} The detected browser name.
     */
    function getName(guesses) {
      return reduce(guesses, function(result, guess) {
        return result || RegExp('\\b' + (
          guess.pattern || qualify(guess)
        ) + '\\b', 'i').exec(ua) && (guess.label || guess);
      });
    }

    /**
     * Picks the OS name from an array of guesses.
     *
     * @private
     * @param {Array} guesses An array of guesses.
     * @returns {null|string} The detected OS name.
     */
    function getOS(guesses) {
      return reduce(guesses, function(result, guess) {
        var pattern = guess.pattern || qualify(guess);
        if (!result && (result =
              RegExp('\\b' + pattern + '(?:/[\\d.]+|[ \\w.]*)', 'i').exec(ua)
            )) {
          result = cleanupOS(result, pattern, guess.label || guess);
        }
        return result;
      });
    }

    /**
     * Picks the product name from an array of guesses.
     *
     * @private
     * @param {Array} guesses An array of guesses.
     * @returns {null|string} The detected product name.
     */
    function getProduct(guesses) {
      return reduce(guesses, function(result, guess) {
        var pattern = guess.pattern || qualify(guess);
        if (!result && (result =
              RegExp('\\b' + pattern + ' *\\d+[.\\w_]*', 'i').exec(ua) ||
              RegExp('\\b' + pattern + '(?:; *(?:[a-z]+[_-])?[a-z]+\\d+|[^ ();-]*)', 'i').exec(ua)
            )) {
          // Split by forward slash and append product version if needed.
          if ((result = String((guess.label && !RegExp(pattern, 'i').test(guess.label)) ? guess.label : result).split('/'))[1] && !/[\d.]+/.test(result[0])) {
            result[0] += ' ' + result[1];
          }
          // Correct character case and cleanup string.
          guess = guess.label || guess;
          result = format(result[0]
            .replace(RegExp(pattern, 'i'), guess)
            .replace(RegExp('; *(?:' + guess + '[_-])?', 'i'), ' ')
            .replace(RegExp('(' + guess + ')[-_.]?(\\w)', 'i'), '$1 $2'));
        }
        return result;
      });
    }

    /**
     * Resolves the version using an array of UA patterns.
     *
     * @private
     * @param {Array} patterns An array of UA patterns.
     * @returns {null|string} The detected version.
     */
    function getVersion(patterns) {
      return reduce(patterns, function(result, pattern) {
        return result || (RegExp(pattern +
          '(?:-[\\d.]+/|(?: for [\\w-]+)?[ /-])([\\d.]+[^ ();/_-]*)', 'i').exec(ua) || 0)[1] || null;
      });
    }

    /**
     * Returns `platform.description` when the platform object is coerced to a string.
     *
     * @name toString
     * @memberOf platform
     * @returns {string} Returns `platform.description` if available, else an empty string.
     */
    function toStringPlatform() {
      return this.description || '';
    }

    /*------------------------------------------------------------------------*/

    // Convert layout to an array so we can add extra details.
    layout && (layout = [layout]);

    // Detect product names that contain their manufacturer's name.
    if (manufacturer && !product) {
      product = getProduct([manufacturer]);
    }
    // Clean up Google TV.
    if ((data = /\bGoogle TV\b/.exec(product))) {
      product = data[0];
    }
    // Detect simulators.
    if (/\bSimulator\b/i.test(ua)) {
      product = (product ? product + ' ' : '') + 'Simulator';
    }
    // Detect Opera Mini 8+ running in Turbo/Uncompressed mode on iOS.
    if (name == 'Opera Mini' && /\bOPiOS\b/.test(ua)) {
      description.push('running in Turbo/Uncompressed mode');
    }
    // Detect iOS.
    if (/^iP/.test(product)) {
      name || (name = 'Safari');
      os = 'iOS' + ((data = / OS ([\d_]+)/i.exec(ua))
        ? ' ' + data[1].replace(/_/g, '.')
        : '');
    }
    // Detect Kubuntu.
    else if (name == 'Konqueror' && !/buntu/i.test(os)) {
      os = 'Kubuntu';
    }
    // Detect Android browsers.
    else if (manufacturer && manufacturer != 'Google' &&
        ((/Chrome/.test(name) && !/\bMobile Safari\b/i.test(ua)) || /\bVita\b/.test(product))) {
      name = 'Android Browser';
      os = /\bAndroid\b/.test(os) ? os : 'Android';
    }
    // Detect Silk desktop/accelerated modes.
    else if (name == 'Silk') {
      if (!/\bMobi/i.test(ua)) {
        os = 'Android';
        description.unshift('desktop mode');
      }
      if (/Accelerated *= *true/i.test(ua)) {
        description.unshift('accelerated');
      }
    }
    // Detect PaleMoon identifying as Firefox.
    else if (name == 'PaleMoon' && (data = /\bFirefox\/([\d.]+)\b/.exec(ua))) {
      description.push('identifying as Firefox ' + data[1]);
    }
    // Detect Firefox OS and products running Firefox.
    else if (name == 'Firefox' && (data = /\b(Mobile|Tablet|TV)\b/i.exec(ua))) {
      os || (os = 'Firefox OS');
      product || (product = data[1]);
    }
    // Detect false positives for Firefox/Safari.
    else if (!name || (data = !/\bMinefield\b/i.test(ua) && /\b(?:Firefox|Safari)\b/.exec(name))) {
      // Escape the `/` for Firefox 1.
      if (name && !product && /[\/,]|^[^(]+?\)/.test(ua.slice(ua.indexOf(data + '/') + 8))) {
        // Clear name of false positives.
        name = null;
      }
      // Reassign a generic name.
      if ((data = product || manufacturer || os) &&
          (product || manufacturer || /\b(?:Android|Symbian OS|Tablet OS|webOS)\b/.test(os))) {
        name = /[a-z]+(?: Hat)?/i.exec(/\bAndroid\b/.test(os) ? os : data) + ' Browser';
      }
    }
    // Detect non-Opera (Presto-based) versions (order is important).
    if (!version) {
      version = getVersion([
        '(?:Cloud9|CriOS|CrMo|Edge|FxiOS|IEMobile|Iron|Opera ?Mini|OPiOS|OPR|Raven|Silk(?!/[\\d.]+$))',
        'Version',
        qualify(name),
        '(?:Firefox|Minefield|NetFront)'
      ]);
    }
    // Detect stubborn layout engines.
    if ((data =
          layout == 'iCab' && parseFloat(version) > 3 && 'WebKit' ||
          /\bOpera\b/.test(name) && (/\bOPR\b/.test(ua) ? 'Blink' : 'Presto') ||
          /\b(?:Midori|Nook|Safari)\b/i.test(ua) && !/^(?:Trident|EdgeHTML)$/.test(layout) && 'WebKit' ||
          !layout && /\bMSIE\b/i.test(ua) && (os == 'Mac OS' ? 'Tasman' : 'Trident') ||
          layout == 'WebKit' && /\bPlayStation\b(?! Vita\b)/i.test(name) && 'NetFront'
        )) {
      layout = [data];
    }
    // Detect Windows Phone 7 desktop mode.
    if (name == 'IE' && (data = (/; *(?:XBLWP|ZuneWP)(\d+)/i.exec(ua) || 0)[1])) {
      name += ' Mobile';
      os = 'Windows Phone ' + (/\+$/.test(data) ? data : data + '.x');
      description.unshift('desktop mode');
    }
    // Detect Windows Phone 8.x desktop mode.
    else if (/\bWPDesktop\b/i.test(ua)) {
      name = 'IE Mobile';
      os = 'Windows Phone 8.x';
      description.unshift('desktop mode');
      version || (version = (/\brv:([\d.]+)/.exec(ua) || 0)[1]);
    }
    // Detect IE 11.
    else if (name != 'IE' && layout == 'Trident' && (data = /\brv:([\d.]+)/.exec(ua))) {
      if (name) {
        description.push('identifying as ' + name + (version ? ' ' + version : ''));
      }
      name = 'IE';
      version = data[1];
    }
    // Leverage environment features.
    if (useFeatures) {
      // Detect server-side environments.
      // Rhino has a global function while others have a global object.
      if (isHostType(context, 'global')) {
        if (java) {
          data = java.lang.System;
          arch = data.getProperty('os.arch');
          os = os || data.getProperty('os.name') + ' ' + data.getProperty('os.version');
        }
        if (isModuleScope && isHostType(context, 'system') && (data = [context.system])[0]) {
          os || (os = data[0].os || null);
          try {
            data[1] = context.require('ringo/engine').version;
            version = data[1].join('.');
            name = 'RingoJS';
          } catch(e) {
            if (data[0].global.system == context.system) {
              name = 'Narwhal';
            }
          }
        }
        else if (typeof context.process == 'object' && (data = context.process)) {
          name = 'Node.js';
          arch = data.arch;
          os = data.platform;
          version = /[\d.]+/.exec(data.version)[0];
        }
        else if (rhino) {
          name = 'Rhino';
        }
      }
      // Detect Adobe AIR.
      else if (getClassOf((data = context.runtime)) == airRuntimeClass) {
        name = 'Adobe AIR';
        os = data.flash.system.Capabilities.os;
      }
      // Detect PhantomJS.
      else if (getClassOf((data = context.phantom)) == phantomClass) {
        name = 'PhantomJS';
        version = (data = data.version || null) && (data.major + '.' + data.minor + '.' + data.patch);
      }
      // Detect IE compatibility modes.
      else if (typeof doc.documentMode == 'number' && (data = /\bTrident\/(\d+)/i.exec(ua))) {
        // We're in compatibility mode when the Trident version + 4 doesn't
        // equal the document mode.
        version = [version, doc.documentMode];
        if ((data = +data[1] + 4) != version[1]) {
          description.push('IE ' + version[1] + ' mode');
          layout && (layout[1] = '');
          version[1] = data;
        }
        version = name == 'IE' ? String(version[1].toFixed(1)) : version[0];
      }
      os = os && format(os);
    }
    // Detect prerelease phases.
    if (version && (data =
          /(?:[ab]|dp|pre|[ab]\d+pre)(?:\d+\+?)?$/i.exec(version) ||
          /(?:alpha|beta)(?: ?\d)?/i.exec(ua + ';' + (useFeatures && nav.appMinorVersion)) ||
          /\bMinefield\b/i.test(ua) && 'a'
        )) {
      prerelease = /b/i.test(data) ? 'beta' : 'alpha';
      version = version.replace(RegExp(data + '\\+?$'), '') +
        (prerelease == 'beta' ? beta : alpha) + (/\d+\+?/.exec(data) || '');
    }
    // Detect Firefox Mobile.
    if (name == 'Fennec' || name == 'Firefox' && /\b(?:Android|Firefox OS)\b/.test(os)) {
      name = 'Firefox Mobile';
    }
    // Obscure Maxthon's unreliable version.
    else if (name == 'Maxthon' && version) {
      version = version.replace(/\.[\d.]+/, '.x');
    }
    // Detect Xbox 360 and Xbox One.
    else if (/\bXbox\b/i.test(product)) {
      os = null;
      if (product == 'Xbox 360' && /\bIEMobile\b/.test(ua)) {
        description.unshift('mobile mode');
      }
    }
    // Add mobile postfix.
    else if ((/^(?:Chrome|IE|Opera)$/.test(name) || name && !product && !/Browser|Mobi/.test(name)) &&
        (os == 'Windows CE' || /Mobi/i.test(ua))) {
      name += ' Mobile';
    }
    // Detect IE platform preview.
    else if (name == 'IE' && useFeatures && context.external === null) {
      description.unshift('platform preview');
    }
    // Detect BlackBerry OS version.
    // http://docs.blackberry.com/en/developers/deliverables/18169/HTTP_headers_sent_by_BB_Browser_1234911_11.jsp
    else if ((/\bBlackBerry\b/.test(product) || /\bBB10\b/.test(ua)) && (data =
          (RegExp(product.replace(/ +/g, ' *') + '/([.\\d]+)', 'i').exec(ua) || 0)[1] ||
          version
        )) {
      data = [data, /BB10/.test(ua)];
      os = (data[1] ? (product = null, manufacturer = 'BlackBerry') : 'Device Software') + ' ' + data[0];
      version = null;
    }
    // Detect Opera identifying/masking itself as another browser.
    // http://www.opera.com/support/kb/view/843/
    else if (this != forOwn && product != 'Wii' && (
          (useFeatures && opera) ||
          (/Opera/.test(name) && /\b(?:MSIE|Firefox)\b/i.test(ua)) ||
          (name == 'Firefox' && /\bOS X (?:\d+\.){2,}/.test(os)) ||
          (name == 'IE' && (
            (os && !/^Win/.test(os) && version > 5.5) ||
            /\bWindows XP\b/.test(os) && version > 8 ||
            version == 8 && !/\bTrident\b/.test(ua)
          ))
        ) && !reOpera.test((data = parse.call(forOwn, ua.replace(reOpera, '') + ';'))) && data.name) {
      // When "identifying", the UA contains both Opera and the other browser's name.
      data = 'ing as ' + data.name + ((data = data.version) ? ' ' + data : '');
      if (reOpera.test(name)) {
        if (/\bIE\b/.test(data) && os == 'Mac OS') {
          os = null;
        }
        data = 'identify' + data;
      }
      // When "masking", the UA contains only the other browser's name.
      else {
        data = 'mask' + data;
        if (operaClass) {
          name = format(operaClass.replace(/([a-z])([A-Z])/g, '$1 $2'));
        } else {
          name = 'Opera';
        }
        if (/\bIE\b/.test(data)) {
          os = null;
        }
        if (!useFeatures) {
          version = null;
        }
      }
      layout = ['Presto'];
      description.push(data);
    }
    // Detect WebKit Nightly and approximate Chrome/Safari versions.
    if ((data = (/\bAppleWebKit\/([\d.]+\+?)/i.exec(ua) || 0)[1])) {
      // Correct build number for numeric comparison.
      // (e.g. "532.5" becomes "532.05")
      data = [parseFloat(data.replace(/\.(\d)$/, '.0$1')), data];
      // Nightly builds are postfixed with a "+".
      if (name == 'Safari' && data[1].slice(-1) == '+') {
        name = 'WebKit Nightly';
        prerelease = 'alpha';
        version = data[1].slice(0, -1);
      }
      // Clear incorrect browser versions.
      else if (version == data[1] ||
          version == (data[2] = (/\bSafari\/([\d.]+\+?)/i.exec(ua) || 0)[1])) {
        version = null;
      }
      // Use the full Chrome version when available.
      data[1] = (/\bChrome\/([\d.]+)/i.exec(ua) || 0)[1];
      // Detect Blink layout engine.
      if (data[0] == 537.36 && data[2] == 537.36 && parseFloat(data[1]) >= 28 && layout == 'WebKit') {
        layout = ['Blink'];
      }
      // Detect JavaScriptCore.
      // http://stackoverflow.com/questions/6768474/how-can-i-detect-which-javascript-engine-v8-or-jsc-is-used-at-runtime-in-androi
      if (!useFeatures || (!likeChrome && !data[1])) {
        layout && (layout[1] = 'like Safari');
        data = (data = data[0], data < 400 ? 1 : data < 500 ? 2 : data < 526 ? 3 : data < 533 ? 4 : data < 534 ? '4+' : data < 535 ? 5 : data < 537 ? 6 : data < 538 ? 7 : data < 601 ? 8 : '8');
      } else {
        layout && (layout[1] = 'like Chrome');
        data = data[1] || (data = data[0], data < 530 ? 1 : data < 532 ? 2 : data < 532.05 ? 3 : data < 533 ? 4 : data < 534.03 ? 5 : data < 534.07 ? 6 : data < 534.10 ? 7 : data < 534.13 ? 8 : data < 534.16 ? 9 : data < 534.24 ? 10 : data < 534.30 ? 11 : data < 535.01 ? 12 : data < 535.02 ? '13+' : data < 535.07 ? 15 : data < 535.11 ? 16 : data < 535.19 ? 17 : data < 536.05 ? 18 : data < 536.10 ? 19 : data < 537.01 ? 20 : data < 537.11 ? '21+' : data < 537.13 ? 23 : data < 537.18 ? 24 : data < 537.24 ? 25 : data < 537.36 ? 26 : layout != 'Blink' ? '27' : '28');
      }
      // Add the postfix of ".x" or "+" for approximate versions.
      layout && (layout[1] += ' ' + (data += typeof data == 'number' ? '.x' : /[.+]/.test(data) ? '' : '+'));
      // Obscure version for some Safari 1-2 releases.
      if (name == 'Safari' && (!version || parseInt(version) > 45)) {
        version = data;
      }
    }
    // Detect Opera desktop modes.
    if (name == 'Opera' &&  (data = /\bzbov|zvav$/.exec(os))) {
      name += ' ';
      description.unshift('desktop mode');
      if (data == 'zvav') {
        name += 'Mini';
        version = null;
      } else {
        name += 'Mobile';
      }
      os = os.replace(RegExp(' *' + data + '$'), '');
    }
    // Detect Chrome desktop mode.
    else if (name == 'Safari' && /\bChrome\b/.exec(layout && layout[1])) {
      description.unshift('desktop mode');
      name = 'Chrome Mobile';
      version = null;

      if (/\bOS X\b/.test(os)) {
        manufacturer = 'Apple';
        os = 'iOS 4.3+';
      } else {
        os = null;
      }
    }
    // Strip incorrect OS versions.
    if (version && version.indexOf((data = /[\d.]+$/.exec(os))) == 0 &&
        ua.indexOf('/' + data + '-') > -1) {
      os = trim(os.replace(data, ''));
    }
    // Add layout engine.
    if (layout && !/\b(?:Avant|Nook)\b/.test(name) && (
        /Browser|Lunascape|Maxthon/.test(name) ||
        name != 'Safari' && /^iOS/.test(os) && /\bSafari\b/.test(layout[1]) ||
        /^(?:Adobe|Arora|Breach|Midori|Opera|Phantom|Rekonq|Rock|Sleipnir|Web)/.test(name) && layout[1])) {
      // Don't add layout details to description if they are falsey.
      (data = layout[layout.length - 1]) && description.push(data);
    }
    // Combine contextual information.
    if (description.length) {
      description = ['(' + description.join('; ') + ')'];
    }
    // Append manufacturer to description.
    if (manufacturer && product && product.indexOf(manufacturer) < 0) {
      description.push('on ' + manufacturer);
    }
    // Append product to description.
    if (product) {
      description.push((/^on /.test(description[description.length - 1]) ? '' : 'on ') + product);
    }
    // Parse the OS into an object.
    if (os) {
      data =
        / ([\d.+]+)$/.exec(os) ||
        (isSpecialCasedOS = /^[a-z]+ ([\d.+]+) \//i.exec(os));
      os = {
        'architecture': 32,
        'family': (data && !isSpecialCasedOS) ? os.replace(data[0], '') : os,
        'version': data ? data[1] : null,
        'toString': function() {
          var version = this.version;
          return this.family + ((version && !isSpecialCasedOS) ? ' ' + version : '') + (this.architecture == 64 ? ' 64-bit' : '');
        }
      };
    }
    // Add browser/OS architecture.
    if ((data = /\b(?:AMD|IA|Win|WOW|x86_|x)64\b/i.exec(arch)) && !/\bi686\b/i.test(arch)) {
      if (os) {
        os.architecture = 64;
        os.family = os.family.replace(RegExp(' *' + data), '');
      }
      if (
          name && (/\bWOW64\b/i.test(ua) ||
          (useFeatures && /\w(?:86|32)$/.test(nav.cpuClass || nav.platform) && !/\bWin64; x64\b/i.test(ua)))
      ) {
        description.unshift('32-bit');
      }
    }

    ua || (ua = null);

    /*------------------------------------------------------------------------*/

    /**
     * The platform object.
     *
     * @name platform
     * @type Object
     */
    var platform = {};

    /**
     * The platform description.
     *
     * @memberOf platform
     * @type string|null
     */
    platform.description = ua;

    /**
     * The name of the browser's layout engine.
     *
     * @memberOf platform
     * @type string|null
     */
    platform.layout = layout && layout[0];

    /**
     * The name of the product's manufacturer.
     *
     * @memberOf platform
     * @type string|null
     */
    platform.manufacturer = manufacturer;

    /**
     * The name of the browser/environment.
     *
     * @memberOf platform
     * @type string|null
     */
    platform.name = name;

    /**
     * The alpha/beta release indicator.
     *
     * @memberOf platform
     * @type string|null
     */
    platform.prerelease = prerelease;

    /**
     * The name of the product hosting the browser.
     *
     * @memberOf platform
     * @type string|null
     */
    platform.product = product;

    /**
     * The browser's user agent string.
     *
     * @memberOf platform
     * @type string|null
     */
    platform.ua = ua;

    /**
     * The browser/environment version.
     *
     * @memberOf platform
     * @type string|null
     */
    platform.version = name && version;

    /**
     * The name of the operating system.
     *
     * @memberOf platform
     * @type Object
     */
    platform.os = os || {

      /**
       * The CPU architecture the OS is built for.
       *
       * @memberOf platform.os
       * @type number|null
       */
      'architecture': null,

      /**
       * The family of the OS.
       *
       * Common values include:
       * "Windows", "Windows 7 / Server 2008 R2", "Windows Vista / Server 2008",
       * "Windows XP", "OS X", "Ubuntu", "Debian", "Fedora", "Red Hat", "SuSE",
       * "Android", "iOS" and "Windows Phone"
       *
       * @memberOf platform.os
       * @type string|null
       */
      'family': null,

      /**
       * The version of the OS.
       *
       * @memberOf platform.os
       * @type string|null
       */
      'version': null,

      /**
       * Returns the OS string.
       *
       * @memberOf platform.os
       * @returns {string} The OS string.
       */
      'toString': function() { return 'null'; }
    };

    platform.parse = parse;
    platform.toString = toStringPlatform;

    if (platform.version) {
      description.unshift(version);
    }
    if (platform.name) {
      description.unshift(name);
    }
    if (os && name && !(os == String(os).split(' ')[0] && (os == name.split(' ')[0] || product))) {
      description.push(product ? '(' + os + ')' : 'on ' + os);
    }
    if (description.length) {
      platform.description = description.join(' ');
    }
    return platform;
  }

  /*--------------------------------------------------------------------------*/

  // Export platform.
  // Some AMD build optimizers, like r.js, check for condition patterns like the following:
  if (typeof define == 'function' && typeof define.amd == 'object' && define.amd) {
    // Define as an anonymous module so platform can be aliased through path mapping.
    define(function() {
      return parse();
    });
  }
  // Check for `exports` after `define` in case a build optimizer adds an `exports` object.
  else if (freeExports && freeModule) {
    // Export for CommonJS support.
    forOwn(parse(), function(value, key) {
      freeExports[key] = value;
    });
  }
  else {
    // Export to the global object.
    root.platform = parse();
  }
}.call(this));

import "@website/models/models.website";
import "@website/models/models.user";
import "@website/views/views.website";

/**
 * Start App
 * @since 3.0.0
 */
ph.api.start = function (data) {
    PH_Website_Settings.debug && console.log('Site Data:', data); // debug

    // set globals
    ph.api.setGlobal(data);

    // set global heartbeat for timed events
    setInterval(function () {
        ph.api.Event.trigger('heartbeat');
    }, 500);

    ph.api.WebsiteProject = new ph.api.models.Website(data);
    // global website data
    ph.api.WebsiteProjectView = new ph.api.views.Website({
        model: ph.api.WebsiteProject
    });
};

ph.api.setGlobal = function(data) {
    // store project id
    ph.api.project_id = data.id;

    // store me
    ph.api.me  = new ph.api.models.UserMe(data.me || {});

    // access token
    ph.api.access_token = data.access_token;

    // store comment scroll
    ph.api.comment_scroll = data.comment_scroll;

    // editor buttons
    ph.api.global.editorButtons = [
        {
            name          : 'bold',
            tagNames      : ['strong'],
            contentDefault: '<svg viewBox="0 0 18 18"> <path class="ql-stroke" d="M5,4H9.5A2.5,2.5,0,0,1,12,6.5v0A2.5,2.5,0,0,1,9.5,9H5A0,0,0,0,1,5,9V4A0,0,0,0,1,5,4Z"></path> <path class="ql-stroke" d="M5,9h5.5A2.5,2.5,0,0,1,13,11.5v0A2.5,2.5,0,0,1,10.5,14H5a0,0,0,0,1,0,0V9A0,0,0,0,1,5,9Z"></path> </svg>',
        },
        {
            name: 'italic',
            action: 'italic',
            aria: 'italic',
            tagNames      : ['em'],
            useQueryState: true,
            style: {
                prop: 'font-style',
                value: 'italic'
            },
            contentDefault: '<svg viewBox="0 0 18 18"> <line class="ql-stroke" x1="7" x2="13" y1="4" y2="4"></line> <line class="ql-stroke" x1="5" x2="11" y1="14" y2="14"></line> <line class="ql-stroke" x1="8" x2="10" y1="14" y2="4"></line> </svg>',
        },
        {
            name: 'quote',
            action: 'append-blockquote',
            aria: 'blockquote',
            tagNames      : ['blockquote'],
            contentDefault: '<svg viewBox="0 0 18 18"> <rect class="ql-fill ql-stroke" height="3" width="3" x="4" y="5"></rect> <rect class="ql-fill ql-stroke" height="3" width="3" x="11" y="5"></rect> <path class="ql-even ql-fill ql-stroke" d="M7,8c0,4.031-3,5-3,5"></path> <path class="ql-even ql-fill ql-stroke" d="M14,8c0,4.031-3,5-3,5"></path> </svg>',
        },
        {
            name: 'pre',
            action: 'append-pre',
            aria: 'preformatted text',
            tagNames: ['pre'],
            contentDefault: '<svg viewBox="0 0 18 18"> <polyline class="ql-even ql-stroke" points="5 7 3 9 5 11"></polyline> <polyline class="ql-even ql-stroke" points="13 7 15 9 13 11"></polyline> <line class="ql-stroke" x1="10" x2="8" y1="5" y2="13"></line> </svg>',
        },
        {
            name          : 'anchor',
            action        : 'createLink',
            aria          : 'Link',
            tagNames      : ['a'],
            contentDefault: '<svg viewBox="0 0 18 18"> <line class="ql-stroke" x1="7" x2="11" y1="7" y2="11"></line> <path class="ql-even ql-stroke" d="M8.9,4.577a3.476,3.476,0,0,1,.36,4.679A3.476,3.476,0,0,1,4.577,8.9C3.185,7.5,2.035,6.4,4.217,4.217S7.5,3.185,8.9,4.577Z"></path> <path class="ql-even ql-stroke" d="M13.423,9.1a3.476,3.476,0,0,0-4.679-.36,3.476,3.476,0,0,0,.36,4.679c1.392,1.392,2.5,2.542,4.679.36S14.815,10.5,13.423,9.1Z"></path> </svg>',
        },
        {
            name          : 'orderedlist',
            action        : 'insertorderedlist',
            aria          : 'ordered list',
            tagNames      : ['ol'],
            useQueryState : true,
            contentDefault: '<svg viewBox="0 0 18 18"> <line class="ql-stroke" x1="7" x2="15" y1="4" y2="4"></line> <line class="ql-stroke" x1="7" x2="15" y1="9" y2="9"></line> <line class="ql-stroke" x1="7" x2="15" y1="14" y2="14"></line> <line class="ql-stroke ql-thin" x1="2.5" x2="4.5" y1="5.5" y2="5.5"></line> <path class="ql-fill" d="M3.5,6A0.5,0.5,0,0,1,3,5.5V3.085l-0.276.138A0.5,0.5,0,0,1,2.053,3c-0.124-.247-0.023-0.324.224-0.447l1-.5A0.5,0.5,0,0,1,4,2.5v3A0.5,0.5,0,0,1,3.5,6Z"></path> <path class="ql-stroke ql-thin" d="M4.5,10.5h-2c0-.234,1.85-1.076,1.85-2.234A0.959,0.959,0,0,0,2.5,8.156"></path> <path class="ql-stroke ql-thin" d="M2.5,14.846a0.959,0.959,0,0,0,1.85-.109A0.7,0.7,0,0,0,3.75,14a0.688,0.688,0,0,0,.6-0.736,0.959,0.959,0,0,0-1.85-.109"></path> </svg>',
            contentFA: '<i class="fa fa-list-ol"></i>'                    },
        {
            name          : 'unorderedlist',
            action        : 'insertunorderedlist',
            aria          : 'unordered list',
            tagNames      : ['ul'],
            useQueryState : true,
            contentDefault: '<svg viewBox="0 0 18 18"> <line class="ql-stroke" x1="6" x2="15" y1="4" y2="4"></line> <line class="ql-stroke" x1="6" x2="15" y1="9" y2="9"></line> <line class="ql-stroke" x1="6" x2="15" y1="14" y2="14"></line> <line class="ql-stroke" x1="3" x2="3" y1="4" y2="4"></line> <line class="ql-stroke" x1="3" x2="3" y1="9" y2="9"></line> <line class="ql-stroke" x1="3" x2="3" y1="14" y2="14"></line> </svg>',
        }
    ];
};
/**
 * Utility library used for the front-end experience
 */
ph.api.utils = {
	/**
	 * Normalize urls to check for matches
	 *
	 * @param url
	 *
	 * @uses https://github.com/unshiftio/url-parse
	 *
	 * @returns {string|*|null|string}
	 */
	normalizeURL: function (url) {
		var parsed = new URL(url);

		if (PH_Website_Settings.options.project.query_strings) {
			return parsed.pathname;
		} else {
			return parsed.pathname + parsed.search;
		}
	},

	/**
	 * Read a stored browser cookie
	 *
	 * @param name Name of cookie
	 * @returns string|null
	 */
	readCookie: function (name) {
		var nameEQ = name + "=";
		var ca     = document.cookie.split(';');
		for (var i = 0; i < ca.length; i++) {
			var c = ca[i];
			while (c.charAt(0) == ' ') c = c.substring(1, c.length);
			if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length, c.length);
		}
		return null;
	},

	/**
	 * Checks if string is whitespace or not
	 *
	 * @param ch string
	 * @returns {boolean}
	 */
	isWhitespace: function (ch) {
		var whiteSpace = false;
		if ((ch == ' ') || (ch == '\t') || (ch == '\n')) {
			whiteSpace = true;
		}
		return whiteSpace;
	},

	/**
	 * Find the best match for saved HTML/Path vs page HTML/Path
	 *
	 * @param modelPath string Path stored im model
	 * @param modelHTML string outerHTML stored in model
	 *
	 * @returns object/boolean Matched object or false
	 */
	matchElement: function (modelPath, modelHTML) {
		var path       = _.unescape(modelPath);
		var path_split = path.split(' > ');
		var parentHtml = _.unescape(modelHTML);
		var result     = false;

		// do we have exact match?
		result = this.findElement(path, parentHtml);
		if (result) {
			return result;
		}

		// go through all fuzzy matches
		for (var i = 0; i < path_split.length; i++) {
			result = this.findElement(path_split[path_split.length - i - 1], parentHtml);
			if (result) {
				return result;
			}
		}

		return result;
	},

	/**
	 * Find the difference between two strings using the
	 * Levenshtein method
	 *
	 * @param a
	 * @param b
	 * @returns match percentage
	 */
	levenshtein: function (a, b) {
		var tmp;
		if (a.length === 0) {
			return b.length;
		}
		if (b.length === 0) {
			return a.length;
		}
		if (a.length > b.length) {
			tmp = a;
			a   = b;
			b   = tmp;
		}

		var i, j, res, alen = a.length, blen = b.length, row = Array(alen);
		for (i = 0; i <= alen; i++) {
			row[i] = i;
		}

		for (i = 1; i <= blen; i++) {
			res = i;
			for (j = 1; j <= alen; j++) {
				tmp        = row[j - 1];
				row[j - 1] = res;
				res        = b[i - 1] === a[j - 1] ? tmp : Math.min(tmp + 1, Math.min(res + 1, row[j] + 1));
			}
		}
		return res;
	},

	/**
	 * Get the best match on the page using html and path of clicked element.
	 * Bubbles up to next element if nothing is found.
	 *
	 * @param path string CSS path of clicked element
	 * @param html string InnerHTML of clicked element
	 * @returns Dom result
	 */
	findElement: function (path, html) {
		// get parent fuzzy match
		var parentFuzzy = ph.api.parent.find(path.replace( /(\[|\]|,|=|@)/g, "\\$1" ));
		var match       = 0;
		var percentage  = null;
		var result      = false;

		// if there's matches in the dom (classes/tags are the same)
		if (parentFuzzy.length) {
			// pick best match based on content if more than one
			if (parentFuzzy.length > 1) {
				parentFuzzy.each(function () {
					match = ph.api.utils.levenshtein(jQuery(this)[0].outerHTML.substring(0, 500).replace(/\u2029/, "/r").replace(/\u2028/, "/r"), _.unescape(html));

					// if match is better than previous
					if (match < percentage || percentage === null) {
						result     = this; // use this item
						percentage = match; // update percentage to beat
					}
				});
			} else {
				result = parentFuzzy;
			}

			return jQuery(result);
		}

		return false;
	},

	/**
	 * Get right arrow parents
	 * i.e. body > div.some-class > {target}
	 *
	 * @param target Html element on page
	 * @returns {Array} of parents
	 */
	getCSSParents: function (target) {
		var rightArrowParents = [],
			$target           = jQuery(target).removeClass('_ph_highlight');

		// if there's an empty class tag, remove tag
		if ($target.hasClass()) {
			$target.removeAttr('class');
		}

		var clicked = target.tagName.toLowerCase();
		if (target.className) {
			clicked += this.classList(target);
		}
		if (target.id) {
			clicked += "#" + target.id.replace(/ /g, '#');
		}

		var index     = $target.index(),
			more      = ph.api.parent.find(clicked).length,
			selectors = $target.removeClass('_ph_highlight').parents().addBack().not('html').not('body'),
			total     = selectors.length;

		selectors.each(function (i) {
			var entry = this.tagName.toLowerCase();
			if (this.className) {
				entry += ph.api.utils.classList(this);
			}
			if (this.id) {
				entry += "#" + this.id.replace(/ /g, '#');
			}
			// if there's more than one
			if (more > 1 && index) {
				// last index
				if (i === total - 1) {
					entry += ':nth-child(' + (index + 1) + ')';
				}
			}
			rightArrowParents.push(entry);
		});

		return rightArrowParents;
	},

	/**
	 * Get element classlist
	 *
	 * @param target
	 * @returns {string}
	 */
	classList: function (target) {
		var classes = [];
		jQuery(target).each(function (i, v) {
			var splitClassName = v.className.split(/\s+/);
			for (var j in splitClassName) {
				var className = splitClassName[j];
				if (className && -1 === classes.indexOf(className)) {
					classes.push(className);
				}
			}
		});
		return '.' + classes.join(".");
	},

	/**
	 * Get relative X coordinate
	 * @param xpos
	 * @param element
	 * @returns {number}
	 */
	relativeX: function (xpos, element) {
		var width = element.outerWidth();
		return xpos / width;
	},

	/**
	 * Get relative Y coordinate
	 * @param ypos
	 * @param element
	 * @returns {number}
	 */
	relativeY: function (ypos, element) {
		var height = element.outerHeight();
		return ypos / height;
	},

	UTCTimeStamp: function () {
		var now           = new Date;
		var utc_timestamp = Date.UTC(now.getFullYear(), now.getMonth(), now.getDate(),
			now.getHours(), now.getMinutes(), now.getSeconds(), now.getMilliseconds());

		return utc_timestamp;
	},

  iframeMouseMove: function( iframe ){
    iframe.contentWindow.addEventListener('mousemove', function( event ) {
      var boundingClientRect = iframe.getBoundingClientRect();

      var evt = new CustomEvent( 'mousemove', {bubbles: true, cancelable: false})
      evt.clientX = event.clientX + boundingClientRect.left;
      evt.clientY = event.clientY + boundingClientRect.top;

      iframe.dispatchEvent( evt );
    });
  }
};

function ScrollPosition(node) {
	this.node = node;
	this.previousScrollHeightMinusTop = 0;
	this.readyFor = 'up';
}

ScrollPosition.prototype.restore = function () {
	if (this.readyFor === 'up') {
		this.node.scrollTop = this.node.scrollHeight
			- this.previousScrollHeightMinusTop;
	}

	// 'down' doesn't need to be special cased unless the
	// content was flowing upwards, which would only happen
	// if the container is position: absolute, bottom: 0 for
	// a Facebook messages effect
}

ScrollPosition.prototype.prepareFor = function (direction) {
	this.readyFor = direction || 'up';
	this.previousScrollHeightMinusTop = this.node.scrollHeight
		- this.node.scrollTop;
}
/**
 * Mixins used in the app.
 *
 * @package     ProjectHuddle
 * @subpackage  ph-website-comments
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       3.0.0
 */

/**
 * Underscore Mixins
 *
 * @since 1.0.0
 */
_.mixin({
    /**
     * Convert /n newline to <br>
     *
     * @param str String to convert
     * @param is_xhtml Use xhtml tag
     * @returns {string} Output with <br> tag
     *
     * @since 1.0.0
     */
    nl2br: function (str, is_xhtml) {
        var breakTag = (is_xhtml || typeof is_xhtml === 'undefined') ? '<br />' : '<br>';
        return (str + '').replace(/([^>\r\n]?)(\r\n|\n\r|\r|\n)/g, '$1' + breakTag + '$2');
    },

	/**
	 * Mixin to let new models extend initialize function
	 *
	 * @param oldmodel
	 * @param callback
	 */
	extendInitialize: function (oldmodel, callback) {
		// cach old init
		var cachedInit = oldmodel.prototype.initialize;

		/**
		 * Extend model prototype functions with our own
		 */
		_.extend(oldmodel.prototype, {
			initialize: function (attributes, options) {
				// do cached init
				cachedInit.call(this, attributes, options);
				// do new callback
				callback.call(this, attributes, options);
			}
		});
	},

    /**
     * Human readable time
     *
     * @param time
     * @returns {*}
     */
    timeSince: function (time) {
        switch (typeof time) {
            case 'number':
                break;
            case 'string':
                time = +new Date(time);
                break;
            case 'object':
                if (time.constructor === Date) time = time.getTime();
                break;
            default:
                time = +new Date();
        }

        var time_formats = [
            [60, 's', 1], // 60
            [120, '1m', '1m'], // 60*2
            [3600, 'm', 60], // 60*60, 60
            [7200, '1h', '1h'], // 60*60*2
            [86400, 'h', 3600], // 60*60*24, 60*60
            [172800, '1d', '1d'], // 60*60*24*2
            [604800, 'd', 86400], // 60*60*24*7, 60*60*24
            [1209600, '1w', '1w'], // 60*60*24*7*4*2
            [2419200, 'w', 604800], // 60*60*24*7*4, 60*60*24*7
            [4838400, '1mth', '1mth'], // 60*60*24*7*4*2
            [29030400, 'mths', 2419200], // 60*60*24*7*4*12, 60*60*24*7*4
            [58060800, 'y', '1y'], // 60*60*24*7*4*12*2
            [2903040000, 'y', 29030400] // 60*60*24*7*4*12*100, 60*60*24*7*4*12
        ];

        // use gmt
        var now     = new Date();
        var now_utc = new Date(now.getUTCFullYear(), now.getUTCMonth(), now.getUTCDate(), now.getUTCHours(), now.getUTCMinutes(), now.getUTCSeconds());

        var seconds     = (+now_utc.getTime() - time) / 1000,
            token       = 'ago',
            list_choice = 1;

        if (seconds == 0) {
            return 'Now'
        }
        if (seconds < 0) {
            seconds     = Math.abs(seconds);
            token       = 'from now';
            list_choice = 2;
        }
        var i = 0,
            format;
        while (format = time_formats[i++]) {
            if (seconds < format[0]) {
                if (typeof format[2] === 'string')
                    return format[list_choice];
                else
                    return Math.floor(seconds / format[2]) + format[1];
            }
        }
        return time;
    }
});
wp.api.loadPromise.done(function () {
/**
 * Declare global events in namespace
 */
ph.api.Event = _.extend( {}, Backbone.Events );
/**
 * Model to store our comment filter data
 *
 * @since 2.5.0
 */
ph.api.models.CommentFilter = Backbone.Model.extend({
  defaults  : {
    'name'  : '',
    'active': false,
  },
  initialize: function() {
    ph.api.hooks.doAction('ph.api.models.CommentFilter.initialize', this);
  },
});
/**
 * Model to store our individual comment item
 *
 * @since 2.0.0
 */
ph.api.models.Comment = wp.api.models.Comment.extend(_.defaults({
	// extend defaults
	defaults: _.defaults({}, wp.api.models.Comment.prototype.defaults, {
		'edit'    : false,
		'moderate': false,
		'attachments': []
	}),

	// extend initialize
	initialize: function (attributes, options) {
		wp.api.models.Comment.prototype.initialize.call(this, attributes, options);

		this.setModerate();
		this.listenTo(ph.api.me, 'change:id', this.setModerate);

		this.setDate();
		this.listenTo(this.collection, 'update', this.setDate);

		// hook into init
		wp.hooks.doAction('ph.api.models.Comment.initialize', this);
    ph.api.hooks.doAction('ph.api.models.Comment.initialize', this);
	},

	// get thread from comment based on current page
	getThread: function() {
		return ph.api.WebsiteProject.get('currentPage').get('threads').get(this.get('post'));
	},

	setModerate: function() {
		this.set({
			'moderate' : this.get('author') === ph.api.me.get('id')
		});
	},

	setDate: function(event) {
		this.set({
			'humanDate': this.get('date_gmt') ? _.timeSince(this.get('date_gmt')) : 'Now',
		});
	}
}, ph.api.Model));
/**
 * Model to store our individual comment item
 *
 * @since 2.0.0
 */
ph.api.models.User = wp.api.models.User.extend(_.defaults({
  noRegister: true,

  can: function(cap) {
    var caps = this.get('capabilities');

    if (_.isEmpty(caps)) {
      return false;
    }

    return caps[cap];
  },

  initialize: function(attributes, options) {
    // init parent
    wp.api.models.User.prototype.initialize.call(
        this,
        attributes,
        options,
    );

    ph.api.hooks.doAction('ph.api.models.User.initialize', this);
  }
}, ph.api.Model));

ph.api.models.UserMe = wp.api.models.UsersMe.extend(_.defaults({
  noRegister: true,

  can       : function(cap) {
    var caps = this.get('capabilities');

    if (_.isEmpty(caps)) {
      return false;
    }

    return caps[cap];
  },

  initialize: function(attributes, options) {
    // init parent
    wp.api.models.User.prototype.initialize.call(
        this,
        attributes,
        options,
    );

    ph.api.hooks.doAction('ph.api.models.UserMe.initialize', this);
  }
}, ph.api.Model));
import "@website/collections/collections.website-thread";
import "@website/collections/collections.filter";

ph.api.models.WebsitePage = wp.api.models.WebsitePage.extend(_.defaults({
  // extend defaults
  defaults: _.extend({}, wp.api.models.WebsitePage.prototype.defaults, {
    'comment_count'   : 0,
    'resolved_count'  : 0,
    'show_resolved'   : false,
    'filter'          : {
      'slug'  : 'all',
      'name'  : PH_Website_Settings.translations.all_comments,
      'active': true,
    },
    'unresolved_count': 0,
    'parent_id'       : 0,
    'controls'        : '',
    'commentsEnabled' : false,
  }),

  // don't store filters in model attributes
  filters: {},

  initialize: function(attributes, options) {
    // init parent
    wp.api.models.WebsitePage.prototype.initialize.call(this, attributes,
        options);
    this.requireForceForDelete = false; // don't force delete

    // set threads
    this.set('threads',
        new ph.api.collections.WebsiteThread(this.get('threads') || []));

    // set comment thread filters
    this.setFilters();

    // set order
    this.setOrder();

    // set order
    this.listenTo(this.get('threads'), 'add remove reset', this.setOrder);

    // set comment counts
    this.counts();

    this.listenTo(this.get('threads'), 'change:resolved add remove',
        this.counts);

    // when active filter is changed
    this.listenTo(this.filters, 'change:active', this.filter);

    ph.api.hooks.doAction('ph.api.models.WebsitePage.initialize', this);
  },

  /**
   * Set filters for comment threads
   */
  setFilters: function() {
    this.filters = new ph.api.collections.CommentFilters(this.get('filters') ||
        [
          {
            'function': 'filter_all',
            'name'    : PH_Website_Settings.translations.all_comments,
            'active'  : true,
          },
          {
            'function': 'filter_mine',
            'name'    : PH_Website_Settings.translations.assigned_to_me,
            'active'  : false,
          },
          {
            'function': 'filter_unassigned',
            'name'    : PH_Website_Settings.translations.unassigned,
            'active'  : false,
          },
        ]);
  },

  // update threads subcollection on parse
  parse: function(response, options) {
    // rule out patch requests that don't contain comments
    if (options.patch === true) {
      if (typeof options.attrs.threads === 'undefined') {
        response.threads = this.get('threads');
        return response;
      }
    }

    // handle threads sync
    if (response.threads) {
      // set models threads to response
      this.get('threads').set(response.threads);
      response.threads = this.get('threads');
    }
    return response;
  },

  /**
   * Sets model counts
   */
  counts: function() {
    this.set('comment_count', this.get('threads').length);
    this.set('resolved_count',
        this.get('threads').where({'resolved': true}).length);
    this.set('unresolved_count',
        this.get('threads').where({'resolved': false}).length);
  },

  /**
   * Selected filter model
   * @param model
   */
  filter: function(model) {
    this.set('filter', model.attributes);
  },

  /**
   * Update the order attribute for all comments
   */
  setOrder: function() {
    this.get('threads').forEach(function(thread, index) {
      thread.set({
        order: index,
      }, {
        silent: typeof silent === 'boolean' && silent ? silent : false,
      });
    }, this);
  },
}, ph.api.Model));
import "@website/collections/collections.comments";

/**
 * Website Thread
 */
ph.api.models.WebsiteThread = wp.api.models.WebsiteThread.extend(_.defaults({
  // extend defaults
  defaults: _.defaults({},
      wp.api.models.WebsiteThread.prototype.defaults, {
        title             : '',
        author_avatar_urls: {},
        page_url          : '',
        comments_pages    : 0,
        formContent       : '',
        author_name       : '',
        website_id        : 0,
        controls          : false,
        focus             : false,
        highlight         : false,
        show              : false,
        diff              : 0,
        assigned          : 0,
        assigned_model    : {},
        humanDate         : '',
        order             : 0,
      }),

  users: {},

  initialize: function(attributes, options) {
    // init parent
    wp.api.models.WebsiteThread.prototype.initialize.call(
        this,
        attributes,
        options,
    );
    this.requireForceForDelete = false; // don't force delete

    this.set('assigned_model', new ph.api.models.User());
    this.set('users', new ph.api.collections.Users());
    this.get('users').comparator = function(model) {
      return model.get('assigned') ? 0 : 1;
    };
    this.get('users').sort();

    // update assignments
    this.listenTo(this.get('users'), 'assign', this.assign);
    this.listenTo(this.get('users'), 'unAssign', this.unAssign);
    this.listenTo(
        this.get('users'),
        'update assign unAssign',
        this.selectedUser,
    );

    // listen to submit
    this.listenTo(this, 'submit', this.saveThread);
    this.listenTo(this, 'submit', this.createComment);

    this.listenTo(this, 'change:show', this.maybeDestroy);

    // set website ID in model
    this.setWebsiteID();

    // set comments in model
    this.setComments();

    // set the correct order on init
    this.trigger('setOrder', this);

    this.getAuthorUser().done(
        _.bind(function(user) {
          this.set({
            author_name       : user.get('name'),
            author_avatar_urls: user.get('avatar_urls'),
          });
        }, this),
    );

    this.set({humanDate: _.timeSince(this.get('date'))});

    this.hasMoreComments();
    this.listenTo(this.get('comments'), 'sync', this.hasMoreComments);

    // hook into init
    wp.hooks.doAction('ph.api.models.WebsiteThread.initialize', this);
    ph.api.hooks.doAction('ph.api.models.WebsiteThread.initialize', this);
  },

  hasMoreComments: function() {
    this.set('hasMore', Boolean(this.get('comments').hasMore()));
  },

  // update comments subcollection on parse
  parse: function(response, options) {
    // rule out patch requests that don't contain comments
    if (options.patch === true) {
      if (typeof options.attrs.comments === 'undefined') {
        response.comments = this.get('comments');
        return response;
      }
    }

    // handle comments sync
    if (response.comments && this.get('comments')) {
      // set models comments to response
      this.get('comments').set(response.comments);
      response.comments = this.get('comments');
    }
    return response;
  },

  // maybe destroy thread
  maybeDestroy: function() {
    if (this.get('show')) return; // only if we're hiding

    if (
        this.get('comment_content') &&
        this.get('comment_content') !== '<p><br></p>'
    ) {
      this.confirmDelete(); // confirm delete if form content
    } else if (!this.get('comments').length) {
      this.destroyThread(); // else if there are no comments, destroy automatically
    }
  },

  confirmDelete: function() {
    vex.dialog.confirm({
      message : PH_Settings.translations.discard,
      callback: function(value) {
        if (value) {
          if (this.isNew()) {
            this.destroyThread();
          } else {
            this.set({
              comment_content: '',
              controls       : false,
              show           : false,
            }).trigger('resetTextArea');
          }
        }
      }.bind(this),
    });
  },

  // destroy thread model
  destroyThread: function() {
    // if (ph.api.hooks.applyFilters('ph_destroy_thread', true, this)) {
    this.destroy();
    // }
  },

  /**
   * Store website_id in model
   */
  setWebsiteID: function() {
    this.set('website_id', ph.api.project_id);
  },

  /**
   * Set initial comment load state
   */
  initialState: function() {
    // has been initially fetched
    if (this.get('comments').state &&
        this.get('comments').state.totalPages) {
      return;
    }

    // set currents from load
    this.get('comments').state = {
      totalObjects: this.get('comments_count'),
      currentPage : 1,
      totalPages  : Math.ceil(this.get('comments_count') /
          this.get('comments').length),
    };
  },

  /**
   * Set comments in model
   */
  setComments: function() {
    if (!this.get('comments')) {
      this.set('comments', new ph.api.collections.Comments([]));
      return;
    }

    this.set(
        'comments',
        new ph.api.collections.Comments(this.get('comments') || []),
    );

    this.initialState();

    // update count
    this.listenTo(
        this.get('comments').state.totalObjects,
        'change',
        this.updateCount,
    );
  },

  /**
   * Set the assigned user in the model
   */
  getAssigned: function() {
    this.getter(
        this.get('assigned'),
        'User',
        'assigned',
        'assigned_model',
    ).done(
        _.bind(function(user) {
          this.set('assigned_model', user);
        }, this),
    );
  },

  /**
   * Save thread
   */
  saveThread: function() {
    if (!this.isNew()) {
      return;
    }

    var content = this.get('formContent') ?
        this.get('formContent') :
        this.get('title');

    // add comment to response
    this.get('comments').add(
        ph.api.hooks.applyFilters('ph_new_comment_data', {
          author_name       : ph.api.me.get('name'),
          content           : content,
          author            : ph.api.me.get('id'),
          author_avatar_urls: ph.api.me.get('avatar_urls'),
        }, this),
        {validate: true},
    );

    // get page url minus hash
    var page_url = window.parent.location.href.toString().
        replace(window.parent.location.hash, '');

    // save thread with comment
    this.save(ph.api.hooks.applyFilters('ph_new_thread_data', {
          page_url  : page_url,
          page_title: parent.document.title,
          content   : this.get('comments').first().get('content'),
          slug      : this.get('id'),
          website_id: ph.api.project_id,
          status    : 'publish',
          title     : this.get('comments').first().get('content'),
          author    : ph.api.me ? ph.api.me.get('id') : 0,
        }, this), {
          success: _.bind(function(model) {
            this.set('formContent', '');
            PH_Website_Settings.debug && console.log('New Thread:', model); // debug
          }, this),
          error  : this.trigger('error'),
        },
    );

    ph.api.me.get('id') && PH_Website_Settings.options.global.auto_close &&
    this.autoHide();
  },

  /**
   * Create/Add Comment
   */
  createComment: function() {
    if (this.isNew()) {
      return;
    }

    // create comment
    this.get('comments').create(
        ph.api.hooks.applyFilters('ph_new_comment_data', {
          author_name       : ph.api.me.get('name'),
          content           : this.get('formContent'),
          post              : this.get('id'),
          author            : ph.api.me.get('id'),
          author_avatar_urls: ph.api.me.get('avatar_urls'),
        }, this),
        {validate: true},
    );
  },

  /**
   * Update item count in model
   */
  updateCount: function() {
    this.set('comments_count', this.get('comments').state.totalObjects);
  },

  /**
   * Set/save assignment
   * @param model User model
   */
  assign: function(model) {
    var method = this.isNew() ? 'set' : 'save';
    this[method](ph.api.hooks.applyFilters('ph_assign_thread_data', {
          assigned: model.get('id'),
        }),
        {patch: true},
    );

    this.set({assigned_model: new ph.api.models.User(model.toJSON())});
  },

  /**
   * Set/save unassignment
   */
  unAssign: function() {
    var method = this.isNew() ? 'set' : 'save';
    this[method](
        ph.api.hooks.applyFilters('ph_unassign_thread_data', {
          assigned: 0,
        }),
        {patch: true},
    );

    this.set({assigned_model: new ph.api.models.User()});
  },

  /**
   * Set assigned user in sub collection
   */
  selectedUser: function() {
    this.get('users').invoke('set', {assigned: false}); // set all as unassigned
    this.assigned = this.get('users').get(this.get('assigned'));
    this.assigned && this.assigned.set({assigned: true});
    this.get('users').sort(); // sort by assigned first
  },

  /**
   * Auto hide comment after 1.5 seconds
   */
  autoHide: function() {
    this.hiding = _.delay(
        _.bind(function() {
          this.set({show: false});
        }, this),
        1500,
    ); // wait a second and a half
  },

  /**
   * Kill autohide timer
   */
  cancelAutoHide: function() {
    clearTimeout(this.hiding); //Kill the timer
  },
}, ph.api.Model));

import "@website/collections/collections.website-page";
import "@website/collections/collections.user";

/**
 * Website model
 * Stores entire website project
 */
ph.api.models.Website = wp.api.models.Website.extend(_.defaults({
	// extend defaults
	defaults: _.extend({}, wp.api.models.Website.prototype.defaults, {
		currentPage: {},
		filter     : '',
		filterSlug : '',
		edit_link : PH_Website_Settings.edit_link
	}),

	pages: {},

	initialize: function (attributes, options) {
		wp.api.models.Website.prototype.initialize.call(this, attributes, options);
		this.requireForceForDelete = false; // don't force delete

		// all pages
		this.pages = new ph.api.collections.WebsitePage(this.get('pages') || []);
		this.unset('pages');

		this.users = new ph.api.collections.Users(this.get('users') || []);

		this.setPage();

		this.listenTo(ph.api.Event, 'heartbeat', _.bind(this.updateCurrentPage, this));

    ph.api.hooks.doAction('ph.api.models.Website.initialize', this);
	},

	setPage: function() {
		// get and set current page if have one
		var currentPage = this.pages.find(function (model) {
			return ph.api.utils.normalizeURL(model.get('page_url')) === ph.api.utils.normalizeURL(window.parent.location.href);
		});
		this.set({
			'currentPage': currentPage || new ph.api.models.WebsitePage(),
			'currentPageLocation': window.parent.location.href
		});
		// current
		PH_Website_Settings.debug && console.log('Current Page:', this.get('currentPage'));
	},

	updateCurrentPage: function() {
		if ( this.get('currentPageLocation') === window.parent.location.href ) {
			return;
		}
		this.setPage();
	}
}, ph.api.Model));
import "@website/models/models.comment";

ph.api.collections.Comments = wp.api.collections.Comments.extend({
	model: ph.api.models.Comment,

	comparator: function (model) {
		return model.get('date');
	},

	initialize: function( attributes, options ) {
		// init parent
		wp.api.collections.Comments.prototype.initialize.call(this, attributes, options);
		this.listenTo(this, 'add update remove', this.sort);
	},
});
import "@website/models/models.comment-filter";

ph.api.collections.CommentFilters = Backbone.Collection.extend({
    model: ph.api.models.CommentFilter
});
import "@website/models/models.user";

ph.api.collections.Users = wp.api.collections.Users.extend({
    model: ph.api.models.User
});
import "@website/models/models.website-page";

ph.api.collections.WebsitePage = wp.api.collections.WebsitePage.extend({
    model: ph.api.models.WebsitePage
});
import "@website/models/models.website-thread";

/**
 * Website Threads
 */
ph.api.collections.WebsiteThread = wp.api.collections.WebsiteThread.extend({
  model: ph.api.models.WebsiteThread,

  comparator: function(model) {
    return model.get('menu_order');
  },

  initialize: function(models, options) {
    wp.api.collections.WebsiteThread.prototype.initialize.apply(models,
        options);
  },

  // filter
  filter_all: function() {
    PH_Website_Settings.debug && console.log('filter all');
    return this;
  },

  filter_mine: function() {
    PH_Website_Settings.debug && console.log('filter mine');
    if (!ph.api.me) {
      return this;
    }
    return new ph.api.collections.WebsiteThread(
        _.filter(this.models, function(thread) {
          return parseInt(thread.get('assigned')) ===
              parseInt(ph.api.me.get('id'));
        }));
  },

  filter_unassigned: function() {
    PH_Website_Settings.debug && console.log('filter unassigned');
    return new ph.api.collections.WebsiteThread(
        _.filter(this.models, function(thread) {
          return !thread.get('assigned');
        }));
  },
});
import '@website/views/controls/views.controls';
import '@website/views/panel/views.panel-iframe';
import '@website/views/global/views.comment-tooltip';
import '@website/views/popup/views.modal';
import '@website/views/comment/views.comment-container';

ph.api.views.WebsitePage = ph.api.View.extend({
    className: "ph-website-inner",

    events: {
        'keyup': 'escapeHandler'
    },

    triggers: {
        'change:commentsEnabled': 'bodyClass', // toggle body class if comments are enabled
        'change:controls'       : 'togglePanel', // toggle panel if controls are set to panel
        'change:show_resolved'  : 'toggleResolvedClass',
    },

    initialize: function () {
        // toolbar
        this.views.add(new ph.api.views.ControlsView({
            model: this.model
        }));

        // panel
        this.views.add(new ph.api.views.PanelIframe({
            model: this.model
        }));

        // tooltip
        this.views.add(new ph.api.views.CommentTooltip({
            model: this.model
        }));

        // modal popup view
        this.views.add(new ph.api.views.Modal({
            model: this.model
        }));

        // comments container
        this.commentsContainer = new ph.api.views.CommentContainer({
            model: this.model
        });
        this.commentsContainer.create('ph-annotation-dot-container', true, 'absolute');

        // escape key
        ph.api.parent.window.on('keyup', _.bind(this.escapeHandler, this));

        this.toggleResolvedClass();
    },

    ready: function() {
        this.regions();
        this.setPanel();
    },

    // set subview regions
    regions: function() {
        this.panel = this.$('.project-huddle-panel');
    },


    toggleResolvedClass: function() {
       ph.api.parent.body.toggleClass('_ph-hide-resolved', !this.model.get('show_resolved'));
    },

    // change body class if comments are enabled
    bodyClass: function() {
        ph.api.parent.body.toggleClass('_ph-cursor', this.model.get('commentsEnabled'));
    },

    // escape key cancels
    escapeHandler: function (e) {
        if ( e.keyCode === 27 ) {
            this.model.set('commentsEnabled', false);
            e.preventDefault();
        }
    },

    // hide panel if controls change
    setPanel: function() {
        if ( this.model.get('controls') !== 'panel' ) {
            this.hidePanel();
        }
    },

    // hide panel with css
    hidePanel: function() {
        this.panel.css({
            'transform': 'translateX(100px)',
            'opacity': 0,
            'visibility': 'hidden'
        });
    },

    // show panel with css
    showPanel: function() {
        this.panel.css({
            'transform': 'translateX(0px)',
            'opacity': 1,
            'visibility': 'visible'
        });
    },

    // toggle the panel
    togglePanel: function() {
        this.model.get('controls') === 'panel' ? this.showPanel() : this.hidePanel();
    }
});
import '@website/views/views.website-page';

ph.api.views.Website = ph.api.View.extend({
	initialize: function () {
		// when current page changes, update the view
		this.listenTo(this.model, 'change:currentPage', this.updatePageView);

		// set website page view
		ph.api.views.container = new ph.api.views.WebsitePage({
			model: this.model.get('currentPage')
		});

		// create in parent frame
		ph.api.views.container.create('projecthuddle-container', true);
	},

	updatePageView: function () {
		// set website page view
		ph.api.views.container = new ph.api.views.WebsitePage({
			model: this.model.get('currentPage')
		});

		// create in parent frame
		ph.api.views.container.create('projecthuddle-container', true);
	}
});
/**
 * Assign View Option Item
 */
ph.api.views.AssignOption = ph.api.View.extend({
    className: 'ph-single-user-option-wrap',
    template : wp.template('ph-assign-dropdown-option'),

    events: {
        'click': 'assign',
        'click .ph-close': 'unAssign'
    },

    triggers: {
        'change:assigned': 'render'
    },

    assign: function () {
        this.model.trigger('assign', this.model);
        return false;
    },

    unAssign: function() {
        this.model.trigger('unAssign', this.model);
        return false;
    }
});
import "@website/views/assign/views.assign-option";

/**
 * Panel Assign View Dropdown
 */
ph.api.views.AssignOptions = ph.api.View.extend({
    className: "ph-assign-options-select",
    template: wp.template('ph-loading'),

    initialize: function () {
        this.setOptions();
        this.listenTo(this.model.get('users'), 'update', this.setOptions);
    },

    setOptions: function() {
        var views    = [];

        if ( this.model.get('users').length ) {
            this.model.get('users').forEach(function(user){
                views.push(new ph.api.views.AssignOption({
                    model: user
                }));
            }, this);
			this.views.set(views);
        }
    }
});
import "@website/views/assign/views.assign-options";

/**
 * Assign View Dropdown
 */
ph.api.views.Assign = ph.api.View.extend({
  template : wp.template('ph-assign-dropdown'),
  className: 'ph-comment-assigned',

  events: {
    'click': 'open',
  },

  triggers: {
    'change:assigned_model': 'render',
  },

  initialize: function() {
    this.views.add('.ph-assign-options', new ph.api.views.AssignOptions({
      model: this.model,
    }));
    ph.api.parent.window.on('click', _.bind(this.close, this));

    // listen for custom events
    this.listenTo(this.model, 'change:assigned', this.render);
    this.listenTo(this.model, 'change:assigned', this.close);
    this.listenTo(this.model, 'change:assigned_model', this.render);
  },

  ready: function() {
    this.model.getAssigned();
  },

  open: function(e) {
    this.$el.toggleClass('ph-open');

    this.model.get('users').fetch({
      data: {
        project : ph.api.project_id,
        per_page: 100,
      },
    });

    e.stopPropagation();
  },

  close: function() {
    this.$el.removeClass('ph-open');
  },
});
import '@website/views/comment/views.comment-bubble';

ph.api.views.BubbleCSS = ph.api.View.extend({
    template: wp.template('ph-comment-bubble-css'),
    tagName : 'style',
    id: 'bubble-style'
});

ph.api.views.CommentBubbleIframe = ph.api.View.extend({
    className: "project-huddle-comment-bubble",
    tagName  : 'iframe',
    id       : function () {
        return 'bubble-' + this.model.get('id')
    },

    attributes: {
        "allowfullscreen": ""
    },

    initialize: function() {
        this.$el.on('load', _.bind(this.subViews, this));
    },

    subViews: function() {
        this.el  = this.$el.contents().get(0);
        this.$el = this.$el.contents();

        this.views.add('head', new ph.api.views.BubbleCSS({
            model: this.model
        }));
        this.views.set('body', new ph.api.views.CommentBubble({
            model: this.model
        }));

        this.$el.find('head').prepend('<base target="_parent">');

        // force ready
        this.views.ready();
    }
});
import '@website/views/comment/views.comment-header';
import "@website/views/comment/views.comment-form";
import "@website/views/comment/views.comment-form-controls";
import "@website/views/comment/views.comment-controls";
import "@website/views/comment/views.comments-container";
import elementResizeDetectorMaker from "element-resize-detector";

ph.api.views.CommentBubble = ph.api.View.extend({
  template : wp.template('ph-comment-bubble'),
  className: 'ph-comment-wrapper',

  triggers: {
    'change:show': 'sizeFrame', // when show/hide scroll to bottom
  },

  events: {
    'keydown'                 : 'cancelAutoHide',
    'keydown'                 : 'sizeFrame',
    'click'                   : 'cancelAutoHide',
    'click'                   : 'show',
    'hover .ph-comment-header': 'cancelAutoHide',
  },

  initialize: function() {
    // set iframe
    this.$iframe = ph.api.parent.find('#bubble-' + this.model.get('id'));
    this.iframe  = this.$iframe[0];

    // comment header
    this.views.set('.ph-comment-header', new ph.api.views.CommentHeader({
      model: this.model,
    }));

    // comment form view
    this.views.add('.ph-comment-form', new ph.api.views.CommentForm({
      model : this.model,
      iframe: this.iframe,
    }));

    // comment form view
    this.views.add('.ph-comment-form', new ph.api.views.CommentFormControls({
      model: this.model,
    }));

    // submit/cancel button view
    this.views.set('.ph-comment-submit', new ph.api.views.CommentControls({
      model: this.model,
    }));

    this.views.set('.ph-comment-text-wrapper',
        new ph.api.views.CommentsContainer({
          model: this.model,
        }));

    this.listenTo(this.model.get('comments'), 'request', this.addLoading);
    this.listenTo(this.model.get('comments'), 'sync', this.removeLoading);
    this.listenTo(this.model.get('comments'), 'sync add', this.moreClass);
    this.moreClass();

    _.bindAll(this, 'setDimensions');
  },

  moreClass: function() {
    this.$el.toggleClass('ph-has-more', Boolean(this.model.get('comments').hasMore()));
  },

  addLoading: function(collection, xhr, options) {
    options || (options = {});
    options.loading && this.$el.addClass('ph-comments-loading');
  },

  removeLoading: function() {
    this.$el.removeClass('ph-comments-loading');
  },

  // cache subview regions
  regions: function() {
    this.commentsList = this.$('.ph-comment-text');
  },

  // dom is ready
  ready: function() {
    // size the frame correctly
    this.sizeFrame();
  },

  sizeFrame: function() {
    // run always at first
    _.defer(_.bind(function() {
      this.model.set('height', this.el.offsetHeight);
      this.model.set('width', this.el.offsetWidth);
    }, this));

    if (!this.resizeDetector) {
      this.resizeDetector = elementResizeDetectorMaker();
      this.resizeDetector.listenTo(this.el, this.setDimensions);
    }
  },

  setDimensions: function(element) {
    this.model.set('height', element.offsetHeight);
    this.model.set('width', element.offsetWidth);
  },

  cancelAutoHide: function() {
    this.model.cancelAutoHide();
  },

  show: function(e) {
    this.model.set('show', true);
  },
});
/**
 * View to show our comment button
 *
 * @since 1.0
 */
ph.api.views.CommentCancelButton = ph.api.View.extend({
    template : wp.template('ph-comment-cancel-button'),
    className: 'ph-cancel',
    tagName  : 'span',

    events: {
        'click': 'cancelComment'
    },

    cancelComment: function () {
        if (!this.model.get('formContent') || this.model.get('formContent') === '<p><br></p>') {
            this.model.set('controls', false);
            return;
        }

        var r = confirm(PH_Website_Settings.translations.discard);
        if (r === true) {
            this.model.trigger('resetTextArea');
            this.model.set('formContent', '');
        }

        this.model.set('controls', false);
        return false;
    }
});

/**
 * View to show our comment button
 *
 * @since 1.0
 */
ph.api.views.CommentClose = ph.api.View.extend({
  template : wp.template('ph-close-comment'),
  className: 'ph-header-controls',
  tagName  : 'span',

  events: {
    'click': 'hide',
  },

  hide: function() {
    _.defer(_.bind(function() {
      this.model.set({
        'show' : false,
        'hover': false,
      });
    }, this));
  },
});
import '@website/views/comment/views.comment';

ph.api.views.CommentContainer = ph.api.View.extend({
  className: "ph-comment-container",

  triggers: {
    "change:commentsEnabled": "clickEvents"
  },

  initialize: function() {
    // add existing comment views
    this.model.get("threads").forEach(this.addThread, this);

    // when a comment thread is shown, hide others
    this.listenTo(this.model.get("threads"), "change:show", this.hideOthers);
    this.listenTo(this.model.get("threads"), "change:show", this.hidePanel);
    this.listenTo(this.model.get("threads"), "add", this.newThread);

    // bind this
    _.bindAll(this, "clicked", "stopAllPropagation");
  },
  // add thread to comment container
  addThread: function(model) {
    this.thread = new ph.api.views.Comment({
      model: model
    });
    this.views.add(this.thread);
  },

  // hide other models besides {model}
  hideOthers: function(model, value, options) {
    if (value !== true) {
      return;
    }
    this.model.get("threads").forEach(function(thread, index) {
      if (thread.get("id") !== model.get("id")) {
        thread.set("show", false);
      }
    });
  },

  // element click event
  clickEvents: function() {
    if (this.model.get("commentsEnabled")) {
      ph.api.parent.off("click");
      ph.api.parent.on("click", this.clicked);
    } else {
      ph.api.parent.off("click", this.clicked);
    }
  },

  // stop other events from propagating
  stopAllPropagation: function(e) {
    e.preventDefault();
    e.stopPropagation();
    e.stopImmediatePropagation();
  },

  // element clicked
  clicked: function(e) {
    if (
      e.target.className.length &&
      e.target.className.trim() === "ph-annotation-dot"
    ) {
      return false;
    }

    this.model.set("commentsEnabled", false);

    var xpos = 0,
      ypos = 0,
      elementXpos = 0,
      elementYpos = 0,
      element,
      parents = ph.api.utils.getCSSParents(e.target);

    var uniquePathCSS = parents.join(" > ");
    var htmlOffset =
      parseInt(ph.api.parent.html.css("padding-top")) +
      parseInt(ph.api.parent.html.css("margin-top"));

    // if click event, calculate offsets
    if (typeof e !== "undefined" && e) {
      xpos = e.pageX ? e.pageX : e.originalEvent.touches[0].pageX;
      ypos = e.pageY ? e.pageY : e.originalEvent.touches[0].pageY;
      elementXpos = xpos - jQuery(e.target).offset().left;
      elementYpos = ypos - jQuery(e.target).offset().top;
      element = e.target;
    }

    if (htmlOffset) {
      ypos = ypos - htmlOffset;
    }

    // add comment to collection
    this.model.get("threads").add(
      new ph.api.models.WebsiteThread({
        x: parseFloat(xpos), // set left click position
        y: parseFloat(ypos), // set top click position
        elementX: parseFloat(elementXpos),
        elementY: parseFloat(elementYpos),
        relativeX: parseFloat(
          ph.api.utils.relativeX(elementXpos, jQuery(element))
        ), // store right relative position
        relativeY: parseFloat(
          ph.api.utils.relativeY(elementYpos, jQuery(element))
        ),
        path: uniquePathCSS,
        html: e.target.outerHTML,
        resX: ph.api.parent.window.outerWidth(),
        resY: ph.api.parent.window.outerHeight(),
        browser: platform.name,
        browserVersion: parseInt(platform.version),
        browserOS: platform.os.toString(),
        parent_id: this.model.get("id"),
        focus: true,
        show: true
      })
    );

    return false;
  },

  newThread: function(model) {
    this.addThread(model);
    this.thread.views.ready(); // Find all attached subviews, and call ready on them.
  },

  hidePanel: function() {
    this.model.get("controls") === "panel" && this.model.set("controls", false);
  }
});

import "@website/views/comment/views.comment-submit-button";
import "@website/views/comment/views.comment-cancel-button";

/**
 * View to show our comment button
 *
 * @since 1.0
 */
ph.api.views.CommentControls = ph.api.View.extend({
    triggers: {
        'change:controls': 'controlsChangeHandler',
        'change:show'    : 'showChangeHandler'
    },

    initialize: function () {
        // submit button view
        this.views.add(new ph.api.views.CommentSubmitButton({
            model: this.model
        }));

        // cancel button view
        this.views.add(new ph.api.views.CommentCancelButton({
            model: this.model
        }));

		this.listenTo(this.model.get('comments'), 'add', this.hideControls);
    },

    ready: function () {
        this.$el.hide();
    },

    showChangeHandler: function () {
        if (!this.model.get('show')) {
            this.model.set('controls', false);
        }
    },

    hideControls: function() {
		this.model.set('controls', false);
    },

    controlsChangeHandler: function () {
        this.$el.toggle(this.model.get('controls'));
    }
});
ph.api.views.CommentDot = ph.api.View.extend({
    template : wp.template('ph-website-comment-dot'),
    className: 'ph-annotation-dot',

    triggers: {
        'change:resolved': 'resolvedClass',
        'change:order'   : 'render'
    },

    initialize: function () {
        this.resolvedClass();
    },

    resolvedClass: function () {
        this.$el.toggleClass('ph-approved', !!+this.model.get('resolved'));
    }
});
/**
 * View to show our individual comment item edit box
 *
 * @since 1.0
 */
ph.api.views.CommentEditForm = ph.api.View.extend({
    template: wp.template('edit-comment-form'),
    className: 'ph-edit-form',

    events: {
        'click .ph-edit-cancel': 'cancelEdit',
        'click .ph-edit-save:enabled': 'updateComment'
    },

    initialize: function() {
        this.listenTo(this.model, 'change:edit', this.toggleEdit);
        this.listenTo(this.model, 'change:edit', this.setEditor);
        this.toggleEdit();
    },

    ready: function() {
        this.toggleEdit();
    },

    setEditor: function () {
        this.editor = new MediumEditor(this.$('.ph-edit-content'), {
            contentWindow: this.options.iframe.contentWindow,
            ownerDocument: this.options.iframe.contentWindow.document,
            autoLink: true,
            toolbar: {
                buttons: ph.api.global.editorButtons
            },
            placeholder: {
                /* This example includes the default options for placeholder,
                 if nothing is passed this is what it used */
                hideOnClick: false
            }
        });
    },

    toggleEdit: function() {
        this.$el.toggle(this.model.get('edit'));
    },

    cancelEdit: function() {
        this.model.set('edit', false);
    },

    updateComment: function() {
        this.model.save({
            'content': this.$('.ph-edit-content').html(),
            'edit': false // done editing
        });
        return false;
    }
});
/**
 * View to show our comment form
 *
 * @since 1.0
 */
ph.api.views.CommentFormControls = ph.api.View.extend({
	className: 'ph-comment-form-controls',
	template : wp.template('thread-form-controls')
});
import MediumEditor from 'medium-editor';

/**
 * View to show our comment form
 *
 * @since 1.0
 */
ph.api.views.CommentForm = ph.api.View.extend({
    className: 'comment-textarea',
    tagName: 'div',

    events: {
        "focus": "textAreaFocus"
    },

    /**
     * Model trigger handlers
     */
    triggers: {
        'resetTextArea' : 'resetTextArea',
        'change:focus': 'focusHandler',
        'error': 'reAddTextArea'
    },

    initialize: function() {
        this.listenTo(this.model.get('comments'), 'add', this.resetTextArea);

        _.bindAll(this, 'contentChanged', 'resetEditor', 'emptyForm');
    },

    ready: function() {
        this.setEditor();
        this.focusHandler();
    },

    setEditor: function() {
        if ( ! this.options.iframe ) {
            return;
        }
		var isFirefox = navigator.userAgent.toLowerCase().indexOf('firefox') > -1;
        this.editor = new MediumEditor(this.$el, {
            contentWindow: this.options.iframe.contentWindow,
            ownerDocument: this.options.iframe.contentWindow.document,
            autoLink: true,
            targetBlank: true,
            anchor: {
                linkValidation: true,
                placeholderText: 'http://'
            },
            toolbar: {
                buttons: ph.api.global.editorButtons
            },
            placeholder: {
                text: PH_Website_Settings.translations.comment_placeholder,
                hideOnClick: isFirefox ? true : false
            }
        });

        this.editor.subscribe('editableInput', this.contentChanged);
    },

    textAreaFocus: function() {
        this.model.set('controls', true);
    },

	resetTextArea: function (comment) {
		if (comment.isValid()) {
			this.model.set('formContent', '');
			this.emptyTextArea();
		}
	},

    emptyTextArea: function() {
        if ( ! this.editor ) return;
        this.selection = this.editor.exportSelection();
        _.defer(this.emptyForm);
        this.editor.resetContent();
    },

    reAddTextArea: function() {
        if (this.selection) {
            this.editor.importSelection(this.selection);
        }
    },

    emptyForm: function() {
        this.$el.empty().addClass('medium-editor-placeholder');
    },

    resetEditor: function() {
        this.editor.resetContent();
    },

    contentChanged: function (e, editable) {
        this.model.set('formContent', e.target.innerHTML);
    },

    focusHandler: function() {
        if ( this.model.get('focus') ) {
            _.defer(_.bind(function() {
                this.$el.focus();
            }, this));
            this.model.set('focus', false);
        }
    }
});

import "@website/views/comment/views.comment-resolved";
import "@website/views/comment/views.comment-tech-details";
import "@website/views/comment/views.comment-close";
import "@website/views/assign/views.assign";

/**
 * View to show our comment header
 *
 * @since 1.0
 */
ph.api.views.CommentHeader = ph.api.View.extend({
    className: 'ph-header-inner',
    template : wp.template('project-comment-header'),

    events: {
        'click .ph-share-comment'          : 'triggerCommentShare',
        'click .ph-copy-link'              : 'triggerCopyLink',
        'click .ph-delete-comment-location': 'deleteLocation',
    },

    initialize: function () {
        var region = '.ph-comment-header-left';

        // resolved
        this.views.add('.ph-comment-header-left', new ph.api.views.CommentResolved({
            model: this.model
        }));
        region = '.ph-comment-header-right';

        // status
        // this.views.add(new ph.api.PanelStatusView({
        //     model: this.model
        // }));

        this.views.add(region, new ph.api.views.CommentTechDetails({
            model: this.model
        }));

        // assigned
        this.views.add(region, new ph.api.views.Assign({
            model: this.model
        })) ;

        // close
        this.views.add('.ph-comment-header-right', new ph.api.views.CommentClose({
            model: this.model
        }));
    },

    /**
     * Trigger copy comment link
     * @param e Event
     */
    triggerCopyLink: function (e) {
        e.preventDefault();
        ph.api.Event.trigger('copyCommentLink', this.model);
    },

    /**
     * Trigger share comment
     * @param e Event
     */
    triggerCommentShare: function (e) {
        e.preventDefault();
        ph.api.Event.trigger('shareComment', this.model);
    },

    /**
     * Trigger delete comment location
     * @param e Event
     */
    deleteLocation: function (e) {
        e.preventDefault();
        this.model.trigger('trashLocation', this.model);
    }
});

/**
 * View to show our individual comment item text
 *
 * @since 1.0
 */
ph.api.views.CommentItemControls = ph.api.View.extend({
    template : wp.template('comment-item-controls'),
    className: 'comment-item-controls-inner',

    initialize: function () {
        this.listenTo(this.model, 'change:edit', this.showHide);
    },

    showHide: function () {
        this.$el.toggle(!this.model.get('edit'));
    }
});
/**
 * View to show our individual comment item text
 *
 * @since 1.0
 */
ph.api.views.CommentItemText = ph.api.View.extend({
    template: wp.template('comment-item-text'),
    className: 'comment-item-text',

    triggers: {
        'change:content': 'render',
        'change:edit'   : ['showHide', 'render']
    },

    showHide: function() {
        this.$el.toggle(!this.model.get('edit'));
    }
});
import "@website/views/comment/views.comment-item-text";
import "@website/views/comment/views.comment-edit-form";
import "@website/views/comment/views.comment-item-controls";
import "@website/views/global/views.avatar";

/**
 * View to show our individual comment item
 *
 * @since 1.0
 */
ph.api.views.CommentItem = ph.api.View.extend({
	template : wp.template('project-comment-item'),
	className: 'ph-comment-item',

	events: {
		'click .ph-remove': 'removeComment',
		'click .ph-edit'  : 'editComment'
	},

	triggers: {
		'change:moderate': 'commentControls'
	},

	initialize: function () {
		// avatar if set
		if (this.model.get('author_avatar_urls')) {
			this.views.set('.ph-avatar', new ph.api.views.Avatar({
				model: this.model
			}));
		}

		// comment item text view
		this.views.set('.ph-comment-item-text', new ph.api.views.CommentItemText({
			model: this.model
		}));

		// edit comment form
		this.views.set('.ph-edit-textarea', new ph.api.views.CommentEditForm({
			model : this.model,
			iframe: this.options.iframe
		}));

		// moderation controls
		this.setControls();
		this.listenTo(this.model, 'change:moderate', this.setControls);

		// re-render if user changes
		this.listenTo(ph.api.me, 'change:id', this.render);
	},

	// set comment controls
	setControls: function() {
		if ( this.model.get('moderate')) {
			this.views.set('.ph-item-controls', new ph.api.views.CommentItemControls({
				model: this.model
			}));
		}
	},

	/**
	 * Remove comment click handler - let the collection handle itself
	 */
	removeComment: function (e) {
		e.preventDefault();
		confirm(PH_Website_Settings.translations.are_you_sure) && this.destroyComment();
	},

	/**
	 * Shows the edit textbox, focuses and places cursor at end
	 */
	editComment: function () {
		this.model.set('edit', true);
	},

	/**
	 * Animate removal
	 */
	destroyComment: function () {
		this.$el.slideToggle(250, _.bind(function () {
			this.remove();
			this.unbind();
			this.model.destroy();
		}, this));
	}
});
/**
 * Resolve view
 *
 * @since 1.2.0
 */
ph.api.views.CommentResolved = ph.api.View.extend({
    template : wp.template('ph-resolve-check'),
    className: 'ph-resolve',
    tagName  : 'div',

    events: {
        'click': 'toggleResolve'
    },

    triggers: {
        'error'          : 'removePending',
        'change:resolved': 'render'
    },

    toggleResolve: function () {
        var action = this.model.isNew() ? 'set' : 'save';

        // make sure to save resolved after sync
        if (action === 'set') {
            this.listenToOnce(this.model, 'sync', function () {
                this.model.save({
                    'resolved': !this.model.get('resolved')
                }, {
                    patch: true
                });
            });
        }

        // set/save
        this.model[action]({
            'resolved': !this.model.get('resolved')
        }, {
            patch: true,
			success: _.bind(function() {
				this.model.get('comments').fetch({
					data: {
						post: this.model.get('id'),
						per_page: 25,
					},
				});
			}, this)
        });
    }
});
/**
 * View to show our comment button
 *
 * @since 1.0
 */
ph.api.views.CommentSubmitButton = ph.api.View.extend({
    template : wp.template('project-comment-submit-button'),
    className: 'ph-button submit-comment',
    tagName  : 'button',

    events: {
        'click': 'buttonClickHandler'
    },

    /**
     * Handle Button Click
     */
    buttonClickHandler: function () {
        this.model.trigger('submit', this.model);
        return false;
    }
});
/**
 * View to show tech details
 *
 * @since 1.0
 */
ph.api.views.CommentTechDetails = ph.api.View.extend({
  template : wp.template('ph-comment-tech-details'),
  className: 'ph-tech-details',

  events: {
    'click .ph-click-open': 'toggleClass',
  },

  initialize: function() {
    this.views.add('.ph-dropdown-inner',
        new ph.api.views.CommentDetailBrowserView({
          model: this.model,
        }));

    this.views.add('.ph-dropdown-inner',
        new ph.api.views.CommentDetailResolutionView({
          model: this.model,
        }));

    this.views.add('.ph-dropdown-inner', new ph.api.views.CommentDetailOSView({
      model: this.model,
    }));

    this.views.add('.ph-dropdown-inner',
        new ph.api.views.CommentAdditionalInfo({
          model: this.model,
        }));

    if (this.model.isNew()) {
      this.listenToOnce(this.model, 'sync', this.linkView);
    } else {
      this.views.add('.ph-dropdown-inner',
          new ph.api.views.CommentDetailLinkView({
            model: this.model,
          }));
    }

    // delete view, should refresh after login
    this.deleteView();
    this.listenTo(ph.api.me, 'change:id', this.deleteView);

    // close when hover or show changes
    this.listenTo(this.model, 'change:hover change:show', this.close);

    jQuery(window).on('click', _.bind(this.close, this));
  },

  deleteView: function() {
    // must be logged in to show
    if (ph.api.me.get('id') && ph.api.me.can('delete_phw_comment_locs')) {
      this.views.add('.ph-dropdown-inner',
          new ph.api.views.CommentDetailDeleteView({
            model: this.model,
          }));
    }
  },

  linkView: function() {
    var views = this.views.get('.ph-dropdown-inner');
    this.views.add('.ph-dropdown-inner',
        new ph.api.views.CommentDetailLinkView({
          model: this.model,
        }), {at: views.length - 1});
  },

  toggleClass: function(e) {
    var item = jQuery(e.currentTarget);
    jQuery('.ph-open').not(item).removeClass('ph-open');
    item.toggleClass('ph-open');
    e.stopPropagation();
  },

  close: function() {
    this.$('.ph-click-open').removeClass('ph-open');
  },
});

ph.api.views.CommentDetailBrowserView = ph.api.View.extend({
  template : wp.template('ph-detail-browser'),
  className: 'ph-tech-detail ph-browser-tech-detail',
});

ph.api.views.CommentDetailOSView = ph.api.View.extend({
  template : wp.template('ph-detail-os'),
  className: 'ph-tech-detail ph-os-tech-detail',
});

ph.api.views.CommentDetailResolutionView = ph.api.View.extend({
  template : wp.template('ph-detail-resolution'),
  className: 'ph-tech-detail ph-resolution-tech-detail',
});

ph.api.views.CommentDetailLinkView = ph.api.View.extend({
  template : wp.template('ph-detail-link'),
  className: 'ph-tech-detail ph-link-tech-detail',

  events: {
    'click': 'share',
  },

  share: function(e) {
    prompt('Copy this shareable link:', this.model.get('link'));
    e.preventDefault();
    return false;
  },
});

ph.api.views.CommentDetailDeleteView = ph.api.View.extend({
  template : wp.template('ph-detail-delete'),
  className: 'ph-tech-detail ph-delete-tech-detail',

  events: {
    'click'     : 'trash',
    'touchstart': 'trash',
  },

  trash: function() {
    if (parent.window.confirm(PH_Website_Settings.translations.are_you_sure)) {
      this.model.collection.remove(this.model).destroy();
    }
    return false;
  },
});

ph.api.views.CommentAdditionalInfo = ph.api.View.extend({
  template : wp.template('ph-detail-additional'),
  className: 'ph-tech-detail ph-detail-additional',

  events: {
    'click': 'modal',
  },

  modal: function() {
    ph.api.Event.trigger('tech', this.model);
  },
});
import '@website/views/comment/views.comment-dot';
import '@website/views/comment/views.comment-bubble-iframe';

ph.api.views.Comment = ph.api.View.extend({
  template : wp.template('website-comment'),
  className: 'ph-comment',

  events: {
    'click .ph-annotation-dot'     : 'toggleShow',
    'mouseenter'                   : 'hoverDot',
    'mouseleave'                   : 'unHoverDot',
    'touchstart .ph-annotation-dot': 'toggleShow',
    'start'                        : 'start',
    'stop'                         : 'stop',
  },

  triggers: {
    'change:show'  : 'showHide', //['showHide', 'maybeRemove'],
    'change:scroll': ['scroll', 'checkEdges'],
    'change:height': ['frameHeight', 'checkEdges'],
    'checkScroll'  : 'checkScroll',
    'remove'       : 'removeThread',
    'change:hover' : ['toggleHover', 'checkEdges'],
    // 'remove'       : 'remove',
    'change:x'     : ['setCoords', 'checkEdges'],
    'change:y'     : ['setCoords', 'checkEdges'],
  },

  ui: {
    top : 0,
    left: 0,
  },

  place: false,

  initialize: function() {

    this.listenTo(this, 'stop', this.stop);
    this.listenTo(this.model.get('comments'), 'remove', this.checkEmpty);

    // hook into heartbeat to update coords
    this.listenTo(ph.api.Event, 'heartbeat', this.updateCoords);

    this.views.add('.ph-comment-thread', new ph.api.views.CommentDot({
      model: this.model,
    }));

    var iframe = new ph.api.views.CommentBubbleIframe({
      model: this.model,
    });
    this.views.add('.ph-comment-thread', iframe);

    jQuery(window.parent).on('click', _.bind(function() {
      this.model.set('show', false);
    }, this));

    ph.api.parent.window.on('resize scroll', _.bind(this.checkEdges, this));
    ph.api.parent.window.on('load', _.bind(this.findElement, this));

    _.bindAll(this, 'checkEdges', 'checkScroll', 'findElement');
  },

  ready: function() {
    this.findElement();

    this.frame = this.$('.project-huddle-comment-bubble');
    this.inner = this.$('.ph-comment-thread');

    this.draggable();
    this.showHide();
  },

  findElement: function() {
    // get element match async
    _.defer(_.bind(function() {
      this.place = ph.api.utils.matchElement(this.model.get('path'),
          this.model.get('html'));
    }, this));
  },

  frameHeight: function() {
    this.frame.css({
      'height': (this.model.get('height') + 5) + 'px',
    });
  },

  setCoords: function() {
    this.inner && this.inner.css({
      left: this.model.get('x'),
      top : this.model.get('y'),
    });
  },

  /**
   * Checks edges of window
   */
  checkEdges: function() {
    this.fixOverflow();
  },

  /**
   * Checks scroll cookie on load
   */
  checkScroll: function() {
    this.stopListening(this.model, 'checkScroll');
    if (!ph.api.comment_scroll) {
      return;
    }
    if (parseInt(ph.api.comment_scroll) === this.model.get('id')) {
      this.model.set({
        'show'  : true,
        'scroll': true,
      });
      ph.api.comment_scroll = false;
    }
  },

  fixOverflow: function() {
    if (!this.frame) {
      return;
    }

    var windowOffsetY = (this.model.get('y') -
        ph.api.parent.window.scrollTop() - 48);

    this.frame.css({
      'width': ph.api.parent.window.width(),
    });

    var diffX = Math.max(0, this.frame.outerWidth() + this.model.get('x') -
        ph.api.parent.window.width() + 28);
    var diffY = Math.max(0, this.frame.outerHeight() + parseInt(windowOffsetY) -
        ph.api.parent.window.outerHeight());

    // check if item is above top of window
    if (windowOffsetY < -8) {
      diffY = -(ph.api.parent.window.scrollTop() - this.model.get('y') + 42);
    }

    if (diffY >= this.frame.outerHeight()) {
      diffY = this.frame.outerHeight();
    }

    // fixed comments setting
    if (!PH_Website_Settings.options.global.fixedComments) {
      if (diffY < 0) {
        diffY = 0;
      }

      var difference = this.frame.outerHeight() - 100;
      if (diffY > difference) {
        diffY = difference;
      }
    }

    if (diffX) {
      // won't fit
      if (this.frame.outerWidth() > this.model.get('x')) {
        this.$el.addClass('ph-left-overflow');
      } else {
        this.$el.removeClass('ph-left-overflow');
      }
    } else {
      this.$el.removeClass('ph-left-overflow');
    }

    var xpos = 0;
    var ypos = -diffY;
    if (this.$el.hasClass('ph-left-overflow') &&
        this.$el.hasClass('ph-right-overflow')) {
      xpos = diffX < 56 ? -diffX : -(diffX - 56);
      ypos = 0;
    }

    this.frame.css({
      'transform': 'translate(' + xpos + 'px, ' + ypos + 'px )',
    });

    // toggle right overflow class
    this.$el.toggleClass('ph-right-overflow', diffX !== 0);
  },

  draggable: function() {
    var move = this.$('.ph-annotation-dot').on('mousedown', _.bind(function(e) {
      if (e.type === 'touch') {
        this.toggleShow(e);
        return false;
      }
      var startingTop  = e.clientY,
          startingLeft = e.clientX,
          drop         = false;

      move.on('mouseup', _.bind(function(e) {
        jQuery(parent.window).off('mousemove');
      }, this));

      // cancel if leaving window
      jQuery(window.parent.document).on('mouseleave', function() {
        jQuery(parent.window).off('mousemove');
      });

      // prevent text highlighting
      if (e.stopPropagation) e.stopPropagation();
      if (e.preventDefault) e.preventDefault();

      ph.api.parent.window.on('mousemove', _.bind(function(e) {
        var math     = Math.round(
            Math.sqrt(Math.pow(startingTop - e.clientY, 2) +
                Math.pow(startingLeft - e.clientX, 2))),
            movement = e;

        // need to drag at least 10px
        if (math <= 10) {
          return;
        }

        this.model.set({
          'show' : false,
          'hover': false,
        });

        if (drop === false) {
          // this.$el.trigger('start');
          move.on('mouseup', _.bind(function(e) {
            this.$el.trigger('stop', e, movement);
            jQuery(parent.window).off('mousemove');
            move.off('mouseup');
          }, this));
          drop = true;
        }

        this.ui.top  = e.pageY;
        this.ui.left = e.pageX;
        this.inner.css({
          top   : this.ui.top > 0 ? this.ui.top : 0,
          left  : this.ui.left > 0 ? this.ui.left : 0,
          bottom: 'auto',
          right : 'auto',
        });
      }, this));
    }, this));
  },

  start: function(e, ui) {
    this.inner.hide();
  },

  stop: function(e, move) {
    var xpos        = parseInt(move.pageX, 10),
        ypos        = parseInt(move.pageY, 10),
        container   = ph.api.parent.find('.ph-comment-container'),
        elementXpos = xpos - window.parent.pageXOffset,
        elementYpos = ypos - window.parent.pageYOffset,
        element;

    // need to hide before we us elementFromPoint
    container.hide();
    element = parent.document.elementFromPoint(elementXpos, elementYpos);
    container.show();

    // verify element
    if (!element) {
      return;
    }

    // get relative click position on element (where click occurred on element)
    elementXpos = xpos - jQuery(element).offset().left;
    elementYpos = ypos - jQuery(element).offset().top;

    // set or save
    var action = this.model.isNew() ? 'set' : 'save';
    this.model[action]({
      path     : ph.api.utils.getCSSParents(element).join(' > '),
      html     : element.outerHTML,
      x        : parseFloat(xpos),
      y        : parseFloat(ypos),
      relativeX: parseFloat(
          ph.api.utils.relativeX(elementXpos, jQuery(element))),
      relativeY: parseFloat(
          ph.api.utils.relativeY(elementYpos, jQuery(element))),
    }, {patch: true});

    // get element match
    this.place = ph.api.utils.matchElement(this.model.get('path'),
        this.model.get('html'));
  },

  // Update coordinates based on parent site's element position
  updateCoords: function() {
    if (typeof this.place !== 'object') {
      return false;
    }

    var offset = this.place && this.place.offset();

    if (!offset) {
      return false;
    }

    var elementTop  = offset.top,
        elementLeft = offset.left - ph.api.parent.scrollLeft(),
        yPos        = elementTop +
            (this.model.get('relativeY') * this.place.outerHeight()),
        xPos        = elementLeft +
            (this.model.get('relativeX') * this.place.outerWidth());

    this.model.set({
      y: yPos,
      x: xPos,
    });

    this.model.trigger('checkScroll');
  },

  toggleShow: function(e) {
    this.model.set('show', true);
    this.checkEdges();
    e.stopPropagation();
  },

  // remove if no comments and show == false
  maybeRemove: function() {
    if (!this.model.get('comments').length && !this.model.get('show')) {
      this.model.collection.remove(this.model);
    }
  },

  showHide: function() {
    this.$el.toggleClass('ph-active-dot', this.model.get('show'));
  },

  // Event handler when dot is hovered
  hoverDot: function() {
    clearTimeout(this.hoverTimer);
    this.model.collection.forEach(_.bind(function(model, index) {
      model.set('hover', false);
    }, this));
    this.model.set('hover', true);
  },

  // change hover class
  toggleHover: function() {
    this.$el.toggleClass('ph-hover-dot', this.model.get('hover'));
  },

  // unhover dot, small delay for ux
  unHoverDot: function() {
    this.hoverTimer = _.delay(_.bind(function() {
      this.model.set('hover', false);
    }, this), 750);
  },

  // scroll to comment
  scroll: function() {
    if (this.model.get('scroll') === true) {
      ph.api.parent.find('html,body').animate({
        scrollTop: this.model.get('y') - 75,
      }, 500);
      this.model.set('scroll', false);
    }
  },

  removeThread: function() {
    this.remove();
    this.unbind();
  },
});
import "@website/views/comment/views.minimal-comment-item";
import "@website/views/comment/views.comment-item";

ph.api.views.CommentsContainer = ph.api.View.extend({
  unwrap: true,

  className: 'ph-comment-text',

  triggers: {
    'change:show': 'scrollBottom', // when show/hide scroll to bottom
  },

  // element ui defaults
  savedScrollHeight  : 0,
  savedScrollPosition: 0,
  loading            : false,

  initialize: function() {
    // set iframe
    this.$iframe = ph.api.parent.find('#bubble-' + this.model.get('id'));
    this.iframe  = this.$iframe[0];

    // comment items
    this.setComments();

    // comments added, defer
    this.listenTo(this.model.get('comments'), 'update', this.setComments);

    // scroll to bottom on add update sync
    this.listenTo(this.model.get('comments'), 'add update sync',
        this.scrollBottom);

    // scroll to bottom on first hover
    this.listenToOnce(this.model, 'change:hover', this.scrollBottom);

    // bind this
    _.bindAll(this, 'pagination', 'scrollBottom', 'saveScrollPosition',
        'restoreScrollPosition');
  },

  ready: function() {
    // scroll pagination events
    this.$el.on('scroll', _.debounce(this.pagination, 350));
  },

  // set comment subviews
  setComments: function() {
    var views = [];
    this.model.get('comments').forEach(function(item) {
      if (item.get('type') && item.get('type') === 'ph_approval') {
        views.push(new ph.api.views.MinimalCommentItem({
          model : item,
          iframe: this.iframe,
        }));
      } else {
        views.push(new ph.api.views.CommentItem({
          model : item,
          iframe: this.iframe,
        }));
      }
    }, this);
    this.views.set(views);
  },

  // scroll to bottom of list
  scrollBottom: function(collection, response, options) {
    options || (options = {});
    options.scroll = _.isUndefined(options.scroll) ? true : options.scroll;
    if (options.scroll) {
      typeof this.$el !== 'undefined' &&
      this.$el.scrollTop(this.$el[0].scrollHeight);
      this.$el.focus();
    }
  },

  // do pagination
  pagination: function(e) {
    // must be showing to do pagination
    if (!this.model.get('show') && !this.model.get('hover')) {
      return;
    }

    if (!this.model.get('comments').hasMore()) {
      return;
    }

    // if we've reached the top and we're not loading
    if (this.$el.scrollTop() < 250 && !this.loading) {
      this.loading = true;

      // save and restore scroll position
      this.listenToOnce(this.model.get('comments'), 'add',
          this.saveScrollPosition);
      this.listenToOnce(this.model.get('comments'), 'update',
          this.restoreScrollPosition);

      this.model.get('comments').more({
        data   : {
          per_page: this.model.get('comments').length /
          this.model.get('comments').state.currentPage,
          post    : this.model.get('id'),
          page    : this.model.get('comments').hasMore() === null ?
              2 :
              undefined,
        },
        remove : false,
        scroll : false,
        loading: true,
        success: _.bind(function() {
          this.loading = false;
        }, this),
      });
    }
  },

  // save current scroll position
  saveScrollPosition: function(collection, response, options) {
    options || (options = {});
    options.scroll = _.isUndefined(options.scroll) ? true : options.scroll;

    if (!options.scroll) {
      this.savedScrollHeight   = this.$el.prop('scrollHeight');
      this.savedScrollPosition = this.$el.scrollTop();
    }
  },

  // restore saved scroll position
  restoreScrollPosition: function(collection, options) {
    options || (options = {});
    options.scroll = _.isUndefined(options.scroll) ? true : options.scroll;
    if (!options.scroll) {
      this.$el.scrollTop(this.$el.prop('scrollHeight') -
          this.savedScrollHeight + this.savedScrollPosition);
    }
  },
});
import "@website/views/comment/views.comment-item-text";

/**
 * View to show our individual comment item
 *
 * @since 1.0
 */
ph.api.views.MinimalCommentItem = ph.api.View.extend({
	template : wp.template('project-minimal-comment-item'),
	className: 'ph-comment-item minimal-comment',

	events: {
		'click .ph-remove': 'removeComment',
	},

	triggers: {
		'change:moderate': 'commentControls'
	},

	initialize: function () {
		// comment item text view
		this.views.set('.ph-comment-item-text', new ph.api.views.CommentItemText({
			model: this.model
		}));
	},

	/**
	 * Remove comment click handler - let the collection handle itself
	 */
	removeComment: function (e) {
		e.preventDefault();
		confirm(PH_Website_Settings.translations.are_you_sure) && this.destroyComment();
	},

	/**
	 * Animate removal
	 */
	destroyComment: function () {
		this.$el.slideToggle(250, _.bind(function () {
			this.remove();
			this.unbind();
			this.model.destroy();
		}, this));
	}
});
ph.api.views.CommentButton = ph.api.View.extend({
    template : wp.template('ph-comment-button'),
    className: 'ph-new-comment',

    events: {
        'click': 'clicked'
    },

    triggers: {
        'change:commentsEnabled': ['buttonClass', 'hideComments']
    },

    clicked: function (e) {
        this.model.set('commentsEnabled', !this.model.get('commentsEnabled'));
        e.stopPropagation();
        return false;
    },

    buttonClass: function () {
        this.$el.toggleClass('ph-cancel', this.model.get('commentsEnabled'));
    },

    hideComments: function () {
        this.model.get('threads').invoke('set', {'show': false}); // hide all comments
    },

    hideControls: function () {
        this.model.set('controls', '');
    }
});
import '@website/views/controls/views.toolbar';

/**
 * Website Commenting controls
 *
 * Subview of the website view that contains the toolbar controls
 *
 * @since 3.0.0
 */
ph.api.views.ControlsView = ph.api.View.extend({
  tagName: 'iframe',

  attributes: function() {
    return {
      'allowfullscreen': '',
      'class'          : 'project-huddle-toolbar ph-' +
      ph.api.WebsiteProject.get('toolbar_location'),
    };
  },

  triggers: {
    'change:height': 'frameHeight'
  },

  ui: {
    top      : 0,
    left     : 0,
    perm_top : 0,
    perm_left: 0,
  },

  initialize: function() {
    jQuery(window.parent).on('resize', _.bind(this.doOffset, this));
    this.$el.on('load', _.bind(this.subViews, this));
  },

  subViews: function() {
    this.$iframe = this.$el;
    this.iframe  = this.el;

    // replace el with inside
    this.el  = this.$el.contents().get(0);
    this.$el = this.$el.contents();

    this.views.set('head', new ph.api.views.ToolbarCSS({
      model: this.model,
    }));
    this.views.set('body', new ph.api.views.ToolbarView({
      model: this.model,
    }));

    this.draggable();
  },

  frameHeight: function () {
    this.$iframe.css({
      'height': this.model.get('height') + 'px'
    })
  },

  pagePos: function(e, pos) {
    if (typeof e.originalEvent.touches !== 'undefined') {
      return e.originalEvent.touches[0]['page' + pos];
    } else {
      return e['page' + pos];
    }
  },

  /**
   * Draggable iframe
   */
  draggable: function() {
    // Run it through the function to setup bubbling
    ph.api.utils.iframeMouseMove(this.iframe);
    var moveControl = this.$el.find('.ph-move-control');

    var move = moveControl.on('mousedown touchstart', _.bind(function(e) {
      var drg_h = this.$iframe.outerHeight(),
          drg_w = this.$iframe.outerWidth(),
          pos_y = drg_h - this.pagePos(e, 'Y'),
          pos_x = drg_w - this.pagePos(e, 'X');

      ph.api.parent.window.on('mousemove', _.bind(function(e) {
        this.ui.top       = e.pageY + pos_y - drg_h;
        this.ui.left      = e.pageX + pos_x - drg_w;
        this.ui.perm_top  = this.ui.top;
        this.ui.perm_left = this.ui.left;
        this.doOffset();
      }, this));

      jQuery(e.target).on('touchmove', _.bind(function(e) {
        e.preventDefault(); // prevent scroll
        this.ui.top       = e.originalEvent.touches[0].screenY - (drg_h / 2) +
            ph.api.parent.scrollTop();
        this.ui.left      = e.originalEvent.touches[0].screenX - (drg_w / 2) +
            ph.api.parent.scrollLeft();
        this.ui.perm_top  = this.ui.top;
        this.ui.perm_left = this.ui.left;
        this.doOffset();
      }, this));
    }, this));

    move.on('mouseup touchend', _.bind(function() {
      this.trigger('drop');
      ph.api.parent.window.off('mousemove');
      moveControl.off('touchmove');
    }, this));

    ph.api.parent.on('mouseup touchend', _.bind(function() {
      this.trigger('drop');
      ph.api.parent.window.off('mousemove touchmove');
    }, this));

    ph.api.parent.on('mouseleave', function() {
      ph.api.parent.window.off('mousemove touchmove');
    });
  },

  /**
   * Make sure toolbar doesn't exceed window
   */
  checkEdge: function() {
    var frameWidth   = this.$iframe.outerWidth(),
        windowWidth  = parent.window.innerWidth,
        frameHeight  = this.$iframe.outerHeight(),
        windowHeight = parent.window.innerHeight,
        windowScroll = ph.api.parent.window.scrollTop();

    // right edge
    if (this.ui.perm_left && this.ui.perm_left + frameWidth < windowWidth) {
      this.ui.left = this.ui.perm_left;
    } else {
      this.ui.left = windowWidth - frameWidth;
    }

    // top edge
    if (this.ui.top < windowScroll) {
      this.ui.top = windowScroll;
    }

    // bottom edge
    if (this.ui.perm_top && this.ui.perm_top - windowScroll + frameHeight <
        windowHeight) {
      this.ui.top = this.ui.perm_top;
    } else {
      this.ui.top = windowHeight + windowScroll - frameHeight;
    }
  },

  /**
   * Set offset
   */
  doOffset: function() {
    if (!this.ui.perm_top || !this.ui.perm_left) {
      return;
    }
    // this.checkEdge();
    this.$iframe.css({
      top   : this.ui.top > 0 ?
          this.ui.top - ph.api.parent.window.scrollTop() :
          0,
      left  : this.ui.left > 0 ?
          this.ui.left - ph.api.parent.window.scrollLeft() :
          0,
      bottom: 'auto',
      right : 'auto',
    });
  },
});
ph.api.views.IconButton = ph.api.View.extend({
    template: wp.template('ph-comment-icon'),
    className: 'ph-comment-icon ph-secondary-link',
    tagName: 'button',

    events: {
        'click': 'showPanel'
    },

    initialize: function() {
        this.listenTo(this.model, 'change', this.render);
    },

    showPanel: function() {
        this.model.set({
            'controls': this.model.get('controls') === 'panel' ? '' : 'panel'
        });
    }
});
import '@website/views/controls/views.icon-button';
import '@website/views/controls/views.comment-button';
var elementResizeDetectorMaker = require("element-resize-detector");

ph.api.views.ToolbarCSS = ph.api.View.extend({
  template: wp.template('ph-toolbar-css'),
  tagName : 'style',
});

ph.api.views.ToolbarView = ph.api.View.extend({
  template : wp.template('ph-toolbar'),
  className: 'project-huddle-toolbar',

  initialize: function() {
    // comments
    this.views.add('.ph-controls', new ph.api.views.IconButton({
      model: this.model,
    }));

    // new comment
    this.views.add('.ph-controls', new ph.api.views.CommentButton({
      model: this.model,
    }));

    _.bindAll(this, 'setDimensions');
  },

  // dom is ready
  ready: function() {
    // size the frame correctly
    this.sizeFrame();
  },

  sizeFrame: function() {
    // run always at first
    _.defer(_.bind(function() {
      this.model.set('height', this.el.offsetHeight);
      this.model.set('width', this.el.offsetWidth);
    }, this));

    if (!this.resizeDetector) {
      this.resizeDetector = elementResizeDetectorMaker();
      this.resizeDetector.listenTo(this.el, this.setDimensions);
    }
  },

  setDimensions: function(element) {
    this.model.set('height', element.offsetHeight);
    this.model.set('width', element.offsetWidth);
  },
});
/**
 * Comment Filter Dropdown
 *
 * @since 2.5.0
 */
ph.api.views.CommentFilterView = ph.api.View.extend({
    template : wp.template('ph-panel-comment-filter-item'),
    className: 'ph-filter-item',

    events: {
        'click': 'filter'
    },

    filter: function () {
        this.model.collection.invoke('set', {active: false});
        this.model.set('active', true);
    }
});
import '@website/views/filter/views.comment-filter';

/**
 * Comment Filter Dropdown
 *
 * @since 2.5.0
 */
ph.api.views.CommentFilters = ph.api.View.extend({
    template : wp.template('ph-panel-comment-filter'),
    className: 'ph-comments-filter-dropdown-wrap',

    initialize: function () {
        this.addFilters();

        this.listenTo(this.model, 'change:filter', this.render);
    },

    addFilters: function () {
        if (!this.model.filters) {
            return;
        }
        var views = [];
        this.model.filters.forEach(function (filter) {
            views.push(new ph.api.views.CommentFilterView({
                model: filter
            }));
        }, this);
        this.views.set('.ph-dropdown-inner', views);
    }
});
ph.api.views.Avatar = ph.api.View.extend({
	className: 'gravatar avatar',
	template : wp.template('avatar'),
	unwrap   : true,

	initialize: function () {

	}
});
ph.api.views.CommentTooltip = ph.api.View.extend({
    template : wp.template('ph-image-tip'),
    className: 'ph-image-tip',

    triggers: {
        'change:commentsEnabled': 'toggleTool'
    },

    initialize: function () {
        _.bindAll(this, 'show', 'hide', 'track');
    },

    ready: function(){
        this.$el.show();
    },

    // turn tool on/off
    toggleTool: function () {
        if (this.model.get('commentsEnabled')) {
            this.enable();
        } else {
            this.disable();
            this.reset();
        }
    },

    // Make tooltip track mouse pointer
    track: function (e) {
		this.$el && this.$el.css({
            left: e.pageX - window.parent.pageXOffset + 'px',
            top : e.pageY - window.parent.pageYOffset + 'px'
        });
    },

    // Show tooltip
    show: function () {
        this.$el && this.$el.stop().fadeIn(100);
    },

    // Hide tooltip
    hide: function () {
        this.$el && this.$el.stop().fadeOut(100);
    },

    // Reset position
    reset: function () {
        this.$el.css({
            'top' : '-99999px',
            'left': '-99999px'
        });
    },

    // enable tootip events
    enable: function () {
        ph.api.parent.body.on('mousemove', this.track);
        ph.api.parent.body.on('mouseenter', this.show);
        ph.api.parent.body.on('mouseleave', this.hide);
    },

    // disable tooltip events
    disable: function () {
        ph.api.parent.body.off('mousemove mouseenter mouseleave');
    }
});
ph.api.views.LoginButton = ph.api.View.extend({
	template : wp.template('ph-login-button'),
	className: 'ph-login-button',

	events: {
		'click': 'login'
	},

	login: function(e) {
		e.preventDefault();
		ph.api.Event.trigger('login', this.model);
	}
});
ph.api.views.LogoutButton = ph.api.View.extend({
	template : wp.template('ph-logout-button'),
	className: 'ph-logout-button',
});
ph.api.views.ManageButton = ph.api.View.extend({
	template : wp.template('ph-manage-button'),
	className: 'ph-manage-button',
});
ph.api.views.PanelComment = ph.api.View.extend({
    template : wp.template('ph-panel-item'),
    className: 'ph-list-item',

    events: {
        'click .ph-navigate': 'navigateItem'
    },

    triggers: {
        'change': 'render',
        'remove': 'remove',
        'change:resolved': 'setClass'
    },

    initialize: function () {
		// avatar if set
		if (this.model.get('author_avatar_urls')) {
			this.views.add('.avatar', new ph.api.views.Avatar({
				model: this.model
			}));
		}

        // assigned
        this.views.add('.ph-comment-header-right', new ph.api.views.Assign({
            model: this.model
        }));

        this.setClass();
    },

    setClass: function() {
        this.$el.toggleClass('ph-resolved', this.model.get('resolved'));
    },

    navigateItem: function (e) {
        this.model.set({
            'show': true,
            'scroll': true,
            'focus': !!e.currentTarget.dataset.focus
        });
    }
});
/**
 * Comment List Item
 *
 * @since 1.2.0
 */
ph.api.views.PanelEmptyComments = ph.api.View.extend({
    className: 'ph-empty-panel-notice',
    template: wp.template('ph-panel-empty-comments')
});
ph.api.views.PanelEmptyPages = ph.api.View.extend({
    className: 'ph-empty-panel-notice',
    template: wp.template('ph-panel-empty-pages')
});
import '@website/views/panel/views.panel';

ph.api.views.PanelCSS = ph.api.View.extend({
    template: wp.template('ph-panel-css'),
    tagName : 'style'
});

ph.api.views.PanelIframe = ph.api.View.extend({
    className : "project-huddle-panel",
    tagName   : 'iframe',
    attributes: {
        "allowfullscreen": "",
        "style": "transform: translateX(100px); opacity: 0; visibility:hidden"
    },

    initialize: function() {
        this.$el.on('load', _.bind(this.subViews, this));
    },

    subViews: function() {
        this.el = this.$el.contents().get(0);
        this.$el = this.$el.contents();

        this.views.set('head', new ph.api.views.PanelCSS({
            model: this.model
        }));
        this.views.set('body', new ph.api.views.Panel({
            model: this.model
        }));

        // link target
        this.$el.find('head').prepend('<base target="_parent">');

        // force ready
        this.views.ready();
    }
});
ph.api.views.PanelPage = ph.api.View.extend({
    template : wp.template('ph-panel-page-item'),
    className: 'ph-list-item',

    events: {
        'click a': 'navigateItem'
    },

    initialize: function () {
        this.listenTo(this.model.get('threads'), 'change:approval', this.render);
    },

    /**
     * Navigate parent
     * @param e jQuery normalized event
     */
    navigateItem: function (e) {
        window.parent.location = e.currentTarget.href;
        this.$el.trigger('mouseout');
        e.preventDefault();
    }
});
ph.api.views.PanelResolvedToggle = ph.api.View.extend({
    template: wp.template('ph-panel-resolved-toggle'),
    className: 'ph-panel-toggle-resolve',

    events: {
        'click': 'toggle'
    },

    triggers : {
        'change:show_resolved': 'render'
    },

    toggle: function() {
        this.model.set('show_resolved', ! this.model.get('show_resolved'));
        return false;
    }
});
import '@website/views/filter/views.comment-filters';
import '@website/views/panel/views.panel-resolved-toggle';
import '@website/views/panel/views.panel-comment';
import '@website/views/panel/views.panel-page';
import '@website/views/panel/views.panel-empty';
import '@website/views/global/views.manage-button';
import '@website/views/global/views.logout-button';
import '@website/views/global/views.login-button';

ph.api.views.Panel = ph.api.View.extend({
    template : wp.template('ph-panel'),
    className: "ph-panel",

    events: {
        'click .ph-close': 'hide',
        'click .ph-tab'  : 'showTab'
    },

    triggers:  {
        'change:show_resolved': 'resolvedClass'
    },

    initialize: function () {
        this.views.add('.ph-panel-subheading', new ph.api.views.CommentFilters({
            model: this.model
        }));

        this.views.add('.ph-panel-subheading', new ph.api.views.PanelResolvedToggle({
            model: this.model
        }));

        this.setButtons();

        this.listenTo(this.model.filters, 'change', this.filter);
        this.listenTo(this.model.get('threads'), 'add remove', this.addModelComments);

        this.listenTo(ph.api.me, 'change:id', this.setButtons);

        this.addModelComments();
        this.setPages(ph.api.WebsiteProject.pages);

        this.resolvedClass();
    },

    ready: function () {
        this.logo = this.$('.ph-panel-logo-wrap');
        this.body = this.$('.ph-panel-body');
        this.body.on('scroll', _.bind(this.adjustMargin, this));
    },

	setButtons: function () {
		if (ph.api.me.can('edit_ph-website')) {
			this.views.set('.ph-panel-footer .left-col', new ph.api.views.ManageButton({
				model: ph.api.WebsiteProject
			}));
		}

		if ( ph.api.me.get('id') ) {
			this.views.set('.ph-panel-footer .right-col', new ph.api.views.LogoutButton({
				model: ph.api.WebsiteProject
			}));
		} else {
			this.views.set('.ph-panel-footer .right-col', new ph.api.views.LoginButton({
				model: ph.api.WebsiteProject
			}));
        }
	},

    resolvedClass: function() {
        this.$el.toggleClass('_ph-hide-resolved', !this.model.get('show_resolved'));
    },

    reachedBottom: function () {
        return this.body[0].scrollHeight - this.body.scrollTop() === this.body.outerHeight();
    },

    adjustMargin: function () {
        if (!this.reachedBottom()) {
            this.logo.css({
                'margin-top': -this.body.scrollTop() + 'px'
            });
        }
    },

    addModelComments: function() {
        this.setComments(this.model.get('threads'));
    },

    // set comment views in body
    setComments: function (threads) {
        var views = [];
        threads.forEach(function (comment) {
            views.push(new ph.api.views.PanelComment({
                model: comment
            }));
        }, this);

        if (!views.length) {
            views.push(new ph.api.views.PanelEmptyComments({
                model: this.model
            }));
        }

        this.views.set('.ph-panel-comments-list', views);
    },

    // set page views in body
    setPages: function (pages) {
        var views = [];
        pages.forEach(function (page) {
            page.get('comment_count') && views.push(new ph.api.views.PanelPage({
                model: page
            }));
        }, this);

        if (!views.length) {
            views.push(new ph.api.views.PanelEmptyPages({
                model: this.model
            }));
        }

        this.views.set('.ph-panel-pages-list', views);
    },

    /**
     * Show content when tab is clicked
     * @param e
     */
    showTab: function (e) {
        // hide all
        this.$('.ph-active').removeClass('ph-active');

        // add class to target
        var $target = jQuery(e.target).addClass('ph-active');

        // change content class
        if ($target.hasClass('ph-pages-tab')) {
            this.$('.ph-panel-pages-list, .ph-show-pages').addClass('ph-active');
        } else {
            this.$('.ph-panel-comments-list, .ph-show-comments').addClass('ph-active');
        }

        this.$('.ph-panel-body').animate({scrollTop: "0"}, 100);
    },

    // hide panel
    hide: function () {
        this.model.set('controls', '');
    },

    // filter items
    filter: function (model) {
        if (model.get('active') && model.get('function')) {
            this.setComments(this.model.get('threads')[model.get('function')]());
        }
    }
});
import '@website/views/popup/views.popup-iframe';
import '@website/views/popup/views.popup-login';
import '@website/views/popup/views.popup-register';
import '@website/views/popup/views.popup-reset';
import '@website/views/popup/views.popup-tech';

ph.api.views.Modal = ph.api.View.extend({
	className: 'ph-modal-wrapper',

	initialize: function () {
		// listen for events
		this.listenTo(ph.api.Event, 'register', this.registerModal);
		this.listenTo(ph.api.Event, 'login', this.loginModal);
		this.listenTo(ph.api.Event, 'reset', this.resetModal);
		this.listenTo(ph.api.Event, 'tech', this.techModal);
	},

	// register modal popup
	registerModal: function (model, changed) {
		this.views.set(new ph.api.views.PopupIframe({
			model: model,
			body : new ph.api.views.PopupRegister({
				model: model,
				changed: changed
			})
		}));
	},

	loginModal: function ( model, changed ) {
		this.views.set(new ph.api.views.PopupIframe({
			model: model,
			body : new ph.api.views.PopupLogin({
				model: model,
				changed: changed
			})
		}));
	},

	resetModal: function ( model, changed ) {
		this.views.set(new ph.api.views.PopupIframe({
			model: model,
			body : new ph.api.views.PopupReset({
				model: model,
				changed: changed
			})
		}));
	},

	techModal: function( model ) {
		this.views.set(new ph.api.views.PopupIframe({
			model: model,
			body : new ph.api.views.PopupTech({
				model: model,
			})
		}));
	}
});
ph.api.views.PopupCSS = ph.api.View.extend({
    template: wp.template('ph-popup-css'),
    tagName : 'style'
});

ph.api.views.PopupIframe = ph.api.View.extend({
    className : "ph-popup-frame",
    tagName   : 'iframe',
    attributes: {
        "allowfullscreen": ""
    },

    triggers: {
        'toggle:register': 'toggle'
    },

    initialize: function () {
        this.$el.on('load', _.bind(this.subViews, this));
    },

    subViews: function () {
        this.el  = this.$el.contents().get(0);
        this.$el = this.$el.contents();

        // add popup css
        this.views.set('head', new ph.api.views.PopupCSS({
            model: this.model
        }));

        if ( this.options.body ) {
            // use registration body
            this.views.set('body', this.options.body);
        } else {
            // use registration body
            this.views.set('body', new ph.api.views.PopupRegister({
                model: this.model
            }));
        }

        // link target
        this.$el.find('head').prepend('<base target="_parent">');

        // force ready
        this.views.ready();

        // focus window
		this.$el.focus();
    },

    toggle: function () {
        ph.api.parent.find('.' + this.className).fadeToggle(350);
    }
});
ph.api.views.PopupLogin = ph.api.View.extend({
	template : wp.template('ph-popup-login'),
	className: "ph-popup ph-popup-login",

	events: {
		'click .ph-close'          : 'toggle',
		'click .ph-dialog-reset'   : 'toggleReset',
		'click .ph-dialog-register': 'triggerRegister',
		'submit form'              : 'submitForm'
	},

	initialize: function () {
		_.bindAll(this, 'success', 'error', 'toggle');
	},

	ready: function () {
		this.$el.css('opacity', 0).stop().animate({'opacity': 1}, 250);

    this.setPlaceholders();
	},

	toggle: function () {
		this.model.trigger('toggle:register');
	},

  // set labels as placeholders
  setPlaceholders: function() {
    var placeholder_login    = this.$('#loginform label[for="user_login"]');
    var placeholder_password = this.$('#loginform label[for="user_pass"]');

    this.$('#loginform input[type="text"]').
        attr('placeholder', placeholder_login.html());
    this.$('#loginform input[type="password"]').
        attr('placeholder', placeholder_password.html());

    placeholder_login.contents().filter(function() {
      return this.nodeType === 3;
    }).remove();

    placeholder_password.contents().filter(function() {
      return this.nodeType === 3;
    }).remove();
  },

	toggleReset: function () {
		ph.api.Event.trigger('reset', this.model, this.options.changed);
	},

	triggerRegister: function () {
		ph.api.Event.trigger('register', this.model, this.options.changed);
	},

	submitForm: function (e) {
		// add loading class
		this.$el.addClass('ph-loading');

    // get values
    var values = this.$('#loginform').serializeArray();
    var data   = {};

    // prepare data
    values.forEach(function(element, index, array) {
      if (element.name === 'log') {
        element.name = 'username';
      }
      if (element.name === 'pwd') {
        element.name = 'password';
      }
      data[element.name] = element.value;
    });

    ph.api.me.save(data, {
          wait   : true,
          url    : wpApiSettings.root + wpApiSettings.versionString + 'users/login',
          success: this.success,
          error  : this.error,
        },
    );

    e.preventDefault();
	},

	/**
	 * Store in session storage after user self-registers
	 *
	 * @param model
	 * @param response
	 */
	success: function (model, response) {
		this.$el.addClass('ph-success');

		_.delay(_.bind(function(){
			this.toggle();
		}, this), 1000);
	},

	// show loading class on error
	error: function () {
		this.$el.removeClass('ph-loading');
	}
});
ph.api.views.PopupRegister = ph.api.View.extend({
	template : wp.template('ph-popup-register'),
	className: "ph-popup ph-popup-register",

	events: {
		'click .ph-close'       : 'toggle',
		'click .ph-dialog-login': 'triggerLogin',
		'submit form'           : 'submitForm'
	},

	initialize: function () {
		_.bindAll(this, 'success', 'error', 'toggle');
	},

	ready: function() {
		this.$el.css('opacity', 0).stop().animate({'opacity': 1}, 250);
	},

	toggle: function () {
		this.model.trigger('toggle:register');
	},

	triggerLogin: function () {
		ph.api.Event.trigger('login', this.model, this.options.changed);
	},

	submitForm: function (e) {
		// add loading class
		this.$el.addClass('ph-loading');

		// create user
		ph.api.WebsiteProject.users.create({
			'email'       : this.$("#ph-register-email").val(),
			'username'    : this.$('#ph-register-username').val(),
			'project_id'  : ph.api.project_id,
		}, {
			wait   : true,
			success: this.success,
			error  : this.error
		});

		e.preventDefault();
	},

	/**
	 * Store in session storage after user self-registers
	 *
	 * @param model
	 * @param response
	 */
	success: function (model, response) {
		this.$el.addClass('ph-success');

		// set model
		ph.api.me.set(model.toJSON());

		_.delay(_.bind(function(){
			this.toggle();
		}, this), 1500);
	},

	// remove loading class on error
	error: function (model, response) {
		if ( response.responseJSON && response.responseJSON.code === 'existing_user_email' ) {
			var login = confirm("That email already exists! Do you want to login?");

			if (  login ) {
				this.triggerLogin();
				return false;
			}
		}

		this.$el.removeClass('ph-loading');
		return false;
	}
});
ph.api.views.PopupReset = ph.api.View.extend({
	template : wp.template('ph-popup-reset'),
	className: "ph-popup ph-popup-reset",

	events: {
		'click .ph-close'          : 'toggle',
		'click .ph-dialog-register': 'triggerRegister',
		'submit form'              : 'submitForm'
	},

	initialize: function () {
		_.bindAll(this, 'success', 'error', 'toggle');
	},

	ready: function () {
		this.$el.css('opacity', 0).stop().animate({'opacity': 1}, 250);
	},

	toggle: function () {
		this.model.trigger('toggle:register');
	},

	triggerRegister: function () {
		ph.api.Event.trigger('register', this.model, this.options.changed);
	},

	submitForm: function (e) {
		// add loading class
		this.$el.addClass('ph-loading');

		jQuery.ajax({
			method    : 'POST',
			beforeSend: function (xhr) {
				xhr.setRequestHeader('X-WP-Nonce', wpApiSettings.nonce);
			},
			url       : wpApiSettings.root + wpApiSettings.versionString + "users/reset",
			data      : {
				'username': this.$('#ph-register-username-email').val(),
			},
			success   : this.success,
			error     : this.error
		});

		e.preventDefault();
	},

	/**
	 * Store in session storage after user self-registers
	 *
	 * @param model
	 * @param response
	 */
	success: function (model, response) {
		this.$el.addClass('ph-success');

		_.delay(_.bind(function(){
			this.toggle();
		}, this), 5000);
	},

	// remove loading class on error
	error: function (model, response) {
		if (response.responseJSON && response.responseJSON.code === 'existing_user_email') {
			var login = confirm("That email already exists! Do you want to login?");

			if (login) {
				this.triggerLogin();
				return false;
			}
		}

		this.$el.removeClass('ph-loading');
		return false;
	}
});
ph.api.views.PopupTech = ph.api.View.extend({
	template : wp.template('ph-popup-tech'),
	className: "ph-popup ph-popup-tech",

	events: {
		'click .ph-close': 'toggle',
	},

	initialize: function () {
		_.bindAll(this, 'toggle');
	},

	ready: function() {
		this.$el.css('opacity', 0).stop().animate({'opacity': 1}, 250);
	},

	toggle: function () {
		this.model.trigger('toggle:register');
	}
});
}); // end promise
/**
 * Get Porthole
 */
window.onpageshow = function(event) {
    if (event.persisted) {
        window.location.reload()
    }
};

/*! jquery-iframe-auto-height - v2.0.0
 *  Release on: 2015-06-28
 *  Copyright (c) 2015 Jesse House
 *  Licensed The Unlicense */
!function(a,b){"function"==typeof define&&define.amd?define([],function(){return b()}):"object"==typeof exports?module.exports=b():b()}(this,function(){!function(a){a.fn.iframeAutoHeight=function(b){function c(a){g.debug&&g.debug===!0&&window.console&&console.log(a)}function d(b,d){c("Diagnostics from '"+d+"'");try{c("  "+a(b,window.parent).contents().find("body")[0].scrollHeight+" for ...find('body')[0].scrollHeight"),c("  "+a(b.contentWindow.document).height()+" for ...contentWindow.document).height()"),c("  "+a(b.contentWindow.document.body).height()+" for ...contentWindow.document.body).height()")}catch(e){c("  unable to check in this state")}c("End diagnostics -> results vary by browser and when diagnostics are requested")}var e;if(a.browser===e){var f=[];return f.push("WARNING: you appear to be using a newer version of jquery which does not support the $.browser variable."),f.push("The jQuery iframe auto height plugin relies heavly on the $.browser features."),f.push("Install jquery-browser: https://raw.github.com/house9/jquery-iframe-auto-height/master/release/jquery.browser.js"),alert(f.join("\n")),a}var g=a.extend({heightOffset:0,minHeight:0,maxHeight:0,callback:function(){},animate:!1,debug:!1,diagnostics:!1,resetToMinHeight:!1,triggerFunctions:[],heightCalculationOverrides:[]},b);return c(g),this.each(function(){function b(a){var b=null;return jQuery.each(f,function(c,d){return a[d]?(b=h[d],!1):void 0}),null===b&&(b=h["default"]),b}function e(e){g.diagnostics&&d(e,"resizeHeight"),g.resetToMinHeight&&g.resetToMinHeight===!0&&(e.style.height=g.minHeight+"px");var f=a(e,window.parent).contents().find("body"),h=b(a.browser),i=h(e,f,g,a.browser);c(i),i<g.minHeight&&(c("new height is less than minHeight"),i=g.minHeight),g.maxHeight>0&&i>g.maxHeight&&(c("new height is greater than maxHeight"),i=g.maxHeight),i+=g.heightOffset,c("New Height: "+i),g.animate?a(e).animate({height:i+"px"},{duration:500}):e.style.height=i+"px",g.callback.apply(a(e),[{newFrameHeight:i}])}var f=["webkit","mozilla","msie","opera","chrome"],h={};h["default"]=function(a,b,c){return b[0].scrollHeight+c.heightOffset},jQuery.each(f,function(a,b){h[b]=h["default"]}),jQuery.each(g.heightCalculationOverrides,function(a,b){h[b.browser]=b.calculation});var i=0,j=this.contentDocument||this.contentWindow.document;if(c(this),g.diagnostics&&d(this,"each iframe"),g.triggerFunctions.length>0){c(g.triggerFunctions.length+" trigger Functions");for(var k=0;k<g.triggerFunctions.length;k++)g.triggerFunctions[k](e,this)}if(a.browser.webkit||a.browser.opera||a.browser.chrome){c("browser is webkit (Safari/Chrome) or opera"),a(this).load(function(){var a=0,b=this,d=function(){e(b)};0===i?a=500:b.style.height=g.minHeight+"px",c("load delay: "+a),setTimeout(d,a),i++});var l=a(this).attr("src");a(this).attr("src",""),a(this).attr("src",l)}else"complete"===j.readyState?e(this):a(this).load(function(){e(this)})})}}(jQuery)});

// ie polyfill for custom javascript event
(function () {
	if ( typeof window.CustomEvent === "function" ) return false; //If not IE

	function CustomEvent ( event, params ) {
		params = params || { bubbles: false, cancelable: false, detail: undefined };
		var evt = document.createEvent( 'CustomEvent' );
		evt.initCustomEvent( event, params.bubbles, params.cancelable, params.detail );
		return evt;
	}

	CustomEvent.prototype = window.Event.prototype;

	window.CustomEvent = CustomEvent;
})();

var bubbleIframeMouseMove = function( iframe ){
    iframe.contentWindow.addEventListener('mousemove', function( event ) {
        var boundingClientRect = iframe.getBoundingClientRect();

        var evt = new CustomEvent( 'mousemove', {bubbles: true, cancelable: false})
        evt.clientX = event.clientX + boundingClientRect.left;
        evt.clientY = event.clientY + boundingClientRect.top;

        iframe.dispatchEvent( evt );
    });
};

(function($) {

    // draggable
    $.fn.drags = function(opt) {
        opt = $.extend({handle: "", cursor: "move"}, opt);

        if(opt.handle === "") {
            var $el = this;
        } else {
            var $el = this.find(opt.handle);
        }

        return $el.css('cursor', opt.cursor).on("mousedown touchstart", function(e) {
            if(opt.handle === "") {
                var $drag = $(this).addClass('draggable');
            } else {
                var $drag = $(this).addClass('active-handle').parent().addClass('draggable');
            }
            var z_idx = $drag.css('z-index'),
                drg_h = $drag.outerHeight(),
                drg_w = $drag.outerWidth(),
                pos_y = $drag.offset().top + drg_h - e.pageY,
                pos_x = $drag.offset().left + drg_w - e.pageX;

            $drag.css('z-index', 1000).parents().on("mousemove touchmove", function(e) {
                $('.draggable').offset({
                    top:e.pageY + pos_y - drg_h,
                    left:e.pageX + pos_x - drg_w
                }).on("mouseup", function() {
                    $(this).removeClass('draggable').css('z-index', z_idx);
                });
            });
            e.preventDefault(); // disable selection
        }).on("mouseup touchend", function() {
            if(opt.handle === "") {
                $(this).removeClass('draggable');
            } else {
                $(this).removeClass('active-handle').parent().removeClass('draggable');
            }
        });
    };
})(jQuery);

// from http://www.backalleycoder.com/2013/03/18/cross-browser-event-based-element-resize-detection/
(function(){
    var attachEvent = document.attachEvent;
    var isIE = navigator.userAgent.match(/Trident/);
    var requestFrame = (function(){
        var raf = window.requestAnimationFrame || window.mozRequestAnimationFrame || window.webkitRequestAnimationFrame ||
            function(fn){ return window.setTimeout(fn, 20); };
        return function(fn){ return raf(fn); };
    })();

    var cancelFrame = (function(){
        var cancel = window.cancelAnimationFrame || window.mozCancelAnimationFrame || window.webkitCancelAnimationFrame ||
            window.clearTimeout;
        return function(id){ return cancel(id); };
    })();

    function resizeListener(e){
        var win = e.target || e.srcElement;
        if (win.__resizeRAF__) cancelFrame(win.__resizeRAF__);
        win.__resizeRAF__ = requestFrame(function(){
            var trigger = win.__resizeTrigger__;
            if ( trigger ) {
                trigger.__resizeListeners__.forEach(function (fn) {
                    fn.call(trigger, e);
                });
            }
        });
    }

    function objectLoad(e){
        this.contentDocument.defaultView.__resizeTrigger__ = this.__resizeElement__;
        this.contentDocument.defaultView.addEventListener('resize', resizeListener);

        // trigger resize on load
        var event = document.createEvent('HTMLEvents');
        event.initEvent('resize', true, false);
        this.contentDocument.defaultView.dispatchEvent(event);
    }

    window.addResizeListener = function(element, fn){
        if (!element.__resizeListeners__) {
            element.__resizeListeners__ = [];
            if (attachEvent) {
                element.__resizeTrigger__ = element;
                element.attachEvent('onresize', resizeListener);
                element.attachEvent('onload', resizeListener);
            }
            else {
                if (jQuery(element).css('position') == 'static') jQuery(element).css('position', 'relative');
                var obj = element.__resizeTrigger__ = document.createElement('object');
                obj.setAttribute('style', 'display: block; position: absolute; top: 0; left: 0; height: 100%; width: 100%; overflow: hidden; pointer-events: none; z-index: -1;');
                obj.__resizeElement__ = element;
                obj.onload = objectLoad;
                obj.type = 'text/html';
                if (isIE) element.appendChild(obj);
                obj.data = 'about:blank';
                if (!isIE) element.appendChild(obj);
            }
        }
        element.__resizeListeners__.push(fn);
    };

    window.removeResizeListener = function(element, fn){
        element.__resizeListeners__.splice(element.__resizeListeners__.indexOf(fn), 1);
        if (!element.__resizeListeners__.length) {
            if (attachEvent) element.detachEvent('onresize', resizeListener);
            else {
                element.__resizeTrigger__.contentDocument.defaultView.removeEventListener('resize', resizeListener);
                element.__resizeTrigger__ = !element.removeChild(element.__resizeTrigger__);
            }
        }
    }
})();